(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   6818640,     121134]
NotebookOptionsPosition[   6799824,     120591]
NotebookOutlinePosition[   6800293,     120610]
CellTagsIndexPosition[   6800250,     120607]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Definitions", "Chapter",
 CellChangeTimes->{{3.661864018657823*^9, 3.661864020033535*^9}}],

Cell["\<\
Here are a number of definitions which help to calculate and more importantly \
visualize things neccesary in the research. Some functions are supportive, \
others generate figures and plots.\
\>", "Text",
 CellChangeTimes->{{3.662995572820295*^9, 3.662995616068881*^9}, {
  3.6629957033626337`*^9, 3.662995747957158*^9}}],

Cell[CellGroupData[{

Cell["Requirements", "Subsubsection",
 CellChangeTimes->{{3.661864009137839*^9, 3.6618640109613953`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`NDSolveUtilities`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Needs", "[", "\"\<DifferentialEquations`InterpolatingFunctionAnatomy`\>\"",
    "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", 
    RowBox[{"ShowGroupOpener", "\[Rule]", "True"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$PlotTheme", "=", "\"\<Default\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"$FrontEndSession", ",", 
    RowBox[{"\"\<ExportTypesetOptions\>\"", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<PageWidth\>\"", "\[Rule]", "500"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"$FrontEndSession", ",", 
    RowBox[{"AutoStyleOptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<HighlightFormattingErrors\>\"", "\[Rule]", "False"}], 
      "}"}]}]}], "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.66186597332102*^9, 3.6618659755282693`*^9}, {
   3.661929647286083*^9, 3.661929656109311*^9}, {3.6619297559668016`*^9, 
   3.66192975658824*^9}, {3.662739148259458*^9, 3.662739152251397*^9}, {
   3.662878342160122*^9, 3.662878345088052*^9}, 3.6629644309152737`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Constants", "Subsubsection",
 CellChangeTimes->{{3.661864013657734*^9, 3.6618640148095446`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g", "=", "9.81"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"l", "=", "60"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uMax", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P", "=", 
   RowBox[{"2", "\[Pi]", 
    SqrtBox[
     FractionBox["l", "g"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figureExport", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<..\>\"", ",", 
      "\"\<Report\>\"", ",", "\"\<figures\>\""}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"animationExport", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<..\>\"", ",", 
      "\"\<Presentation\>\"", ",", "\"\<animations\>\""}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.662017157970728*^9, 3.6620171599011054`*^9}, {
  3.6625503109568563`*^9, 3.662550321508321*^9}, {3.6625503764522514`*^9, 
  3.662550396244278*^9}, {3.6628726257004614`*^9, 3.6628726274447002`*^9}, {
  3.662873386482314*^9, 3.6628733891551995`*^9}, {3.6628742725602584`*^9, 
  3.6628742768803186`*^9}}]
}, Closed]],

Cell[TextData[StyleBox["Functions", "Subsection"]], "Subsubsection",
 CellChangeTimes->{{3.661864033081517*^9, 3.6618640357536297`*^9}}],

Cell[CellGroupData[{

Cell["Ellipse", "Subsubsection",
 CellChangeTimes->{{3.6629107948487573`*^9, 3.6629107955522556`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"withinEllipse", "[", 
    RowBox[{"p1_", ",", "c_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"First", "@", "p1"}], "-", 
        RowBox[{"First", "@", "c"}]}], ")"}], "2"], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Last", "@", "p1"}], "-", 
         RowBox[{"Last", "@", "c"}]}], ")"}], "2"], 
      RowBox[{"g", "/", 
       RowBox[{"(", 
        RowBox[{"m", " ", "l"}], ")"}]}]]}], "<", 
    SuperscriptBox["r", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"withinEllipse", "::", "usage"}], "=", 
    "\"\<Calculates whether the point \!\(\*SubscriptBox[\(p\), \(1\)]\) is \
strictly inside the ellipse centered at \!\(\*Cell[\"c\"]\) with radius \
\!\(\*Cell[\"r\"]\)\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"above\[CapitalGamma]", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"x", "\[GreaterEqual]", "0"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"y", ">", "0"}], "||", 
      RowBox[{"withinEllipse", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"Floor", "[", 
               FractionBox["x", 
                RowBox[{"2", "/", "g"}]], "]"}]}], "+", "1"}], ")"}], 
           FractionBox["1", "g"]}], ",", "0"}], "}"}], ",", 
        FractionBox["1", "g"]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"!", 
      RowBox[{"above\[CapitalGamma]", "[", 
       RowBox[{
        RowBox[{"-", "x"}], ",", 
        RowBox[{"-", "y"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"above\[CapitalGamma]", "::", "usage"}], "=", 
    "\"\<Calculates whether the point (x,y) is above the separation line \
\[CapitalGamma]\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"firstCuttingPoint", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", "r", ",", "xs"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"above\[CapitalGamma]", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "||", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], "\[Equal]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"r", "=", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "+", 
              FractionBox["1", "g"]}], ")"}], "2"], "+", 
           FractionBox[
            SuperscriptBox["y", "2"], 
            RowBox[{"g", "/", 
             RowBox[{"(", 
              RowBox[{"m", " ", "l"}], ")"}]}]]}]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"k", "=", 
         RowBox[{"Floor", "[", 
          FractionBox[
           RowBox[{"r", "-", 
            RowBox[{"1", "/", "g"}]}], 
           RowBox[{"2", "/", "g"}]], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"xs", "=", 
         FractionBox[
          RowBox[{
           SuperscriptBox["r", "2"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["1", "g"], ")"}], "2"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", "k"}], "+", "1"}], ")"}], "2"], "-", "1"}], 
             ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["1", "g"], ")"}], "2"]}]}], 
          RowBox[{"4", 
           RowBox[{"(", 
            RowBox[{"k", "+", "1"}], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "/", "g"}], ")"}]}]]}], ";", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"xs", ",", 
          RowBox[{"-", 
           SqrtBox[
            RowBox[{
             FractionBox["g", 
              RowBox[{"m", " ", "l"}]], 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["r", "2"], "-", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"xs", "+", 
                  FractionBox["1", "g"]}], ")"}], "2"]}], ")"}]}]]}]}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"-", 
        RowBox[{"firstCuttingPoint", "[", 
         RowBox[{
          RowBox[{"-", "x"}], ",", 
          RowBox[{"-", "y"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"findCuttingPoints", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"First", "@", 
    RowBox[{"Last", "@", 
     RowBox[{"Reap", "[", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cp", "=", 
          RowBox[{"firstCuttingPoint", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Sow", "[", "cp", "]"}], ";", 
         RowBox[{"findRemainingCuttingPoints", "@@", "cp"}]}]}], 
       "\[IndentingNewLine]", "]"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"findRemainingCuttingPoints", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"!", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", "g"]}], "\[LessEqual]", "x", "\[LessEqual]", 
        FractionBox["2", "g"]}], ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"cp", "=", 
         RowBox[{"firstCuttingPoint", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", 
              RowBox[{"First", "@", "cp"}]}], ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"y", "-", 
              RowBox[{"Last", "@", "cp"}]}], ")"}], "2"]}], ">", "0.01"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Sow", "[", "cp", "]"}], ";", 
          RowBox[{"findRemainingCuttingPoints", "@@", "cp"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6629125147123775`*^9, 3.6629125148775043`*^9}, {
  3.662913038745699*^9, 3.6629131200663214`*^9}, {3.6629132657722273`*^9, 
  3.662913272265829*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hautus", "Subsubsection",
 CellChangeTimes->{{3.6629108205129423`*^9, 3.6629108209602594`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"solveHautus", "[", 
    RowBox[{"xx0_", ",", "yy0_", ",", "threshold_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
           {"0", "1"},
           {
            RowBox[{
             RowBox[{"-", "g"}], "/", 
             RowBox[{"(", "l", ")"}]}], "0"}
          }], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
           {"0"},
           {
            RowBox[{"1", "/", "l"}]}
          }], ")"}]}], ",", "\[IndentingNewLine]", "F", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"x10", "=", "xx0"}], ",", 
       RowBox[{"x20", "=", "yy0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"x0", "=", "xx0"}], ",", 
       RowBox[{"y0", "=", "yy0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"T", "=", "35"}], ",", "\[IndentingNewLine]", "r", ",", "cp", 
       ",", "points", ",", "stopThreshold", ",", "u", ",", "count", ",", "tt",
        ",", "te", ",", "sol", ",", "events", ",", "ts"}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"r", "=", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"above\[CapitalGamma]", "[", 
              RowBox[{"x0", ",", "y0"}], "]"}], ",", 
             RowBox[{"x0", "+", 
              FractionBox["1", "g"]}], ",", 
             RowBox[{"x0", "-", 
              FractionBox["1", "g"]}]}], "]"}], ")"}], "2"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", "y0", ")"}], "2"], 
          RowBox[{"g", "/", 
           RowBox[{"(", 
            RowBox[{"m", " ", "l"}], ")"}]}]]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cp", "=", 
       RowBox[{"findCuttingPoints", "[", 
        RowBox[{"x0", ",", "y0"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"points", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"x0", ",", "y0"}], "}"}], "}"}], ",", "cp", ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"F", "=", 
       RowBox[{
        RowBox[{"(", GridBox[{
           {"f11", "f12"}
          }], ")"}], "/.", 
        RowBox[{"First", "@", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{"Eigenvalues", "[", 
            RowBox[{"A", "+", 
             RowBox[{"B", ".", 
              RowBox[{"(", GridBox[{
                 {"f11", "f12"}
                }], ")"}]}]}], "]"}], "\[Equal]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", 
             RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"stopThreshold", "=", 
       RowBox[{"threshold", "/", "100000"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"\[Theta]_", ",", "\[Theta]d_"}], "]"}], "=", 
       RowBox[{"Piecewise", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"F", ".", 
                  RowBox[{"(", GridBox[{
                    {"\[Theta]"},
                    {"\[Theta]d"}
                    }], ")"}]}], ")"}], "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{
                SqrtBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "2"], "+", 
                  SuperscriptBox["\[Theta]d", "2"]}]], "<", "threshold"}]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{
                RowBox[{"\[Theta]", "<", "0"}], "&&", 
                RowBox[{"\[Theta]d", "<", "0"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", 
               RowBox[{
                RowBox[{"\[Theta]", ">", "0"}], "&&", 
                RowBox[{"\[Theta]d", ">", "0"}]}]}], "}"}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"Sign", "[", 
                  RowBox[{"First", "[", "#", "]"}], "]"}]}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Abs", "[", "\[Theta]", "]"}], ">", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"First", "[", "#", "]"}], "]"}]}], "&&", 
                 RowBox[{"withinEllipse", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"\[Theta]", ",", "\[Theta]d"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Sign", "[", 
                    RowBox[{"First", "[", "#", "]"}], "]"}], 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", 
                    RowBox[{"Floor", "[", 
                    FractionBox[
                    RowBox[{"Abs", "[", 
                    RowBox[{"First", "[", "#", "]"}], "]"}], 
                    RowBox[{"2", "/", "g"}]], "]"}]}], "+", "1"}], ")"}], " ", 
                    RowBox[{"(", 
                    FractionBox["1", "g"], ")"}]}], ")"}], ",", "0"}], "}"}], 
                   ",", 
                   FractionBox["1", "g"]}], "]"}]}]}], "}"}], ")"}], "&"}], "/@",
             "cp"}]}], "\[IndentingNewLine]", "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Sign", "[", "\[Theta]d", "]"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"count", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"tt", "=", "T"}], ";", "\[IndentingNewLine]", 
      RowBox[{"te", "=", "T"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"sol", ",", "events"}], "}"}], "=", 
       RowBox[{"Reap", "[", 
        RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", GridBox[{
                {
                 RowBox[{
                  RowBox[{"x1", "'"}], "[", "t", "]"}]},
                {
                 RowBox[{
                  RowBox[{"x2", "'"}], "[", "t", "]"}]}
               }], ")"}], "\[Equal]", 
             RowBox[{
              RowBox[{"A", ".", 
               RowBox[{"(", GridBox[{
                  {
                   RowBox[{"x1", "[", "t", "]"}]},
                  {
                   RowBox[{"x2", "[", "t", "]"}]}
                 }], ")"}]}], "+", 
              RowBox[{"B", " ", 
               RowBox[{"u", "[", 
                RowBox[{
                 RowBox[{"x1", "[", "t", "]"}], ",", 
                 RowBox[{"x2", "[", "t", "]"}]}], "]"}]}]}]}], ",", 
            RowBox[{
             RowBox[{"x1", "[", "0", "]"}], "\[Equal]", "x10"}], ",", 
            RowBox[{
             RowBox[{"x2", "[", "0", "]"}], "\[Equal]", "x20"}]}], "}"}], ",",
           "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x1", ",", "x2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PrecisionGoal", "\[Rule]", "6"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Method", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<EventLocator\>\"", ",", 
             RowBox[{"\"\<Event\>\"", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"u", "[", 
                 RowBox[{
                  RowBox[{"x1", "[", "t", "]"}], ",", 
                  RowBox[{"x2", "[", "t", "]"}]}], "]"}], ",", 
                RowBox[{
                 SqrtBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{"x1", "[", "t", "]"}], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{"x2", "[", "t", "]"}], "2"]}]], "<", 
                 "threshold"}], ",", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"x1", "[", "t", "]"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"x2", "[", "t", "]"}], "2"]}], "<", 
                 "stopThreshold"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"\"\<EventAction\>\"", "\[RuleDelayed]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"count", "++"}], ";", 
                 RowBox[{"Sow", "[", 
                  RowBox[{"Chop", "@", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", 
                    RowBox[{"x1", "[", "t", "]"}], ",", 
                    RowBox[{"x2", "[", "t", "]"}], ",", 
                    RowBox[{"u", "[", 
                    RowBox[{
                    RowBox[{"x1", "[", "t", "]"}], ",", 
                    RowBox[{"x2", "[", "t", "]"}]}], "]"}]}], "}"}]}], 
                  "]"}]}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"tt", "=", "t"}], ";", 
                 RowBox[{"Print", "[", 
                  RowBox[{"StringForm", "[", 
                   RowBox[{"\"\<Final time: ``\>\"", ",", "t"}], "]"}], 
                  "]"}]}], ",", "\[IndentingNewLine]", 
                RowBox[{"Throw", "[", 
                 RowBox[{
                  RowBox[{"te", "=", "t"}], ",", "\"\<StopIntegration\>\""}], 
                 "]"}]}], "}"}]}]}], "\[IndentingNewLine]", "}"}]}]}], 
         "\[IndentingNewLine]", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tt", "=", 
       RowBox[{"Min", "[", 
        RowBox[{"tt", ",", "te"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"StringForm", "[", 
        RowBox[{"\"\<Interval: ``\>\"", ",", 
         RowBox[{"First", "@", 
          RowBox[{"InterpolatingFunctionDomain", "[", 
           RowBox[{"First", "[", 
            RowBox[{"x1", "/.", "sol"}], "]"}], "]"}]}]}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "sol", ",", "u", ",", "te", ",", "r", ",", "cp", ",", "ts", ",", 
        "points", ",", "tt"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "hautus", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Threshold", "\[Rule]", "0.005"}], "\[IndentingNewLine]", "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"hautus", "[", 
    RowBox[{"xx0_", ",", "yy0_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x0", "=", "xx0"}], ",", 
       RowBox[{"y0", "=", "yy0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"threshold", "=", 
        RowBox[{"OptionValue", "[", "Threshold", "]"}]}], ",", 
       "\[IndentingNewLine]", "sol", ",", "r", ",", "u", ",", "te", ",", "cp",
        ",", "ts", ",", "points", ",", "tt"}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "sol", ",", "u", ",", "te", ",", "r", ",", "cp", ",", "ts", ",", 
         "points", ",", "tt"}], "}"}], "=", 
       RowBox[{"solveHautus", "[", 
        RowBox[{"xx0", ",", "yy0", ",", "threshold"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Quiet", "@", 
           RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"above\[CapitalGamma]", "[", 
                RowBox[{"x", ",", "y"}], "]"}], ",", 
               RowBox[{"Not", "@", 
                RowBox[{"above\[CapitalGamma]", "[", 
                 RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{
                RowBox[{"-", "1.05"}], "r"}], ",", 
               RowBox[{"1.05", "r"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", 
               RowBox[{
                RowBox[{"-", "1.05"}], 
                RowBox[{"r", "/", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{"m", " ", "l"}], "g"]]}]}], ",", 
               RowBox[{"1.05", 
                RowBox[{"r", "/", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{"m", " ", "l"}], "g"]]}]}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"MaxRecursion", "\[Rule]", "6"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"\"\<u = -1\>\"", ",", "\"\<u = 1\>\""}], "}"}]}], ",",
              "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AxesOrigin", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"Opacity", "[", "0.25", "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"BoundaryStyle", "\[Rule]", "Black"}]}], 
            "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ParametricPlot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "@", 
             RowBox[{"Join", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"above\[CapitalGamma]", "[", 
                    RowBox[{"x0", ",", "y0"}], "]"}], ",", 
                    RowBox[{"-", "1"}], ",", "1"}], "]"}], 
                    FractionBox["1", "g"]}], "+", 
                   RowBox[{"r", " ", 
                    RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
                  RowBox[{
                   SqrtBox[
                    FractionBox["g", 
                    RowBox[{"m", " ", "l"}]]], "r", " ", 
                   RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"With", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"rr", "=", 
                    RowBox[{"\[Sqrt]", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"First", "@", "#"}], "+", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"above\[CapitalGamma]", "@@", "#"}], ",", "1", 
                    ",", 
                    RowBox[{"-", "1"}]}], "]"}], 
                    FractionBox["1", "g"]}]}], ")"}], "2"], "+", 
                    FractionBox[
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"Last", "@", "#"}], ")"}], "2"], 
                    RowBox[{"g", "/", 
                    RowBox[{"(", 
                    RowBox[{"m", " ", "l"}], ")"}]}]]}], ")"}]}]}], "}"}], 
                   ",", "\[IndentingNewLine]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"above\[CapitalGamma]", "@@", "#"}], ",", 
                    RowBox[{"-", "1"}], ",", "1"}], "]"}], 
                    FractionBox["1", "g"]}], "+", 
                    RowBox[{"rr", " ", 
                    RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
                    RowBox[{
                    SqrtBox[
                    FractionBox["g", 
                    RowBox[{"m", " ", "l"}]]], "rr", " ", 
                    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]}], 
                  "\[IndentingNewLine]", "]"}], "&"}], "/@", "cp"}]}], 
              "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", 
              RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"Take", "[", 
              RowBox[{
               RowBox[{"ColorData", "[", 
                RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], ",", "2"}], 
              "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Ellips voor u = -1\>\"", ",", 
               "\"\<Ellips voor u = 1\>\""}], "}"}]}]}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "k"}], "+", "1"}], ")"}], 
                    FractionBox[
                    RowBox[{"m", " ", "l"}], "g"]}], "+", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"m", " ", "l"}], "g"], 
                    RowBox[{"Cos", "[", 
                    RowBox[{"t", "+", "\[Pi]"}], "]"}]}]}], ",", 
                    RowBox[{
                    SqrtBox[
                    FractionBox["g", 
                    RowBox[{"m", " ", "l"}]]], 
                    FractionBox[
                    RowBox[{"m", " ", "l"}], "g"], 
                    RowBox[{"Sin", "[", 
                    RowBox[{"t", "+", "\[Pi]"}], "]"}]}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "0", ",", "2"}], "}"}]}], "]"}], ",", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "k"}], "+", "1"}], ")"}]}], 
                    FractionBox[
                    RowBox[{"m", " ", "l"}], "g"]}], "+", 
                    RowBox[{
                    FractionBox[
                    RowBox[{"m", " ", "l"}], "g"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"\[Pi]", "-", "t"}], "]"}]}]}], ",", 
                    RowBox[{
                    SqrtBox[
                    FractionBox["g", 
                    RowBox[{"m", " ", "l"}]]], 
                    FractionBox[
                    RowBox[{"m", " ", "l"}], "g"], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"\[Pi]", "-", "t"}], "]"}]}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"k", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "]"}],
               ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"t", ",", "0", ",", "\[Pi]"}], "}"}]}], 
             "\[IndentingNewLine]", "]"}], ","}], "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "g"]}], ",", "0"}], "}"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{
                 FractionBox["1", "g"], ",", "0"}], "}"}], "}"}]}], "}"}], 
            ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"PointSize", "[", "Large", "]"}]}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ListPlot", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", "#", "}"}], "&"}], "/@", "points"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"PointSize", "[", "Large", "]"}], ",", "Green"}], 
                 "}"}], "}"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"PointSize", "[", "Large", "]"}], ",", "Purple"}], 
                  "}"}], "&"}], "/@", "cp"}], ",", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"PointSize", "[", "Large", "]"}], ",", "Red"}], 
                 "}"}], "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{
               "{", "\"\<(\!\(\*SubscriptBox[\(x\), \
\(0\)]\),\!\(\*SubscriptBox[\(y\), \(0\)]\))\>\"", "}"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"StringForm", "[", 
                  RowBox[{
                  "\"\<(\!\(\*SubscriptBox[\(x\), \
\(``\)]\),\!\(\*SubscriptBox[\(y\), \(``\)]\))\>\"", ",", "kk", ",", "kk"}], 
                  "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"kk", ",", "1", ",", 
                   RowBox[{"Length", "[", "cp", "]"}]}], "}"}]}], "]"}], ",", 
               RowBox[{
               "{", "\"\<(\!\(\*SubscriptBox[\(x\), \
\(e\)]\),\!\(\*SubscriptBox[\(y\), \(e\)]\))\>\"", "}"}]}], "]"}]}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x1", "[", "t", "]"}], ",", 
                RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "te"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"{", "\"\<Simulatie\>\"", "}"}]}]}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Axes", "->", "True"}], ",", "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], 
         "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x1", "[", "t", "]"}], ",", 
              RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "te"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Placed", "[", 
            RowBox[{
             RowBox[{"{", "\"\<Simulatie\>\"", "}"}], ",", "Right"}], "]"}]}],
           ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.005"}], ",", "0.005"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.005"}], ",", "0.005"}], "}"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x1", "[", "t", "]"}], ",", 
              RowBox[{"x2", "[", "t", "]"}], ",", 
              RowBox[{"u", "[", 
               RowBox[{
                RowBox[{"x1", "[", "t", "]"}], ",", 
                RowBox[{"x2", "[", "t", "]"}]}], "]"}]}], "}"}], "/.", 
            "sol"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "te"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Placed", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<x(t)\>\"", ",", "\"\<y(t)\>\"", ",", "\"\<u(t)\>\""}], 
              "}"}], ",", "Right"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Filling", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"3", "\[Rule]", "Axis"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x1", "[", "t", "]"}], "/.", 
                RowBox[{"First", "@", "sol"}]}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x2", "[", "t", "]"}], "/.", 
                RowBox[{"First", "@", "sol"}]}], ")"}], "2"]}]], "\[Equal]", 
           "threshold"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"te", "/", "2"}], ",", "0", ",", "te"}], "}"}]}], "]"}]}],
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.6629108341456094`*^9}, {3.6629648066930046`*^9, 
   3.6629648239632187`*^9}, {3.6629649366519175`*^9, 3.6629649702216597`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Energy", "Subsubsection",
 CellChangeTimes->{{3.662910836424217*^9, 3.6629108369605975`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "energy", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"T", "\[Rule]", "5.5"}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"energy", "[", 
    RowBox[{"x10_", ",", "x20_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
           {"0", "1"},
           {
            RowBox[{
             RowBox[{"-", "g"}], "/", 
             RowBox[{"(", 
              RowBox[{"m", " ", "l"}], ")"}]}], "0"}
          }], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
           {"0"},
           {
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"m", " ", "l"}], ")"}]}]}
          }], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"T", "=", 
        RowBox[{"OptionValue", "[", "T", "]"}]}], ",", "\[IndentingNewLine]", 
       "sol", ",", "H", ",", "Eh", ",", "Ev", ",", "u", ",", "xx1", ",", 
       "xx2", ",", "q", ",", "\[Theta]s", ",", "\[Theta]E", ",", "ts", ",", 
       "QQ", ",", "te", ",", "QQn", ",", "QQp", ",", "W"}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Ev", "[", 
        RowBox[{"\[Theta]_", ",", "\[Theta]d_"}], "]"}], ":=", 
       RowBox[{
        FractionBox["1", "2"], "m", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"l", " ", "\[Theta]d"}], ")"}], "2"]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Eh", "[", 
        RowBox[{"\[Theta]_", ",", "\[Theta]d_"}], "]"}], ":=", 
       RowBox[{"m", " ", "g", " ", "l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}]}]}], ";", 
      RowBox[{"(*", 
       RowBox[{"m", " ", "g", " ", "l", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"(", 
           FractionBox["\[Theta]", "2"], ")"}], "]"}], "2"]}], "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"\[Theta]s", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"x10", "\[GreaterEqual]", "0"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"(", 
           RowBox[{"x10", "+", 
            FractionBox[
             RowBox[{
              RowBox[{"Ev", "[", 
               RowBox[{"x10", ",", "x20"}], "]"}], "+", 
              RowBox[{"Eh", "[", 
               RowBox[{"x10", ",", "x20"}], "]"}]}], "l"]}], ")"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"(", 
           RowBox[{"x10", "-", 
            FractionBox[
             RowBox[{
              RowBox[{"Ev", "[", 
               RowBox[{"x10", ",", "x20"}], "]"}], "+", 
              RowBox[{"Eh", "[", 
               RowBox[{"x10", ",", "x20"}], "]"}]}], "l"]}], ")"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"StringForm", "[", 
        RowBox[{
        "\"\<\!\(\*SubscriptBox[\(\[Theta]\), \(s\)]\) = ``\>\"", ",", 
         "\[Theta]s"}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"u", "[", 
        RowBox[{"\[Theta]_", ",", "\[Theta]d_"}], "]"}], ":=", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{"x10", "\[GreaterEqual]", "0"}], ",", "\[IndentingNewLine]", 
         TagBox[GridBox[{
            {"\[Piecewise]", GridBox[{
               {
                RowBox[{"-", "1"}], 
                RowBox[{
                 RowBox[{"\[Theta]d", ">", "0"}], "||", 
                 RowBox[{"\[Theta]s", "<", "\[Theta]"}]}]},
               {"1", 
                RowBox[{"0", "<", "\[Theta]", "\[LessEqual]", "\[Theta]s"}]},
               {"0", 
                RowBox[{"\[Theta]", "\[LessEqual]", "0"}]}
              },
              AllowedDimensions->{2, Automatic},
              Editable->True,
              
              GridBoxAlignment->{
               "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{1.}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.84]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}},
              Selectable->True]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{1.}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.35]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          "Piecewise",
          DeleteWithContents->True,
          Editable->False,
          SelectWithContents->True,
          Selectable->False], ",", "\[IndentingNewLine]", 
         RowBox[{"x10", "<", "0"}], ",", "\[IndentingNewLine]", 
         TagBox[GridBox[{
            {"\[Piecewise]", GridBox[{
               {"1", 
                RowBox[{
                 RowBox[{"\[Theta]d", "<", "0"}], "||", 
                 RowBox[{"\[Theta]s", ">", "\[Theta]"}]}]},
               {
                RowBox[{"-", "1"}], 
                RowBox[{"\[Theta]s", "\[LessEqual]", "\[Theta]", "<", "0"}]},
               {"0", 
                RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}]}
              },
              AllowedDimensions->{2, Automatic},
              Editable->True,
              
              GridBoxAlignment->{
               "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{1.}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.84]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}},
              Selectable->True]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{1.}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.35]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          "Piecewise",
          DeleteWithContents->True,
          Editable->False,
          SelectWithContents->True,
          Selectable->False]}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"sol", "=", 
         RowBox[{"NDSolve", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"x1", "'"}], "[", "t", "]"}], "\[Equal]", 
              RowBox[{"x2", "[", "t", "]"}]}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"x2", "'"}], "[", "t", "]"}], "\[Equal]", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["g", "l"]}], 
                RowBox[{"Sin", "[", 
                 RowBox[{"x2", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"u", "[", "t", "]"}]}]}], ",", 
             RowBox[{
              RowBox[{"x1", "[", "0", "]"}], "\[Equal]", "x10"}], ",", 
             RowBox[{
              RowBox[{"x2", "[", "0", "]"}], "\[Equal]", "x20"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"x1", ",", "x2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}]}], ";"}], 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{"First", "@", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"(", GridBox[{
                {
                 RowBox[{
                  RowBox[{"x1", "'"}], "[", "t", "]"}]},
                {
                 RowBox[{
                  RowBox[{"x2", "'"}], "[", "t", "]"}]}
               }], ")"}], "\[Equal]", 
             RowBox[{
              RowBox[{"A", ".", 
               RowBox[{"(", GridBox[{
                  {
                   RowBox[{"x1", "[", "t", "]"}]},
                  {
                   RowBox[{"x2", "[", "t", "]"}]}
                 }], ")"}]}], "+", 
              RowBox[{"B", " ", 
               RowBox[{"u", "[", 
                RowBox[{
                 RowBox[{"x1", "[", "t", "]"}], ",", 
                 RowBox[{"x2", "[", "t", "]"}]}], "]"}]}]}]}], ",", 
            RowBox[{
             RowBox[{"x1", "[", "0", "]"}], "\[Equal]", "x10"}], ",", 
            RowBox[{
             RowBox[{"x2", "[", "0", "]"}], "\[Equal]", "x20"}]}], "}"}], ",",
           "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x1", ",", "x2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "\[IndentingNewLine]", 
         "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xx1", "[", "t_", "]"}], "=", 
       RowBox[{
        RowBox[{"x1", "[", "t", "]"}], "/.", "sol"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xx2", "[", "t_", "]"}], "=", 
       RowBox[{
        RowBox[{"x2", "[", "t", "]"}], "/.", "sol"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ts", "=", 
       RowBox[{"t", "/.", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"xx1", "[", "t", "]"}], "\[Equal]", "\[Theta]s"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"T", "/", "2"}], ",", "0", ",", "T"}], "}"}]}], "]"}]}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"te", "=", 
       RowBox[{"t", "/.", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"xx1", "[", "t", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"T", "/", "2"}], ",", "0", ",", "T"}], "}"}]}], "]"}]}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"StringForm", "[", 
        RowBox[{"\"\<Final time: ``\>\"", ",", "te"}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"StringForm", "[", 
        RowBox[{"\"\<Switch time: ``\>\"", ",", "ts"}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"W", "[", "t_", "]"}], "=", 
       RowBox[{
        RowBox[{"WW", "[", "t", "]"}], "/.", 
        RowBox[{"First", "@", 
         RowBox[{"NDSolve", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"WW", "'"}], "[", "t", "]"}], "\[Equal]", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"-", 
                 RowBox[{"u", "[", 
                  RowBox[{
                   RowBox[{"xx1", "[", "t", "]"}], ",", 
                   RowBox[{"xx2", "[", "t", "]"}]}], "]"}]}], ")"}]}], 
              RowBox[{"(", 
               RowBox[{"l", " ", 
                RowBox[{"xx2", "[", "t", "]"}]}], ")"}]}]}], "&&", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"WW", "[", "0", "]"}], "\[Equal]", "0"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"WW", "[", "t", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "\[IndentingNewLine]",
           "]"}]}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x1", "[", "t", "]"}], ",", 
              RowBox[{"x2", "[", "t", "]"}], ",", 
              FractionBox[
               RowBox[{"u", "[", 
                RowBox[{
                 RowBox[{"x1", "[", "t", "]"}], ",", 
                 RowBox[{"x2", "[", "t", "]"}]}], "]"}], 
               RowBox[{"m", " ", "l"}]]}], "}"}], "/.", "sol"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<\[Theta]\>\"", ",", 
             "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)\>\"", ",", 
             "\"\<u/l\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Filling", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"3", "\[Rule]", "Axis"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x1", "[", "t", "]"}], ",", 
             RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Ev", "[", 
               RowBox[{
                RowBox[{"x1", "[", "t", "]"}], ",", 
                RowBox[{"x2", "[", "t", "]"}]}], "]"}], "/.", "sol"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Eh", "[", 
               RowBox[{
                RowBox[{"x1", "[", "t", "]"}], ",", 
                RowBox[{"x2", "[", "t", "]"}]}], "]"}], "/.", "sol"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"W", "[", "t", "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Ev", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"x1", "[", "t", "]"}], "/.", "sol"}], ",", 
                RowBox[{
                 RowBox[{"x2", "[", "t", "]"}], "/.", "sol"}]}], "]"}], "+", 
              RowBox[{"Eh", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"x1", "[", "t", "]"}], "/.", "sol"}], ",", 
                RowBox[{
                 RowBox[{"x2", "[", "t", "]"}], "/.", "sol"}]}], "]"}], "-", 
              RowBox[{"W", "[", "t", "]"}]}]}], "\[IndentingNewLine]", "}"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<\!\(\*SubscriptBox[\(E\), \(v\)]\)\>\"", ",", 
             "\"\<\!\(\*SubscriptBox[\(E\), \(h\)]\)\>\"", ",", "\"\<W\>\"", 
             ",", "\"\<\!\(\*SubscriptBox[\(E\), \(v\)]\)+\!\(\*SubscriptBox[\
\(E\), \(h\)]\)-W\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
        "\[IndentingNewLine]", "sol", ",", "u", ",", "te"}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.6629108451954327`*^9}, {3.6629653447665553`*^9, 3.6629653752871404`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Costs on input", "Subsubsection",
 CellChangeTimes->{{3.6629108509845343`*^9, 3.662910853424262*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"epsilonOC", "[", 
    RowBox[{
    "n_", ",", "A_", ",", "B_", ",", "s_", ",", "eps_", ",", "x0temp_", ",", 
     RowBox[{"{", 
      RowBox[{"TminTemp_", ",", "TmaxTemp_"}], "}"}], ",", "\[Epsilon]_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Q", "=", 
        RowBox[{"ConstantArray", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"S", "=", 
        RowBox[{"s", " ", 
         RowBox[{"IdentityMatrix", "[", "n", "]"}]}]}], ",", 
       "\[IndentingNewLine]", "sol", ",", "H", ",", "u", ",", "xx2", ",", "q",
        ",", "ts", ",", "\[Theta]s", ",", "\[IndentingNewLine]", "variables", 
       ",", "\[IndentingNewLine]", "x0", ",", "\[IndentingNewLine]", "R", ",",
        "\[IndentingNewLine]", "xs", ",", "ps", ",", "xps", ",", "T", ",", 
       "it", ",", "\[IndentingNewLine]", 
       RowBox[{"maxIt", "=", "25"}], ",", "\[IndentingNewLine]", "Tmin", ",", 
       "Tmax"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"R", "=", 
       RowBox[{"2", "eps"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"x0", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", "#", "}"}], "&"}], "/@", "x0temp"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"H", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"A", ",", "Q"}], "]"}], ",", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"B", ".", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["R", 
                RowBox[{"-", "1"}]], 
               RowBox[{"B", "\[Transpose]"}]}], ")"}]}]}], ",", 
           RowBox[{"-", 
            RowBox[{"A", "\[Transpose]"}]}]}], "]"}], ",", "2"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"SetPrecision", "[", 
       RowBox[{"H", ",", "25"}], "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"xs", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["x", "i"], "[", "t", "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ps", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["p", "i"], "[", "t", "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xps", "=", 
       RowBox[{"Join", "[", 
        RowBox[{"xs", ",", "ps"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"variables", "=", 
       RowBox[{"Flatten", "@", "xps"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"Tmin", "=", "TminTemp"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Tmax", "=", "TmaxTemp"}], ";", "\[IndentingNewLine]", 
      RowBox[{"it", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Tmax", "-", "Tmin"}], ">", "\[Epsilon]"}], "&&", 
         RowBox[{"it", "<", "maxIt"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"T", "=", 
          FractionBox[
           RowBox[{"Tmin", "+", "Tmax"}], "2"]}], ";", "\[IndentingNewLine]", 
         RowBox[{"sol", "=", 
          RowBox[{"First", "@", 
           RowBox[{"NDSolve", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"D", "[", 
                   RowBox[{"#", ",", "t"}], "]"}], "&"}], "/@", "xps"}], 
                "\[Equal]", 
                RowBox[{"H", ".", "xps"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"xs", "/.", 
                  RowBox[{"t", "\[Rule]", "0"}]}], ")"}], "\[Equal]", "x0"}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ps", "/.", 
                  RowBox[{"t", "\[Rule]", "T"}]}], ")"}], "\[Equal]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"S", ".", "xs"}], "/.", 
                  RowBox[{"t", "\[Rule]", "T"}]}], ")"}]}]}], 
              "\[IndentingNewLine]", "}"}], ",", "variables", ",", "t"}], 
            "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"u", "[", "t_", "]"}], "=", 
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["R", 
                  RowBox[{"-", "1"}]], 
                 RowBox[{"B", "\[Transpose]"}]}], ")"}], ".", "ps"}]}], ")"}],
             "/.", "sol"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Max", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"First", "@", 
                 RowBox[{"FindMaximum", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"First", "@", 
                    RowBox[{"First", "@", 
                    RowBox[{"u", "[", "t", "]"}]}]}], "]"}], ",", 
                    RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "T"}]}],
                     "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "#"}], "}"}]}], "]"}]}], "&"}], "/@", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"T", "/", "100"}], ",", 
                 RowBox[{"T", "/", "2"}], ",", 
                 RowBox[{
                  RowBox[{"99", "/", "100"}], "T"}]}], "}"}]}], "]"}], ")"}], 
            "<", "1"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Tmax", "=", "T"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Tmin", "=", "T"}]}], "\[IndentingNewLine]", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"it", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"T", "=", 
       RowBox[{"N", "@", 
        FractionBox[
         RowBox[{"Tmax", "+", "Tmin"}], "2"]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{"First", "@", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"#", ",", "t"}], "]"}], "&"}], "/@", "xps"}], 
             "\[Equal]", 
             RowBox[{"H", ".", "xps"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xs", "/.", 
               RowBox[{"t", "\[Rule]", "0"}]}], ")"}], "\[Equal]", "x0"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ps", "/.", 
               RowBox[{"t", "\[Rule]", "T"}]}], ")"}], "\[Equal]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"S", ".", "xs"}], "/.", 
               RowBox[{"t", "\[Rule]", "T"}]}], ")"}]}]}], 
           "\[IndentingNewLine]", "}"}], ",", "variables", ",", "t"}], 
         "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"u", "[", "t_", "]"}], "=", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["R", 
               RowBox[{"-", "1"}]], 
              RowBox[{"B", "\[Transpose]"}]}], ")"}], ".", "ps"}]}], ")"}], "/.",
          "sol"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"{", 
        RowBox[{"s", ",", "eps", ",", 
         RowBox[{"s", "/", "eps"}], ",", 
         RowBox[{"LinearAlgebra`MatrixConditionNumber", "[", "H", "]"}], ",", 
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
               SubscriptBox["x", "1"], "[", "t", "]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
               SubscriptBox["x", "2"], "[", "t", "]"}], "2"]}]], "/.", 
           "sol"}], "/.", 
          RowBox[{"t", "\[Rule]", "T"}]}]}], "}"}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{
              SubscriptBox["x", "1"], "[", "t", "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["x", "2"], "[", "t", "]"}], "2"]}]], "/.", "sol"}],
          "/.", 
         RowBox[{"t", "\[Rule]", "T"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{"xs", "/.", "sol"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Flatten", "@", "xs"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{"ps", "/.", "sol"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Flatten", "@", "ps"}]}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
             RowBox[{
              SubscriptBox["x", "2"], "[", "t", "]"}]}], "}"}], "/.", "sol"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<\[Theta]\>\"", ",", 
             "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)\>\""}], "}"}]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "300"}]}], "\[IndentingNewLine]", 
         "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"n", "\[GreaterEqual]", "4"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                SubscriptBox["x", "3"], "[", "t", "]"}], ",", 
               RowBox[{
                SubscriptBox["x", "4"], "[", "t", "]"}]}], "}"}], "/.", 
             "sol"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
              "\"\<r\>\"", ",", 
               "\"\<\!\(\*OverscriptBox[\(r\), \(.\)]\)\>\""}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"AspectRatio", "\[Rule]", 
             RowBox[{"1", "/", "3"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"ImageSize", "\[Rule]", "300"}]}], "\[IndentingNewLine]", 
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", "t", "]"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<u(t)\>\"", "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        "\[IndentingNewLine]", "T", ",", "\[IndentingNewLine]", "sol", ",", 
        "\[IndentingNewLine]", "u"}], "\[IndentingNewLine]", "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.6629108591803417`*^9}, {3.6629654854070225`*^9, 3.662965538242401*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Timing", "Subsubsection",
 CellChangeTimes->{{3.662910861088694*^9, 3.6629108614889774`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "time", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Precision", "\[Rule]", 
     SuperscriptBox["10", 
      RowBox[{"-", "2"}]]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"time", "[", 
    RowBox[{"x0_", ",", "target_", ",", "u_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"solves", ",", "sol", ",", 
       RowBox[{"eps", "=", 
        RowBox[{"OptionValue", "[", "Precision", "]"}]}], ",", "sols", ",", 
       "q", ",", "ret", ",", "x"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"solves", "=", 
        RowBox[{"DSolve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"m", " ", "l", " ", 
              RowBox[{
               RowBox[{"x", "''"}], "[", "t", "]"}]}], "\[Equal]", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "g"}], " ", 
               RowBox[{"x", "[", "t", "]"}]}], "+", "u"}]}], ",", 
            RowBox[{
             RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
             RowBox[{"First", "@", "x0"}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", 
             RowBox[{"Last", "@", "x0"}]}]}], "}"}], ",", 
          RowBox[{"x", "[", "t", "]"}], ",", "t"}], "]"}]}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "t_", "]"}], ":=", 
       RowBox[{"sinDistance", "[", 
        RowBox[{
         RowBox[{"First", "@", "x0"}], ",", 
         RowBox[{"Last", "@", "x0"}], ",", "u", ",", "t"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"sol", "=", 
         RowBox[{"First", "@", "solves"}]}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"sols", "=", 
         RowBox[{"t", "/.", 
          RowBox[{"Quiet", "[", 
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "\[Equal]", 
              RowBox[{"First", "[", "target", "]"}]}], ",", "t"}], "]"}], 
           "]"}]}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"sols", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SqrtBox["g"]]}], 
          SqrtBox["l"], " ", 
          SqrtBox["m"], " ", 
          RowBox[{"ArcCos", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "target", "]"}]}], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               RowBox[{"First", "[", "target", "]"}], " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "-", 
              RowBox[{"\[Sqrt]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "target", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "target", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "x0", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "x0", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "2"], " ", 
                  SuperscriptBox["l", "2"], " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "4"]}]}], ")"}]}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"2", " ", "g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               SuperscriptBox[
                RowBox[{"First", "[", "x0", "]"}], "2"]}], "+", 
              RowBox[{"g", " ", "l", " ", "m", " ", 
               SuperscriptBox[
                RowBox[{"Last", "[", "x0", "]"}], "2"]}]}], ")"}]}], "]"}]}], 
         ",", 
         RowBox[{
          FractionBox["1", 
           SqrtBox["g"]], 
          SqrtBox["l"], " ", 
          SqrtBox["m"], " ", 
          RowBox[{"ArcCos", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "target", "]"}]}], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               RowBox[{"First", "[", "target", "]"}], " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "-", 
              RowBox[{"\[Sqrt]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "target", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "target", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "x0", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "x0", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "2"], " ", 
                  SuperscriptBox["l", "2"], " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "4"]}]}], ")"}]}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"2", " ", "g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               SuperscriptBox[
                RowBox[{"First", "[", "x0", "]"}], "2"]}], "+", 
              RowBox[{"g", " ", "l", " ", "m", " ", 
               SuperscriptBox[
                RowBox[{"Last", "[", "x0", "]"}], "2"]}]}], ")"}]}], "]"}]}], 
         ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", 
            SqrtBox["g"]]}], 
          SqrtBox["l"], " ", 
          SqrtBox["m"], " ", 
          RowBox[{"ArcCos", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "target", "]"}]}], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               RowBox[{"First", "[", "target", "]"}], " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{"\[Sqrt]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "target", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "target", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "x0", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "x0", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "2"], " ", 
                  SuperscriptBox["l", "2"], " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "4"]}]}], ")"}]}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"2", " ", "g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               SuperscriptBox[
                RowBox[{"First", "[", "x0", "]"}], "2"]}], "+", 
              RowBox[{"g", " ", "l", " ", "m", " ", 
               SuperscriptBox[
                RowBox[{"Last", "[", "x0", "]"}], "2"]}]}], ")"}]}], "]"}]}], 
         ",", 
         RowBox[{
          FractionBox["1", 
           SqrtBox["g"]], 
          SqrtBox["l"], " ", 
          SqrtBox["m"], " ", 
          RowBox[{"ArcCos", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "target", "]"}]}], "-", 
              RowBox[{"g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               RowBox[{"First", "[", "target", "]"}], " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{"\[Sqrt]", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "target", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "target", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["g", "2"], " ", "l", " ", "m", " ", "u", " ", 
                  RowBox[{"First", "[", "x0", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "3"], " ", "l", " ", "m", " ", 
                  SuperscriptBox[
                   RowBox[{"First", "[", "x0", "]"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["g", "2"], " ", 
                  SuperscriptBox["l", "2"], " ", 
                  SuperscriptBox["m", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"Last", "[", "x0", "]"}], "4"]}]}], ")"}]}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["u", "2"], "-", 
              RowBox[{"2", " ", "g", " ", "u", " ", 
               RowBox[{"First", "[", "x0", "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", "2"], " ", 
               SuperscriptBox[
                RowBox[{"First", "[", "x0", "]"}], "2"]}], "+", 
              RowBox[{"g", " ", "l", " ", "m", " ", 
               SuperscriptBox[
                RowBox[{"Last", "[", "x0", "]"}], "2"]}]}], ")"}]}], 
           "]"}]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sols", "=", 
       RowBox[{"Chop", "[", "sols", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sols", "=", 
       RowBox[{"Re", "[", 
        RowBox[{"Select", "[", 
         RowBox[{"sols", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Im", "[", "#", "]"}], "<", "eps"}], "&"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sols", "=", 
       RowBox[{"Sort", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"#", "\[LessEqual]", "0"}], ",", 
            RowBox[{
             RowBox[{"2", "\[Pi]", 
              SqrtBox[
               FractionBox["g", 
                RowBox[{"m", " ", "l"}]]]}], "+", "#"}], ",", "#"}], "]"}], 
          "&"}], "/@", "sols"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ret", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"sols", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              RowBox[{"x", "[", "#", "]"}], "-", 
              RowBox[{"First", "@", "target"}]}], "]"}], "<", "eps"}], 
           "\[IndentingNewLine]", "&&", 
           RowBox[{
            RowBox[{"Abs", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"x", "'"}], "[", "#", "]"}], "-", 
              RowBox[{"Last", "@", "target"}]}], "]"}], "<", "eps"}]}], 
          "&"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "ret", "]"}], ">", "0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"First", "@", "ret"}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "totalTime", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Precision", "\[Rule]", 
     SuperscriptBox["10", 
      RowBox[{"-", "2"}]]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"totalTime", "[", 
    RowBox[{"x0_", ",", "y0_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cp", ",", "points", ",", "u"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"cp", "=", 
       RowBox[{"findCuttingPoints", "[", 
        RowBox[{"x0", ",", "y0"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"points", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"x0", ",", "y0"}], "}"}], "}"}], ",", "cp", ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"u", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"above\[CapitalGamma]", "[", 
          RowBox[{"x0", ",", "y0"}], "]"}], ",", 
         RowBox[{"-", "1"}], ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"cp", ",", "points", ",", "u"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"Total", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"time", "[", 
           RowBox[{
            RowBox[{
            "points", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
            ",", 
            RowBox[{"points", "\[LeftDoubleBracket]", 
             RowBox[{"#", "+", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"u", "*", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"OddQ", "[", "#", "]"}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "]"}]}], ",", "opts"}], "]"}], ")"}], 
         "&"}], "\[IndentingNewLine]", "/@", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"Length", "[", "points", "]"}], "-", "1"}], "]"}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"uFromSwitchTimes", "[", "Ts_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "=", "1"}], ",", 
       RowBox[{"acc", "=", 
        RowBox[{"Accumulate", "[", "Ts", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Piecewise", "[", 
      RowBox[{"Join", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"u", ",", 
           RowBox[{"0", "\[LessEqual]", "t", "<", 
            RowBox[{
            "acc", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}],
           "}"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", "=", 
             RowBox[{"-", "u"}]}], ";", 
            RowBox[{"{", 
             RowBox[{"u", ",", 
              RowBox[{
               RowBox[{
               "acc", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
               "\[LessEqual]", "t", "<", 
               RowBox[{"acc", "\[LeftDoubleBracket]", 
                RowBox[{"#", "+", "1"}], "\[RightDoubleBracket]"}]}]}], 
             "}"}]}], ")"}], "&"}], "/@", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"Length", "[", "Ts", "]"}], "-", "1"}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0", ",", "True"}], "}"}], "}"}]}], "\[IndentingNewLine]", 
       "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.6629108663374195`*^9}, {3.6629112686701145`*^9, 3.662911292875266*^9}, {
   3.662911406902064*^9, 3.662911416685997*^9}, {3.662911467598072*^9, 
   3.66291157430068*^9}, {3.6629116471823225`*^9, 3.6629116908112383`*^9}, {
   3.662911758262032*^9, 3.662911786829274*^9}, {3.6629118381216335`*^9, 
   3.662911844406072*^9}, {3.66291189622479*^9, 3.662911898294256*^9}, {
   3.6629125461976905`*^9, 3.6629125548328056`*^9}, {3.662965812710507*^9, 
   3.6629658158357162`*^9}, {3.662966148709531*^9, 3.6629661488856554`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Distances", "Subsubsection",
 CellChangeTimes->{{3.662910868136688*^9, 3.662910869440612*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"paraDistance", "[", 
    RowBox[{"r0_", ",", "rd0_", ",", "u_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], "u", " ", "uMax", " ", 
     SuperscriptBox["t", "2"]}], "+", 
    RowBox[{"rd0", " ", "t"}], "+", "r0"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sinDistance", "[", 
    RowBox[{"x0_", ",", "y0_", ",", "u_", ",", "t_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["1", "g"], 
    RowBox[{"(", 
     RowBox[{"u", "-", 
      RowBox[{"u", " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["g"], " ", "t"}], 
         RowBox[{
          SqrtBox["l"], " ", 
          SqrtBox["m"]}]], "]"}]}], "+", 
      RowBox[{"g", " ", "x0", " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["g"], " ", "t"}], 
         RowBox[{
          SqrtBox["l"], " ", 
          SqrtBox["m"]}]], "]"}]}], "+", 
      RowBox[{
       SqrtBox["g"], " ", 
       SqrtBox["l"], " ", 
       SqrtBox["m"], " ", "y0", " ", 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{
          SqrtBox["g"], " ", "t"}], 
         RowBox[{
          SqrtBox["l"], " ", 
          SqrtBox["m"]}]], "]"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dSinDistance", "[", 
    RowBox[{"x0_", ",", "y0_", ",", "u_", ",", "t_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{
     RowBox[{
      SqrtBox["g"], " ", 
      SqrtBox["l"], " ", 
      SqrtBox["m"], " ", "y0", " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{
         SqrtBox["g"], " ", "t"}], 
        RowBox[{
         SqrtBox["l"], " ", 
         SqrtBox["m"]}]], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"u", "-", 
        RowBox[{"g", " ", "x0"}]}], ")"}], " ", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{
         SqrtBox["g"], " ", "t"}], 
        RowBox[{
         SqrtBox["l"], " ", 
         SqrtBox["m"]}]], "]"}]}]}], 
    RowBox[{
     SqrtBox["g"], " ", 
     SqrtBox["l"], " ", 
     SqrtBox["m"]}]]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.6629108814080925`*^9}, {3.6629661476617928`*^9, 3.6629661507649736`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation of crane system", "Subsubsection",
 CellChangeTimes->{{3.6629108924218874`*^9, 3.662910901472309*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "finalOc", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", "None"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"finalOc", "[", 
    RowBox[{"x0temp_", ",", "T_", ",", "u_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"A", "=", 
        RowBox[{"(", GridBox[{
           {"0", "1", "0", "0"},
           {
            RowBox[{
             RowBox[{"-", "g"}], "/", "l"}], "0", "0", "0"},
           {"0", "0", "0", "1"},
           {"0", "0", "0", "0"}
          }], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"B", "=", 
        RowBox[{"(", GridBox[{
           {"0"},
           {
            RowBox[{
             RowBox[{"-", "uMax"}], "/", "l"}]},
           {"0"},
           {"uMax"}
          }], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"n", "=", "4"}], ",", "\[IndentingNewLine]", "sol", ",", "q", 
       ",", "\[IndentingNewLine]", "variables", ",", "\[IndentingNewLine]", 
       "x0", ",", "xs"}], "\[IndentingNewLine]", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"x0", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", "#", "}"}], "&"}], "/@", "x0temp"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"xs", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["x", "i"], "[", "t", "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"variables", "=", 
       RowBox[{"Flatten", "@", "xs"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{"First", "@", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"#", ",", "t"}], "]"}], "&"}], "/@", "xs"}], 
             "\[Equal]", 
             RowBox[{
              RowBox[{"A", ".", "xs"}], "+", 
              RowBox[{"B", "*", 
               RowBox[{"u", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"xs", "/.", 
               RowBox[{"t", "\[Rule]", "0"}]}], ")"}], "\[Equal]", "x0"}]}], 
           "\[IndentingNewLine]", "}"}], ",", "variables", ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "\[IndentingNewLine]", 
         "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{
         "\"\<Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``\>\"", 
          ",", 
          RowBox[{"First", "@", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{
               SuperscriptBox["#", "2"], "&"}], "/@", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"xs", "/.", "sol"}], "/.", 
                RowBox[{"t", "\[Rule]", "T"}]}], ")"}]}], "]"}], "]"}]}], ",",
           "T", ",", 
          RowBox[{
          "x0", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
         "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{"xs", "/.", "sol"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Flatten", "@", "xs"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{"xs", "/.", "sol"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{
             FractionBox["99", "100"], "T"}], ",", "T"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Flatten", "@", "xs"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", "\"\<t\>\"", "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
             RowBox[{
              SubscriptBox["x", "2"], "[", "t", "]"}]}], "}"}], "/.", "sol"}],
           ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<\[Theta]\>\"", ",", 
             "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)\>\""}], "}"}]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AxesOrigin", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"OptionValue", "[", "PlotLegends", "]"}]}]}], 
         "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"n", "\[GreaterEqual]", "4"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                SubscriptBox["x", "3"], "[", "t", "]"}], ",", 
               RowBox[{
                SubscriptBox["x", "4"], "[", "t", "]"}]}], "}"}], "/.", 
             "sol"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
              "\"\<r\>\"", ",", 
               "\"\<\!\(\*OverscriptBox[\(r\), \(.\)]\)\>\""}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"AxesOrigin", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"AspectRatio", "\[Rule]", 
             RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"OptionValue", "[", "PlotLegends", "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"300", ",", "200"}], "}"}]}]}], "\[IndentingNewLine]", 
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "[", "t", "]"}], "/.", "sol"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"OptionValue", "[", "PlotLegends", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<t\>\"", ",", "\"\<u(t)\>\""}], "}"}]}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], ",", 
        "\[IndentingNewLine]", "sol"}], "\[IndentingNewLine]", "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.6629109057433357`*^9}, {3.662966197689161*^9, 3.6629662124856415`*^9}, 
   3.662966859732355*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Exporting", "Subsubsection",
 CellChangeTimes->{{3.6629109072564073`*^9, 3.662910907904868*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"export", "[", 
    RowBox[{"content_List", ",", "name_", ",", "ex_"}], "]"}], ":=", 
   RowBox[{"MapIndexed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"export", "[", 
       RowBox[{"#1", ",", 
        RowBox[{"name", "<>", "\"\<-\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"First", "@", "#2"}], "]"}]}], ",", "ex"}], "]"}], "&"}], 
     ",", "content"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"export", "[", 
    RowBox[{"content_", ",", "name_", ",", "ex_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{"ex", ",", 
        RowBox[{"Export", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"FileNameJoin", "[", 
           RowBox[{"{", 
            RowBox[{"figureExport", ",", 
             RowBox[{"name", "<>", "\"\<.pdf\>\""}]}], "}"}], "]"}], ",", 
          "content"}], "\[IndentingNewLine]", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "content"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exportRaster", "[", 
    RowBox[{"content_List", ",", "name_", ",", "ex_"}], "]"}], ":=", 
   RowBox[{"MapIndexed", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"exportRaster", "[", 
       RowBox[{"#1", ",", 
        RowBox[{"name", "<>", "\"\<-\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"First", "@", "#2"}], "]"}]}], ",", "ex"}], "]"}], "&"}], 
     ",", "content"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exportRaster", "[", 
    RowBox[{"content_", ",", "name_", ",", "ex_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{"ex", ",", 
        RowBox[{"Export", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"FileNameJoin", "[", 
           RowBox[{"{", 
            RowBox[{"figureExport", ",", 
             RowBox[{"name", "<>", "\"\<.png\>\""}]}], "}"}], "]"}], ",", 
          "content", ",", 
          RowBox[{"ImageResolution", "\[Rule]", "600"}]}], 
         "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      "content"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exportAnimation", "[", 
    RowBox[{"content_", ",", "name_", ",", 
     RowBox[{"{", 
      RowBox[{"tMin_", ",", "tMax_", ",", 
       RowBox[{"step_:", "1"}]}], "}"}], ",", "ex_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{"ex", ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Export", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"animationExport", ",", 
            RowBox[{"name", "<>", "\"\<.mov\>\""}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{"content", "@", "t"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "tMin", ",", "tMax", ",", "step"}], "}"}]}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"\"\<VideoEncoding\>\"", "\[Rule]", "\"\<Cinepak\>\""}]}], 
        "\[IndentingNewLine]", "]"}], ","}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Export", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"animationExport", ",", 
            RowBox[{"name", "<>", "\"\<.png\>\""}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "[", 
          RowBox[{"content", "[", 
           RowBox[{"tMin", "+", 
            RowBox[{"step", "/", "100"}]}], "]"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Export", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"animationExport", ",", 
            RowBox[{"name", "<>", "\"\<.swf\>\""}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ParallelTable", "[", 
          RowBox[{
           RowBox[{"Evaluate", "[", 
            RowBox[{"content", "[", "t", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "tMin", ",", "tMax", ",", "step"}], "}"}]}], 
          "]"}]}], "\[IndentingNewLine]", "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Animate", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"content", "[", "t", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "tMin", ",", "tMax"}], "}"}], ",", 
       RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.66291091707337*^9}, {3.662911095912521*^9, 3.662911096280776*^9}, {
   3.662913769596554*^9, 3.6629137841881385`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation", "Subsubsection",
 CellChangeTimes->{{3.6629109142643733`*^9, 3.662910915184025*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"swingBall", "[", "c_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "coord", ",", "gradient", ",", "img", ",", "rastimg", ",", "shiny"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gradient", "=", 
       RowBox[{"Image", "[", 
        RowBox[{"DensityPlot", "[", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "y"}], ")"}], "2"], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", ".8"}], ",", ".2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
          RowBox[{"Frame", "\[Rule]", "None"}], ",", 
          RowBox[{"ColorFunction", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"GrayLevel", "[", 
              RowBox[{"1", "-", 
               RowBox[{"#", "/", "2"}]}], "]"}], "&"}], ")"}]}], ",", 
          RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"coord", "=", 
       RowBox[{"CirclePoints", "[", "100", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Texture", "@", "gradient"}], ",", 
        RowBox[{"EdgeForm", "@", "None"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"c", "+", "#"}], "&"}], "/@", "coord"}], ",", 
          RowBox[{"VertexTextureCoordinates", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"coord", "/", "2"}], "+", ".5"}], ")"}]}]}], "]"}], ",", 
        "Gray", ",", 
        RowBox[{"Thickness", "[", "0.0001", "]"}], ",", 
        RowBox[{"Circle", "[", "c", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "cartAnimation", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CableLength", "\[Rule]", "60"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Width", "\[Rule]", "1024"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Variables", "\[Rule]", "False"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Values", "\[Rule]", "True"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cartAnimation", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Theta]_", ",", "\[Theta]d_", ",", "r_", ",", "rd_"}], "}"}], 
     ",", "u_", ",", 
     RowBox[{"{", 
      RowBox[{"rMin_", ",", "rMax_"}], "}"}], ",", "trolleyControl_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"R", "=", 
        RowBox[{"OptionValue", "[", "CableLength", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"w", "=", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"h", "=", ".5"}], ",", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"OptionValue", "[", "Variables", "]"}]}]}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"r", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"r", "+", 
               RowBox[{"R", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
              RowBox[{
               RowBox[{"-", "R"}], " ", 
               RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}]}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Thick", ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rMin", "-", "w"}], ",", "H"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"rMax", "+", "w"}], ",", "H"}], "}"}]}], "}"}], 
             "]"}]}], "}"}], "/.", 
          RowBox[{"H", "\[Rule]", 
           RowBox[{"If", "[", 
            RowBox[{"trolleyControl", ",", 
             RowBox[{
              FractionBox[
               RowBox[{"-", "8"}], "5"], "h"}], ",", "0"}], "]"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"trolleyControl", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"EdgeForm", "[", 
              RowBox[{"Thickness", "[", "Medium", "]"}], "]"}], ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "-", "w"}], ",", 
                 RowBox[{"-", "h"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "+", "w"}], ",", "h"}], "}"}]}], "]"}], ",", 
             "LightGray", ",", 
             RowBox[{"Rectangle", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "-", "w"}], ",", 
                 RowBox[{"-", "h"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "+", "w"}], ",", "h"}], "}"}]}], "]"}]}], 
            "}"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"trolleyControl", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"GrayLevel", "[", ".45", "]"}], ",", 
             RowBox[{"Disk", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "-", 
                  RowBox[{
                   FractionBox["8", "10"], "w"}]}], ",", 
                 RowBox[{"-", "h"}]}], "}"}], ",", 
               RowBox[{
                FractionBox["3", "5"], "h"}]}], "]"}], ",", 
             RowBox[{"Disk", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "+", 
                  RowBox[{
                   FractionBox["8", "10"], "w"}]}], ",", 
                 RowBox[{"-", "h"}]}], "}"}], ",", 
               RowBox[{
                FractionBox["3", "5"], "h"}]}], "]"}]}], "}"}]}], 
          "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"swingBall", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"r", "+", 
             RowBox[{"R", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"-", "R"}], " ", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"u", "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"trolleyControl", ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Which", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"u", " ", "rd"}], ">", "0"}], ",", "Green", ",", 
                 RowBox[{
                  RowBox[{"u", " ", "rd"}], "<", "0"}], ",", "Red"}], "]"}], 
               ",", 
               RowBox[{"Arrow", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"r", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"r", "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"rMax", "-", "rMin"}], ")"}], "/", "6"}], "u"}]}],
                     ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Which", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"u", " ", "\[Theta]d"}], ">", "0"}], ",", "Green", 
                 ",", 
                 RowBox[{
                  RowBox[{"u", " ", "\[Theta]d"}], "<", "0"}], ",", "Red"}], 
                "]"}], ",", 
               RowBox[{"Arrowheads", "[", ".05", "]"}], ",", 
               RowBox[{"Arrow", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"r", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"R", "+", "2"}], ")"}], 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"R", "+", "2"}], ")"}]}], " ", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"r", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"R", "+", "2"}], ")"}], 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"rMax", "-", "rMin"}], ")"}], "/", "8"}], "u", 
                    " ", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"R", "+", "2"}], ")"}]}], " ", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"rMax", "-", "rMin"}], ")"}], "/", "8"}], "u", 
                    " ", 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], "}"}]}], 
                 "}"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", "]"}]}], 
          "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"v", "&&", 
            RowBox[{"u", "\[NotEqual]", "0"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"trolleyControl", ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"Gray", ",", 
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"OptionValue", "[", "Values", "]"}], ",", 
                   RowBox[{"StringForm", "[", 
                    RowBox[{"\"\<u=``\>\"", ",", 
                    RowBox[{"Round", "[", 
                    RowBox[{"u", ",", 
                    SuperscriptBox["10", 
                    RowBox[{"-", "1"}]]}], "]"}]}], "]"}], ",", "\"\<u\>\""}],
                   "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"r", "+", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"rMax", "-", "rMin"}], ")"}], "/", "6"}], "u"}], 
                    "+", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"u", ">", "0"}], ",", ".5", ",", 
                    RowBox[{"-", ".5"}]}], "]"}]}], ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"u", ">", "0"}], ",", 
                    RowBox[{"-", "1"}], ",", "1"}], "]"}], ",", "0"}], "}"}], 
                 ",", 
                 RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"Gray", ",", 
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"OptionValue", "[", "Values", "]"}], ",", 
                   RowBox[{"StringForm", "[", 
                    RowBox[{"\"\<u=``\>\"", ",", 
                    RowBox[{"Round", "[", 
                    RowBox[{"u", ",", 
                    SuperscriptBox["10", 
                    RowBox[{"-", "1"}]]}], "]"}]}], "]"}], ",", "\"\<u\>\""}],
                   "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"r", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"R", "+", "3"}], ")"}], 
                    RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"(", 
                    RowBox[{"R", "+", "3"}], ")"}]}], " ", 
                    RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}], "}"}], ",", 
                 RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], 
              "}"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"v", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Dashed", ",", "Gray", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"r", ",", 
                  RowBox[{
                   RowBox[{"-", "R"}], "-", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"r", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
             RowBox[{"Circle", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"r", ",", "0"}], "}"}], ",", 
               RowBox[{"R", "/", "4"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["\[Pi]", "2"]}], ",", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox["\[Pi]", "2"]}], "+", "\[Theta]"}]}], "}"}]}], 
              "]"}], ",", 
             RowBox[{"Text", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"OptionValue", "[", "Values", "]"}], ",", 
                 RowBox[{"StringForm", "[", 
                  RowBox[{"\"\<\[Theta]=``\>\"", ",", "\[Theta]"}], "]"}], 
                 ",", "\"\<\[Theta]\>\""}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"r", "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"R", "/", "3"}], ")"}], 
                   RowBox[{"Sin", "[", 
                    RowBox[{"\[Theta]", "/", "2"}], "]"}]}]}], ",", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{"R", "/", "3"}], ")"}]}], 
                  RowBox[{"Cos", "[", 
                   RowBox[{"\[Theta]", "/", "2"}], "]"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}]}],
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"v", "&&", "trolleyControl"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Gray", ",", 
             RowBox[{"Text", "[", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"OptionValue", "[", "Values", "]"}], ",", 
                 RowBox[{"StringForm", "[", 
                  RowBox[{"\"\<r=``\>\"", ",", "r"}], "]"}], ",", 
                 "\"\<r\>\""}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"r", ",", 
                 RowBox[{"3", "h"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}], ",", 
               RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}]}],
           "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{"rMin", "-", "5"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "R"}], "/", 
                SqrtBox["3"]}], "-", "5"}]}], "]"}], ",", 
            RowBox[{"Max", "[", 
             RowBox[{
              RowBox[{"rMax", "+", "5"}], ",", 
              RowBox[{
               RowBox[{"R", "/", 
                SqrtBox["3"]}], "+", "5"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "R"}], "-", "3"}], ",", "3"}], "}"}]}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"OptionValue", "[", "Width", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Axes", "\[Rule]", 
        RowBox[{"If", "[", 
         RowBox[{"trolleyControl", ",", 
          RowBox[{"{", 
           RowBox[{"False", ",", "True"}], "}"}], ",", "False"}], "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", "None"}]}], "\[IndentingNewLine]", "]"}]}],
     "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.662910922719364*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Finding solutions for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "0"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " for crane system"
}], "Subsubsection",
 CellChangeTimes->{{3.662910924368523*^9, 3.6629109309121695`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"find3Times", "[", "r0_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "r1", ",", "r2", ",", "rd0", ",", "rd1", ",", "rd2", ",", "x0", ",", 
       "x1", ",", "x2", ",", "y0", ",", "y1", ",", "y2", ",", "s1", ",", "s2",
        ",", "q", ",", "P", ",", "root"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"rd0", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"r1", "[", "T1_", "]"}], "=", 
       RowBox[{"paraDistance", "[", 
        RowBox[{"r0", ",", "rd0", ",", "1", ",", "T1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rd1", "[", "T1_", "]"}], "=", 
       RowBox[{"rd0", "+", 
        RowBox[{"uMax", " ", "T1"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"r2", "[", 
        RowBox[{"T1_", ",", "T2_"}], "]"}], "=", 
       RowBox[{"paraDistance", "[", 
        RowBox[{
         RowBox[{"r1", "[", "T1", "]"}], ",", 
         RowBox[{"rd1", "[", "T1", "]"}], ",", 
         RowBox[{"-", "1"}], ",", "T2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rd2", "[", 
        RowBox[{"T1_", ",", "T2_"}], "]"}], "=", 
       RowBox[{
        RowBox[{"rd1", "[", "T1", "]"}], "-", 
        RowBox[{"uMax", " ", "T2"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"x0", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"y0", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x1", "[", "T1_", "]"}], "=", 
       RowBox[{"sinDistance", "[", 
        RowBox[{"x0", ",", "y0", ",", "1", ",", "T1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"y1", "[", "T1_", "]"}], "=", 
       RowBox[{"dSinDistance", "[", 
        RowBox[{"x0", ",", "y0", ",", "1", ",", "T1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x2", "[", 
        RowBox[{"T1_", ",", "T2_"}], "]"}], "=", 
       RowBox[{"sinDistance", "[", 
        RowBox[{
         RowBox[{"x1", "[", "T1", "]"}], ",", 
         RowBox[{"y1", "[", "T1", "]"}], ",", 
         RowBox[{"-", "1"}], ",", "T2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"y2", "[", 
        RowBox[{"T1_", ",", "T2_"}], "]"}], "=", 
       RowBox[{"dSinDistance", "[", 
        RowBox[{
         RowBox[{"x1", "[", "T1", "]"}], ",", 
         RowBox[{"y1", "[", "T1", "]"}], ",", 
         RowBox[{"-", "1"}], ",", "T2"}], "]"}]}], ";", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"rr0", "+", 
             RowBox[{
              FractionBox["1", "2"], 
              SuperscriptBox["T1", "2"]}], "+", " ", 
             RowBox[{"T1", " ", "T2"}], "-", 
             RowBox[{
              FractionBox["1", "2"], 
              SuperscriptBox["T2", "2"]}]}], "\[Equal]", 
            RowBox[{"rr0", "/", "2"}]}], ",", 
           RowBox[{"{", "T1", "}"}]}], "]"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"s1", "[", "T2_", "]"}], ":=", 
       RowBox[{
        RowBox[{"-", "T2"}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "r0"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["T2", "2"]}]}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"s2", "[", "T2_", "]"}], ":=", 
       RowBox[{
        RowBox[{"-", "T2"}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "r0"}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["T2", "2"]}]}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"-", "T2"}], "-", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "rr0"}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["T2", "2"]}]}]]}], "\[Equal]", "T2"}], ",", 
           "rr0"}], "]"}], "]"}], ";"}], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"P", "=", 
       RowBox[{"2", "\[Pi]", 
        SqrtBox[
         FractionBox[
          RowBox[{"m", " ", "l"}], "g"]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"root", "=", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{"x2", "[", 
          RowBox[{
           RowBox[{"s2", "[", "TT2", "]"}], ",", "TT2"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"TT2", ",", 
           RowBox[{"P", "/", "8"}], ",", "0", ",", 
           RowBox[{"P", "/", "4"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "root", "]"}], ">", "0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"q", "=", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"T1", "\[Rule]", 
              RowBox[{"s2", "[", "TT2", "]"}]}], ",", 
             RowBox[{"T2", "\[Rule]", "TT2"}]}], "}"}], "/.", "root"}]}], ";",
          "\[IndentingNewLine]", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"StringForm", "[", 
            RowBox[{
            "\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\) = ``\>\"", ",", "r0"}], 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Show", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ListPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"x0", ",", "y0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x1", "[", "T1", "]"}], ",", 
                    RowBox[{"y1", "[", "T1", "]"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x2", "[", 
                    RowBox[{"T1", ",", "T2"}], "]"}], ",", 
                    RowBox[{"y2", "[", 
                    RowBox[{"T1", ",", "T2"}], "]"}]}], "}"}]}], "}"}], "/.", 
                "q"}], ",", 
               RowBox[{"PlotRange", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "0.4"}], ",", "0.4"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}]}], "}"}]}], ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"PointSize", "[", "Large", "]"}]}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"ParametricPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"sinDistance", "[", 
                   RowBox[{"x0", ",", "y0", ",", "1", ",", "t"}], "]"}], ",", 
                  RowBox[{"dSinDistance", "[", 
                   RowBox[{"x0", ",", "y0", ",", "1", ",", "t"}], "]"}]}], 
                 "}"}], "/.", "q"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", 
                 RowBox[{"T1", "/.", "q"}]}], "}"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"ParametricPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"sinDistance", "[", 
                   RowBox[{
                    RowBox[{"x1", "[", "T1", "]"}], ",", 
                    RowBox[{"y1", "[", "T1", "]"}], ",", 
                    RowBox[{"-", "1"}], ",", "t"}], "]"}], ",", 
                  RowBox[{"dSinDistance", "[", 
                   RowBox[{
                    RowBox[{"x1", "[", "T1", "]"}], ",", 
                    RowBox[{"y1", "[", "T1", "]"}], ",", 
                    RowBox[{"-", "1"}], ",", "t"}], "]"}]}], "}"}], "/.", 
                "q"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", 
                 RowBox[{"T2", "/.", "q"}]}], "}"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Show", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ListPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"r0", ",", "rd0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"r1", "[", "T1", "]"}], ",", 
                    RowBox[{"rd1", "[", "T1", "]"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"r2", "[", 
                    RowBox[{"T1", ",", "T2"}], "]"}], ",", 
                    RowBox[{"rd2", "[", 
                    RowBox[{"T1", ",", "T2"}], "]"}]}], "}"}]}], "}"}], "/.", 
                "q"}], ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"PointSize", "[", "Large", "]"}]}], ",", 
               RowBox[{"AxesOrigin", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"ParametricPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"r0", "+", 
                   RowBox[{"rd0", " ", "t"}], "+", 
                   RowBox[{
                    FractionBox["1", "2"], "uMax", " ", 
                    SuperscriptBox["t", "2"]}]}], ",", 
                  RowBox[{"rd0", "+", 
                   RowBox[{"uMax", " ", "t"}]}]}], "}"}], "/.", "q"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", 
                 RowBox[{"T1", "/.", "q"}]}], "}"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"ParametricPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"r1", "[", "T1", "]"}], "+", 
                   RowBox[{
                    RowBox[{"rd1", "[", "T1", "]"}], "t"}], "-", 
                   RowBox[{
                    FractionBox["1", "2"], "uMax", " ", 
                    SuperscriptBox["t", "2"]}]}], ",", 
                  RowBox[{
                   RowBox[{"rd1", "[", "T1", "]"}], "-", 
                   RowBox[{"uMax", " ", "t"}]}]}], "}"}], "/.", "q"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", 
                 RowBox[{"T2", "/.", "q"}]}], "}"}]}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", "q", 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x2", "[", 
                RowBox[{
                 RowBox[{"s2", "[", "T2", "]"}], ",", "T2"}], "]"}], ",", 
               RowBox[{"y2", "[", 
                RowBox[{
                 RowBox[{"s2", "[", "T2", "]"}], ",", "T2"}], "]"}]}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"T2", ",", "0", ",", "50"}], "}"}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<\[Theta](\!\(\*SubscriptBox[\(t\), \(2\)]\))\>\"", ",", 
                "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \
\(.\)]\)(\!\(\*SubscriptBox[\(t\), \(2\)]\))\>\""}], "}"}]}], ",", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{
              "{", "\"\<\!\(\*SubscriptBox[\(T\), \(2\)]\)\>\"", "}"}]}], ",", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"300", ",", "200"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", 
              RowBox[{"2", "/", "3"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"s1", "[", "T2", "]"}], ",", 
               RowBox[{"s2", "[", "T2", "]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"T2", ",", 
               RowBox[{"-", "20"}], ",", "50"}], "}"}], ",", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<\!\(\*SubscriptBox[\(T\), \(2\)]\)\>\"", ",", 
                "\"\<\!\(\*SubscriptBox[\(T\), \(1\)]\)\>\""}], "}"}]}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<-\!\(\*SubscriptBox[\(T\), \
\(2\)]\)-\!\(\*SqrtBox[\(\(-\*SubscriptBox[\(r\), \(0\)]\) + 2\\\ \
\*SuperscriptBox[SubscriptBox[\(T\), \(2\)], \(2\)]\)]\)\>\"", ",", 
                "\"\<-\!\(\*SubscriptBox[\(T\), \
\(2\)]\)+\!\(\*SqrtBox[\(\(-\*SubscriptBox[\(r\), \(0\)]\) + 2\\\ \
\*SuperscriptBox[SubscriptBox[\(T\), \(2\)], \(2\)]\)]\)\>\""}], "}"}]}], ",",
              "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"300", ",", "200"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", 
              RowBox[{"2", "/", "3"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s2", "[", "T2", "]"}], "+", "T2"}], ")"}]}], "/.", 
            "q"}]}], "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "find5Times", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"PlotLegends", "\[Rule]", "None"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"find5Times", "[", 
    RowBox[{"rr0_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "r1", ",", "r2", ",", "r3", ",", "s1", ",", "s2", ",", "x0", ",", "x1", 
       ",", "x2", ",", "x3", ",", "sol", ",", "q"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"r1", "=", 
       RowBox[{"paraDistance", "[", 
        RowBox[{"r0", ",", "0", ",", "1", ",", "T1"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"r2", "=", 
       RowBox[{"paraDistance", "[", 
        RowBox[{"r1", ",", 
         RowBox[{"uMax", " ", "T1"}], ",", 
         RowBox[{"-", "1"}], ",", "T2"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"r3", "=", 
       RowBox[{"paraDistance", "[", 
        RowBox[{"r2", ",", 
         RowBox[{"uMax", 
          RowBox[{"(", 
           RowBox[{"T1", "-", "T2"}], ")"}]}], ",", "1", ",", "T1"}], "]"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"FullSimplify", "@", "r3"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"r3", "\[Equal]", 
           RowBox[{"r0", "/", "2"}]}], ",", "T1"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"s1", "[", "T2_", "]"}], ":=", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "r0"}], "+", 
          SuperscriptBox["T2", "2"]}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"s2", "[", "T2_", "]"}], ":=", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "r0"}], "+", 
          SuperscriptBox["T2", "2"]}]]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"s1", "[", "T2", "]"}], ",", 
             RowBox[{"s2", "[", "T2", "]"}]}], "}"}], "/.", 
           RowBox[{"r0", "\[Rule]", 
            RowBox[{"-", "30"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"T2", ",", "0", ",", "10"}], "}"}]}], "]"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"x0", "=", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x1", "[", "T2_", "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "@@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"First", "@", "x0"}], ",", 
            RowBox[{"Last", "@", "x0"}], ",", "1", ",", 
            RowBox[{"s2", "[", "T2", "]"}]}], "}"}]}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"sinDistance", ",", "dSinDistance"}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x2", "[", "T2_", "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "@@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"First", "@", 
             RowBox[{"x1", "[", "T2", "]"}]}], ",", 
            RowBox[{"Last", "@", 
             RowBox[{"x1", "[", "T2", "]"}]}], ",", 
            RowBox[{"-", "1"}], ",", "T2"}], "}"}]}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"sinDistance", ",", "dSinDistance"}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x3", "[", "T2_", "]"}], ":=", 
       RowBox[{"Chop", "@", 
        RowBox[{"FullSimplify", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "@@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"First", "@", 
               RowBox[{"x2", "[", "T2", "]"}]}], ",", 
              RowBox[{"Last", "@", 
               RowBox[{"x2", "[", "T2", "]"}]}], ",", "1", ",", 
              RowBox[{"s2", "[", "T2", "]"}]}], "}"}]}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{"sinDistance", ",", "dSinDistance"}], "}"}]}], "]"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{
           RowBox[{"x3", "[", "T2", "]"}], "/.", 
           RowBox[{"r0", "\[Rule]", "rr0"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"T2", ",", "0", ",", "10"}], "}"}]}], "]"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"First", "[", 
           RowBox[{"x3", "[", "T2", "]"}], "]"}], "/.", 
          RowBox[{"r0", "\[Rule]", "rr0"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"T2", ",", "1", ",", "0", ",", "100"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"q", "=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"T1", "\[Rule]", 
          RowBox[{"s2", "[", "T2", "]"}]}], "}"}], "/.", 
        RowBox[{"r0", "\[Rule]", "rr0"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Most", "@", 
         RowBox[{"finalOc", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "rr0", ",", "0"}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"4", "T1"}], "+", 
              RowBox[{"2", "T2"}]}], "/.", "q"}], "/.", "sol"}], ",", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", "\[IndentingNewLine]", 
             RowBox[{"uFromSwitchTimes", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "T1", ",", "T2", ",", "T1", ",", "T1", ",", "T2", ",", 
                  "T1"}], "}"}], "/.", "q"}], "/.", "sol"}], "]"}]}], 
            "\[IndentingNewLine]", "]"}], ",", 
           RowBox[{"PlotLegends", "\[Rule]", 
            RowBox[{"OptionValue", "[", "PlotLegends", "]"}]}]}], "]"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"x3", "[", "T2", "]"}], "/.", 
              RowBox[{"r0", "\[Rule]", "rr0"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"T2", ",", "0", ",", "35"}], "}"}], ",", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{
              "\"\<\[Theta](\!\(\*SubscriptBox[\(t\), \(3\)]\))\>\"", ",", 
               "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \
\(.\)]\)(\!\(\*SubscriptBox[\(t\), \(3\)]\))\>\""}], "}"}]}], ",", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{
             "{", "\"\<\!\(\*SubscriptBox[\(T\), \(2\)]\)\>\"", "}"}]}], ",", 
            RowBox[{"AspectRatio", "\[Rule]", 
             RowBox[{"2", "/", "3"}]}], ",", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"300", ",", "200"}], "}"}]}]}], "]"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"4", "T1"}], "+", 
             RowBox[{"2", "T2"}]}], "/.", "q"}], "/.", "sol"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.662910941636197*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparing trajectories", "Subsubsection",
 CellChangeTimes->{{3.662910943216318*^9, 3.6629109462324533`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"compareTrajectories", "[", "r0_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f1", ",", "f11", ",", "f2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f1", "=", 
       RowBox[{"find3Times", "[", "r0", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f11", "=", 
       RowBox[{"Most", "@", 
        RowBox[{"finalOc", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
          RowBox[{
          "f1", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], ",", 
          RowBox[{"Function", "[", 
           RowBox[{"t", ",", "\[IndentingNewLine]", 
            RowBox[{"uFromSwitchTimes", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], "/.", 
              RowBox[{
              "f1", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], 
             "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"Placed", "[", 
            RowBox[{
             RowBox[{"{", "\"\<3 switchtijden\>\"", "}"}], ",", "Below"}], 
            "]"}]}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f2", "=", 
       RowBox[{"find5Times", "[", 
        RowBox[{"r0", ",", 
         RowBox[{"PlotLegends", "\[Rule]", 
          RowBox[{"Placed", "[", 
           RowBox[{
            RowBox[{"{", "\"\<5 switchtijden\>\"", "}"}], ",", "Below"}], 
           "]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "f11", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], "/.", 
           RowBox[{
            RowBox[{"_", "?", "ColorQ"}], "\[Rule]", 
            RowBox[{
             RowBox[{"ColorData", "[", 
              RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ",", 
          RowBox[{
           RowBox[{
           "f2", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"_", "?", "ColorQ"}], "\[Rule]", " ", 
             RowBox[{
              RowBox[{"ColorData", "[", 
               RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
              "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "f11", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], "/.", 
           RowBox[{
            RowBox[{"_", "?", "ColorQ"}], "\[Rule]", 
            RowBox[{
             RowBox[{"ColorData", "[", 
              RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ",", 
          RowBox[{
           RowBox[{
           "f2", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"_", "?", "ColorQ"}], "\[Rule]", " ", 
             RowBox[{
              RowBox[{"ColorData", "[", 
               RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
              "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
            "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "f11", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], "/.", 
           RowBox[{
            RowBox[{"_", "?", "ColorQ"}], "\[Rule]", 
            RowBox[{
             RowBox[{"ColorData", "[", 
              RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], ",", 
          RowBox[{
           RowBox[{
           "f2", "\[LeftDoubleBracket]", "6", "\[RightDoubleBracket]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"_", "?", "ColorQ"}], "\[Rule]", " ", 
             RowBox[{
              RowBox[{"ColorData", "[", 
               RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
              "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
            "}"}]}]}], "]"}]}], "\[IndentingNewLine]", "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plotSolveTimes", "[", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r0s", "=", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "100"}], ",", 
         RowBox[{"-", "5"}], ",", "5"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", 
             RowBox[{
              RowBox[{"find3Times", "[", "#", "]"}], "\[LeftDoubleBracket]", 
              "7", "\[RightDoubleBracket]"}]}], "}"}], "&"}], "/@", "r0s"}], 
         ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", 
             RowBox[{
              RowBox[{"find5Times", "[", "#", "]"}], "\[LeftDoubleBracket]", 
              "8", "\[RightDoubleBracket]"}]}], "}"}], "&"}], "/@", "r0s"}]}],
         "}"}], ",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<3 switchtijden\>\"", ",", " ", "\"\<5 switchtijden\>\""}], 
         "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", " ", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\)\>\"", ",", "\"\<T\>\""}], 
         "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"300", ",", "200"}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        RowBox[{"2", "/", "3"}]}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plotSolveTimes2", "[", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r0s", "=", 
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "100"}], ",", 
         RowBox[{"-", "5"}], ",", "5"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLinePlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ParallelMap", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", 
              RowBox[{
               RowBox[{"find3Times", "[", "#", "]"}], "\[LeftDoubleBracket]", 
               "7", "\[RightDoubleBracket]"}]}], "}"}], "&"}], ",", "r0s"}], 
          "]"}], ",", 
         RowBox[{"ParallelMap", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", 
              RowBox[{
               RowBox[{"epsilonOC", "[", 
                RowBox[{"4", ",", 
                 RowBox[{"(", GridBox[{
                    {"0", "1", "0", "0"},
                    {
                    RowBox[{
                    RowBox[{"-", "g"}], "/", "l"}], "0", "0", "0"},
                    {"0", "0", "0", "1"},
                    {"0", "0", "0", "0"}
                   }], ")"}], ",", 
                 RowBox[{"(", GridBox[{
                    {"0"},
                    {
                    RowBox[{
                    RowBox[{"-", "uMax"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"m", " ", "l"}], ")"}]}]},
                    {"0"},
                    {"uMax"}
                   }], ")"}], ",", 
                 SuperscriptBox["10", "6"], ",", "1", ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "#", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "40"}], "}"}], ",", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], "]"}], "\[LeftDoubleBracket]", "7", 
               "\[RightDoubleBracket]"}]}], "}"}], "&"}], ",", "r0s"}], 
          "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<Methode 1\>\"", ",", " ", "\"\<Methode 2\>\""}], 
           "}"}], ",", "Below"}], "]"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", " ", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(r\), \(0\)]\)\>\"", ",", "\"\<T\>\""}], 
         "}"}]}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"300", ",", "200"}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        RowBox[{"2", "/", "3"}]}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6617500691798596`*^9, 3.6617501785029926`*^9}, {
   3.6617502497517834`*^9, 3.661750273071228*^9}, {3.6617700565002337`*^9, 
   3.66177006293077*^9}, {3.6618626606168113`*^9, 3.661862682368267*^9}, {
   3.6618627543918066`*^9, 3.6618627547411013`*^9}, {3.6618632255430346`*^9, 
   3.661863225669772*^9}, {3.6618634166142645`*^9, 3.6618634167316513`*^9}, {
   3.661864307352393*^9, 3.661864307649273*^9}, {3.661865357244912*^9, 
   3.6618653575121984`*^9}, {3.6618712142136364`*^9, 
   3.6618712156636553`*^9}, {3.6618713568993893`*^9, 
   3.6618713574467916`*^9}, {3.6618714052134843`*^9, 
   3.6618714106073027`*^9}, {3.6618715359543304`*^9, 3.661871563495773*^9}, {
   3.6618716086926775`*^9, 3.6618716751295757`*^9}, 3.661872007072898*^9, {
   3.661929867288374*^9, 3.661929931686844*^9}, 3.661930008337953*^9, {
   3.6619302254067025`*^9, 3.6619302365685806`*^9}, {3.661930337743*^9, 
   3.661930412997123*^9}, 3.6619304444853506`*^9, {3.6619304897332916`*^9, 
   3.661930510724098*^9}, {3.661968833111494*^9, 3.6619688973118143`*^9}, {
   3.661968960627509*^9, 3.661968969958107*^9}, {3.6619690046567183`*^9, 
   3.661969024286568*^9}, {3.661969084145819*^9, 3.6619691231423473`*^9}, {
   3.6619691596901464`*^9, 3.661969266743899*^9}, {3.6619693011421804`*^9, 
   3.6619693458227315`*^9}, {3.6620158734165425`*^9, 3.662015893087429*^9}, 
   3.6620162503376255`*^9, {3.6620163019480467`*^9, 3.662016318530754*^9}, {
   3.6620163577114115`*^9, 3.662016361877351*^9}, {3.6620164915138736`*^9, 
   3.662016514069786*^9}, {3.6620167981693335`*^9, 3.66201681525181*^9}, {
   3.66201702628378*^9, 3.6620170782974863`*^9}, {3.6620188678325768`*^9, 
   3.662018984542843*^9}, {3.662019018326621*^9, 3.66201903622393*^9}, {
   3.662019076104412*^9, 3.6620190900169077`*^9}, 3.662019251438798*^9, {
   3.6620192894706917`*^9, 3.662019294514944*^9}, {3.6620193297020264`*^9, 
   3.662019337970579*^9}, {3.662019384415614*^9, 3.662019391887597*^9}, {
   3.662019597343946*^9, 3.6620196001049757`*^9}, {3.6620257837008815`*^9, 
   3.662025794058157*^9}, {3.6620258769082003`*^9, 3.6620258784826565`*^9}, {
   3.662026552283195*^9, 3.662026576842518*^9}, 3.6620266426699862`*^9, {
   3.662026826186532*^9, 3.6620269084045706`*^9}, {3.662027016605951*^9, 
   3.6620270391168413`*^9}, {3.662027102576638*^9, 3.6620271153866806`*^9}, {
   3.6620288830551815`*^9, 3.6620288903523445`*^9}, {3.662048413342513*^9, 
   3.662048413473647*^9}, {3.66204852700159*^9, 3.6620486277366996`*^9}, {
   3.6620486876920233`*^9, 3.6620487484230356`*^9}, {3.662048821011293*^9, 
   3.6620488861522655`*^9}, 3.6620489602996063`*^9, {3.6620490033830194`*^9, 
   3.6620490973743687`*^9}, {3.6620492427880173`*^9, 3.662049244871488*^9}, 
   3.6620492760775166`*^9, {3.662049432788844*^9, 3.662049480189305*^9}, {
   3.662049876534525*^9, 3.662049882529764*^9}, {3.6620499837994833`*^9, 
   3.6620499851694503`*^9}, {3.662050112276176*^9, 3.662050129409277*^9}, {
   3.6620502259504256`*^9, 3.662050259342992*^9}, {3.6620505656384387`*^9, 
   3.662050609648512*^9}, {3.6620506905926447`*^9, 3.6620508623168726`*^9}, {
   3.6620509774971733`*^9, 3.6620509784118195`*^9}, {3.662051178645075*^9, 
   3.6620511955019646`*^9}, {3.6620513956159296`*^9, 
   3.6620514025528316`*^9}, {3.662090888257802*^9, 3.6620909077035294`*^9}, {
   3.6620911889750814`*^9, 3.6620911964243402`*^9}, {3.662092126062577*^9, 
   3.6620921267270513`*^9}, {3.662093505432803*^9, 3.662093505746024*^9}, {
   3.662093961650484*^9, 3.6620939739341617`*^9}, {3.6620965392023168`*^9, 
   3.662096541819154*^9}, {3.662096588399035*^9, 3.662096591534258*^9}, {
   3.662096623326702*^9, 3.662096637894986*^9}, {3.662096695488945*^9, 
   3.662096767403702*^9}, {3.662096822462578*^9, 3.6620968471626863`*^9}, {
   3.662096887040826*^9, 3.662096890101987*^9}, 3.662096967921071*^9, {
   3.6620971065159082`*^9, 3.6620971191238146`*^9}, {3.662097149166004*^9, 
   3.6620972706017466`*^9}, {3.662097317763029*^9, 3.662097371310831*^9}, {
   3.6620974440951986`*^9, 3.6620976200304084`*^9}, {3.662097691327731*^9, 
   3.662097767894781*^9}, {3.6620978908035326`*^9, 3.6620979102752876`*^9}, {
   3.6620979604797287`*^9, 3.6620980141986485`*^9}, {3.6620980600970488`*^9, 
   3.662098069659799*^9}, {3.662098175061204*^9, 3.662098225601879*^9}, {
   3.662098260129243*^9, 3.662098260288355*^9}, {3.6620983337772427`*^9, 
   3.662098336555193*^9}, {3.662098371099595*^9, 3.6620984678919153`*^9}, {
   3.662098506946484*^9, 3.662098644817808*^9}, {3.662110919799115*^9, 
   3.6621109198801727`*^9}, 3.6621140874507093`*^9, {3.66211464717432*^9, 
   3.662114673838214*^9}, {3.662115173418209*^9, 3.662115185922079*^9}, {
   3.662115531383856*^9, 3.6621155410857315`*^9}, 3.662115576823073*^9, {
   3.6621199299494815`*^9, 3.6621199326704097`*^9}, {3.6623866822125125`*^9, 
   3.662386715789461*^9}, {3.662395804984864*^9, 3.662396008379445*^9}, {
   3.6623960607463665`*^9, 3.662396097498943*^9}, {3.6623961467778587`*^9, 
   3.6623962828558517`*^9}, {3.6623964150778785`*^9, 3.662396458203336*^9}, {
   3.662396513452074*^9, 3.6623965135795126`*^9}, {3.6623965436341047`*^9, 
   3.662396660590474*^9}, {3.6623968698128185`*^9, 3.662396870312379*^9}, {
   3.6623971513841257`*^9, 3.6623971515007973`*^9}, {3.6623971981570215`*^9, 
   3.6623972870853386`*^9}, {3.662397320127488*^9, 3.66239733827802*^9}, {
   3.6623974575595627`*^9, 3.662397457622632*^9}, 3.6623974885050898`*^9, {
   3.662440890667824*^9, 3.6624409363431787`*^9}, {3.6624409724648247`*^9, 
   3.6624411126763935`*^9}, {3.6624411697951884`*^9, 
   3.6624412000426936`*^9}, {3.66244129442257*^9, 3.662441295230142*^9}, {
   3.6624425348638716`*^9, 3.6624425357144747`*^9}, {3.6624456340925703`*^9, 
   3.662445636270107*^9}, {3.662448826624366*^9, 3.6624488705154657`*^9}, {
   3.6624613539816294`*^9, 3.66246135415304*^9}, {3.6624619451465745`*^9, 
   3.6624619452453804`*^9}, {3.662462817993928*^9, 3.662462869578537*^9}, {
   3.6624630586030245`*^9, 3.6624630676460185`*^9}, {3.662463141818081*^9, 
   3.6624631992774343`*^9}, {3.6624632427269955`*^9, 3.662463283767668*^9}, {
   3.662463329719535*^9, 3.6624633981917953`*^9}, {3.6624635915819263`*^9, 
   3.6624635970330324`*^9}, {3.6624638195150766`*^9, 3.662463821401824*^9}, {
   3.662464218461467*^9, 3.662464221494892*^9}, {3.662464265486861*^9, 
   3.6624642691229525`*^9}, {3.6624644486756945`*^9, 3.662464466605278*^9}, {
   3.6624645279934216`*^9, 3.6624645286638494`*^9}, {3.6624650227099905`*^9, 
   3.662465046910739*^9}, {3.6624653915512395`*^9, 3.6624654033546295`*^9}, {
   3.662465488101718*^9, 3.662465542964334*^9}, {3.6624671108918514`*^9, 
   3.66246711912082*^9}, {3.6624671530150614`*^9, 3.6624671557346697`*^9}, {
   3.662467222449964*^9, 3.6624672231103096`*^9}, {3.662467555946046*^9, 
   3.6624675636596518`*^9}, 3.662467595630372*^9, 3.6624676271392903`*^9, {
   3.6624676622981195`*^9, 3.6624676876243916`*^9}, {3.662468441422201*^9, 
   3.6624685029161663`*^9}, {3.6624685426253424`*^9, 3.662468569414118*^9}, {
   3.6624686246911044`*^9, 3.6624686268536377`*^9}, {3.662468670984956*^9, 
   3.66246867952396*^9}, {3.6624689032314177`*^9, 3.662468962189908*^9}, {
   3.6624696593142624`*^9, 3.6624699773141947`*^9}, 3.662470304758705*^9, {
   3.6624706114320107`*^9, 3.662470666650137*^9}, {3.6624717431477065`*^9, 
   3.6624717432678027`*^9}, {3.6625504191505156`*^9, 
   3.6625504246183724`*^9}, {3.6625512665407486`*^9, 3.662551364985505*^9}, {
   3.6625527481051707`*^9, 3.6625527956278563`*^9}, {3.6625528341891804`*^9, 
   3.662552834385309*^9}, 3.6625528729669275`*^9, {3.662552972512848*^9, 
   3.662553008204139*^9}, {3.6627078364419293`*^9, 3.662707836770161*^9}, 
   3.6627078907804317`*^9, {3.662710039801504*^9, 3.662710065260544*^9}, {
   3.6627157749021626`*^9, 3.662715780237954*^9}, {3.662715846986253*^9, 
   3.662715848647416*^9}, {3.662716761468002*^9, 3.6627168431628895`*^9}, {
   3.662716914519457*^9, 3.6627169304927607`*^9}, {3.6627198627997055`*^9, 
   3.6627199235051165`*^9}, {3.662720016145392*^9, 3.662720113537964*^9}, {
   3.6627210140449095`*^9, 3.6627210199363365`*^9}, {3.6627211239787693`*^9, 
   3.662721127405961*^9}, {3.662721199035917*^9, 3.662721208682125*^9}, {
   3.662721474350868*^9, 3.662721478279577*^9}, {3.6627215345038776`*^9, 
   3.6627215347185354`*^9}, {3.662723232884014*^9, 3.662723288878706*^9}, {
   3.6627233268261747`*^9, 3.6627233562745676`*^9}, {3.6627234086241517`*^9, 
   3.6627234167710886`*^9}, {3.6627234509241643`*^9, 3.662723508686507*^9}, {
   3.6627235572683635`*^9, 3.6627235577589383`*^9}, {3.6627235965442305`*^9, 
   3.662723633672469*^9}, {3.6627242725647993`*^9, 3.6627243075128107`*^9}, {
   3.662724848395135*^9, 3.6627248695342264`*^9}, {3.6627249050244446`*^9, 
   3.662724968801895*^9}, 3.6627250412801456`*^9, 3.662725073913042*^9, {
   3.6627257561313653`*^9, 3.6627257573767242`*^9}, {3.6627336145057936`*^9, 
   3.662733691233162*^9}, {3.66273381882704*^9, 3.6627338188640647`*^9}, {
   3.6627339583158894`*^9, 3.6627339613440256`*^9}, {3.6627345831654587`*^9, 
   3.6627346116946745`*^9}, {3.6627346977466493`*^9, 3.662734728139186*^9}, {
   3.6627358809536595`*^9, 3.6627358944412165`*^9}, {3.662736322491853*^9, 
   3.662736323919443*^9}, {3.6627393916152287`*^9, 3.662739398990731*^9}, {
   3.662822690666644*^9, 3.662822690762416*^9}, {3.662822798101589*^9, 
   3.662822867172629*^9}, {3.662823006967659*^9, 3.6628230166105275`*^9}, {
   3.6628230556481733`*^9, 3.6628231607259426`*^9}, {3.662823253469039*^9, 
   3.6628233029296703`*^9}, {3.662823378793244*^9, 3.6628233898970213`*^9}, {
   3.6628234290374603`*^9, 3.662823746843974*^9}, {3.662823904509034*^9, 
   3.6628240245812397`*^9}, {3.662824072254754*^9, 3.662824119236082*^9}, {
   3.6628333532848005`*^9, 3.6628334693754187`*^9}, {3.6628335099972496`*^9, 
   3.662833539033514*^9}, {3.6628335715806427`*^9, 3.6628336558568983`*^9}, {
   3.6628337094820113`*^9, 3.662833962010317*^9}, {3.662834036696701*^9, 
   3.662834082902586*^9}, {3.662834149801958*^9, 3.6628341506861024`*^9}, {
   3.6628341927705216`*^9, 3.662834223783763*^9}, {3.6628342578867874`*^9, 
   3.662834263672432*^9}, {3.6628343513455267`*^9, 3.662834358753976*^9}, {
   3.6628347945038347`*^9, 3.6628347992448263`*^9}, {3.66283491065259*^9, 
   3.6628349218399053`*^9}, {3.662834954608799*^9, 3.6628349637435265`*^9}, {
   3.6628350540490084`*^9, 3.6628351492225666`*^9}, {3.6628352404363728`*^9, 
   3.6628352554714313`*^9}, {3.66283530018216*^9, 3.6628354424624295`*^9}, {
   3.6628354957884293`*^9, 3.662835510255189*^9}, 3.6628355513880186`*^9, {
   3.6628726538063765`*^9, 3.662872653861416*^9}, {3.6628727022617116`*^9, 
   3.6628727388556414`*^9}, 3.6628728555581083`*^9, {3.6628754513088245`*^9, 
   3.662875459592678*^9}, {3.662877114296461*^9, 3.662877174626711*^9}, {
   3.6628772313859205`*^9, 3.6628772358794713`*^9}, {3.66287738760378*^9, 
   3.6628774072985888`*^9}, {3.6628775075605044`*^9, 3.66287751705836*^9}, {
   3.662879243246237*^9, 3.6628792632553024`*^9}, {3.662880579066125*^9, 
   3.6628805843876867`*^9}, {3.662880861167446*^9, 3.6628808628740273`*^9}, {
   3.662881157666187*^9, 3.662881200985945*^9}, {3.662884853717659*^9, 
   3.6628848586191425`*^9}, {3.6628850329602146`*^9, 
   3.6628850376585445`*^9}, {3.662887417056095*^9, 3.6628874758780727`*^9}, {
   3.6628904762756815`*^9, 3.6628904804397593`*^9}, {3.662902534652672*^9, 
   3.6629025550421195`*^9}, {3.6629026037896614`*^9, 
   3.6629026053747845`*^9}, {3.662905957448743*^9, 3.662906000521263*^9}, 
   3.662910362803999*^9, {3.662910495165788*^9, 3.662910511903649*^9}, 
   3.662910570450445*^9, 3.662910674767359*^9, {3.662910803660001*^9, 
   3.662910941636197*^9}, {3.6629143328990955`*^9, 3.662914346771489*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Calculations", "Chapter"]], "Title",
 CellChangeTimes->{{3.6618640443536067`*^9, 3.661864045409579*^9}, {
  3.662386683916353*^9, 3.662386687466555*^9}}],

Cell["\<\
The calculations below use the functions defined above to create exportable \
figures.\
\>", "Text",
 CellChangeTimes->{{3.6629956226685543`*^9, 3.662995640588222*^9}, {
  3.662995683204376*^9, 3.6629957007157617`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Try controlling with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "=", 
    SubscriptBox["\[Alpha]p", "2"]}], TraditionalForm]]],
 " and finding ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "i"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6618656037218995`*^9, 3.6618656344593477`*^9}, {
  3.6620270506729994`*^9, 3.6620270610183125`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"u", "[", 
         RowBox[{"t_", ",", "x2_"}], "]"}], ":=", 
        TagBox[GridBox[{
           {"\[Piecewise]", GridBox[{
              {
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"Sign", "[", "x2", "]"}], "3"]}], 
               RowBox[{"0", "<", "t", "<", "10"}]},
              {"0", "True"}
             },
             AllowedDimensions->{2, Automatic},
             Editable->True,
             
             GridBoxAlignment->{
              "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{1.}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.84]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}},
             Selectable->True]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.35]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         "Piecewise",
         DeleteWithContents->True,
         Editable->False,
         SelectWithContents->True,
         Selectable->False]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"k", "=", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"l", "=", "5"}], ",", "\[IndentingNewLine]", 
       RowBox[{"g", "=", "9.81"}], ",", "\[IndentingNewLine]", 
       RowBox[{"w", "=", 
        SqrtBox[
         FractionBox["g", "l"]]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"Good", " ", 
           RowBox[{"valued", ":", " ", "p10"}]}], "=", "0.0035`"}], ",", " ", 
         RowBox[{"p20", "=", "0.0185`"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"x10", "=", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{"x20", "=", "1"}], ",", "\[IndentingNewLine]", "sol", ",", 
       "pp1", ",", "pp2"}], "\[IndentingNewLine]", "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sol", "=", 
       RowBox[{"First", "@", 
        RowBox[{"DSolve", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", GridBox[{
                 {
                  RowBox[{
                   RowBox[{"x1", "'"}], "[", "t", "]"}]},
                 {
                  RowBox[{
                   RowBox[{"x2", "'"}], "[", "t", "]"}]},
                 {
                  RowBox[{
                   RowBox[{"p1", "'"}], "[", "t", "]"}]},
                 {
                  RowBox[{
                   RowBox[{"p2", "'"}], "[", "t", "]"}]}
                }], ")"}], "\[Equal]", 
              RowBox[{
               RowBox[{
                RowBox[{"(", GridBox[{
                   {"0", "1", "0", "0"},
                   {
                    RowBox[{
                    RowBox[{"-", "g"}], "/", "l"}], "0", "0", 
                    RowBox[{"-", "1"}]},
                   {"0", "0", "0", 
                    RowBox[{"g", "/", "l"}]},
                   {"0", "0", 
                    RowBox[{"-", "1"}], "0"}
                  }], ")"}], ".", 
                RowBox[{"(", GridBox[{
                   {
                    RowBox[{"x1", "[", "t", "]"}]},
                   {
                    RowBox[{"x2", "[", "t", "]"}]},
                   {
                    RowBox[{"p1", "[", "t", "]"}]},
                   {
                    RowBox[{"p2", "[", "t", "]"}]}
                  }], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", GridBox[{
                   {"0"},
                   {"1"},
                   {"0"},
                   {"0"}
                  }], ")"}], "*", "0"}]}]}], ")"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"x1", "[", "0", "]"}], "\[Equal]", "x10"}], ",", 
            RowBox[{
             RowBox[{"x2", "[", "0", "]"}], "\[Equal]", "x20"}], ",", 
            RowBox[{
             RowBox[{"x1", "[", "T", "]"}], "\[Equal]", "0"}], ",", 
            RowBox[{
             RowBox[{"x2", "[", "T", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x1", ",", "x2", ",", "p1", ",", "p2"}], "}"}], ",", "t"}],
          "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pp1", "[", "t_", "]"}], ":=", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "T"}]], 
         RowBox[{"Sin", "[", 
          RowBox[{
           SqrtBox[
            FractionBox["g", "l"]], "t"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"p1", "[", "0", "]"}], 
         RowBox[{"Cos", "[", 
          RowBox[{
           SqrtBox[
            FractionBox["g", "l"]], "t"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"pp2", "[", "t_", "]"}], ":=", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", "2"}], 
           RowBox[{"p1", "[", "0", "]"}]}], "3"], 
         RowBox[{"Sin", "[", 
          RowBox[{
           SqrtBox[
            FractionBox["g", "l"]], "t"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"p2", "[", "0", "]"}], 
         RowBox[{"Cos", "[", 
          RowBox[{
           SqrtBox[
            FractionBox["g", "l"]], "t"}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p1", "[", "t", "]"}], "/.", "sol"}], "/.", 
            RowBox[{"t", "\[Rule]", "0"}]}], "]"}], ",", 
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"p2", "[", "t", "]"}], "/.", "sol"}], "/.", 
            RowBox[{"t", "\[Rule]", "0"}]}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x1", "[", "t", "]"}], ",", 
              RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], 
           "\[IndentingNewLine]", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", ".5"}], ",", "1"}], "}"}]}]}], 
         "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"p1", "[", "t", "]"}], ",", 
              RowBox[{"p2", "[", "t", "]"}], ",", 
              RowBox[{"pp1", "[", "t", "]"}], ",", 
              RowBox[{"pp2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], 
           "\[IndentingNewLine]", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", "4"}], "}"}]}]}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"TrigToExp", "@", 
            RowBox[{"Chop", "@", 
             RowBox[{"Evaluate", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"p1", "[", "t", "]"}], ",", 
                 RowBox[{"p2", "[", "t", "]"}], ",", 
                 RowBox[{"pp1", "[", "t", "]"}], ",", 
                 RowBox[{"pp2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], 
              "]"}]}]}]}], "*)"}], "\[IndentingNewLine]", "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"T", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6569160413504667`*^9, 3.6569161827614155`*^9}, {
   3.656916257148992*^9, 3.656916368501698*^9}, {3.656916414223013*^9, 
   3.656916421200944*^9}, {3.656916465562299*^9, 3.65691650969349*^9}, {
   3.6569165646012993`*^9, 3.6569166247328005`*^9}, 3.6569167511331425`*^9, {
   3.6569172666687193`*^9, 3.6569172677845097`*^9}, {3.656933688667467*^9, 
   3.6569336978609657`*^9}, {3.6569337377201495`*^9, 3.656933780156065*^9}, {
   3.656933839780196*^9, 3.656933840567752*^9}, {3.6569338926685896`*^9, 
   3.656933901786024*^9}, {3.656933990524753*^9, 3.656933990639835*^9}, {
   3.656934210817194*^9, 3.656934232713681*^9}, {3.6569342683638673`*^9, 
   3.656934317252434*^9}, 3.656934347689947*^9, {3.6569344208423986`*^9, 
   3.656934471793411*^9}, {3.6569345021568727`*^9, 3.6569345061907234`*^9}, {
   3.6569345631139574`*^9, 3.6569345742017937`*^9}, {3.6569346269570813`*^9, 
   3.656934632549033*^9}, {3.6569346820890923`*^9, 3.6569347229819956`*^9}, {
   3.656934806262848*^9, 3.65693481162665*^9}, {3.6569351740107727`*^9, 
   3.656935176353428*^9}, {3.6571827851404486`*^9, 3.657182795394915*^9}, {
   3.6571829232384105`*^9, 3.657182946757606*^9}, {3.6571829819735327`*^9, 
   3.65718299029912*^9}, {3.6571830235481215`*^9, 3.6571830594925237`*^9}, {
   3.6571831198843546`*^9, 3.6571832035772943`*^9}, {3.657183261611636*^9, 
   3.6571833073879747`*^9}, {3.6571836368505306`*^9, 3.657183690187301*^9}, {
   3.6571837359710555`*^9, 3.6571838773160486`*^9}, {3.657183911636139*^9, 
   3.657183919261925*^9}, {3.6571840612684646`*^9, 3.6571840911880655`*^9}, {
   3.657184124957139*^9, 3.6571841295484805`*^9}, {3.6571841673954487`*^9, 
   3.6571841854124813`*^9}, {3.6571842890773726`*^9, 3.657184326101969*^9}, {
   3.657184393516842*^9, 3.6571843936775002`*^9}, {3.657184754211376*^9, 
   3.6571848540326185`*^9}, {3.657184894307849*^9, 3.657184897792941*^9}, {
   3.6571850180574555`*^9, 3.657185054848668*^9}, {3.6571851557477293`*^9, 
   3.6571851574720125`*^9}, {3.6571851981648293`*^9, 
   3.6571852059871106`*^9}, {3.657185239067772*^9, 3.657185297178646*^9}, {
   3.6571853279547615`*^9, 3.657185447475335*^9}, {3.657185515240858*^9, 
   3.657185694983692*^9}, {3.657185785634753*^9, 3.6571857923450556`*^9}, {
   3.657185865628213*^9, 3.657185868134763*^9}, {3.657185900906483*^9, 
   3.6571859275658913`*^9}, {3.6618654959990053`*^9, 3.6618655942150483`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{DifferentialEquations`NDSolveProblems`T$$ = 1, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[DifferentialEquations`NDSolveProblems`T$$], 1, 10}}, 
    Typeset`size$$ = {903., {113., 117.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, 
    DifferentialEquations`NDSolveProblems`T$1915126$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {DifferentialEquations`NDSolveProblems`T$$ = 1}, 
      "ControllerVariables" :> {
        Hold[
        DifferentialEquations`NDSolveProblems`T$$, 
         DifferentialEquations`NDSolveProblems`T$1915126$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      DynamicModule[{$CellContext`k = 1, $CellContext`l = 5, $CellContext`g = 
         9.81, $CellContext`w = 
         Sqrt[$CellContext`g/$CellContext`l], $CellContext`x10 = 
         0, $CellContext`x20 = 
         1, $CellContext`sol, $CellContext`pp1, $CellContext`pp2}, \
$CellContext`sol = First[
           DSolve[{{{
                Derivative[1][$CellContext`x1][$CellContext`t]}, {
                Derivative[1][$CellContext`x2][$CellContext`t]}, {
                Derivative[1][$CellContext`p1][$CellContext`t]}, {
                Derivative[1][$CellContext`p2][$CellContext`t]}} == 
             Dot[{{0, 1, 0, 
                 0}, {(-$CellContext`g)/$CellContext`l, 0, 0, -1}, {
                 0, 0, 0, $CellContext`g/$CellContext`l}, {0, 0, -1, 0}}, {{
                  $CellContext`x1[$CellContext`t]}, {
                  $CellContext`x2[$CellContext`t]}, {
                  $CellContext`p1[$CellContext`t]}, {
                  $CellContext`p2[$CellContext`t]}}] - {{0}, {1}, {0}, {0}} 
              0, $CellContext`x1[0] == $CellContext`x10, $CellContext`x2[
              0] == $CellContext`x20, $CellContext`x1[
              DifferentialEquations`NDSolveProblems`T$$] == 
             0, $CellContext`x2[DifferentialEquations`NDSolveProblems`T$$] == 
             0}, {$CellContext`x1, $CellContext`x2, $CellContext`p1, \
$CellContext`p2}, $CellContext`t]]; $CellContext`pp1[
           Pattern[$CellContext`t$, 
            Blank[]]] := 
         E^(-DifferentialEquations`NDSolveProblems`T$$) 
           Sin[Sqrt[$CellContext`g/$CellContext`l] $CellContext`t$] + \
$CellContext`p1[0] 
           Cos[Sqrt[$CellContext`g/$CellContext`l] $CellContext`t$]; \
$CellContext`pp2[
           Pattern[$CellContext`t, 
            Blank[]]] := ((-2) ($CellContext`p1[0]/3)) 
           Sin[Sqrt[$CellContext`g/$CellContext`l] $CellContext`t] + \
$CellContext`p2[0] Cos[Sqrt[$CellContext`g/$CellContext`l] $CellContext`t]; {{
           Re[
            ReplaceAll[
             ReplaceAll[
              $CellContext`p1[$CellContext`t], $CellContext`sol], \
$CellContext`t -> 0]], 
           Re[
            ReplaceAll[
             ReplaceAll[
              $CellContext`p2[$CellContext`t], $CellContext`sol], \
$CellContext`t -> 0]]}, 
          Plot[
           Evaluate[
            ReplaceAll[{
              $CellContext`x1[$CellContext`t], 
              $CellContext`x2[$CellContext`t]}, $CellContext`sol]], \
{$CellContext`t, 0, DifferentialEquations`NDSolveProblems`T$$}, ImageSize -> 
           Medium, PlotRange -> {-0.5, 1}], 
          Plot[
           Evaluate[
            ReplaceAll[{
              $CellContext`p1[$CellContext`t], 
              $CellContext`p2[$CellContext`t], 
              $CellContext`pp1[$CellContext`t], 
              $CellContext`pp2[$CellContext`t]}, $CellContext`sol]], \
{$CellContext`t, 0, DifferentialEquations`NDSolveProblems`T$$}, ImageSize -> 
           Medium, PlotRange -> {-2, 4}]}], 
      "Specifications" :> {{
        DifferentialEquations`NDSolveProblems`T$$, 1, 10}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{954., {158., 165.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.6618655364957438`*^9, {3.6618655884920454`*^9, 3.661865636941738*^9}, 
   3.661929685493045*^9, 3.6619297747080355`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["x", "."], "=", "Hx"}], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "=", 
    SubscriptBox["\[Alpha]p", "2"]}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6619684950673304`*^9, 3.6619685125797033`*^9}, {
  3.662016849365892*^9, 3.662016880876135*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"epsilonOC", "[", 
     RowBox[{"2", ",", 
      RowBox[{"(", GridBox[{
         {"0", "1"},
         {
          RowBox[{
           RowBox[{"-", "g"}], "/", "l"}], "0"}
        }], ")"}], ",", 
      RowBox[{"(", GridBox[{
         {"0"},
         {
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"m", " ", "l"}], ")"}]}]}
        }], ")"}], ",", 
      SuperscriptBox["10", "#"], ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "#"}]], ",", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", 
        RowBox[{"-", "0.2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "40"}], "}"}], ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "2"}]]}], "]"}], "&"}], "/@", 
   RowBox[{"N", "@", 
    RowBox[{"Range", "[", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", "6", ",", 
      RowBox[{"1", "/", "2"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6621152436299596`*^9, 3.662115338028858*^9}, 
   3.662115423290279*^9, 3.662115501415622*^9, {3.6621155499760313`*^9, 
   3.6621155574603343`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
\\\"0.15625126256623492`\\\", \\\"}\\\"}]\\)\[NoBreak] lies outside the range \
of data in the interpolating function. Extrapolation will be used. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.662115582640175*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
\\\"0.15625126256623492`\\\", \\\"}\\\"}]\\)\[NoBreak] lies outside the range \
of data in the interpolating function. Extrapolation will be used. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.662115582671199*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \[NoBreak]\\!\\(\\*RowBox[{\\\"{\\\", \
\\\"0.15625731802068732`\\\", \\\"}\\\"}]\\)\[NoBreak] lies outside the range \
of data in the interpolating function. Extrapolation will be used. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/InterpolatingFunction/dmval\\\", \
ButtonNote -> \\\"InterpolatingFunction::dmval\\\"]\\)\"\>"}]], "Message", \
"MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.6621155827092266`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], ":", 
  " ", "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \
\\\"::\\\", \\\"dmval\\\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be \
suppressed during this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\
\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.6621155827502537`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3.1622776601683795`", ",", "0.31622776601683794`", ",", "10.`", ",", 
   "6.1326377402043954`", ",", "0.282264715460006`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.662115582817301*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10.`", ",", "0.1`", ",", "100.`", ",", "6.168163506210248`", ",", 
   "0.2822560951647235`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.6621155832506075`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "31.622776601683793`", ",", "0.03162277660168379`", ",", 
   "1000.0000000000001`", ",", "6.280505842410924`", ",", 
   "0.06350513801807046`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.6621155838310184`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\[NoBreak]\\!\\(\\*RowBox[{\\\"4.6969117923268175`\\\"}]\\)\[NoBreak] \
indicates that the boundary values are not satisfied to specified tolerances. \
Returning the best solution found. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NDSolve\\\", ButtonNote -> \
\\\"NDSolve::berr\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.6621155845805516`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\[NoBreak]\\!\\(\\*RowBox[{\\\"5.085763364044996`\\\"}]\\)\[NoBreak] \
indicates that the boundary values are not satisfied to specified tolerances. \
Returning the best solution found. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NDSolve\\\", ButtonNote -> \
\\\"NDSolve::berr\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.6621155847016354`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100.`", ",", "0.01`", ",", "10000.`", ",", "6.635763502469447`", ",", 
   "0.011888467722046128`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.662115584703639*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "316.22776601683796`", ",", "0.0031622776601683794`", ",", "100000.`", ",", 
   "7.759186864476209`", ",", "0.001193517684294561`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.662115585325078*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\[NoBreak]\\!\\(\\*RowBox[{\\\"3.9895768034239394`\\\"}]\\)\[NoBreak] \
indicates that the boundary values are not satisfied to specified tolerances. \
Returning the best solution found. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NDSolve\\\", ButtonNote -> \
\\\"NDSolve::berr\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.6621155859545236`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \
\\\"berr\\\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during \
this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.662115339327768*^9, 3.662115423768601*^9, 3.662115503688231*^9, {
   3.662115558958394*^9, 3.662115586026576*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000.`", ",", "0.001`", ",", "1.`*^6", ",", "11.311763465061448`", ",", 
   "0.00011900441825226666`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.6621155861126356`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3162.2776601683795`", ",", "0.00031622776601683794`", ",", "1.`*^7", ",", 
   "22.545997085129066`", ",", "0.000011899141642359336`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.6621155867570915`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10000.`", ",", "0.0001`", ",", "1.`*^8", ",", "90.14995978062747`", ",", 
   "1.2755236125618173`*^-6"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.6621155874725995`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "31622.776601683792`", ",", "0.000031622776601683795`", ",", 
   "9.999999999999999`*^8", ",", "776.3303429671373`", ",", 
   "2.080636484240389`*^-7"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6621153390065403`*^9, 3.6621154234834013`*^9, 3.6621155034540663`*^9, {
   3.6621155586822004`*^9, 3.6621155883091927`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100000.`", ",", "0.00001`", ",", "9.999999999999998`*^9", ",", 
   "7386.943990295161`", ",", "1.0106641225140991`*^-7"}], "}"}]], "Print",
 CellChangeTimes->{3.6621153390065403`*^9, 3.6621154234834013`*^9, 
  3.6621155034540663`*^9, 3.6621155586822004`*^9, 3.6621155896171203`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "316227.7660168379`", ",", "3.162277660168379`*^-6", ",", "1.`*^11", ",", 
   "72698.74735456026`", ",", "8.424530466665314`*^-8"}], "}"}]], "Print",
 CellChangeTimes->{3.6621153390065403`*^9, 3.6621154234834013`*^9, 
  3.6621155034540663`*^9, 3.6621155586822004`*^9, 3.6621155909670753`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/NDSolve\\\", ButtonNote -> \\\"NDSolve::bvluc\\\"]\
\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.662115339327768*^9, 3.662115423768601*^9, 
  3.662115503688231*^9, 3.662115558958394*^9, 3.6621155912352657`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/NDSolve\\\", ButtonNote -> \\\"NDSolve::bvluc\\\"]\
\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.662115339327768*^9, 3.662115423768601*^9, 
  3.662115503688231*^9, 3.662115558958394*^9, 3.662115591392378*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/NDSolve\\\", ButtonNote -> \\\"NDSolve::bvluc\\\"]\
\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.662115339327768*^9, 3.662115423768601*^9, 
  3.662115503688231*^9, 3.662115558958394*^9, 3.66211559155149*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \
\\\"bvluc\\\"}], \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during \
this calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.662115339327768*^9, 3.662115423768601*^9, 
  3.662115503688231*^9, 3.662115558958394*^9, 3.662115591580511*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.`*^6", ",", "1.`*^-6", ",", "1.`*^12", ",", "723304.8791518406`", ",", 
   "8.524931016391723`*^-8"}], "}"}]], "Print",
 CellChangeTimes->{3.6621153390065403`*^9, 3.6621154234834013`*^9, 
  3.6621155034540663`*^9, 3.6621155586822004`*^9, 3.6621155924581323`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Drop", "[", 
    RowBox[{
     RowBox[{"epsilonOC", "[", 
      RowBox[{"2", ",", 
       RowBox[{"(", GridBox[{
          {"0", "1"},
          {
           RowBox[{
            RowBox[{"-", "g"}], "/", "l"}], "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0"},
          {
           RowBox[{"1", "/", 
            RowBox[{"(", 
             RowBox[{"m", " ", "l"}], ")"}]}]}
         }], ")"}], ",", 
       SuperscriptBox["10", "4"], ",", "1", ",", 
       RowBox[{"{", 
        RowBox[{"0.2", ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "40"}], "}"}], ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "2"}]]}], "]"}], ",", 
     RowBox[{"-", "2"}]}], "]"}], ",", "\"\<s4\>\"", ",", "True"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Drop", "[", 
    RowBox[{
     RowBox[{"epsilonOC", "[", 
      RowBox[{"4", ",", 
       RowBox[{"(", GridBox[{
          {"0", "1", "0", "0"},
          {
           RowBox[{
            RowBox[{"-", "g"}], "/", "l"}], "0", "0", "0"},
          {"0", "0", "0", "1"},
          {"0", "0", "0", "0"}
         }], ")"}], ",", 
       RowBox[{"(", GridBox[{
          {"0"},
          {
           RowBox[{
            RowBox[{"-", "uMax"}], "/", 
            RowBox[{"(", 
             RowBox[{"m", " ", "l"}], ")"}]}]},
          {"0"},
          {"uMax"}
         }], ")"}], ",", 
       SuperscriptBox["10", "6"], ",", "1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"-", "30"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "40"}], "}"}], ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "2"}]]}], "]"}], ",", 
     RowBox[{"-", "2"}]}], "]"}], ",", "\"\<s18\>\"", ",", "True"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.65743572442144*^9, 3.6574358886536665`*^9}, {
   3.6574359275822163`*^9, 3.657436333242579*^9}, {3.657436367965153*^9, 
   3.657436677803413*^9}, 3.6574367104655275`*^9, {3.6574370642109776`*^9, 
   3.657437164019628*^9}, {3.657437301790517*^9, 3.6574373981867247`*^9}, {
   3.657437656001189*^9, 3.6574377641447277`*^9}, {3.6574379222015657`*^9, 
   3.657437977750889*^9}, {3.657438009812568*^9, 3.6574381431589518`*^9}, {
   3.65743824969435*^9, 3.657438252874596*^9}, {3.65743830596588*^9, 
   3.657438418960845*^9}, {3.6574384515409017`*^9, 3.6574384544279327`*^9}, {
   3.657438584439954*^9, 3.657438597422141*^9}, 3.6574386333645773`*^9, {
   3.6574389245856714`*^9, 3.6574389585957403`*^9}, {3.6574390108247027`*^9, 
   3.657439020805766*^9}, {3.6574390590068007`*^9, 3.65743913017934*^9}, {
   3.6574392300600257`*^9, 3.657439232453719*^9}, {3.657439271144099*^9, 
   3.6574392714513245`*^9}, {3.6574393511227007`*^9, 3.657439362130498*^9}, {
   3.6574394025370855`*^9, 3.6574394401132565`*^9}, {3.657439533839587*^9, 
   3.6574395784491563`*^9}, {3.657439705639179*^9, 3.657439721987748*^9}, {
   3.6574397608662624`*^9, 3.6574397646729565`*^9}, {3.657439869533171*^9, 
   3.6574398714305086`*^9}, {3.657439944430173*^9, 3.6574400164171143`*^9}, {
   3.657440071691231*^9, 3.6574401586147375`*^9}, {3.6574453956944027`*^9, 
   3.657445399328985*^9}, {3.6574455281341395`*^9, 3.6574455292549334`*^9}, {
   3.657445604959509*^9, 3.657445606744776*^9}, {3.657445832720693*^9, 
   3.6574458327967467`*^9}, {3.6574458874524274`*^9, 3.657445900720808*^9}, 
   3.6574459315396166`*^9, {3.65753043537073*^9, 3.65753045365567*^9}, {
   3.6575306169102173`*^9, 3.6575306353933*^9}, {3.6575306737444396`*^9, 
   3.6575307455562444`*^9}, {3.657535551833602*^9, 3.6575357294117737`*^9}, {
   3.657535849878935*^9, 3.6575358499689956`*^9}, {3.6575360759729214`*^9, 
   3.657536076914588*^9}, {3.657536309106909*^9, 3.6575363337253313`*^9}, {
   3.6575364575819836`*^9, 3.657536459309205*^9}, {3.657537616299739*^9, 
   3.657537752838337*^9}, {3.6575378175681458`*^9, 3.657537846827853*^9}, {
   3.6575378874926414`*^9, 3.657537965205628*^9}, {3.657538074110699*^9, 
   3.6575380765664372`*^9}, {3.657538266713524*^9, 3.657538298970342*^9}, {
   3.657538340975069*^9, 3.6575383798425913`*^9}, {3.6575386737365613`*^9, 
   3.657538675806042*^9}, {3.6575387494491425`*^9, 3.6575387533148937`*^9}, {
   3.6575388384111004`*^9, 3.6575388384911575`*^9}, {3.657538902567504*^9, 
   3.657538925848989*^9}, {3.6575397300914164`*^9, 3.657539774844103*^9}, {
   3.657539832873962*^9, 3.6575398357560015`*^9}, {3.6575401028790426`*^9, 
   3.657540124814555*^9}, 3.6575403200176992`*^9, {3.6576016652178144`*^9, 
   3.657601667951747*^9}, {3.6576017164250526`*^9, 3.657601748276594*^9}, {
   3.6576017900631666`*^9, 3.6576018068970776`*^9}, {3.65760885762536*^9, 
   3.6576088745933676`*^9}, {3.6576091160272255`*^9, 
   3.6576091340099525`*^9}, {3.657609303174424*^9, 3.6576093626469193`*^9}, {
   3.657609483037101*^9, 3.6576094837015705`*^9}, 3.6576096473666067`*^9, 
   3.657609742607833*^9, 3.657609880399347*^9, {3.657610117219554*^9, 
   3.657610171110712*^9}, {3.6576108874730406`*^9, 3.6576108924655743`*^9}, 
   3.6576111925601325`*^9, {3.6576112364472055`*^9, 3.657611256930689*^9}, 
   3.657611353133769*^9, {3.65761156619355*^9, 3.6576115670271397`*^9}, {
   3.657611904395282*^9, 3.6576119186243515`*^9}, {3.657615912646001*^9, 
   3.657615938819518*^9}, {3.6576161882902365`*^9, 3.6576162095302844`*^9}, {
   3.657616365437434*^9, 3.657616365501479*^9}, {3.657616436966052*^9, 
   3.657616437952751*^9}, {3.6576165054395123`*^9, 3.657616522993935*^9}, 
   3.6576167292599087`*^9, {3.6578700944135923`*^9, 3.6578701035660686`*^9}, {
   3.657871337154436*^9, 3.6578713423301096`*^9}, {3.657871553167962*^9, 
   3.6578716040339603`*^9}, {3.6578776567658854`*^9, 
   3.6578777651095595`*^9}, {3.6578778702673216`*^9, 
   3.6578779585234227`*^9}, {3.657877999237235*^9, 3.657878000072826*^9}, {
   3.657878194388341*^9, 3.6578782081180573`*^9}, {3.6578792279907*^9, 
   3.6578792305415053`*^9}, {3.6587252174005227`*^9, 
   3.6587253351006603`*^9}, {3.658725728991888*^9, 3.658725758234127*^9}, {
   3.6587257988167925`*^9, 3.658725798900852*^9}, {3.6587258552756724`*^9, 
   3.658725855357731*^9}, {3.658742960310214*^9, 3.658742981410119*^9}, {
   3.658743467892747*^9, 3.658743486005541*^9}, {3.6587439490416436`*^9, 
   3.658744002076103*^9}, 3.6587442241579695`*^9, 3.6587442719787498`*^9, 
   3.658744356150214*^9, {3.6587444009128323`*^9, 3.658744413567771*^9}, {
   3.658745512466251*^9, 3.6587455419620852`*^9}, {3.658745641229204*^9, 
   3.658745642412039*^9}, {3.658746018999117*^9, 3.6587460252315197`*^9}, {
   3.658746382413817*^9, 3.6587463845443225`*^9}, {3.6587465114109354`*^9, 
   3.6587465340769453`*^9}, {3.658746665245596*^9, 3.6587467024949074`*^9}, {
   3.661247814612949*^9, 3.661247829748475*^9}, {3.6612484500262384`*^9, 
   3.661248543594428*^9}, {3.6612485749374747`*^9, 3.661248575121924*^9}, {
   3.6612486183181486`*^9, 3.661248640058983*^9}, {3.6612487232929907`*^9, 
   3.661248744370379*^9}, {3.6612488618822603`*^9, 3.661248897944748*^9}, {
   3.661249116150507*^9, 3.66124912539122*^9}, 3.6612496638096147`*^9, 
   3.6612497738060155`*^9, {3.6612511953647738`*^9, 3.6612512549419174`*^9}, {
   3.6612517598982325`*^9, 3.661251761040848*^9}, {3.6612518387474284`*^9, 
   3.66125186718322*^9}, {3.6612519140720215`*^9, 3.6612519181939526`*^9}, {
   3.661251993417842*^9, 3.66125199516403*^9}, {3.6612520327287035`*^9, 
   3.6612520495364895`*^9}, {3.661252141345457*^9, 3.6612521856971626`*^9}, {
   3.6612522217766676`*^9, 3.661252269943673*^9}, {3.6612523596573305`*^9, 
   3.661252378879433*^9}, {3.6615021828713455`*^9, 3.6615023193416195`*^9}, {
   3.6615023496940317`*^9, 3.661502350870879*^9}, {3.6615023902956753`*^9, 
   3.6615024374149156`*^9}, {3.6615024687390137`*^9, 
   3.6615024697677393`*^9}, {3.6615025121506386`*^9, 
   3.6615025473814926`*^9}, {3.661502632927842*^9, 3.661502769916483*^9}, {
   3.6615028075850573`*^9, 3.661502885030692*^9}, 3.661502953062687*^9, {
   3.6615029842626963`*^9, 3.66150325033922*^9}, {3.661503331091188*^9, 
   3.6615034667608976`*^9}, {3.6615034969371862`*^9, 3.661503708935743*^9}, {
   3.6615037434731083`*^9, 3.6615039371347294`*^9}, {3.6615040039428596`*^9, 
   3.6615040340711136`*^9}, {3.6615041052173047`*^9, 3.661504217485506*^9}, {
   3.6615048176341968`*^9, 3.661505066823804*^9}, 3.6615050972332563`*^9, {
   3.661505137570713*^9, 3.6615051430485773`*^9}, {3.661505176784377*^9, 
   3.6615053740395327`*^9}, {3.661505417402125*^9, 3.6615054664086976`*^9}, {
   3.661505560448037*^9, 3.661505585191493*^9}, {3.6615056170239496`*^9, 
   3.6615056893980064`*^9}, {3.661505734377738*^9, 3.6615057535752926`*^9}, {
   3.6615058623290033`*^9, 3.661505898175291*^9}, {3.661510650930448*^9, 
   3.661510686473522*^9}, {3.6615107462106647`*^9, 3.6615107464098053`*^9}, {
   3.661511194312784*^9, 3.6615112838889775`*^9}, {3.661511352824609*^9, 
   3.661511377468995*^9}, {3.6616022983951173`*^9, 3.661602300347249*^9}, {
   3.6617500551819954`*^9, 3.661750061614523*^9}, {3.661750193335447*^9, 
   3.661750240341129*^9}, {3.66175028129502*^9, 3.661750288235917*^9}, {
   3.661865330379178*^9, 3.661865367027929*^9}, {3.6618654118709917`*^9, 
   3.661865425165084*^9}, {3.661968555035679*^9, 3.661968635418478*^9}, {
   3.6619687106522646`*^9, 3.6619687451628337`*^9}, {3.661969444233189*^9, 
   3.66196945099298*^9}, {3.6620162573525677`*^9, 3.6620162578038845`*^9}, {
   3.662029274681634*^9, 3.6620292895521417`*^9}, {3.662037673654998*^9, 
   3.6620376859086485`*^9}, {3.6620953548822956`*^9, 
   3.6620953719953656`*^9}, {3.6620977909010105`*^9, 
   3.6620978406791587`*^9}, {3.6620979379988627`*^9, 
   3.6620979381419587`*^9}, {3.662098634179299*^9, 3.6620987027236853`*^9}, {
   3.662099316336476*^9, 3.662099316887887*^9}, {3.662099694961191*^9, 
   3.6620997104403443`*^9}, {3.662115122675253*^9, 3.662115137725934*^9}, {
   3.6621170980698724`*^9, 3.662117098820403*^9}, {3.6624614134138207`*^9, 
   3.662461482308397*^9}, {3.6624615167416673`*^9, 3.6624615494051313`*^9}, {
   3.6627245709542756`*^9, 3.662724593281584*^9}, {3.6627246326021795`*^9, 
   3.6627246340491905`*^9}, {3.6627357457478437`*^9, 
   3.6627357677224255`*^9}, {3.662913527931525*^9, 3.6629135339087553`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10000", ",", "1", ",", "10000", ",", "6.121403506584327`", ",", 
   "0.011888454264370189`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6627245577658825`*^9, {3.662724588389079*^9, 3.6627246002837324`*^9}, 
   3.6627246466729436`*^9, {3.6627357561512165`*^9, 3.662735776495633*^9}, 
   3.6629135355669665`*^9, 3.6629142244387903`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.011888454264370189`", ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlnk8VO8Xx1WW7Iwtiso2M0TMTMZW95C9SEplKwmFSJKEJBVlzS6kkrQg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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVl3k4lO8XxiWVosi+G2vZBjFDKs8JCW3atKJS+SJFSUj2ZMueLctE1uwm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          "]]}}}, {
      DisplayFunction -> Identity, AspectRatio -> 
       NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
       AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 300, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None}, 
       PlotRange -> {{0, 23.9404296875}, {-0.41779191461826587`, 
         0.2597114995428477}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{
         RowBox[{
           SubscriptBox["x", "1"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["x", "2"], "(", "t", ")"}]}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVmHc81d8fx6UyQsY1k5l1rbjDte+bOz6fEg0tLZUVmkiRECJ7Fklm+KaU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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVl3c81f8Xx61oZ2TPa5Z5KfcW8TlZScNe9953VBrfElKIFEWSJCQ0qAgp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          "]]}}}, {
      DisplayFunction -> Identity, AspectRatio -> 
       NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
       AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 300, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None}, 
       PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{
         RowBox[{
           SubscriptBox["p", "1"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["p", "2"], "(", "t", ")"}]}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   GraphicsBox[{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJws13c4le//AHBFGZlFsgoVqYSUVXlHKu0pI5RUsiIh9bFl77333usY5xy8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       "]]}},
    Axes->{True, True},
    AxesLabel->{
      FormBox["\"\[Theta]\"", TraditionalForm], 
      FormBox[
      "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
       TraditionalForm]},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->300,
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-0.4177919146581453, 
     0.2597114995421011}, {-0.20427900860035447`, 0.1414557165193523}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.05], 
       Scaled[0.05]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", "Null", ",", 
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJw9mnk0ld/7/s2alCFTmY6pzOcoTqnsO0kikUrKFEmDkmTOFCUhU4pCk5Ay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       "], {{{
          EdgeForm[], 
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{50, 580, 578, 43, 44, 45, 46, 458, 337, 238, 162, 
             109, 78, 47, 459, 338, 239, 163, 110, 79, 481, 360, 261, 185, 
             132, 48, 460, 339, 240, 164, 111, 80, 482, 361, 262, 186, 133, 
             49, 461, 340, 241, 165, 112, 496, 375, 276, 200, 81, 483, 362, 
             263, 187, 519, 398, 299, 134, 506, 385, 286, 210, 529, 408, 309, 
             551, 430, 575}}], 
            PolygonBox[CompressedData["
1:eJwV0klLlXEcBeDbsMoxNfVKEApSQmQgiGTWdcgP0M4hNT+Amgu11J1uCiqH
DAQhCARJGzbm0GhbbZOWNlptyramZSk+/8XDOef33ov4anZj8/mmvZFIZA9T
lBox4vR4Ekhk0gdKeK9fp4pTJPHY/Qwf9BtUU8wbt2o29Xu0kRx+jttZPuo3
qeE0i241/NHHaecg024xPul91PLDbiaeF3YJS3otf/UJOli3O8lk3k5hRi/l
s97Ptt5DNhfsn7KFBF7aB7yPPv1E+D3tt+FzbOnpno3o9/V9+lX9pDwqc+SY
vOzZb9nFcbeoPCzvyiK5EN6jHLILZIHMlePhnctUz2f1MvLsL3aqHLYL5YC9
o/eSb+fII3JU1nm2Ji+RSNT9jpxzj9P7w3fC38N+Fz7PP/0B+z2/Zh/jir0h
u8nitZ3GE72cVX2Qen7ZrSTxyo6xrNfzX39IJ4d46lbBV/0WDeF/kBW3Brb1
R3SFd80zt3N804e4SBkZPHev5Lt+m0bKySRKFrvS7lfK
             "]]}]}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            PolygonBox[CompressedData["
1:eJwt0jdLnVEABuBrb+AQsIBgARXB6HDt0UHwH9izusYoNkgcdbCTLAkIgUDA
Ptg3y6yBRJNozB51ti46+BxweHjf9xy5fvfTgq7e5p7YSCQSw+fnbHLQSKqe
QjJ1dDLDPxr84DZJei0dTHNGvfMtEvUhlrnntbNf1OjtTPGXV842SdAHWeIu
/D5nx1Tr+6TpPVzSZk9yGp7N3iBe/06WPswNA3axnCDWd1q0b8Pz2kdU6WXy
Iynu9+yvenb4/vItF7SG53Q2p+fKfFkuR+Vj+Hz3Vfas/kKe2CWy1l4nLrwz
e0UvlFEZlZ9kujx0XyO/2TkyU5bK9/KafveLssBZkRwnRl9w/kXP0G/Ce9V/
Uqm/lB9Idrcb/pZ6N+e02HlyhIfwefaf8Az6WnhX+gEZ+juu6LPnuabN/kGF
vhP+R/Q3/KfZHuM31fYqT8RVRFs=
             "]], 
            PolygonBox[CompressedData["
1:eJwt0klLVWEABuDr1ErhakJQzkOmICi4iSBINMcs+gc5ZJbkomynVoJtdGWQ
5gxBILQprZYNXq1Vuq3UFmWZWkttkz0fuXh43/c7cj3n3Jvb3HXxenwkEonj
BWeMSkr0Yk5wjk5m2OGCP35Pkd7INabZ5rzzdxzX+3lJot3OFxrsq0yxRZOz
JQr1uwf3kGBfZp16e4nD+i1+02FP8jPcm71Igb5Cpn6bP9yxS+QQhzzTczte
b2ONOrtc3ifF9UU7Te/mF1fsxzLHtQJ5L7wkfUKM6en6ZvgfstGOkW+ftp+E
dyArZIV8IKNy2fWT8pGdKTNkqeyTe+HeXT9lz4bPksWyXA7KJDkfnl0/osfJ
VlapdV4mh0l2LRa+L/2onipvshO+B+f5coB9xu0fNOgL5OkfOKb3skufPRf5
/yNp4TM15gJR/Qbb4TsL74Xv1NtvydV7ecY+zc4+cVZv4yEb1Dl7E9613sNT
/nLJ2Ueq9VZG+Uats9dk61W0MMJXapy/Iiv8HsgIz8M/qcJWkQ==
             "]]}]}, {}, {}}, {{}, {}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1mWYlVUYBdBBuru7uxtEkFLpLlEapUEpBQEDQVKQ7m5QSenu7m4UlBaQ
FFzn8cdi7/ecuZd7v5rJ2LJLnc6RIiIiyr8VERHyZ/8U47g+iDrcMHcgBhvM
hTmk1+dvfR7deGjuTVL2mr1lxC96cU7og3mpf0N66pp/lx2JyUZzDC8aqeeh
iPmwbMAjPam9Kfp8PZI+WM9KRn2B/Mz63/ILcltLJlPLWeEzyH3248mx5kKy
kMwiF8u3ZWT7v+olyGE+aU4kJ5qLyh/Mr/RvyWfOINPJubKUrGf/D70TsUhh
bbrcZD2m/qOeN7yX+YhsyGN9QThW4f3N2fjc/Eh+SXL2m6OwXC/JKX0I9blp
DicwNpvNxTiqN+KJvpDuRGVF+Jyc1ofSgOIcs9aYf/RF9CAaK62V5ow+jIaU
IDqrwjHjrD6cRpQM5y98V2JRzneKLeMQNxx7VntNGc7pI2hMKeKzxvo7nNdH
0oTSHLfWhKf6YnqSgN+sleWC/iMf8jYnrH3IM30JvUjIWmvluKiPoim3zF2I
wxZzGU7qTXmuL6U3j819wjnlQLguWKe/yyV9NP/q34XrkY/Mf8quxGVrOCaO
x6hw7YTvaT4Vfo4XejJ7U/VlemR9iF5AZpeZ5MJwXdt7IvuG+8NaSplGzg7X
rDwYjqMcZy4sC4f7Qy4Jx1wmtr9eL09O82VzYjkp3PPyJ/NrfSD5zZnCfSrn
yY/t/SW7EY+U1mfIbdZj66PDa8L5MJ8OP8/L8DwJ1679oeGeCte0+R/5Fak4
ZE7CBr0CV/QxNON2uKeJz/ZwPXFGb8ar8GyhT3gusNFaRa7qY2nOu5y11px/
w71N33Cs2WStEtf0cbSgPMnZbL0y1/XxtKQCKUhJqvDevlNqmYa0pGOL17zH
DX0CrahIerZaf5/f9Ym0phLnrLXgtb6cr8jANmsf8Ic+iTZU5ry1lrzRV9CP
jGy3VoWb+mTacic8S0jADvN7XNBbER72K0V/nur9SM1hcyZ26FW5pU/hjf49
mfnEfFd2J2E4j47FTLkz3OvhOgrXbvi+5ouyNZFIbm+aXGU9qj5MLyhzhveV
i8LzRg6w/0zvT15zGplWzpEl5ZFw/8vx5iKyiMwml4b7Sma2v1OvRi7zn+Ea
k5PNU/Xwi2mQnoUM+nz5qeV7sgeJ2GWOa29M+IzhXJgvyTa8xWpzNPvDw//B
1+bnckD4rBw1Z2GXXp2/9Gm04765J4nZba7CZb0tkVlj/oas7DbX4LY+nfZU
5Uo4D0ThN/O3ZGOPuSZ39Bl0oBrZ2Wu9Fnf1mXSkOjnISa6I//8OyC3zkJd8
7POa2tzTZ9GJGuRnv/U63Ndn05maXA3HlKisNX9HAQ6Y6/JAn0MXanHNWjui
sc48kIIcNNfjoT6Xrjww9yIJe8y1ua63JzrrzdF9jxF67nDdml+Ec0Q6jpkT
2p+gFyW7vkyWDX8T2PsP2sELMA==
           "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
       AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
       Identity, Frame -> {{False, False}, {False, False}}, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
         True}, PlotRange -> {{0, 23.9404296875}, {-0.9998562727878137, 
         0.9998560602744442}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"u(t)\""}, "LineLegend", DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               "}"}], ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   "23.9404296875`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6615049503846602`*^9, {3.661505017146773*^9, 3.6615050381866107`*^9}, 
   3.6615050682858343`*^9, 3.6615051014872975`*^9, 3.661505144041278*^9, 
   3.6615051793972287`*^9, 3.6615052608737097`*^9, 3.6615054746194983`*^9, 
   3.661505586324293*^9, 3.661505627681485*^9, 3.661505658104952*^9, 
   3.6615056905408235`*^9, {3.661505737869212*^9, 3.6615057570197225`*^9}, 
   3.6615058658875227`*^9, 3.66150590160472*^9, {3.661510664785222*^9, 
   3.6615106878254766`*^9}, 3.661510747754754*^9, 3.661511239690797*^9, 
   3.661511286402752*^9, {3.661511355529517*^9, 3.6615113817740374`*^9}, 
   3.661602302974494*^9, 3.66175029056456*^9, {3.6618654021131706`*^9, 
   3.6618654227228794`*^9}, {3.66186564368841*^9, 3.6618656495108366`*^9}, 
   3.6619685284108677`*^9, {3.66196855885036*^9, 3.661968639654467*^9}, {
   3.661968714820414*^9, 3.6619687485102115`*^9}, {3.661968873381922*^9, 
   3.6619689017349367`*^9}, 3.6619689762445335`*^9, 3.6619690316617813`*^9, 
   3.661969128095849*^9, 3.661969283202526*^9, 3.6619693516958814`*^9, {
   3.661969450593679*^9, 3.66196945466055*^9}, 3.6620159055342245`*^9, 
   3.6620162585354195`*^9, 3.662016338338747*^9, 3.662016369292597*^9, 
   3.6620165198038445`*^9, 3.662028898429034*^9, {3.6620292774325757`*^9, 
   3.662029291620592*^9}, {3.662037677065407*^9, 3.662037687189554*^9}, {
   3.6620953561882076`*^9, 3.662095373035099*^9}, 3.6620964740383067`*^9, 
   3.662096550275138*^9, 3.6620966456024265`*^9, {3.6620967029502025`*^9, 
   3.662096720595668*^9}, {3.6620967520798836`*^9, 3.6620967758606815`*^9}, 
   3.6620968517098856`*^9, 3.662096894276944*^9, 3.6620969734569697`*^9, 
   3.6620971258145313`*^9, {3.6620977757553196`*^9, 3.6620978434271045`*^9}, {
   3.6620979173702874`*^9, 3.6620979408738775`*^9}, 3.66209802924426*^9, 
   3.6620980783299108`*^9, 3.662098218390795*^9, 3.662098270491557*^9, 
   3.6620983445038033`*^9, 3.6620983960061607`*^9, 3.662098473786065*^9, {
   3.6620985169035187`*^9, 3.6620985430449553`*^9}, {3.6620985812489243`*^9, 
   3.662098677085576*^9}, 3.6620987071077795`*^9, 3.662099322545975*^9, {
   3.6620997046474485`*^9, 3.6620997142775955`*^9}, 3.662114699932705*^9, 
   3.662115194126883*^9, 3.662117105650242*^9, 3.662461315492202*^9, 
   3.6624613659140344`*^9, 3.6624614894463606`*^9, {3.6624615348469267`*^9, 
   3.6624615527390747`*^9}, {3.662724553720713*^9, 3.662724606547024*^9}, 
   3.662724653837274*^9, {3.6627357600349693`*^9, 3.6627357768738985`*^9}, 
   3.6629135431767015`*^9, 3.662914230028263*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000027314637654779957`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.6627245577658825`*^9, {3.662724588389079*^9, 3.6627246002837324`*^9}, 
   3.6627246466729436`*^9, {3.6627357561512165`*^9, 3.662735776495633*^9}, 
   3.6629135355669665`*^9, 3.662914232039767*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.000027314637654779957`", ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k8VF8bAHAkyZZlZhBR1hnrXGkTzvNLliiVFNkSbbSLVpVQVGQrZYlK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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVmHk8VV8Xxs1kzlDKeC9SuNdV0k+ls4okokiZJcpQiiJTiaIyz+6JTNdU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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV0gk0VkscAPCPSOHVQ2gRyi5yr6hnuWaiKFJC9VWyluJFStlKZSnZSUmy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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV2Xk8VF8UAPBnF9nGLtsMYWbIkrXinsgashVFyhKKVEgSUZES2iipKEup
ZE+yJaSIisoaQtYsrSIz43d///D5ft6Y++59555zz0P2PuS0j50gCDf84//f
t5yy/OJ90k2IhrETZX7pJj86uB9t3BOOhGJLrgd7hqNSTsYo356zaLl3IS5x
11kkmhke+9PzGuqKODHN43wNNU6X2Y973kNx6+8dIG+5h9Zc7tT74lmBbBca
TZxUKpDlVy/qgGczklNZ3XR4+iUaSKbm9Ht2oX1/XG+nH/mEVjs0MJ5sm0Dv
h49s5zIbQ1psO08qOf5AhTueNswIzSGm7y4F1sACsgq2323R9xNFowp7i1EG
CkgOeCwUuoA2rJdjq19ioBe8IxyBMQtoQSWuzEiYiV7L1p6vu7CAggWdpDSM
mUikZ1jFPncB7R2YHRa9zkTf1kzXCn1aQFtOrD06bMNCJ/qlJeX0/qLVT1Nv
RpWuIBP7dzv95v8iu+tGYb3ABs43DNZM2S4hqebzajx2bODh3/BQ320Jff3d
+1l3JxsYqBrvOOGzhKKcIs0vHWGD/k4enunjS+ihQLWEZTYbSBtI/vO4t4S4
4zY9K+dghxg562MZzCVUfxixLjazg5e2bfnJvH9I18b8nIUtJzhsKe237V9G
4kndeze6ccKnrsAWs6/LaKF9v5GWLyewc7he0pldRpWOKdPSUZxgYWFQ8pe1
jDbu7LadfcQJJjbOoYoUBjIN2C+Sys8FXM33Mmb9GMjhbHLGcCsXlIx914qb
ZiDt1wqhXV1c8Nt2iC3yJwOR+Eq3vhnhguubA775/2Ogj8ldjPJ/XHB76bKw
Oh8TuaYp7DlH4wbOMuOB7VQm8swtUdJM5IbkJT8HbT8mCmr4VBBlzQMB9sGz
En1MFN686W2OCw8sbqtcvPmFiWJbc+Zb9/DAblunvTITTJTaeURHOpwHCnd0
bOX4zUS1IwKVT7J5oDr9+Kt4ARYS5LBonFvmgR8BBjP2iIWKzCp69xbywii3
/J6V2yxUZSm3nPCMF5IUBrPKclioaWucbFETL8ya853wesBCPc5Oe5h9vNCo
Wc37sJyFCN+5rzd4VoFcjmDVXCsLOcSpfO/cuwpiff4YWi2w0M+ma9zmonwQ
eVPsrbXVCpqOluHYrcAH10PkIMtuBQ3rZ66E0fng8QuhyFmnFfQ+P28x14wP
Hlz85xC2ewUVJpVPc4bxgar3bC89ZAUdcOl82/SRD7xuBr7fkrGCRkYFrm+5
xg+DmpPCOmMrqO/W5ase2fxA6f38N29qBXVsF78UVsgP541WsYnOraD6V7Ln
c5v5IWfCKb5nYQVlPqKf4PzLD1RD105eTgJ2hVrvaXJdDQ84RfyyxAjoYI9X
3SItANS02mXb9QT8jB4ISlEWgOVURUumLgGkJb3SHk0BWC2nV/dQnwCX+fFN
By0EYG2Fry7TiICufiuna6EC8OT2CZ9YIOBz+eroyXYBiHkbNkzYEcDU3Neg
0ysA7yJsouLsCZB/VMsT/VUAjINu7OByIGDP3eArIssCUCCf9pblRMBI8vv7
G9QEYalIZv69GwGTfqmdSacFoaUgVeKXDwGrRmYku5MF4duhItOt+wig7Tbf
Tb4hCBwVSw13/AgIdF6YeFIkCKrm7i/N9hMwh9yYg58F4e1LnoX9wQT8kpJV
0zYQgjHOEnXDCAJYrTnRn74JwRvZDNmx8wTo7jSZGF8QArNV0RvHEgl4Ehqk
xiCE4dH2kz9GLhDwjY3nisBqYVjb16banUyAq/ymfVoUYSh9RRnOvkyApus9
/nB7YdgnbZz/Op0Am8zQepazMJDZjDuzbxCwbwyOJuwUhg96E/cjMwi4Gdo/
mO4rDO7397kr3SKA55JwaXWkMPy4asizM4uAodeRbmz3heFBX97VHXkE/BOy
EkgsEAbWMTfR1fcIEHcVbyCVCoP3hJfzc+ytY0V05VphyNqdK62QT8BTtjGW
xQdhGLokPtr4kIBOq9Kydz34+v2C8/6PCJi9GBPgNigMjM7v/3gLCFCSl+nc
PyUMH889MjV/TMDFDdvyklaEYWKn1IWcIgIenpLdJc4lAtEs80d6xQS8fD0l
mMknAsb/wu+8xF7eERdRJC4CgeGCQkMlBPiHPtvaSRcBh0t6lMUyAlCB0k9J
NxE4EFi2tekpAe/tYsSkPUXgz4pmi3ElAd7zffoyviLw+1ZcZzn2WZ0rJ2QP
i8AViXMXbz4joK2S4CKfEwEOsacjW6sJ8NzloUpJEYEff0vnSrC/Lz+1VkoV
gQ9a9FTxGgJE0aGUtXdEoOSVd+kn7F0vByRplfj70h4HGtURMONntIFeJwK9
6ltDk7BP8qZ5qDfh6/tWUQaw7261vbvuvQhkDD87cew5ATqz9xs1u0SA11Cc
9gK7KYVjXOuzCFB3+Jzlrcfx2lFFWz8pArVCD7ddwo4MlbDTnRMBxzr++vfY
/OIhh/R+i8CnXTpjgi8IWOdGLTcgSPD9zB2XOOz6pbguQ24S3FNyzK7Gdrr5
ZdFoNQmSu9Mffcc+OnjdeJMUCajZz/86NxDAHftrj7E8CWSCeE1OY6eTt502
USYBx+HXFoXYtMaHuYhGglPZ9aI92DW+3K9AiwRDnwrvrWDbc3tPbdYnQeBn
B7a1jTje7tfym20iQeg537VW2OzfwhzMrUigItPzPgE7Nel9iIU9CQ7mlrnn
YqusU0+zdCGBt9xiRR125buEp1a7SODs6vO1C9v6yGiv9V58/8plYzPYfSTE
sPEjwW7XvBqiiYCg8gx52yASCDX8PUDCZm1fALsQEvzUD/hJxr7019HHPoIE
jufKXTSxKTcex287SYLIcxlXN2CXb1iV7xBHgmereorNsC0++7Y6JpLAY5BW
aIPdHV0/43SJBMU9DsnbsAMUZIVcrpGA7Q2PgxP2v/pj2ttvkeB2gsDi/07y
/uC8I5sEHV8UEhyx5Tk1w13zSTCVz2DZYRfnJaa7FZJAp9TLywp7s+V41c5y
Evx7u7oYsDsnNw/sqsLz7aie0cf2Tby94l5PAsMkdWk69gJ9iby7mQTWHbIG
ctjn2l22eLaRQCDUxkoAW+ZQsd+eThK8Mwu1X8br9Uh49fm9PSQYFN++dQLb
SbTz3b8BvL72R1o7sRfF0yXSRkngn5l9tgY7U8pzt+YUCRR1nU/9/3y2rFHO
bZkjwTnj2epE7Gm56Wmf3yS4P9lncAj7smKxNmuJBPE+ZxccsQfXbnquwyUK
WbHPN5Ow49TYudv5RGHmJLlj/v94or+29RcWBWmu6fw32Me0XPpurhEFfS9X
g5PYwhuD/nDqiMLaR0F/3+J4rTDW2ZRlIAqdnz/8yMT2gMXTRsaikL7CDwex
H5jHCQdbiQKx8d4AJ7apwy16t6cocJ6IM1f8fz85eYcc8RUFB9Wj3KN4v6Vs
V3vGf0AU3qzKU8nF7t9VbgFHRaH/6vFEMnbYvjavBxdEQaPwL88qvH9lAq7k
m10WhRfM0em6Wry/DrjND1wThYzX0Yah2AKHv0aRskUh7+dh6W6cH+5FMq6f
qBSFb+ddZZJwPrGNbhgUrxOFI3klkXrYv2LOrS1uFAXHU6qOA1UEQLxY2de3
ovDwlpyfGnbvRfW3dmOikOis51aA81fslZ9ik9Oi8Mjn0GVrbJW0SvfT30Vh
4/H1tmM4/4VkbJmqWBYFvW5hWyns1XkenIokMdjuQLkd9IQAk6qkDT9NxGBz
wZemdzifuksOz3Gai8HZJvfQrdgRYXo5klvFYGU85sT/+bd03SC/sasYvObj
u1OO87VKjuZAwiEx8BcSPxiD87lgUmeM3B0xsJGJLXyN6wN9SkVX654YLHl0
ddCwrSxOTJoWiEHHw++BF+4TcJpQdgyoFIONapX8Vri+LIQdpZS9F4PMb6fU
i3JwvOyWemnFJg7S2ZGJ+pk4/1cFHXfnEYdkeY/fsbcJkJJ6oREsIA6xvgo/
W3B9c+rcf+2qtDhcUE8rdr1JQLNFtf+gtjjkptUHeuN6WajpyRfmLQ7PW9UO
6V/B+Zgtd1tWI77+9K3NWByeT4D0tbQWcagMGWlZhd3+NuXzhXfYDx6QNc4Q
IHvr+P6IfnHI2ajiffgUAdX62844/hKHmK/5O6ai8X4J/FfBoSQBjizrc/fC
8fp3OcgHnJYA7jKF9zv9cb16xJzR2iwJdZljDWwWOL4z5nP586QgYCnA/CRB
wHrViHo2VRnIajRSb/BcQRJL6QtwcQ0cUUE3pF6x0L0Ah0s3xeXA5tIzBbIG
C81v60lKXyMH+g4XNk7QWMjQYO/5NLIcaIhEpxeqsVAr1+HTFzXkQP1ltNxm
ZRaazb4YdsZcDg4V8CceXcNCugNv3QKPyoG0lmSmHB8LNTjakTd+koOotj6D
iEkm4jf6JGfYLwdHAtn0D4wzkYvibhm9YTmYXJYp2/2VicbngkQ1Z+WApDWs
bY3P06uSkriUuOTB7VbHMZ0eJnJofjPFpycPdZuIrm2vmWhwg01pX6o8lOwM
9mp8wESbzmz6cDhDHhSiTBt485noxpt1v7nvyEN4BORtu4fH8xDVX/9IHsSv
X1gYzmai1ujPzy68kIc7adKTUreYqKI++MWmOXlQ+Tor1pHCRCkWV99nWirA
NzVTztCjTDSTEv9D104B4sy6V6ZDmci6+xjpjZMCNC1Rcn1DmIgzwMPl724F
CO8o+uZxiIkiz6/t2RamAMquu9K99jORX9vTIeKuAkzytB2t2c1Exk6f57z/
KQC310xRvSUTnY8srDMkFMG2ZuGjswUT/XozxwUcihDnUigztYWJXgUfSrVf
pQhVnEOrZUyZ6FD54ZJAcUXYs+T+IG0TE9Wj0G95GoqwctDj0W9tJqJdLtN5
rKUIdjnlux5q4X5k5Nfx8vWKUGZ9bqO3JhMFxIfxNhopwuL6lrQedSYSfnN0
7RdzRaiIb2oZUmUirx0Re2Q8FSHCzUhqpzwTtd2vvEf2UoRJh1F3HTkm0l9a
nFXzVQTt0bxhAVkm4rt1PMrggCIcV7j19I00E5UOR95wCVeEDaw9D73FmYj9
YPSHlBRF+JEycJW1molyz5y25HiuCDsUtlf/YTJQOteiYvcLRRirCetQxU5O
OPjvYZMiiK7ELrszGCj8gttjp1ZFODArlNyK+zfLq+tEsz8pwlRXX0n9Xwaa
zu4bhBlFMOCs3yuC+71BZYdKsXlFOHrMbdL3BwN9uPfy8uQPReiMyUqs+s5A
NQ+Lt1z6qwj8bVOKQfN4vNKzD4fYyeD61PTO5AwDaTXohJ+UJoMXcdfKcpKB
lLfkb3OSJcMux47HNRMMJN0sR1VRIMMv1RBdXWz2Vt7P7cpkUBl5cp86jsfr
GNwsp0WG4HkpnXVfGei1s8uaHzpksO68U1iO+/yaTy2/m/TIwLn+3zZj7Nze
8vtBG8lgPN3Bvn0Ez3c4UaDGggxpqZO6mV8Y6IAPMXHRmgzb37wb1cPeM3a0
3seWDPoRU1XvhhjIampvKL8TGSKLfUdXYcv80O/dtZsM8yt21PQBBhIMLShd
t5cM121vrd2MzfGHnMTuQ4Y7PCftZj4z0MziavQwgAwLWwrI1ti1xGjuUigZ
rmxOmJDtx/fDs9/yeTj+/Kr3uT19eH0E56fijpNhZol+4hp27prldcIxZHia
ohYqhe1JOdXx6RQZPC43pX7uZSBJKk/YzTgy3LQ78i4bO1Ff9JlKIhn0in5d
1MPeYnzDfSYJ/31pkzg7NstMgVVykQwU9dvl73sY6Igj3cw4jQzMTe7GYdg0
t5Ix9nS8PjqbVK2xv3oanHudQQbfXWtoithuQWbtznfI8JPRGvmxG/f/oS2H
pHPI0Pvp2usS7Lbj20hDeWQwv+2qeRn7bOyn8tx8/HzY+YtCsFGCu+uBR2RY
Kiu03IG9mDy8pFlIhgAvWNqIXZrqf+tPMRkePKttVMIOujlrUl1Ghs5A5fsC
2CrZocOxFWT4rRKSs9TFQF/yl85YPCODUkZu5QR2RlGMyuoaMoSFPRvvxnap
4GrpqMPj+RZqtGIL1F4IvP6CDM0yp5LrsJsbRQR3N5Hh+xZN7ifYsa3Xiymv
yHDuSsX1x9gbOuScJ1vIkFMqZpqP/bs758/jNhwvLpZcediFg9T00HdkKFax
Hc7BDhgr2mDUSYbWHsWuXGzKjN4A6yMZyqUbR+9j9/+sjmnqJsPpdC2+/78/
dWkzJbEPrw+nv3U5tj3xumnbABlkV/vercXm5bH3F/9CBsE9a0kt2A0CH1f1
j5BhfUH+zS7sKLFdBXfGyJCZ/c14HFt/zRd7v0ky+Pz4tvgX+zvZ7wf9G36e
lvfb+PH6PVCbufpjFo/nsuYZGdtbM0T/6XcyXG42rzPCltVf7In6he/PTvmz
M/YlM0553iX8PLb/9krBtrFJrG9fJgOP3nBLITano7DPVRaOx7EImw7sY56y
+fKcFNA/mpUmi+NFa1+2zVduCoyWUveaY08Hqs0+WEWBT9HbzQ5jex7X1dET
wj52zrkNWyq26uM/EQqs4roQy8TuOAvH6sUo0NG/tlnr/3hOta3ZKkMBf8qa
m7ex6UW+Ft5r8XWjxsBLeH8ojpYo+KpRQMjFX/D//SQhubK4j06BkMeRahS8
34iYG4/2a1OA/+BIQy32R/u3wkeMKbDh6LbzJLx/W06vmQ4BCjx3Y3w5iF1X
EdAYZobH49/w+A12vjxHeIQ1BQ6ss7qbMojXf86gP2Y7BUxud0xq4/xxhBJf
fsqNAl/oql13sP12dCafcaeAEe3tetIwAznUBUGCFwXcm78bM7CVU+7mpRyk
gE/hw5OzOF+1a/Afvh1PgZft7Bu34PzY4OVmnXWOAon1lbO92JVpeZS7Fyig
5buZN2SKgXDJ/ZR7mQL7BB+FPJjG+aQ9bEPBbQrEKrIL6s0ykPzBQc7qJxQo
fvN+og7nb9G79MGaSgqo6i13R/7C8fUp4mldNQXyLx1XNfrNQD83iR5oeEEB
gWCnkZo/eH+stnrX0o7X7/e1yi+LDHSooORGzxh+ns+jDt9YYaA5YV2u+5MU
sPuW+D2QYKLgoxWHj36jACVfLhLYmCjIpNqS9IMCRXl/c+bZmejA+6Y/WxkU
YC+JNvTjZqJ9v7sdn5OUYLaqpKZMgIncN7FW3UNKYKT59Hsrrod9d2KPhpkq
gbilH8cArpe7uDiGTc2V4K6CIfcPBSZye8tTOWSjBBIxZr3yFCbasVfET3qH
EmgxwrMuqzCRY5xyQ1KQEgS84BrqxPXZss0mMvSGEji/MttXa4brp2eq7Mlb
SmAWLPtR1ZyJauYH6s5lKcHTycN+qfi8oCN6hCMzD9+fR9b3UGsmkt11Pel1
iRIM+VyKsN3GRD8nRjPlWpUgtLlfy9udiTI5ohtf/VOCfQ2fR8Xx+ebPhqLV
sh7KMG8a4mpVyEThjqsipPYoQ8T8BTnVYiZa8PcZFfNWBu0//Vd4SrFTJasE
ApShzjIsrv0J9lyM/0qoMiw+6HM5WIud7dAwckEZrqjUai63YfP9PPagWhk8
hMY/ms4y0d8+3VH9NWuh4sZRKwkdFkq+zW0Z3r4WcqscquPrWGipMMejMUUF
DFH6j/m9K2hxJGlF10wVKua3oaTFFWRrdX1c6rcq1PbWRzzcjM/TWf8KpP6q
gmGZeMhLUwJm/+wOlfqnChYmJwuHzHA/lqNMSBFqIL95eEoEn5c7WCXSkqvV
oH3YftNBGwJ2PGmzFVdWg5Z3r/qYTgR4UdjLRFzUQOnTmq0nfAjQOb7vuIir
GnSYf9l/wpcA9vevkcgu7IDJtMh9BORGX2wT3qsGP/Z8FwzH5/PxHtlxoSA1
yLWW3O4VSEDQRQNpwTg1qGs4XcYTSkA4IyiGr1wNjpnRmxPw+b/jDFdPV4Ua
tEHbXtfTBKjzZ2rlPFODvsMnF9fifmFE+t3wxudqwPU8WLoe9xP2BtpbDraq
wbegqaWJBNxvhPzhff9FDeJ6byxyphDwaSL6SpoAFSxsonkO3CBA65DENy9h
KqRsEEyQyCAgcaHQbJ0oFZpXh3a9wAauL7+bpajwo0B4SAz3PwUUU9dFJSpE
6XEfLsD9Utxubln3DVRY0NZwuYP7Kd0PKXmK/lSIyLhscLmAgNaEOV3qASrY
9Jn+UcD9295N9k3aB6mg5zYl+Rg7OU9g1DSUCoNxnXENhXh9jiUp7ouhgsnQ
ptZe3A9Gqc8UHTxNhWt2z6Pccb8oOrwVhcdTQXKiKL4fG2z4PRMuUEGZlH61
q5SAG7KJNx9cp8Kas4+CKsvx/DqmaKUZVIi70JyljvvR5njrqqrbVKA9eC2T
hf1zjrf3TQ4VSnJMhk9W4H75RYLEXBEVQj5IRVNxv8vaF39Z5zUV8vnrd1Jx
/5wqM6a48Q0V+iO8tU9h095tKTZ7S4WgnoH13diuhpzvXD5S4XPtqtJo3I8X
851ZfewLFbR+aO4tx/26xfORmzGjVPiqe9GdiT0Qako/N06F6WgI3YL7fb4B
NpsbM1S4z/L83obtUxSbUL1IBYnO33PNzwn45/NFommZCmdc7TKIegIuScG9
NhYVarPOOBti15xaaRrgpIGT67bJu9hO+ntcxnlosLrCsv4D9tR03egcHw0c
KkYzOV4QIOFykp0QoYF2ZFvAbuwC3sHLvGI0UNeIckj4/31GrTFZRJIGh/am
GRRh9xy5XSwtQ4P8C9ayn7AP4RxFkaPBWZVWxiI2d7/HO5oiDZ7lW3XLNBBw
62KN53olGnw/v/BgA/brxRPRW6g0ULO6pxWGPTkgnCWtTgPxqhbjJOxVjXn1
c+to8Ns6Kib7//c1+RtGGrVpQPUy/12BbZP8juOGLg2k9hdktGAHhviuDTag
geobwyN92EmuSxZmG2hQ9f1I+BR2waaUACljGuibDeUvYLeTlRJnEQ1W6Lw8
7I0EzHFXPmowpUGkWNhFfmzBGdv26+Z4vfwegii2ZsfwXJAVDWQSdaSlsR0q
woVNt9KAd/qqpBz24Zv8OpL2NNg4v32Dwv/vo2LvOM840ECSg4j936X79I6+
cKYB+0Xpif8/32nTeu3aDhpcXaQGy2D/1NxTGbiTBkRYqag4tqj4717woIF5
glGXALbuv3PL4ntoMNRoW86J7TIkJ/fNiwZ21ccLlvB8jjaVmtT70kBgxa52
BvvaA8u9af40uKXoOjaAXZHy+dSBA3h+JRSlduzu0CM56CANlM1MjlZhL7px
vxQ7jNfT36AvD1vK5Ob4VAgNPhXedLiIbaSkxfv8KA16Hy12hWPv4n1JTY2g
wd35/kAP7MjZnVv3n6DBY/4PAoB9s3MuyOQkHu9yYDUZ+/MtqeLJMzTYpvh0
/RCOD8apxx21Z2ngYhu/XIUt52/668p5Goiq0VtSsT21g/SNL9KgQlf3sCl2
jASbG+kKDa6fK7WQwL6znHZ8IpUGtE4TuUkcz8Mvn9dczqDBnqSnTfHY7I9c
Bv1u04Cl8PyKIzbl0tTKxjs0sJrnc1+D7btL1Gw8D8/vbN7HfLyfxuf8WjaU
0ODOGW+zR3i/cX9cnhYqp4H3IE+1H7bqs0urxypoUE94khWxA85UbbtYQwPr
EafyJLx/pyUFu0Zf0cCdvb/VFu93Pmb238pWGrSeOX3xL84H9BED6ZR2GjS7
WRrcwQ4q8PIw/EADT7M9tG9VBMzDk5GkQRq4ypuF+z8j4OPDXe3OwzQQs5nT
5sCuEiMqZb7i8b/c7rv1//8TJm2S86fw81OpnW15SoD8pS8GTb9p8OrX0B8+
nL84/8VTLvylQcHOK7/TcH6b9qELOP2jwb+ewk/y2BUG4SNDKzQQWe4xouH8
aD/En7zMR4f3RZ98VXH+1LUuOdYgQIfHjTWOd3F+lSnb4X1emA7BWaES0tjj
Z+8aSErQoSueg8KO8/PJdQYjOmQ6/Ph+UbYK5/PH0d4GBwzokL89Mrw+n4Ar
EzwU7Q10+KrovFkSO8Lx8erFTXRYFH71NvA+AVvWLg7Hm9JhVH+9uuA9HC9t
yUl37egQEkW0GeB6slr22XCPDx3aOFLC5W7j/RLv2ZblR4c9Wfxt23A96pnn
eOq3nw5OcXNvY27ietton/Q7mA4td9u6e3B92xT4VV84kg4DyVs7g6/hfFEl
lGR5iQ5Fm/fYUS/ifOEY9djmKh165WVVyLg+Fk5OvrW7RodSPQ26RDIB3yUa
RFxu0SH0anvZ30Rcn0PDru/Np4Nu7uXL6WcJiFXvzT5eTwdGwwlRh2gC7jaa
N0U10sEo7cGcdBQBDbtKx2Ka6UB7rP35SyQBXOcvqJ1to4OqdufEvghcb8eM
C6/00CFDfuiqLa7/qZnZzx59x/MbOfEhMYCAJ3pC/YW/6HBCJ01kLT4/dLWd
YJQs0OFJs7FVDT5fSC+7oEoGXq9SiRvD3gRkuvK8bOJVh1zXgds8uwnIFw56
P6CoDlEDgf3PHQioPa03IeSoDqHLTJ8uPRzPNt0ZQ87q+Hwmt5OuS4AY6bh9
0Q51iL/GHRutg+P1bs0Tew91OB2v6ymtieOh3iwu2V8d4ow5jDTV8HowHcn8
J9VBbIOCY6c0rrcRwe7cj9ThhLSWT/+fFfQZCQt1PVaHnCZjvvYfKyiBp7Qh
r1gdMos8X1fOrqDBa3+o5hXq8KA7Ifbk2ApKehK1eOaFOqSG6Gc1fFxBUz8T
09h61MF/gnGBXrqCsg/ef8fg1IAUk4SPhwJW0Hlv4SpeXg2oN6KdMvRZQYdd
j+eK8WvgvBQ4vrR7BZls3npcXUQDFvlm3/k5r6A+sXmKh5wGrP3zvnPSeAWJ
1OiHV+tpQLZJuMEFkRUUy9csG+mnASL7Z8L1y1jIf2Udz9n9GmB74t4v4ccs
ZP/7+o/LQRqQ+IC/c/QeC8kO7m9+EKIBp8YX80MyWKiyROBw70kN8H9mHap7
ioXm3bY3Gl7XgNApTTELOxbyvP91/99XGlBnxrn70hAT8ZE95f60aoBN2Tn3
qz1MVJHR/f5nuwa8dDN/ktLBREIprQZzHzQgXn7vkeBGJqoPK+YaG9IArbip
to57uPaaRt3t/KsBvFrVkipBTDT+WbT3seo6iHv9SfPPdwYKJplZ+SasAzAo
Gy4bWUa5NT+S1yWuA7rlwckdfcuo3+/Oh8WkddC6LeLjz45lZFXN9Ey+sg4+
7o3eIf5iGVF8K49W3F4Hp6TVejizllH3E40c3vJ10H9H+VTSzmUEO6VYBV/W
Qd7XoZH1Lf8Q6c5s2R8jTVgc4La+emUJxR3z0WJs0oQoQ7rhuYQltGDfW8AO
mkDrvesfFrWE+phNeUIWmnBQsviUjt8Suut+6zrVSRMeFh87bm60hLQkt57Y
fUATTDNntF4OLKJtKfmmLzM0oTvf4DxZcRElRfl0pC5rwmmngmyOxAXUVksy
UXfTgsNXdK8c0vmFGNvj9F4Va4GLXkJv88AcSk/r55oS1gY+nX7DuRtjKBof
yG8f0Iao95TK1oFu5Klgl68RpA0e8VLSXGe6kYnbi/V1B7Xhav77MSm1bkS0
PrAZOqwNmYUx3W1HutDpx5ER5GPa8Hb4dqEfxyd0Lkz2Y94ZbTAS52zwU+hE
V9j3Xii8pQ2pyTLnI4++RiEbP0qgTG34cO3sQ8+KV8g5zCr7XRYeL9ObtbDQ
jMTGtZ59z9aG9AHZ4C3HXqLrLWwTOg+0AU4fb3AOa0C3LuWYPn2iDc2PZz/e
rq9EUS2Sby2fakPXucaBv4ZP0W72pJ09ldpQXMXRV138BMmHhR1eqsbzOz0j
fjqzFN11Nc/c2KAN1Aun/4qN56PTl55R2xq14ebenRzB7XnIu0XjicdLbRA3
FLlzqywbKW+UaIt+rQ3OCSKdC4vpiDMs0VWwVRuGuo/yuNVdQWMFrJHMN9rw
svWNVhv7edQ8FhKs2a4N6pcc2uN5j6N78hNLz99qg+IUm1eXwwuT/wAfiuw/

          "]]}}}, {
      DisplayFunction -> Identity, AspectRatio -> 
       NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
       AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 300, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None}, 
       PlotRange -> {{0, 17.8076171875}, {-29.999999999999737`, 
         2.095861375725646}}, PlotRangeClipping -> True, PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{
         RowBox[{
           SubscriptBox["x", "1"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["x", "2"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["x", "3"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV2Xc8ld8fAHAzoozsfe+19zNEhOcTFRFKC0lKaFD6Ji3S1kCUUrJCSilF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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k4VF8fAHAkZAszw5DIPnesY0lI82WWay9SZCsqqSgiESItVBSKolLZ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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQPSdoflpr8gw73k3i23s2Hd/v/iRR827cMXsY/26v
5uLbcdfgfJ6AQ3+2+j+H8w0YI+uUAz/C+X9TouT/3f0G59fab/Nze/wHzved
blly04HRAcY38XLtcPNhgfNzDl1dU+PJDud/OjKNzVWYC86/yNSq7iLJC+f/
O7W49uprfjjffo3yJ/EIQTh/tQBPZ8INITjfbleP1Sc7ETi/jnGJ//zDonB+
+uq/bwwcxeH88lnvl3AvlYDzjdUrDjCqS8H5Yj9nfHPol4bzl2UETJgtKgvn
37Py2nRrihycbxt0513SL3k4f0lzkzvzfgU4fy/D4yU/ixXhfO31KW5Jqkpw
fv6ajTNvPEXw3c94VRXPVIbzv1qt55GJUYHzv98yeWwmrQrn985lcy87i+D/
XLc45nCfGpz/41HPfxNndTjfx2P6M4kvCH7Zn5x6ri0aiPi73LdUIV0Tzj/x
o7rWRVMLzn/vsPVRzz0EP3sXf4/7BG2Ef5tMn/MH6sD5i3KXn//Dogvnxy1/
kvn9OIKfJ+TskdKuB+cLLXi7+aulPpzfU5N8ccpvBP/MXiE7nQgDOP9PaIvp
8Q0I/oypt1lfChjC+bXPbsjMzULwJzEldK+bg+Avk3v+c/85BB8AgSiagg==

          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVx3k0lXkYwHEkHVKM7ERCN0nuG3JCnkeWi8jSYslchSkzpUxuGKKGlArJ
ES2WCjUdJloQjX5yk6xlKGQNXSUNbl28bzcz5o/v+Z6PXtAR75+kJCQk3Bf6
/zne+fuTgi/bytU27+wIZMh0u0yxdWAkGMRrqZTuYch9afGIXOBp2GJz8PU5
H4asyIs8KeRmQfgjud1bPRjCH3+wXcC9BZ1lLj73bBmidfFviyFuBeTcaPC7
sJIhnNF9Rv3c52CcyOdu66VJf6pRQS/3Dbg4PQ7l76aJvGeduNxjDJ7F+746
YDlH2JJ+8fpe02BcwGGpGc+S7yH+uvP9M3BF5DUqazBD4qBiu9OIGJwYWVGZ
jIi4Z2/m9aAkDoyvEAWJvxBzV8dkJzdprExtdm7sFZJDda9LjrsswWxunlRE
7TQRPsuScVwhh8Fa/GLWoynSLpXEctBYhn3Kxl56ZpNkvqkg7vUnBWxqijCS
1f5MoERfqOb7A9b3CVujFD6RYkX5s3u7lRB3tGp4vPlAbKtTrIS2ynjxxjYH
G76AxEsWeuTzVTBop6FqRuIoOVD8fYJtp4Z2wRYPD28fJlFXJwuXFqnjrMtH
9j4YImas6FpJlib6rZu+E72kj6jSl2fwghb+Gu5T6t/XRW6FeqZfU1mJSSd4
i5b7dpABK9f7bzN1MDpVPJjb3kq2ePf9E8Toon1svlnU+XpSmJjAWURW4dKZ
QBeBYRWpkRgppCP0MCMU7DSbrxPj0hCnIMPVqOPf62a87DocKbl3pfv9agwb
z98Y0VUFnBbXmIgr+pj8sGf0lXU9iKxK5bUDDHDwnSjD0bYNZt+aj2zSMsR4
D+1kj/MdkJorw4lsNcSA+WNnPYu7gL5bEMBPW4NbRtVtThr0wdxwyr/m9iy0
XFatXrd2CNycswXqX1no4EZxasyHIVJ86ITcw7X4co17m0fYKJh3pBWtOmCE
p43qI1tOCODFXGycg9E6/KvhXdTQkw8wieXDKQPrUDPN/+pA1zgcrFZI4aQb
48G5nKldggmoSbAYU/BajzbzifkhepNwM+z2S7G0CWpljVRuuDYF3NujP882
mGBPjE/LzONpOKxk7xxyZgNeoMpiYruEoHT98wPRZlPcI67YLBr8AinHg9sz
v5nimLJiUfX8V2ipUbJd78vGU3ZqesfkZkC865RFQxkbNXGR5YTiLFy+1Lv4
oyKFx1Ls6LsmcxAn6NbO/YXCwQmTlv2WNHB13f8wOUThsF2ts6wNDba+T82e
hC04y7u+GGmQaLrjOhhO4RhGPZlyoSHhz5hovSgKJzJry2ICaEjmaXcWJVIo
ttlxKe13GjKk9p6/m0Ohamo0t6KZhqPWnaqQt+BhuV7fVzTs4DnffJlPoYZl
rs+3ThqUBeyqqZsUar976okDNGQ3So5tvEOhgcVS+6YpGnLSC7ZWllNI9eey
BlQYON6o1sapXPBGduFJTQZ+lErx635EofmZulX6ugzo8Hjh9GMKN1FjGqFr
Gbjh45hnXUehbRJbXmjFQEJ6lVELn0K7t3XJmcBAUKNJeUD9gk13LbZ0YMDA
WrUl7gWFTj2/zce6MyDNO+ezvGnBG+RjdbwZeF8yP5zXTKFLYt5s7W4Gnr8/
eti0lcJt3Wxe8B4GbumM0aRtwSb8qcV7GfgPxFBX0Q==
          "]]}}}, {
      DisplayFunction -> Identity, AspectRatio -> 
       NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
       AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 300, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None}, 
       PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{
         RowBox[{
           SubscriptBox["p", "1"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["p", "2"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["p", "3"], "(", "t", ")"}], 
         RowBox[{
           SubscriptBox["p", "4"], "(", "t", ")"}]}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   GraphicsBox[{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxd2nc4le8bAHAqysyqiMpqkFFWabgzQikrslXIKjN7770d59gcM3ucI5Vx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       "]]}},
    Axes->{True, True},
    AxesLabel->{
      FormBox["\"\[Theta]\"", TraditionalForm], 
      FormBox[
      "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
       TraditionalForm]},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->300,
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-0.07892025974135802, 
     0.07893391533543682}, {-0.023094961866208807`, 0.03455442944555009}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.05], 
       Scaled[0.05]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw12Hc81d//APArGUUJkb1H9rXutW7nVpJCJSOlZERKKloqqZTs0aAyokFU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       "]]}},
    AspectRatio->NCache[
      Rational[1, 3], 0.3333333333333333],
    Axes->{True, True},
    AxesLabel->{
      FormBox["\"r\"", TraditionalForm], 
      FormBox[
      "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    ImageSize->300,
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-30., 1.328873996597515*^-7}, {0., 2.0958613757478557`}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.05], 
       Scaled[0.05]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJw9mXk81N/3x5FUIjszY88syDY+Klm6JwrJ3kKUJEJJytJKoiKElK3sWyr7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       "], {{{
          EdgeForm[], 
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{50, 417, 415, 93, 71, 38, 39, 40, 41, 42, 43, 44, 45,
              46, 47, 48, 49, 336, 253, 185, 132, 94, 72, 352, 269, 201, 148, 
             110, 367, 284, 216, 163, 382, 299, 231, 397, 314, 412}}], 
            PolygonBox[CompressedData["
1:eJwt0klLlWEYBuBztLVDOS4UDAwEkYhySk1LVzmlZUtzaGGBDWopBCJiZYJI
5ICg7TLHH9Bka6uNuklQKGhjZsMPqK4XXVzc9/N858B7vvNmtd5q6IyJRCJR
lplVZojTS+WufMEdLnKGS/Z/5SuGaCaeMvvvco67VJNPg/0/+ZqHXCOBc/Z7
8iVd1FBAY/TgQG/EI1pIpNzuh5ynm9rwLJyVNX2cQi6bo7zVH9NKhzmFdX2G
o1SY9+UCPdw2Z/BZrwvf0+P5oE/Qq2fzRS/iih7DO31A5jEcziaz2NaHZT5t
+g2Zyhgb4d3JU0wxa34gc3jGN/OILGSaY+bz8qcclYuyX+Yywb3wH8lMnrIV
3p08Tb3eJhP4qA/Kk0zqffIEX/VimvRYVvUn4b3ox9nR27mpp7GpPyeJC+Zf
con74X6Ez9ol8kmf4ixXzUd4H34b10mm0u734f3rDfeFElKo8uyPXAlnDXcj
3EtSSSOd/43RTqw=
             "]]}]}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.368417, 0.506779, 0.709798], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{1, 416, 413, 52, 74, 112, 165, 233, 316, 13, 12, 11, 
             10, 9, 8, 7, 6, 5, 4, 3, 2, 51, 73, 111, 164, 232, 315}}], 
            PolygonBox[CompressedData["
1:eJwt0klLVXEYBvBb0GC1Kluold1UEiFERKJNNmc2CJKzFQipmRoYFNzbYLeI
CM0yIkwx8ws0qOXWsmFltcgWBQaGXyDLMhf9/tDix/O87zkcDv9zonVnSlsX
RyKRRTynX3nIVX2UBUrMWXIftSR4wV+OuJYpW7jLO1bZnWCvXsOV/8+e57B9
hmymm7estDvOHr2adkb4wyH7TfI0d3jDCrtj7Nb7+MhacyNV+mWG+c1Bu6gc
5DNp5laa9G9k6ue5rb8mSa9ll/6dbD1Or54nr/FBT5YNVOoF8gZfwxnIjZzl
kvm+3EI7Q+YuOSeLw32yV26jgxnzPZnDRR6Ze2Q+15kMZyBTaeGUeau8yZSe
Ic/RpefKBOP6clnDTn2azXqMB/p71uj1VOhfSNfbwjvoz/jFAXO6HOATKebm
cOb6LV6xzFzNjvDeTLDafJJy/QJP+UmR3QbZQCcvWRq+H4V6GXGeMMt++/Wy
ng7GWBLOn+36UWI85kf4V+3Xhe9NKv8Ax3hVgA==
             "]]}]}, {}, {}}, {{}, {}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1He81mMcBuCjvZem5mnvvSWy28nKSCki4lAkIVJKVjuVpKHsvffeZM9s
irIzyiiu++OP69z387zvOZ/39zzf9xSOKRp++m4FBQXX+ZHc049v5fUU0Z8u
FKM4JShJKUpThrKUozwVqEgff2eLXMcZDKAr19qvJPeSW+V6zmQg3TjE/i75
MJcwisr0tf+dvIGJDKI7w+3/Kx9hFqOpwt72v5c3MonB9ODQPCSPitkcT1X2
sfeDvImzGJLX8ll5WV9MTw7LOfGYfiljGG9dk7fyfFSjn/WP8mbOzhlY1+dD
fWh+T6/MK/oSpujN+ELvxeF6MR7Xp8v2zMlnk4V8os+R3RmrnyJrMY+3c3ay
M0tZaX2+bMUiNllfLnuynN2t95U/yavkLfJC2ZYlTM4dyQYs4KOcnezKMH2s
rMKr+gzZkav1c2VzvtR7c4RenCf0y3IuemM+1U/gVL0272Qeqc5+1j/LWzkn
85H32qvKa/rSzCxHWpfgyTwbJ1KD/e39Im/LGWdeMpvU5ACvbZO357NmNjKX
1KI2dVjpPXvIutTjQOtf5R1MzTxkNhlhvyRP6VcwjvocZO83eSfn5V4zmxxl
vxRP61dyEg042N7v8q7cWc4sz2KvGhv0ZZlVjrYuzTO5M05mgnUd3tVX0ZD+
1n/Iu7mAidYN2Zgzy+fM/fO6vjzPpLfgq8wwx+hleFa/WHZgrj5ZNuGz3KXs
wXj9tJwX83nPepbswjJW5zPI1ixmc85K9uIaGlkPkNvlXHmPvEi2yzwxzXpS
3sdCPs53UHZjRM5QVucNfabslL+bc5ct+TpzzrF6WZ7T52Wu9KZ8nu8R+YdY
l/f1NRQy0HqHvDffjdxfztxeDd7UV2RWGWldjuf1+ZlpGjPI3p/yvjxT7i+z
yXH2y/OCviB3SBMG2/tL3s/03EPmlVH2K/CivjDnTVOG2PtbPpB7yjNmVmnG
UK/9Ix9kRsH//+tHZjZpTgta0orWtKEt7WhPBzrSiWF+d6d8KGecz5+ZZbT9
irykL8oZUmRdjw/0tUzT2/BNZl72ZgWdrf8D56m0JA==
           "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
       AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
       Identity, Frame -> {{False, False}, {False, False}}, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
         True}, PlotRange -> {{0, 17.8076171875}, {-1.0003562148882594`, 
         1.0005094158673504`}}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"u(t)\""}, "LineLegend", DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               "}"}], ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   "17.8076171875`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.6615049503846602`*^9, {3.661505017146773*^9, 3.6615050381866107`*^9}, 
   3.6615050682858343`*^9, 3.6615051014872975`*^9, 3.661505144041278*^9, 
   3.6615051793972287`*^9, 3.6615052608737097`*^9, 3.6615054746194983`*^9, 
   3.661505586324293*^9, 3.661505627681485*^9, 3.661505658104952*^9, 
   3.6615056905408235`*^9, {3.661505737869212*^9, 3.6615057570197225`*^9}, 
   3.6615058658875227`*^9, 3.66150590160472*^9, {3.661510664785222*^9, 
   3.6615106878254766`*^9}, 3.661510747754754*^9, 3.661511239690797*^9, 
   3.661511286402752*^9, {3.661511355529517*^9, 3.6615113817740374`*^9}, 
   3.661602302974494*^9, 3.66175029056456*^9, {3.6618654021131706`*^9, 
   3.6618654227228794`*^9}, {3.66186564368841*^9, 3.6618656495108366`*^9}, 
   3.6619685284108677`*^9, {3.66196855885036*^9, 3.661968639654467*^9}, {
   3.661968714820414*^9, 3.6619687485102115`*^9}, {3.661968873381922*^9, 
   3.6619689017349367`*^9}, 3.6619689762445335`*^9, 3.6619690316617813`*^9, 
   3.661969128095849*^9, 3.661969283202526*^9, 3.6619693516958814`*^9, {
   3.661969450593679*^9, 3.66196945466055*^9}, 3.6620159055342245`*^9, 
   3.6620162585354195`*^9, 3.662016338338747*^9, 3.662016369292597*^9, 
   3.6620165198038445`*^9, 3.662028898429034*^9, {3.6620292774325757`*^9, 
   3.662029291620592*^9}, {3.662037677065407*^9, 3.662037687189554*^9}, {
   3.6620953561882076`*^9, 3.662095373035099*^9}, 3.6620964740383067`*^9, 
   3.662096550275138*^9, 3.6620966456024265`*^9, {3.6620967029502025`*^9, 
   3.662096720595668*^9}, {3.6620967520798836`*^9, 3.6620967758606815`*^9}, 
   3.6620968517098856`*^9, 3.662096894276944*^9, 3.6620969734569697`*^9, 
   3.6620971258145313`*^9, {3.6620977757553196`*^9, 3.6620978434271045`*^9}, {
   3.6620979173702874`*^9, 3.6620979408738775`*^9}, 3.66209802924426*^9, 
   3.6620980783299108`*^9, 3.662098218390795*^9, 3.662098270491557*^9, 
   3.6620983445038033`*^9, 3.6620983960061607`*^9, 3.662098473786065*^9, {
   3.6620985169035187`*^9, 3.6620985430449553`*^9}, {3.6620985812489243`*^9, 
   3.662098677085576*^9}, 3.6620987071077795`*^9, 3.662099322545975*^9, {
   3.6620997046474485`*^9, 3.6620997142775955`*^9}, 3.662114699932705*^9, 
   3.662115194126883*^9, 3.662117105650242*^9, 3.662461315492202*^9, 
   3.6624613659140344`*^9, 3.6624614894463606`*^9, {3.6624615348469267`*^9, 
   3.6624615527390747`*^9}, {3.662724553720713*^9, 3.662724606547024*^9}, 
   3.662724653837274*^9, {3.6627357600349693`*^9, 3.6627357768738985`*^9}, 
   3.6629135431767015`*^9, 3.6629142382255545`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Error of approximations of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", "(", "t", ")"}], TraditionalForm]]],
 " en ",
 Cell[BoxData[
  FormBox[
   RowBox[{"cos", "(", "t", ")"}], TraditionalForm]]],
 "\t"
}], "Subsubsection",
 CellChangeTimes->{{3.6618654316111565`*^9, 3.6618654440349913`*^9}, {
   3.6618709603824487`*^9, 3.66187096160732*^9}, 3.662016887475794*^9, {
   3.662016924422864*^9, 3.6620169342758193`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"\[Theta]", "-", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        FractionBox[
         RowBox[{"\[Theta]", "-", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "\[Theta]"], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "5"], ",", 
       FractionBox["\[Pi]", "5"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", "\"\<\[Theta]\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.2"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "6"], ",", 
          FractionBox["\[Pi]", "6"], ",", 
          FractionBox["\[Pi]", "6"]}], "]"}], ",", " ", "Automatic"}], 
       "}"}]}]}], "]"}], ",", "\"\<s9\>\"", ",", "True"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "\[Theta]"], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", 
       FractionBox[
        RowBox[{"-", "\[Pi]"}], "5"], ",", 
       FractionBox["\[Pi]", "5"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", "\"\<\[Theta]\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.2"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], "6"], ",", 
          FractionBox["\[Pi]", "6"], ",", 
          FractionBox["\[Pi]", "6"]}], "]"}], ",", " ", "Automatic"}], 
       "}"}]}]}], "]"}], ",", "\"\<s14\>\"", ",", "True"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6587601178819413`*^9, 3.658760363175195*^9}, {
  3.658760402695121*^9, 3.658760440921111*^9}, {3.6602859621318827`*^9, 
  3.660286013527278*^9}, {3.6602860441639733`*^9, 3.6602860791721463`*^9}, {
  3.6602861109086275`*^9, 3.660286227930488*^9}, {3.660286306892404*^9, 
  3.660286330658233*^9}, {3.6618652805590897`*^9, 3.6618653166444845`*^9}, {
  3.6619299490140753`*^9, 3.6619299511986065`*^9}, {3.66202079679126*^9, 
  3.6620208066206493`*^9}, {3.662913569182197*^9, 3.6629135722454453`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJw12Xk01N//B/B3QkrJ9kGLEiKhkC3LfY1dJWVLIk12KhGVvbFlyVYhlTSW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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJw1mGc81X3cxzlmoYEySqUysyVC/29kXYVsZWUeRHbl2DuEjIOSEUfhuOLI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        "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox["\"\[Theta]\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, 
     PlotRange -> {{-0.6283185050723044, 0.6283185050723044}, {0, 0.2}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, Ticks -> {{{
         NCache[Rational[-1, 6] Pi, -0.5235987755982988], 
         FormBox[
          RowBox[{"-", 
            FractionBox["\[Pi]", "6"]}], TraditionalForm]}, {0, 
         FormBox["0", TraditionalForm]}, {
         NCache[Rational[1, 6] Pi, 0.5235987755982988], 
         FormBox[
          FractionBox["\[Pi]", "6"], TraditionalForm]}}, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       TemplateBox[{
         RowBox[{"\[Theta]", "-", 
           RowBox[{"sin", "(", "\[Theta]", ")"}]}]}, "Abs"], 
       TemplateBox[{
         FractionBox[
          RowBox[{"\[Theta]", "-", 
            RowBox[{"sin", "(", "\[Theta]", ")"}]}], "\[Theta]"]}, "Abs"]}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.661865311773385*^9, 3.661865316910887*^9}, {
   3.661872103766143*^9, 3.661872128289472*^9}, {3.6618721744360285`*^9, 
   3.6618721985670757`*^9}, 3.661929706941183*^9, 3.661929780411048*^9, {
   3.6619299456687207`*^9, 3.661929951527839*^9}, 3.6619300117623777`*^9, 
   3.661930450372497*^9, 3.662020807201316*^9, 3.6629135773493867`*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJw12Hk0Vd3/B/BDQlEJRaWSMitUotL5UEIlkSky3AzXELoZytw1JAl5kNST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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJw1lPk7FHgAhy1dKh2mYwpP7OZoHYPlScKHXB0IWzka0yy5WdekcaRkY2ZW
aEaiWnJUUnJlIunbjHvRlBxNhZ7tEa2UqxzV2u2HfZ/nfd7/4FXzDnP1lZWR
kXH6z29NRcuaI9NScjHnG20o6+9JGj0hJYm1m3KpWm3QcJXMzLT2kTx57R3G
SS3QWp29RMGgl9iuM2s5PNuE9Kgb/lr53WSv2/n3WVGNWGH+iWv7oYuMMMIu
LeoQQ3G/on2w5xOi0H2nywYieKU+5anbS4hZo5+s9xYCRhtFJ/FtO5nrKPtn
Z2cdoi9Myr5vaiXt8osTtCprUEvbTWcwmsjG31ZO3nKpBsXDbHRQX0y2sz4/
XL6tEvo5TnNtCfVEyhacD48uRbuKve9YnZAo6oae3FxzDYLGeLOfQsvJmnq3
UVHwFfgswEBGt5AYWb9zCNURwEk27uboXAH5o0Li7DXHh8lioXpfcwG5vZBs
5tjMx8oVOptvMwvI+7BjHTpMPoQbqHL0zHwyIBvW87fgHBTpr26EzeSRnOxT
3KZP6ThSazkxkJlDOPXxD1MyuTAiwqFqvRwSK3Cu9dbjYlmTzvPU1mxi3baa
b97KQeVjaoPplwskUew+NPk5BUtGxjOzfLLIRJyzGt0nGbc25Js4GQqI6sQd
5jbDJIwPy8rE5XHJXYdzVN+8GDjYUxR1+jjE2kaiTO1j4/q1H7b2r+KQyccF
su2r2GD42uxGQjIZcRqM1k+IRudfZzLkvJIIR/u08jw9Cgfq1u6iGseS7GJF
P0XjIKyINfSLLWKTslV6KceKAiA2+Zn3knKclLBVeM8o/jAQZnZdmYwirdaq
5rmTPlDxpjW7MoNJ25f7m12Yh5E6GL5qIwKIqyRmaD3cMU+vPPRCxZfst+Lw
n6scRFlZ0KMWoRdJOSu2bRE6IrVkjOHMciNqdveVnFn2CLoa/uGZgQtJrp3q
fmZghTTL4QXxgC25IPWcFA8YIyPkuVVxlSHRXBqK4qrv8S7Pb7zHfRNOuayb
6nGXR/J9BVMKE6D1z9IoTBo4IzLxs0YOOJndwZg1MoN/zInSKfoBXLqYnDhF
twEvYV45OM8T1aLye0F5e9Er2mk3Ec5ElHnR2/FwZ8w111QHVPlBL1ZW7F91
CLw9x0OLugPhYhewpLDbA8odxuqvPoagVImmPfCRjrwAjz+1L0fg5j4ruR8v
/wJxaO+OwoHjUDVJ7Mgd8Iem1VCcJYsDlv6RCF0WG5a07dw0Ry7C1+2KiHGM
gacKN+ulBg8b+LcdmjRikTanU8GW/o6jljhHl8ZhuoL1ptwiHTdtZGhci5Ng
rj1dnLFIACVBYk/IoiTonl5L+U6SA+Gri7zrj7h4bUCdHq8oxJifU6dLhQAZ
/owYO1o58pcG7hzSvQKpWkPUWYW7EO23b8+Qvw6+xWL1uvZ6DGuGN25pKEWa
8hnj18vFsI2PqLCQq0SxZM2hoagmTFRV/KrgX41bE18tewtaoWOcu+Noeg2G
Gz1S7onaMSnpCRy7WoeZTot9l7ZK0HuQKvL8+gCzBeKQao0nUHWej09YKcJg
TEmkUn8XzkQm+uGeGKbLGvrZ0d1Y3811W9jTCIMP/E+Spb0wfWNX7Pa4CZQI
TSf1uj5MsCJ5L461ILDk3fJIFylkTgQ+OPy1FZZPlUsjpqX4/2f/As50Y5o=

        "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox["\"\[Theta]\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, 
     PlotRange -> {{-0.6283185050723044, 0.6283185050723044}, {0, 0.2}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, Ticks -> {{{
         NCache[Rational[-1, 6] Pi, -0.5235987755982988], 
         FormBox[
          RowBox[{"-", 
            FractionBox["\[Pi]", "6"]}], TraditionalForm]}, {0, 
         FormBox["0", TraditionalForm]}, {
         NCache[Rational[1, 6] Pi, 0.5235987755982988], 
         FormBox[
          FractionBox["\[Pi]", "6"], TraditionalForm]}}, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       TemplateBox[{
         RowBox[{"1", "-", 
           RowBox[{"cos", "(", "\[Theta]", ")"}]}]}, "Abs"], 
       TemplateBox[{
         FractionBox[
          RowBox[{"1", "-", 
            RowBox[{"cos", "(", "\[Theta]", ")"}]}], "\[Theta]"]}, "Abs"]}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.661865311773385*^9, 3.661865316910887*^9}, {
   3.661872103766143*^9, 3.661872128289472*^9}, {3.6618721744360285`*^9, 
   3.6618721985670757`*^9}, 3.661929706941183*^9, 3.661929780411048*^9, {
   3.6619299456687207`*^9, 3.661929951527839*^9}, 3.6619300117623777`*^9, 
   3.661930450372497*^9, 3.662020807201316*^9, 3.662913579409811*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure: Solution of a swing with the energy method", "Subsubsection",
 CellChangeTimes->{{3.6618654525307026`*^9, 3.661865459770751*^9}, {
  3.6618709554869876`*^9, 3.6618709561504517`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"energy", "[", 
      RowBox[{"0.1", ",", "0.092", ",", 
       RowBox[{"T", "\[Rule]", "10"}]}], "]"}], ",", "3"}], "]"}], ",", 
   "\"\<s6\>\"", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.6576121437967043`*^9, 3.6576122531381187`*^9}, {
   3.657612331581646*^9, 3.657612352310302*^9}, {3.6576123997538967`*^9, 
   3.6576124478258977`*^9}, {3.657612589987505*^9, 3.6576125902807226`*^9}, {
   3.657615967700947*^9, 3.657615974858012*^9}, {3.6576161470850763`*^9, 
   3.65761614710509*^9}, 3.6576162305051117`*^9, {3.6578699448461013`*^9, 
   3.657869985235675*^9}, 3.65787919371044*^9, {3.657879241960598*^9, 
   3.657879311410736*^9}, {3.6578793721987667`*^9, 3.657879373081391*^9}, {
   3.6578794406892366`*^9, 3.6578794705393505`*^9}, {3.6578795537492375`*^9, 
   3.657879557315761*^9}, {3.657879596606578*^9, 3.6578795972810583`*^9}, {
   3.6578797947167683`*^9, 3.657879804534716*^9}, {3.6578798367465115`*^9, 
   3.6578798477092705`*^9}, {3.6578803927379932`*^9, 
   3.6578804301244416`*^9}, {3.657880513662561*^9, 3.6578805266737795`*^9}, {
   3.6578806014336753`*^9, 3.6578806130649204`*^9}, {3.6578806511308455`*^9, 
   3.6578807365993423`*^9}, {3.657881399422903*^9, 3.657881414791766*^9}, {
   3.6578824642642374`*^9, 3.657882485241083*^9}, 3.657882568048688*^9, 
   3.6578826250690374`*^9, {3.657882820760527*^9, 3.657882862794287*^9}, {
   3.6578828991850405`*^9, 3.657882915718728*^9}, {3.657883051700961*^9, 
   3.657883076744685*^9}, {3.657883137317565*^9, 3.6578831437551203`*^9}, {
   3.6578832635618973`*^9, 3.65788326834529*^9}, 3.657883329717083*^9, {
   3.657883647914725*^9, 3.6578836491626077`*^9}, {3.6578837001426754`*^9, 
   3.6578837014716177`*^9}, {3.657883745328664*^9, 3.6578837563664637`*^9}, {
   3.657883842861676*^9, 3.6578838569766765`*^9}, 3.657884077275651*^9, {
   3.6578844397321696`*^9, 3.6578844826935625`*^9}, {3.6578845320234723`*^9, 
   3.65788453413897*^9}, {3.6578846519793787`*^9, 3.657884652090455*^9}, {
   3.6578847106178627`*^9, 3.657884728749695*^9}, {3.657885605536189*^9, 
   3.657885747672779*^9}, {3.6578857794192457`*^9, 3.6578857974610133`*^9}, {
   3.657885914828854*^9, 3.657885999927077*^9}, {3.6578862300059023`*^9, 
   3.6578862382257185`*^9}, {3.657886292449093*^9, 3.65788629484779*^9}, {
   3.6578863593854666`*^9, 3.6578863606693716`*^9}, {3.657886577534856*^9, 
   3.6578866610869746`*^9}, {3.6578867388359976`*^9, 
   3.6578867498698053`*^9}, {3.657886890223132*^9, 3.657886892344634*^9}, {
   3.657887149076324*^9, 3.6578872173956375`*^9}, {3.6578872917352467`*^9, 
   3.6578872924697676`*^9}, {3.657887326540876*^9, 3.6578873268500986`*^9}, {
   3.657887368473555*^9, 3.657887368630666*^9}, {3.657887411535289*^9, 
   3.657887411649373*^9}, {3.657981129118106*^9, 3.6579814135789866`*^9}, {
   3.657981448339356*^9, 3.6579814483943963`*^9}, {3.6579814978744135`*^9, 
   3.657981498834092*^9}, {3.657981546010332*^9, 3.6579815486982346`*^9}, {
   3.6579815922420497`*^9, 3.6579816484168043`*^9}, {3.6579816866358523`*^9, 
   3.6579817924917655`*^9}, 3.6579819060101013`*^9, {3.6579820004589424`*^9, 
   3.6579820563124695`*^9}, {3.6579821107203064`*^9, 3.657982126888748*^9}, {
   3.6579822019042006`*^9, 3.6579822331619153`*^9}, {3.6579822812659435`*^9, 
   3.6579823327693925`*^9}, {3.6579824089683175`*^9, 3.657982436920099*^9}, {
   3.657982477191599*^9, 3.657982495599626*^9}, {3.6579825703545294`*^9, 
   3.6579825729914107`*^9}, {3.65798267435905*^9, 3.6579826941980906`*^9}, {
   3.6579827375597763`*^9, 3.6579827636222205`*^9}, {3.657982813542549*^9, 
   3.6579829436286097`*^9}, 3.6579829953322115`*^9, {3.6580359897898674`*^9, 
   3.658036060637006*^9}, {3.6580360951734467`*^9, 3.658036102149384*^9}, {
   3.6580361692278543`*^9, 3.658036169308912*^9}, {3.658036237431121*^9, 
   3.6580362385909414`*^9}, {3.6580362726450415`*^9, 
   3.6580364157162924`*^9}, {3.658036446427026*^9, 3.658036613005913*^9}, {
   3.658036644255028*^9, 3.6580366554539533`*^9}, {3.658036823258707*^9, 
   3.6580368756958294`*^9}, {3.658036918611187*^9, 3.6580371447860966`*^9}, {
   3.6580372541705093`*^9, 3.6580373174262733`*^9}, {3.658037380182686*^9, 
   3.6580373814175587`*^9}, {3.6580374730654173`*^9, 3.658037477041231*^9}, {
   3.6580381008103514`*^9, 3.6580381090491915`*^9}, {3.6580382596527634`*^9, 
   3.658038273215361*^9}, 3.6580383160146503`*^9, {3.658038555579188*^9, 
   3.6580385572393627`*^9}, {3.658038653694624*^9, 3.6580386538377247`*^9}, {
   3.6580387094620895`*^9, 3.658038709605191*^9}, {3.658038779653764*^9, 
   3.6580387797328196`*^9}, {3.658038814998354*^9, 3.6580388151724772`*^9}, {
   3.6580388967187586`*^9, 3.658038898990366*^9}, {3.65803894589456*^9, 
   3.658038947390619*^9}, {3.658039020901642*^9, 3.658039021508071*^9}, 
   3.6580390734047985`*^9, 3.6580391247091055`*^9, {3.658039231564727*^9, 
   3.658039234853053*^9}, {3.6580399976597013`*^9, 3.6580400033277016`*^9}, {
   3.658040079636716*^9, 3.658040099962244*^9}, {3.658053461311554*^9, 
   3.658053464309675*^9}, 3.6580535528583403`*^9, {3.658053659102528*^9, 
   3.658053660021179*^9}, {3.658053798863436*^9, 3.65805387609301*^9}, {
   3.6580539161883845`*^9, 3.6580539528453274`*^9}, {3.658053995586573*^9, 
   3.6580539964441824`*^9}, {3.658075113552378*^9, 3.6580751146385307`*^9}, 
   3.6580787210611715`*^9, 3.658078810517234*^9, {3.659158616716791*^9, 
   3.6591587260690327`*^9}, {3.659158758319813*^9, 3.659158944321196*^9}, {
   3.6591590243209925`*^9, 3.659159059259672*^9}, {3.659159616811483*^9, 
   3.6591596744922256`*^9}, {3.6591597357965283`*^9, 
   3.6591597558627024`*^9}, {3.659159819624967*^9, 3.659159862413191*^9}, {
   3.659160025165151*^9, 3.659160084436017*^9}, {3.659160138719361*^9, 
   3.6591603715998573`*^9}, {3.659160401653085*^9, 3.659160437730569*^9}, {
   3.6591604789897127`*^9, 3.6591604831106234`*^9}, {3.6591605303309774`*^9, 
   3.659160543666397*^9}, {3.659160579995058*^9, 3.6591608173445015`*^9}, 
   3.6591608545567865`*^9, {3.659160887331938*^9, 3.6591609025947185`*^9}, {
   3.65916094201056*^9, 3.659161031492777*^9}, {3.6591611230614586`*^9, 
   3.659161143178656*^9}, {3.6591619861626835`*^9, 3.659161994228381*^9}, {
   3.659162051164598*^9, 3.6591620996098175`*^9}, {3.6591622379865603`*^9, 
   3.6591622681178436`*^9}, {3.6591627940754814`*^9, 3.659162883878914*^9}, {
   3.6591629189847136`*^9, 3.6591629190837817`*^9}, {3.659163089942724*^9, 
   3.6591631179004726`*^9}, {3.6591631549046106`*^9, 3.659163198930708*^9}, {
   3.659163305540013*^9, 3.6591633400103607`*^9}, {3.6591633894743*^9, 
   3.6591634043087783`*^9}, {3.659163589845931*^9, 3.6591635968358684`*^9}, {
   3.6591636482511873`*^9, 3.6591636518006926`*^9}, 3.6591637324846845`*^9, {
   3.6618644742450705`*^9, 3.661864532047213*^9}, {3.6618645746630745`*^9, 
   3.661864597903304*^9}, {3.661864683343041*^9, 3.6618647597418256`*^9}, {
   3.661865254998163*^9, 3.6618652616991105`*^9}, {3.6619304619376593`*^9, 
   3.661930463351658*^9}, {3.661953867235011*^9, 3.6619539461236997`*^9}, {
   3.6619539985397005`*^9, 3.6619540228248434`*^9}, {3.661954056477599*^9, 
   3.661954074652429*^9}, {3.661954112219948*^9, 3.661954176091036*^9}, {
   3.6619542061162305`*^9, 3.6619542146912837`*^9}, {3.6619624417578325`*^9, 
   3.661962459700719*^9}, {3.661962513013278*^9, 3.661962574263274*^9}, {
   3.6619626545403767`*^9, 3.661962671771064*^9}, {3.6620206469763517`*^9, 
   3.662020659795556*^9}, {3.6624618508315926`*^9, 3.662461934058881*^9}, {
   3.6625505970115275`*^9, 3.662550614644032*^9}, {3.6625506556681013`*^9, 
   3.662550679947294*^9}, {3.662551192587555*^9, 3.6625511932180004`*^9}, {
   3.6625513707065597`*^9, 3.662551380865758*^9}, {3.662551427649908*^9, 
   3.6625514530749245`*^9}, {3.6627245153779573`*^9, 3.662724531520603*^9}, {
   3.662913624956209*^9, 3.6629136262527328`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \\(s\\)]\\) = \
\\!\\(\\*RowBox[{\\\"0.20146456931128331`\\\"}]\\)\"\>",
  StringForm[
  "\!\(\*SubscriptBox[\(\[Theta]\), \(s\)]\) = ``", 0.20146456931128331`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6619541420620193`*^9, 3.661954176258181*^9}, {
   3.661954206506506*^9, 3.6619542149014316`*^9}, {3.6619624470527124`*^9, 
   3.6619624598679414`*^9}, {3.6619625290394187`*^9, 3.661962578123576*^9}, 
   3.661962673259034*^9, 3.6620206620949273`*^9, {3.6624619058226805`*^9, 
   3.662461952985289*^9}, {3.6624628561544504`*^9, 3.662462881962514*^9}, 
   3.6624630841471167`*^9, 3.6624634212327013`*^9, 3.6624636011625257`*^9, 
   3.6624644726825037`*^9, 3.6624654086431*^9, 3.6624654954912148`*^9, 
   3.6624655465498486`*^9, {3.6625505798753843`*^9, 3.6625506147611227`*^9}, {
   3.662550655945301*^9, 3.6625506801944714`*^9}, 3.6625511933761015`*^9, {
   3.662551372735998*^9, 3.662551380958824*^9}, {3.662551428207303*^9, 
   3.662551453248047*^9}, {3.6627245068440304`*^9, 3.662724531866547*^9}, 
   3.6629025919552765`*^9, 3.662902626839995*^9, 3.662913626715415*^9, 
   3.6629136587578497`*^9, 3.662913724340621*^9, 3.6629137931810465`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final time: \\!\\(\\*RowBox[{\\\"9.426757046705006`\\\
\"}]\\)\"\>",
  StringForm["Final time: ``", 9.426757046705006],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6619541420620193`*^9, 3.661954176258181*^9}, {
   3.661954206506506*^9, 3.6619542149014316`*^9}, {3.6619624470527124`*^9, 
   3.6619624598679414`*^9}, {3.6619625290394187`*^9, 3.661962578123576*^9}, 
   3.661962673259034*^9, 3.6620206620949273`*^9, {3.6624619058226805`*^9, 
   3.662461952985289*^9}, {3.6624628561544504`*^9, 3.662462881962514*^9}, 
   3.6624630841471167`*^9, 3.6624634212327013`*^9, 3.6624636011625257`*^9, 
   3.6624644726825037`*^9, 3.6624654086431*^9, 3.6624654954912148`*^9, 
   3.6624655465498486`*^9, {3.6625505798753843`*^9, 3.6625506147611227`*^9}, {
   3.662550655945301*^9, 3.6625506801944714`*^9}, 3.6625511933761015`*^9, {
   3.662551372735998*^9, 3.662551380958824*^9}, {3.662551428207303*^9, 
   3.662551453248047*^9}, {3.6627245068440304`*^9, 3.662724531866547*^9}, 
   3.6629025919552765`*^9, 3.662902626839995*^9, 3.662913626715415*^9, 
   3.6629136587578497`*^9, 3.662913724340621*^9, 3.6629137931900396`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Switch time: \\!\\(\\*RowBox[{\\\"2.2703231719666306`\
\\\"}]\\)\"\>",
  StringForm["Switch time: ``", 2.2703231719666306`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6619541420620193`*^9, 3.661954176258181*^9}, {
   3.661954206506506*^9, 3.6619542149014316`*^9}, {3.6619624470527124`*^9, 
   3.6619624598679414`*^9}, {3.6619625290394187`*^9, 3.661962578123576*^9}, 
   3.661962673259034*^9, 3.6620206620949273`*^9, {3.6624619058226805`*^9, 
   3.662461952985289*^9}, {3.6624628561544504`*^9, 3.662462881962514*^9}, 
   3.6624630841471167`*^9, 3.6624634212327013`*^9, 3.6624636011625257`*^9, 
   3.6624644726825037`*^9, 3.6624654086431*^9, 3.6624654954912148`*^9, 
   3.6624655465498486`*^9, {3.6625505798753843`*^9, 3.6625506147611227`*^9}, {
   3.662550655945301*^9, 3.6625506801944714`*^9}, 3.6625511933761015`*^9, {
   3.662551372735998*^9, 3.662551380958824*^9}, {3.662551428207303*^9, 
   3.662551453248047*^9}, {3.6627245068440304`*^9, 3.662724531866547*^9}, 
   3.6629025919552765`*^9, 3.662902626839995*^9, 3.662913626715415*^9, 
   3.6629136587578497`*^9, 3.662913724340621*^9, 3.662913793192541*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJw92nk8VN//B/BBKMo+Yw0zoxIlslTIOfaUZC1JoiIpkkQL2UlKUdaEGEXW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       "], {{{}, {}, {}, {}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{801, 802, 693, 743, 694, 695, 696, 697, 698, 699, 
             700, 701, 702, 703, 704, 765, 756, 793}}]}]}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{801, 791, 750, 757, 739, 738, 737, 736, 735, 734, 
             733, 732, 731, 730, 729, 728, 727, 726, 725, 724, 723, 722, 721, 
             720, 719, 718, 717, 716, 715, 714, 713, 712, 711, 710, 709, 708, 
             707, 706, 745, 705, 753, 744, 762, 749, 785, 772, 799, 
             781}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1Hecz3UcwPE7hTKyolLKnrncdecUpbiQ7YwSGidJuAslo6VltZBZtrJH
2atFUtmjrAYhRbQo7eebP573+n7ev+P3/X4+38eVycrJzE5MSEho4Ec00Y91
+jL3cxvXk4sLuJDcsfZ76/UVusS/J5U88Xs++0hf5QEakkYx8906hb7cQd74
P8036Ai60oiaXGr+uU7lMe7kovh+8491JA9yO+kUN/9Cp9GP9lwc92S+UUfR
jcaUNjuk83mWWpQw26PT6c9dVDQ7posZSr64Z7NP9DUeopr1j7qCJpSx/lYX
8Bw3cJnZXp3BAJKsf9LVdKCS9fe6hBtd/63DSHH9m77HTa7/0/yxD64/1bo6
OvZL/9D62l2v1ZN6q67U2vpPnKc21bJ6WG/RhXGP+pdm6POarL9qPX1X6+i/
cW9c7nqfvhn75vpPHch1rn/WNXSksvUPupTh8R5Zn9b3KRBnY/2ZjqEHzeI+
ucJ8v77F43SiYOy9+SYdS0+ax31xSeyJzzbrOLJpEftFIQpThKLxDsZ7Fe9K
nHecSzxPfCcluZKrKMXVXBPvSpxp7BnlKE+FeDfi3OI5qULVeC73sUXHk0NL
bo53JJ7BZ1t1Ag/TKs4vvtf8gM7kCe6O84vnMt+mr9OLzDivuEfzL3UWT3IP
1eNZzbfrG/Smddyv2RFdxAvxPsTzmX2ls3mKe0mKfTLfoRPpQ5t4VrOj+jaD
432IvTH7WufwNDWsf9G13Bd7YX1cl/EiqdZn9IN4R+IsrHfqJNJdn9VH4hlc
n9JVtI09tv5O32EI9eNMzL7RuQwiK76f5Dhfn+3SyTxKOzLiDM0P6jyeoXOc
ldkJXc5LpFn/rh/GeZ37Q3j+b2KKy/8BCB2Ldw==
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1Hecz3UcB/DfIYpChabZkJGmSLL3duZxd9VdW3VFVvbes2ggZ28Zhxbt
SYmmNEhkj0pGpOf74Y/nvV/v9/d+n999v9/P50pnZCU/lZRIJOJHQ+7LlUgU
Y7u8jLH0phGNaUJTmtGcFrSkFa2532ev4Cd5OeN4jq5m5Tgsv8tMRuhrkJtv
9ck8IF/Jz/Iramtei3XUeizhImbRkfGuDVSrcEb+kj5005fniPwe2bQhw+wq
fpFXMIG+tKUd7elAR1LoRGdSSSPTZ6/mV3klE+lHOg+aX8MOeRWT6M+zZhU4
Kr/PrHjOPGR2LTvl1UxmAN3NKnJM/oDZ8Vx52Kw4v8k5PM8gfVXOypvjWdBD
fzN/yh8yJ54rj5iVYJe8hhcYrL+b/+SvYj166ivxl/xR3IfciEuYqx+p1iQP
3+mnqs25jAz9o2pJfpenqcmslcer9cnPbFKYYj5ErcYizulfVduxgi3xd6pN
WUZh5pHKaga73ku9hYX8rZ+utol9w8fxXNXGLKVg3AOdYx3XRqm1uIBsOvC9
+YtqCy4nU/+YWord8rrYN3IDCjBVP1S9hwRb457i3Mi3clz+hPmM1tcmLz/E
nuFxuTR75Nfju2O9ODdmt/GP/CkLYs/QxawMf8hv8BLDYt+b3c4J+TMWxp7h
CbPr2Cu/ycsMj/3Ak+bXs09+K85cnMt4h3HP8bfF98Ua8btJ5/9PZPE0z8S5
jrMWezyuWecG9stvx7uPvRLny+wOTsqfsyj2eKxjdiMH5PVxluSGXMwcOrGK
6XF/anUWk8RM2rOSr12fojZjOZcynzRGxflU7+SUPENty8Y4P2oTCsW6+jFq
HfKxLZ6r2pIi9Ih7VstyUN4Qa8Vz1N9LLr6J9xtnXq7MaXkTS+JMxfMyu4lD
8juxz+M748yb3cW/8hcsZay+LhfyY7wztRVFWUA6OfRy7X/NS7mz
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwNzkVWA1AQBMCfBNfgLrkSR2APnA539+Du7u5OLer19MxmEo0tDc2REEIT
rdEQzmijnQ466aKbHnrpo58BfnimIhZCglzqSKGAG7dPznlgkAuGGGaEUcYY
Z4JJpphmhlmSzDHPAossscwKq6yxzgabbLHNDrvssc8Bhxzxwi1lfs2mlijV
xPlyq5R5pHKpl8hMAu/6I8cU6en8ml+544oTiu0z+DO/cc81pXZZRPjQnyg3
5xDjW6+S+aRRQyH1nLr9A0QORSw=
           "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
         True}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{
        "\"\[Theta]\"", 
         "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", "\"u/l\""},
         "LineLegend", DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   GraphicsBox[{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwV1nc81f8XB/AQ0lKorERRKlFoWceOSnQR0iDhS4jKlpE9s3fmvVbIHtc4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       "]]}},
    Axes->{True, True},
    AxesLabel->{None, None},
    AxesOrigin->{0, 0},
    DisplayFunction->Identity,
    FrameLabel->{{None, None}, {None, None}},
    FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{"ScalingFunctions" -> None},
    PlotRange->{{-0.0006616573023518235, 
     0.2022769740506687}, {-0.04123471222651929, 0.092}},
    PlotRangeClipping->True,
    PlotRangePadding->{{
       Scaled[0.05], 
       Scaled[0.05]}, {
       Scaled[0.05], 
       Scaled[0.05]}},
    Ticks->{Automatic, Automatic}], ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k4lG0XAPAZ20yyhRlLwsxoo0RJKpwjSkqyRFkqjBBCSLZEspYIlbyU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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwdlnc81W8Ux+8lspVQ9r3WLaKsUvR9DjKSZLeL7EKopCIiREZkVIgoIitS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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxF1nk4Vev3APBzDjJkyHDO2eTK2USGcE4ajPulolKSKMk8RUkRZUhEoTKU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          "]]}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwl13c8lV8YAPAr0jCS7eLe971GhWQlSr2PBpJESZokq2SrJElRRiWRlCiR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          "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None}, 
       PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{
        "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(v\\)]\\)\"", 
         "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(h\\)]\\)\"", "\"W\"", 
         "\"\\!\\(\\*SubscriptBox[\\(E\\), \\(v\\)]\\)+\\!\\(\\*SubscriptBox[\
\\(E\\), \\(h\\)]\\)-W\""}, "LineLegend", DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]}], "}"}]], "Output",
 CellChangeTimes->{{3.661954142319208*^9, 3.6619541765133457`*^9}, {
   3.6619542067717104`*^9, 3.6619542151826305`*^9}, {3.6619624478905563`*^9, 
   3.661962460135893*^9}, {3.6619625293057632`*^9, 3.661962578889024*^9}, 
   3.661962674014062*^9, 3.662020662923127*^9, {3.662461907037616*^9, 
   3.6624619532918587`*^9}, {3.6624628564904947`*^9, 3.662462882318796*^9}, 
   3.662463084441413*^9, 3.662463421577733*^9, 3.662463601511025*^9, 
   3.6624644730912724`*^9, 3.6624654091962132`*^9, 3.662465495992504*^9, 
   3.6624655468657675`*^9, {3.662550580316697*^9, 3.6625506151804013`*^9}, {
   3.662550656342568*^9, 3.6625506805307083`*^9}, 3.6625511937643766`*^9, {
   3.66255137312027*^9, 3.6625513813410935`*^9}, {3.6625514285495443`*^9, 
   3.662551453584285*^9}, {3.6627245073386145`*^9, 3.6627245330218353`*^9}, 
   3.662902593040045*^9, 3.6629026275935287`*^9, 3.6629136321459846`*^9, 
   3.662913664189068*^9, 3.6629137297859745`*^9, 3.662913798910132*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Applicable start conditions in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Theta]", ",", 
     OverscriptBox["\[Theta]", "."]}], ")"}], TraditionalForm]]],
 "-plane for the energy method"
}], "Subsubsection",
 CellChangeTimes->{{3.6619548808239255`*^9, 3.661954898695542*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Quiet", "@", 
    RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x", "+", 
                RowBox[{"1", "/", "g"}]}], ")"}], "2"], "+", 
             FractionBox[
              SuperscriptBox["y", "2"], 
              RowBox[{"g", "/", 
               RowBox[{"(", 
                RowBox[{"m", " ", "l"}], ")"}]}]]}], "<", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["1", "g"], ")"}], "2"]}], "||", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x", "-", 
                RowBox[{"1", "/", "g"}]}], ")"}], "2"], "+", 
             FractionBox[
              SuperscriptBox["y", "2"], 
              RowBox[{"g", "/", 
               RowBox[{"(", 
                RowBox[{"m", " ", "l"}], ")"}]}]]}], "<", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox["1", "g"], ")"}], "2"]}]}], ")"}], "&&", 
         RowBox[{
          RowBox[{"x", " ", "y"}], "<", "0"}]}], ",", 
        RowBox[{"Not", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "+", 
                 RowBox[{"1", "/", "g"}]}], ")"}], "2"], "+", 
              FractionBox[
               SuperscriptBox["y", "2"], 
               RowBox[{"g", "/", 
                RowBox[{"(", 
                 RowBox[{"m", " ", "l"}], ")"}]}]]}], "<", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["1", "g"], ")"}], "2"]}], "||", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "-", 
                 RowBox[{"1", "/", "g"}]}], ")"}], "2"], "+", 
              FractionBox[
               SuperscriptBox["y", "2"], 
               RowBox[{"g", "/", 
                RowBox[{"(", 
                 RowBox[{"m", " ", "l"}], ")"}]}]]}], "<", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["1", "g"], ")"}], "2"]}]}], ")"}], "&&", 
          RowBox[{
           RowBox[{"x", " ", "y"}], "<", "0"}]}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", 
         FractionBox["4", "g"]}], ",", 
        FractionBox["4", "g"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", 
         FractionBox["1.5", "g"]}], ",", 
        FractionBox["1.5", "g"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"Opacity", "[", ".5", "]"}], ",", "#"}], "]"}], "&"}], "/@", 
         RowBox[{
          RowBox[{"ColorData", "[", 
           RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
          "\[LeftDoubleBracket]", 
          RowBox[{"3", ";;", "4"}], "\[RightDoubleBracket]"}]}], ")"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<Wel\>\"", ",", "\"\<Niet\>\""}], "}"}], ",", "Right"}],
         "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"MaxRecursion", "\[Rule]", "8"}], ",", "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Theta]\>\"", ",", 
         "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)\>\""}], "}"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}]}], ",", 
   "\"\<s19\>\"", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.6619549016856585`*^9, 3.6619550568344564`*^9}, {
  3.6619598965090795`*^9, 3.661959924246513*^9}, {3.661959995139372*^9, 
  3.661960003194875*^9}, {3.661962400864553*^9, 3.66196242568029*^9}, {
  3.662020626832394*^9, 3.6620206393798246`*^9}, {3.662020711709794*^9, 
  3.662020712115877*^9}, {3.6620207569258995`*^9, 3.6620207593248672`*^9}, {
  3.6624734333324647`*^9, 3.6624735050853076`*^9}, {3.662550432294812*^9, 
  3.6625504362466173`*^9}, {3.6625504874629183`*^9, 3.6625504937443542`*^9}, {
  3.6625505247533264`*^9, 3.6625505699343524`*^9}, {3.6629045603020177`*^9, 
  3.662904632843417*^9}, {3.6629046650552416`*^9, 3.662904699938969*^9}, {
  3.6629136764945335`*^9, 3.662913682286945*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJx0fXd8zdf/v6q9i1o1YtSqasxSes/brA/KtYkVs7ZbmwYXQRBcQQQRkVzE
XklEcE9CSKKKKmrvWVsVNX/xPuf5et9z+v39lccz73HP+5zXee3X65TtO7L9
gMyZMmV6WzFTpo9/w3+bcrHchL2sdoneX5ZY4eYlbTUnx/27lJ2debbag4Qw
HrL1VqkWv2wnjPuBO7yY99uU7w4SxvMu8zknPQ+M54HxPLB4TxrhMwJziVk7
cT/hMPE+wgvE7xHOJ8bzn+fleOl5YDwPjOf1++V8saLm9Tg53kj5O0mEi5vX
1xJW5yOSFzGvH5LYxQsLLN/jkuNJkjiSFRK/R7igeD9hjAfrqc6v9XtYL3W+
Xdp8uxjGg+9X5z9Sm29rfJgfu3n/Lt63f1TZHXOjWEeBmcR81MmEsTfOJxMW
z6WwgKftanv+DOcv+2Q9be+WKr9nCS9vvn+mHK+DZxdY/r6D/SPul+9ZwmqK
93H5PuYQv0fjUefbSc/jfer6OGl8+H2MD1idPwf9PrA63w6u0m8k8/v8y+Bu
33pofMCYT5WeXNp+c9H8iN8J4ir96PTk1OjJpWGnRl8uDTtZhDn+TbR+mF98
r5iPBMLLxP2Eg5V949D2q0P7XidfIucJ84ffB1afdzHQh5wPbb+6uIqdHPSJ
950X4yes7m+Xhp28l1gvuh/0DYzvx/qq/DCSnsd84v3AmA/sX8wH9ou6Px1E
P8AqvTlofwKr+9nB1P3lJPrB+HE/MOgD/ALri/2H8WI/4zrWRx2/i/YPrqv7
Sef/Lvpe3K9+j4u+F9dBP5g/zC8w5h/zjfXBdXW9I2m99eeBwf+xnuDPwOAn
+D2V3zm1/e7Q5IlDk68Ojf87+OGiB87uGZQuv38CG2mOdwdvxZ3RA0KiGb4H
8kPld5b8wPeAX2K9wU+x3lhP0Ie6fpFstPh9Jn+f3/37kbN0zjSW7cQXVWZs
COVpYrxyPibw2+I6l9c1/q3zawdvUP/VjeehnL5PnU+Xxh8dGv9zaPxO50e6
/HFp/EXnFw7OxHjoe5sGjZ3Y+q+DbGLOlNVvp6+R33WYbWyw1LdT2gqeRWAu
MWss7ufyfvbl5ha/3/nfIdZmfb56le5E8PICc4kZ6AX7bZkcJ+YXWKxPCO9s
rlc0vQ/8D/QJDPqoYb5/rPw+f/7v9yaW3+3P5ih80p/mB++ra74nluYDGO/H
+0CvGC9+D78P+lDXw5+p43EwdX8Fkf4DDHoTvx+o0XcQg3wHxn6S97OpxvH0
z79KJnqD/AP9A0Oe4/ewv8EPob9AngFjPkH/wHL9SL/CfOI65k9dD4cmHyeQ
PML67N2wKXB2sUR6n6ofORn2I74f/Aj3Y35wP+gL64f9h/maJuaPnsf+xXxF
meNbqT2/nZ5X+aM/D7315Ic+5ZN40oORN1kRN9EP9oNKvw6N3/rzZuZ+28Xk
8xo/CtL4aRDplxgP5hvrB/mA71P1GX+ab9A/9j/oGfQF/Nxcj92ET5njiCF8
UWB6/ytxP2HMNzD4DzD4F8aL9cb7/U06OUB4txg/YSGPt/5nP4JeVHryZ+D/
+H3wM1wH/wPG+mG/qvqnv6Z/+mv6pz9rK+iR8GJBX4T7iPH/h79hvbFeuC72
zQHCoF+8b6IpF/cRFvIwljDksf594A+qvPPX9Hl/TX75a/LLX5Nf/pq+rPNL
J/Mz52exvN/OY8z5mUd41vjzf1f/w9pfqj4XRvMJ+fWj+XsD6PlL5u8NkL9n
Z+D/GB/kJTDknX4d+0XlN/5Mtcf8Nf3SX9Mf/TV90V+jTxfxO/BbvB8Y18FP
1f3iYI+qvt747Q7Ik0EM8h/fo47fwVT5FsShL+H+yYKeCKv2qIv0Kch3yDtg
XAc/VPVJf02f9Nf0SX8OelP1u1jif8C6PwDXwf+g74K/Q/9R5csShu8FPwLG
+qv6n79mH0Zy8EPoW6q+ZvE74DAhP4j/R8h9AfoFPcv15NPlPgU9g76x3ur+
sq6D3sCf8X3A+D6sl9Cvg2k9gU+0+S3zHwXSpf62gLCYz7k0n/J+ol/gY+J+
uV/nknzBegH/3/qLPwe/xPwCQ59Q/WlBmnwMJH0EGPwa9gT4GTD4N/Rd7GfQ
I/gtxg+M8avyIJLkJ/Rr0Av0YfBP4HryPd9mfrjnwqPVpD+DfoFhL4E+QA8q
vVj8F9chTzF+YIwf/BX6IOYXuLXg3/yxyXeW0XyBH4NfA2O/g/42m/9PJPoH
Bj2ekPtWp2cx/9NJH9L1I8gXyGdVv06g61gfXFfXy0n6BdYL/ATzD3sW3zNi
RoOr82bvp+/B+g1o7Rs/6soqsm9w/z1zvyTQ/Sp/D2KX993onLVPGu0XlZ8F
af70ILK3sF+hz0FeYH8Bgx51/R37VdXvg0gfAMb7sZ/Ar3Fd3c+Bmv8miH4f
11V91UX8Gt+jyg8X8V/IF2Dwe4wX+oPqH/XnKn9xcKFv7qT7+wtM65N0NX5r
ZFK6HE8A6fOQd+AvkNdYf8gH7FfsZ9UesHPsJ9B7sNCH/kP/8vcJi+8fQ/oP
xgcsr3PwX8m/WWNTv9nGzixa1HdevmhNnvlr/kl/zd+o6wP+XPW/+Gv+V3/W
2dwvEfQ9qv/QX/MX+mv2uJ3Hjor0G+FIZI+2n2mW/aKbq/qev2Zv2TV/q7/m
T/PX/E/+HPtN7M/F7KrAcr8u5o2EvUb0AfkH+sT8Yv9APmF+fzCfz7Dbi454
51c/kqv2si7PJzBV/k/gqv1gZ+4sc7M19NlL86Hq27r8dzLQL+gB9IfxQ/+A
PIc+ju8HPWJ+wB/1+Av2C+YP+xPri/nDfEP/GmvS1xril8CQh+p66/4x/Xsd
TNhH27icfzZA0B/RxxVpR+j2B8bb2vzOXWzSjDtZvu7qpu/HePH7WG/IW+wv
YPBvzC/0J9WfYOfYH4tDR+/MeWIl7RfoI1h/XMf3SMyBoQ+Af+I65BPk60Bz
nvcT/YxLbJ5r7TcW9jfXa4Ycn8Hjzff9QhjyC++7bq5nAj3/xNQLdhMG/YGe
Ie9xHd8H+w7yP9l8bjnpH8AzTdyJxrPWXP9Ocv0Npv7eIPp9qT8Qhv0L+QP6
a27Sz2r2pHSjsWHdV/GBks4PnHo34ZOhq3mgKf/WsPMTy7xs3S+CBwl7lehf
9SfZST8DvYCeMR6Vvp38iCmf9tD7gDHfB8zx76H5G2qu/wKaD8wf9K/HJr9e
xuvmW/d4UtMVbLPcJ7gf8ynmqysfI/cZ5hPzK69r+826jv2o+oci+Wvz99ez
LBdP9Sr3wYpfA+M69HvII+D9pn66kT2qu+vqmWxW/Arzg/GL+R1GWMxXf6IP
eZ3GK6+z4N6Dgp5U2kfvA8Z8B1bu2evPqftovrG+8HdjPwPDvyH1Y7of+gn4
j6RnTb5Gkr8H3w8Mewf2JfTJiqb/Io7GD4zxQ95C329p8iEP8WNg6P9Yf6y3
Sg+6vOqq+ddcxP/F+BeRPQkMfRHjKSfGS+MBxnhUf4eL5Id8H9mbwMK/GU/v
A8b7YA/g928Jfkb3A+N+rBfWE/wZ/Aj8Cxj3w16AfwP8Gf4ZyDfoI8Cq/yaS
/H0YH/yDWG/wA8gr+C9wHfSL65AXoD/QJ7Cq74eRfaXnO8C+hf4H+Qh/IjD8
zbAfYT/AvgKGPqH6g1w0P5DPqv7p1PxNgURvwKp94dT24wSNXzvInsJ1VR91
0P6GfMH4sL+xflh/YKw//En4HvX5IE0/tfxtGA/8lXg/7gdW96OT9j/WT9W/
IxnoC+tR2Xz/WtayWU9bnf2RPE/2Sh3C2x2m/Q//LDD2F/Dfgp8TVu0hO/F7
YPAr4BzifYThLwOGvAUuPfb79cfWHCKcT4yXsEfIe/J/DFm5pdWRmgdIP8d1
2FPAsLeA4X8Ahn4NfRW/V7Dl/Z0d2yZxud/InwX9Gv5Y6IfYz5Avb8MKfBj8
SSrN3wRzXZIJgz8Bxwv5SBjyEuOBvgY8SbyP8Hvxe4TBX/E++JeBu3697OWy
6wcIDxLzSThG6HeExffuIQz9nL7PnOfNhCE/MB6hT1rjKynWm+6veqPDm0zP
Ugi3NPn6QcLftRvStlZj67qvlIvAI8T6EYZ9jN9zivERhv4KDP0M2E/MD2HQ
GzDihzReKX+Bg4T+QXiI0N8JQz4Cwz4FnmLy0x2E4d8AVuM9di3eY9fiPXYt
3mPX4j12ftK0fy19tIHk+9AvJ5jzu4jwbekHAt5p0usKXnpw4M/ftF6p6fe6
fa/r+/4M8VSMR8hRD+Fqgj4Iw17H96j72c6E/XeQ7m8o6Oc//AT25nQx33Qd
/iNg6JPAsMeAVf+WXYuP2LX4iJ0niflicr5I3mP+1XiFnd83938Mqx3ZIOle
ih6fsJM+DVxY8C/SFzr+dXLZlZtpUl938fYCc4lZU2Evkj0wRdiLhIX8iOdy
fEzwt92EBb9JIPxA2I+El5h2rOXvgP+F5kOx5+wc9g5+H/QFrPoD9ecdpM9D
H8J64PdbCP8A8XfY9/CnwD8C/8MYKfdzpPT9+0aHcBYo5bDERA94vxoPsuxt
XFf3h12zHw3te/yJP+F5Nd5q8FymvF3HPKNaT83faI1mDw7iqv03iOwlvO+9
mG8m7Ustv8Cu5RfYtfwCu5ZfYNfyOexctSftXI3n2rX8A7sW37Vr+Qh2Ld5r
1/IT9P3tz2B/6frC/x2PtWv5C3Ytf8Gu5S/YNfvJruUn2LX8BLuWX2DX8gns
XM0fsGv5A3Ytf8Cu5Q/YtfwBu5Y/YNfi94YWX7Zr8We7Fl+2a/FlO/EX2Ifg
L7Dn1HiWQfom+AP0IWDVv2/X4kmGFr+3a/F7uxa/t2vxe0teYv9DvsC/r8qb
SJIf8HfAv479o8YDDN56V+rwww3TpT9qPmHhz5vHWwrM5XUGLK9r8RQ7r22O
i9N41fwDu2bP2bV4mV2Lj9mZGi+wU/4K9Fnwf4xHjSfYNX+HXbPn7Fo8wa7F
E/T4gV2LH9i1+IGh5Q8aTI0P2LX4gF2zv+ykf0B/B//AemN94a8BfwM9fiv8
ifT7kAfA+D3Qx/Yp3Vx5D6eQ/YX1h3zBesOfCP8s6AP6Jda7tfn7C+X3+PK5
8jngEeZ8jCZ80nzfUML/mN/fjHAdcz6byfH7Er+D/QgMex72AeQh9Gn484D1
/GXMJ/Qx3I/5hz0N+w/+W+g/OoZ9DPsQ/nFgPf8Y/grYP4h3Q77BPwJ7Df4f
PA8M/oL5gX0iv4feX8r8jqUkT4Ah7+DPsZn0Fkv6GexDzC8w/Ftv3em1c3ZJ
5tk6vzrY/lQ0rQ/ux34FPwG/Fd8/i/IHgOEPFOObydT8gyB6n/j+OfQ8MOgV
/A32JuKnfmUvJ78KTpPjW8ywvvCPQV5j/TD/8Her8TKDRRVo0vDC2EPkv3eY
+tYWVvJN8cYRR6M45Cn8I7AHJf0QRj5I36737n9WJ43H/NBm4PNSS8k+g38O
GP7DviLeQvxglIi3EAZ/BX3Angd9fC39RPieIcKeItxW+P8Jwx4CfcCfAvoB
hn8403JTHyd5BH1PzOck8peL9RlFWKzDOLLX5P2kP8r7Ccv7OfwBmC9gzJew
z/bQ/Ah9y8Kw7/A9wPiekKhqd2O+PEzxG3FfCtk/0FdJX5b2FDD0G7n/yP8H
jHiLXH+KN2O+Ec/H/kW8FxjrBfpR44EGn2hen0L8Fvot1idN6qU6fxb7rwXv
KvV+8Gfwa3ldi9dY10E/sK/kfqd8CeCmAfuabFmSLudjJvn7kQ/RQ+xfqS8v
Jox4MvRLrL/wz8SSvII/Axj8BPIO/AHxaOgjkA9bTTrcyGJ+q/pJSosozV5y
aP4DB/mbEJ+FfQgM/VTI+4XErxDvhT4JDP8Y9i/8WzqGfAQ/Q/wIGP5k+Odg
j0JeQD5Bf8Lz8JeBXjF/Qn7NpvmEvob3I76B53WM98NeAz+EfwgY/jWpH5E+
DXkE/xbWHxj7X7UHI8mfLPUj8i/ieWA8D30f8hrxY2Dw0/4mHw8jfzbkITDG
m9n83SSSn6p+6SJ7GvYL9HlgNd/DRfk9sG+QT6DbO/A3Q34CQ/6K8c2gfDzQ
A+TDpHe5hvT8ehkDP8D+V/mDHt9tQfsf8Wnsf2Dsf/n7ZF9BH4L/ReitVvwe
GP5p6LvA0PeOmr+3gfg17EHoJ9AH8Twwngc9Y/9AP9f1ddhnCXH9EyuOsPRt
6IPYb8DQH9X6wTAGex36BzD0CfhbcR36IK7Dvsf+wfuBVfs/kuw10Ovz4Z5c
T7Zm2G+Vc86YYLfqXTAfwNCv4f+HP0OtXwkk+gWGPwr8P1ehq0EN1lv7AfQo
fm8a8SPwD/AD6FPQt4Ah3yDPoY9AnsKfg+vNHZ/my8c4Xcf+g/zB/oI+CXqE
Pv7+uOBjAeOrH5+feQUDPcvxk/wA/YHf6/KH7G+pz4M/AUOfg/8R9I/9Aoz1
1evxQB/4HvBr8Atg+HNB79BHYM+o9m4kyRfMF9YLGPwe8hr3I16J/QX5AnsI
8w37BxjyCvIa/mL4B9T80TCy5/H9qn0fSfVaGC/0J70eAfFSNV8vgPxR2B/4
XvBrjBf8GPog5cMp/ggX2Rv4XvA7YPBP/D78IVgfrB8w1hv6BDDo74iME2P+
4K/BfGE+gTFfWD/kJ+B7MH7E6zFfyBcExnwiXoHxwv8I+0z1R+r9IYKInuDP
UPtBBJF9je9V/clW/T3mB/OB/Qh6xvthX+H7oK8Aq/QdqOlfQWQfQr6q+eNh
pK/o+fKQr4iv6PEU6A8Nm+0ovuRBOtlLwMhnwvdAHmG9YQ+p+oUuzycw1Z9v
7Qfos9jPkG9qfDSS+DX0OdA/+DfGC/vPJeI1ND6nyD8hjPkHv4R+B35ZVuQf
cCmPaX3xfQVEPInsoUiRD0vv3y7yhQlD38N6QV+C/of4BOQZ9D3ol8iHRPwL
/AvxL8g/5LNjPmDvDhb+Bi79DWx67SJLxp0+TPE75BvC/kN8CLixfC/svakm
/5pG+LlcZ2A1HuRL9IR8OMg7qkeW9qOgtx6ExfWOvK7wD5K92Ff4B/9jP8rn
CcvnWWlzPZfykJL2H8+9DiOcrSVbsGvKcsoXhLyF/gd7DuMR+30EYUFvQwiL
/dOXsJj/geSvlM/T+OTzhOXzhOXztJ6wH+G/An8Rdvwhyu+GPol4Wtddo0N+
ypvE/2xTfmn5iW4tH95gav6mL1fzM3X/q6HZs77kP4U/a8W5bwse+O0Q5afO
HVrWs3DyYYo3TjDtglTKB4U/C/6JAybdxzI5XvIv6voe/IGgD6HPzGFhHbqP
fxaVJvXRxWyyyJflcjzkH8P+VOsfDK3+wWDwV+n+KeTrqPmeY8i/hPer+d4G
+W+gv8Afg+9X8519ab9A/10hvo/J7+MeMV+0voLO0yQ9uLT9N4Yw4qvwB4A/
CLstleKphqgf4JK+yF7G92UW8Vsu6Y3sYVxvaD6/mJd+7J/nw7gwZuRrX7jk
58m8X9naHf/3TzTxN+g/4G/Qf7DfBT8M1PLpDS1f3JdP31r/33Ub06W+Hqj5
p/T8Yt0/1ZX4A/TjU6a82sAWDR1vv3prjcavhmn8qj9X+dEwjR/1J38E5gf2
pZSHhKFvIH4j/Ymkj8I/hXwkyEPkyyFfHxj6GPKVIE/V/KVIyleCfER8GPSK
9cF41XoIg8G+Q37we+H/Z3L/8gcmXz1A9iLiW6Bv8B/499qY67CHtQooeObd
WzfZf5CPvn+uONQnPJGuq/xKz9/R40dWfTzyI/JNa5lwtGK69Ncv1PbLBN5L
2rHSn0/xa6znTZHvwqU8ofg7rneXdsLG5J9/rfD3Mspnhv2K9YT9Df0T6wn7
HuuH9YL+IvSKNPIPR84duCZ3qzTe9/KhWdd6L2XIf4J/FPoN4h3w34P/Il8J
613P5AvWfEN/Bv25hP+b6BX+BNDTVhFfJP2qcuTClS2eW+/zMfWSvYQjRfyE
5tsl+JvkRy7mFPoM5W8JfphC86/m1xoUf5TzwUdIOYr5gf8L39tI+MPl7y8k
+Ynvg32N9VHzZ3wpX+//pk+9X4DuD7czm0l/Fv0fvdr3j0aLkniphE1j6n7r
ZimmXr6Btcr82PFbpSiN3w3iKn8bxOqJeDzZA8hvBab+KPL3Opv8KIFwsinf
lvOzH94sKrlgJdET7DnQE+xtxJvBfwJN+RHOD/idL/T70nDW3JRv1vchXwi4
hUkn1vfCvw3/9cW08GB3/AGSX0MWPv/8q0up5H+k/FDJb+Cvgn81vkGjTi/C
knnM3H21euyKZofL/5Kvm+cg0Q/8IcC4Dn96msCkPyL/BBjXoU9CvmC9IR+B
fUW8nDDoExj+WPjTof+IfR9EWHz/bAZ/FdVjmO+fKunPh4fJPGPguebz/Qjn
OvZx/3QnPEzMr9QTlpH/A/425F9K+4Yw/EOn2cf769D7OjU0sfw+H8r/xn5F
fhiwiMfGEYY9Boz8QeA8Ql4Qhn4KjHgd8HeC35P8XmjS62aK5wDDnwl/Kujh
mN+seqMGHuTyfqJH8TuhFF8HVvMXXdRPB/5R8d4DUt+L5gPNebX2o1iP3YQn
mPHdLWzi4U4nlzyM4nmEPCP+1cv0H1rPjzn8gTWdaT0PfxPWD/WjmB/kcwJX
N/WHWMLwnwKD3wALOWCtB+LjxJ+lvaCvB/SnlmK/MKlPcjW/39Dy+w0tv9/Q
8vsNLb/f0PL7DS2/39Dy+w3uJ+wrkpcYL/gtMOLV/YT9TPIL8434FvKVsb9Q
74ffQz0g/b7M9wZ/AQZ9Xhb8kewzrBf4PTD4Q2PBL0i/BEZ8C/YU9D3oQ8Bq
frbBB0s/JORhqilf5hLG/CC+r+YPG1q+sMHhzwJGfFd8v+V/BS6S0On6rWNp
kh8v4kLfteK9wPg++Nfl8xRfBS4s3iflwSLSD8Cf4d8HvmrulzDCUdLPBQx5
Cox8W+xH6t8gMeXzS36g+oMNkq943wDT3l1FeO6tpuWT2qdLezyYBwks9d9g
Bn8Orqv5ur58qfm9I4h/Z9om9BRg8HexDvW4j9RzwN/B7+V1Td+xrmO8Qab/
bjPj31zesX5TFK9QcVjdYmXS+Nnccal7bywlfyj47zoRPyH+C31b16+Evvwz
g74kMe0/yZ8pPgWMfDb5+xzxTvBz+EOBIc8xXsyPkC+tab4E/TUleSiv03zI
6wz0jngD/AFif1v0D4zr0PeR/wD6jzf9RZb/APkQwPuk3QP6QL4D5OE60/+5
iWVdPnBR4mAr/0HH4E/xpn90I+mriL8C4zreD/8J5SPI/Blpn1O+Ht5/Qshf
eh75WYi/Iz4EPMqUf6nkj0V8BvwT9RWQx8Cwb7E/kK+B+CUw/BPwdyOfDvw3
Ucw/yQ/EN/B7K0z5tJ32O/KnsX4Jq561uXuA03qBfyH+A3+YpAfSP6Cfw/8m
7OklVN8KDPsf+j3sS3md8m+AUX+C8QNjvoaZ/Gsn+QNgP8EfCIx4JPhj/5N5
2jXOtZL4MfzdsE/hD0Q+OLAYh0UPkCeI50KfxHoA6/XL8De0v1y8r7HQQ/MP
DPmB+BfuLyHeR/cD437oG5gvYMwX9CXMF+xL5EPAvwEM/wnyIzA/yN/A/AA3
Fv5FyudQ421BlP8r8ycpHwMY70f8DPnByLfE7wGDn4Ke4A8F/WA/AUN+QF6o
8kT339Wj+DboCfL3ibtUgUGzVlB+I/wRwPCfHBL+f7L3wD8Qv4H/Gv5B8BNg
zJe0z2i+gMG/EE9DfRLoAxj0AX8Q/AvAsKfDhD1D/ohTgt5J/gHDXoZ9gu8D
hvyEP0n3L8E/KOSF5b8BvwT9wt5BPDLG9HOl8qSBi//nuB9K+U3w58O+hz8Y
GPsH/lrQK/zBYrzTyX8GjHoRrCcwvh/1ichf6WHqyxY/UvtlBJC9DYzxCP4+
heob8T5g+BdA34h/wx7F72G/Iv8D+wn8DfYL+NNG068XR/IC9Zukr8v9DH8i
4hvg99BPgBF/AL+H/gT6QH4q5C3kMbCqH7qovhLyTu3fP4Gr9WoBxL+AIY/g
jwTGeCF/oM8Ag5+o/GgQU/vZDqL5gT0JeYt8DNTfQp8Ahj6AehzQF+qJsX+A
QW/IR8D7kP8NeYT4GTD8qdjv2N/wT8PfgP1dMCVfsZkVDnKpb9F+a13fnSP0
J2v/6fUEyD/AfqV8cokRj0rZ0GVD5XvW/sT+BcZ+FOsxgzD2q1o/5aT8T+wf
td7bRfoL4tvAiAeBnmn8Uv8G/cJ/gvWEvYT5B8Z6ot4P9KnW/znIvwB/qpqf
MUGr33OQfwD3q/21JzC1X1cAU+uBnVRvgfEDY7zwz4PfqvVCTqpP0fs1YHzQ
H0Gf4B/gX8DgX+A/er826AdqPZaT6iXx+8j/wv1qPpiTvg/3Y/1wv1qv5aR8
Qtyv5vdMoPlHvBP7Ve0/sZXiK2o9ZKR2foWL7G+MR60ns87HwHW1nstJ/mCM
T+23MUF7XyTl2+v9XIERX4G9j3gYMPQHYMRngdX8IF+yf6DfiPjdDpJPanzV
pfkDrf6CyD9A/R/i//BfIT9LjX84tHicQ6sfNHgOM09jD3vdx7f0xLxraT/B
nkG+it5/DPkGaj2OL/UDQb4t/GnIzy1p+hXTpH4CP2OanI/FlL+H+YE9Q/Ug
ct/UurFhfju/SO4Q/lgu/bHUrwP1QIhnU72IlLeoL0J+DurJOku63RiXsHTm
qlV8hPn7USxg6Njljzav5sEmf45kSwosK/rd2giqx4N9CP0Y9hT8czIeqfE/
Q6tf9WVBwj9r0ZfMVwJGfT0w4qHAkL+o34L/D/U+0A+gP1A/DGn/Cv99HFt0
a0Vcgb1u6T+28BmT7jxcYnasceHfau21MPR3jAfxQ2DKZ8b3yPo1YPQLAEa/
AGDoT8CwJ4DhD8H8It8IGP3sgNHPDviFGB9hxNeBkb8BjHwv8hdLeYrxQL8C
Bj8Ahj4ADHsCGPE3mg/E97H+H9bH7+9lYeTLASNfDhj1V8CovwIW9LydsJBX
WwmL/JTNhJH/Bgz/GeYD+iOwiIdY84d4F8ULpD5G3yPj07S+Mr5N9CDys6zv
k/YWMOKJwLCv6PtlPBsY+YnAyM8BJn+RHG97MT+EEb8Chj4KjP6ewOh/Cox+
K8Do/wUMfwsw4g/AFM+S+LagD8LoX4TvQf04MPwtxE9kfAIY+Z+0v2X+J9G7
rIckepf1kMDwzwAjPgCM/hvA8JcCC/3Yos9xQp4SFvHrnYRFfNrCan8cQ+uP
Y2j9cQytP47Bqon4MvnrES8DDjLl8SLCWfp+1DdmE0b/UawH6n2BO4v5J4z4
MjDqx4GRn0j0qOQ3GeQvAob/Fvcjfg6M/EZg1FcCQ55An5gr1sPij1K/AYb9
T/tdynNg9H8BRj87YPQzBUY/U2C1v46h9dcxtP46GfJW+DuZzK/goULekfyK
EPKOcEWZRwv5jPgiMPz3wGr+t9XvAVjtT2OQPiT8C0tIH5KYLxbxJibzOUg/
h34E/yX1W5frgvxf1R4PZCIvN136F+ZQvBD6FzB+H/wB+s0Sk/9F0vc2l3on
cA+Zty+wD7fLPE7g+eb8/Uy4wCzhNwBW8xf0fFg9n8EgexvxhaCn77r2jjnI
ZbyDYX/BnwP7WeybmeS/1Pupwp8J/z78JdTfXPpvoH/AP6Hmu/qySYIfEK69
ZPrcliNTKV8aGPnSeaUfAfzikRgf4R1ynMCgZ2C13tiXlxD5JvL3fVhV8/u7
EwY9yPwWDizzWygfCflfNc18wI2s864W/2Pdoii/SvdPwN+NfBn4r8+a+lcY
z57996RW91aQ/wX5w9B/4Y+BfEd+LOQ38mGhXyB/EvmR2B9VB/uGnih5IGMe
mxYa+XM09cdFPiTkLeK/kLd6PiTyoyCvcR3x37pB6R03FV9F8ec2X98/+eKz
cEb8X+YT3zXpazblT0MfoHwRaWfhfVg/QW/TWKCZf2vZa8jXQn5WaO/CWxa9
OsBlPJf8U8jXgv6NfKws5jwd5DL/Vs7bQcrHVfsT+Gr9CHxpfZEvpda3+2j1
7Pr+1vPffUh/0uPRiPdWE+vJ5HqSPo/5gz4PrOa3jNH6OVr5HcjfUPsFGkzt
b+er9bfzpfwH5EMgfwH5DGq/NF+m9i/z1fqX+Wr9Y3yZ2q/Fh6v9IXy1+oZR
TK2XGEXxdMTXES/HfKr5BC24mj/Qgu15ULz94y1pMt8phE8w5UIsn1W70aWI
OW72nRkH2she38mzp0W9KK2fqKH1EzW0fqKG1k80w155FfDP9ytTKZ8d8WDs
Z9THIP/eMPm7mz2cWHarLTyS9zLXM4pNbF1zeP9ikTxcyCvmc2P9md5lI3iA
9CvnsM3qWrjKah4gvofJ7+ENTHm3jejrxfGRWa6f5fS9u8V8SH9DCBsj9j+T
+5X4s9z/JN/hP4V8R/ztiUknO5n09/I0kx8t58mrWlyr99VKsucRb0X8FPY4
9HXoK2p/UUPrL2po/UUNrb+oofUXNbT+oobWX9TQ+osaWn9RQ+svamj9RQ2t
v6ih9Rc1tP6ihtZf1ND6ixpaf1FD6y9qaP1FDS0/39D6ixpafM7Q+osaWj9R
Q+snamj9RA2tn6ih9RM1tH6ihtZP1ND6iRpaP1FD6ydqaP1EDa2fqKH1EzW0
fqIZ8630+/Tlaj9OQ+vHaWj90QytH6eh9d80tHp9g6v9Ng2t36ah9ds0tH6b
Bod9if2g5n/6MrW/pMEbi3oZ2n/gt6hvcYp6F6qPgX6M/av2//Jlar8tH35X
5u3+6OgW2Wv9CnZU1LuQvIX+h/i22r/GV+tf46v1f7H0N8S/4T+C/Ef+N/SF
ANO+Cufn9s1PiX0VziJlHEXoIzOoXw3ij7B3pb6qnVduaP31DK2/nqH11zNk
/UI8rQ/sbWAxDivehnwaxNuyzt/S/YvCaXxDlqthwUGh2vm8vqS/Il6g9sMz
tH54htYPz9D64RlaPzxDiycYWvzE0PrdGVq/O0Prb2do9e+G1n/ElyM+iHj9
2gLLj311OSlDT5lfbW9Ft3Y+nK/W/87Q4iWGFs8yeIE3w0u9e2Ppn2q9sS/x
B8Sr4G9BfgHsezofxvRH7WRSX+ZRoj6G6kFgLyA+CXoW/vfJrFjNiT8UcVvj
gf8GvweM+YC9AfsW/lj491GPIuqDrPwXYOirqEdS62t9qN8q8gfAP2EPI98A
34/ncf99Uy9J4kdXpe/b8YObvTDl5TK++Ny1qT8PWMEyze+SfmTTPvpetR7e
0PqrGlp/VUPrp2No53MYWj9VQ+unamj9VA2tn6qhxTcNLR5raPnYEyieCf0E
8gr7W+2namj9VA2tn6qhxQ8NrZ+qofVTNbR+KobWT9XQ+qkaWj9VQ+unamj9
VA2tn6qh9VM1tH6qhtZP1Vc7/8HQ+qcaWv9Ug0N+Y/7UeL8vQ349/BvCjjlA
9Qnwr4G+hF1t0RvkKdGf4J9U7wv+L/0T1L8C+uwmIQ/JfwV/mPAXzNPqoX1Z
hDle8DefjOc+yu/5hNX6aB+tn5cPmyv8O5TPing04nvVeo73r5GaSvV/JcR8
UHxQ+A2s+tizprzcRfxKxEM2kP8I/EnEy6Zq9cZWv03UA6ry2UnxEPjXjon6
Mvo9xIsQD0V8BPUh0F+BcR35utiPiMeivgPxWhGHtX4P/ATfT+c3yvXHemI8
P13+onjNNEvewJ4Dri7mm+KbiL9AfkNePx4+aMLq5qHspqmfx9D8PTO/bz3h
ANNPsZtwoMnP4wlDXwM+LOQj4bRVEaPnLD5MWOgNFkb8BPkeYcJfQv4G5H/R
+akTf/3iUa04dv1DwPClG9182Oe/b3+d3cJ9TfkXQvTqMOWThRNkHx/gM6b+
P4dwOVEvRvTtL/O0gLGf0A9mnHn/SPl8AR4r66iAD5j8pgPhSWZ9WSvCeeZ/
+mhogOUfhb0DjOvIf+oovo/G01d8H2G1/6wPR74Une/b87dn0745yAu0TBpc
bWUU+7uq/fug4hZO9fNdV/Z9Ku+3ssueiUdCCSOfcWmjj/v/Sxr/0u9MLH+/
AAs158XKjwfG+pYw9YlNTP4eR/wS3weM8SIeCX8J5A0w9Fnk81C8VNY/kn4p
8dYsdb+69CSZ/I/BZj2IpY9DviK/A/VzyOcAPcP/j3ou5FOgfgr5DrBv4B9B
PAz6EzD0JxFf3kn+TfRDkPoZ6T/A7wvW7r/iDPpXTyZ+jevQf4Dh/8P9kI8Y
D/y3yN+Evgj9DPY8MOLpyE9D/bW8TvluwPBX4n7Ue+I65Bkw+hvI+AD1O0A8
Bd8j5QFfbtJPMNG/mq/pw1FviX52vqZ97GbrTT0+kuKz8D8CIx9M0OkBVsvc
R9EUT0K/atQbSXlL/aPRPwz1R5DH6F8h5IJLq7/vSvwf8h32PPJ5EO/GeIEx
3pZmvHIbjdfP9E9tJUz+G7k/+pt2wSHy1yG+iflS+6f4aP2tfSg/DflQqDdF
Pg/4P/xzyGeAvxwY+1nEu7dxOV4ZD99KuMf6xB5puw+R/7Bp5uWXA/hh8vfB
f458SNAL9gPoD/mgWA+XtLtEPH0z2e87hT+U6jGFfb+L9iv2I+gR6wd9C/kq
sOdhnwLXFf4Hsu/h34Y/G/Y1MPoVod4P9ejwd6NfBTDip6jnw36lfFjpz0b+
LOJl4P/AiF8gHgp5Dv8rsEPmxYI+TpvzMYmw2u/Hn/q/oL4D+13Gs4j/AeM6
6j/gPxfPtycsvqcz/1LU85G8hH9d3k9Y3k/+eFG/MJjeJ/w7PxEW8a4B5K+X
99P75P2E5f2sQs0vh+0eY/ETNX8gkvx16LeG+maxvxaw+iXidg/JnET+cNQP
gh+IOrxDlB+3Iy5f5TNZ02W+nkXf2H/+6ws8LuaTzAtmbx+ektVN9iviT6Bv
qU/ziiIeRPWBSUKfJ/8d8qMgbwuY47fkLeQL9HXK95L5b8CoD0oQ/QuYjJeR
/xbvg36M/Qh7GvUE+0T9GNlnqNcGrmnuC0s/AIa/pV391ytuH0/mr90R969G
RbNC2SfferDHwrVN/+kSoi+1v5Kv1Aus3wOm8y+jnAezd+Kkz6r9kXz4byb9
9iL9C/oR6qmF3p/K5H4ljPpqxzbp94P+JvU5IW8q8+1bhJ0LfQ76nbyu1ata
1/G9BU3/laXfgV7RP3CnKU9iiT9AvwfG+gCj3hwY8gn4auOkp6fmWbiB2A8U
P0K8EPODfCDMDzDmB/Ib5ztAXkPf94j1In8TMOqXnGL9uFw/djh3zugShaz7
gake7ty8hz7vPHR/FlOOWc8HivxWop9xyIuWGPWuQi+x6mGBX5Zelv3ewTSp
j1tY2BchXOTvWfWvwBjfA1MPi6XxwP4R9WZzyd8JXEzmoYt+r3PJfwv9PkLU
z5I9ivxRHSN/Y6uojyV7CPExYFwn+0Gup/RPUz0zMPwd0l9NWNrDHPIN/m34
X4Fd4n7ydwPDnlbj6XYtP8Y67wfz/fzOtZE+gVb8Fhjzj3plXIf/G/ZVOVOP
3MRipwSeqzPJwrC3UK+M6+gfAn4IDP6DfEHUVwFjPJe3Vy07MLflPyR/u+TX
24V9RfFa6C+o30b+Beq1oa+gfhf5GMh3h38Q8myQOR6r3wf6DyBfBxj9h7OZ
3xfKS29+Zlt2zeqPjfuLyDyV/p//Unrj6uXk34Q8FN9v5bPDn4N+kvD3AEP/
RD4b/P3wRyOfEPOPfA7oU8hXAkY9v4hLLaN8NpznAfsSGPnkiLdAfqB+FfVn
wMi3Qn9m5EMAwz9+rvGQ3oHlV1D8Tj+/BBj9IaCfoJ5CHx8w/P3yfupXh/x4
xCeA4c8T/PgXyh9CP1TYu8DQ9+X9pF/iOvRJYOg3uF/tn+ek+Iawh5w0PmCh
V1v0j/lHPBDzD4z8c6w34vPAiOeCXo4I+UH6A/yPkF/wTwJDnkN+q/Jd709R
meLLeB7+cmDUT0h6JH84+IXID4sj/gYM/hFs7p94ikcgnxTfBwx+RPnF0j4F
hj6G+Dj8FyL/fif5U4HhX1H92U6KL8NeO2/u272kT8I+hD8d+hxwuLT7xfcu
ofp25MfA3wt9GFjPD4W9g/HI+l6iZ2DEQ8APYT+AH4Le4I9AvhPy/SC/EU+A
/AYGPaG/Fexd+JNBX8DoHyj8/fNJ35OY7BXwB/BPxAPhT4O9Dgz/Ofaj4FcT
KV8U9b6IL8A+hb8P+jv09fBzfbv/NS2a7AHsn0zZf6n+xslJX0R+N65Df4b+
AAx9Ev526JPotwR6Br3jfbDPIL+RXwcM/RnyGvkdsH+Qrw76AgY9IX4AjHgT
xoN4F/w5yCdH/1xg1N9hPlH/i/wg6GfA8NeCvtD/YHris+rNM6WwM6c+fPN3
9Bqq10H8BBjxk4Rvgsp0aWL5PyCP8Xuob4G+h3wjYNAn/Jewj2BfAiM/FfYp
5D0w/E/wF8PfBH4A/+Vk4W+k/Q//Cfwp0B+Bke8H/ybiJeAP4B96/gv8HcDg
F8hHUv3f1nkqqC8Bf0R8EfQAfyL8c8Dwd8MfAX82/NvYv/D3ASOehfFQPZnk
3/Cv4/fgP4e/EPoE8kPBn4DV/gijqH4O9a+Qr8Aqfx3F1X77geS/Rf9V9K8A
Bv+DvAMGf8R+hr6dx+Rbm2n/It8d+xX7GRj+UeiPlB8o5wv+QewX7A/4HzFe
fK/aP3kc8X/wS8wnMPKFob/g97A/IA8QbwEG/0O9Dtab6pnk+KEvEj+Q6wsM
fRHyB+sBfx4w1gv2HPRb+Pch7+AfBYZ+h/kAf8D3wB4DfwMGP0N+Cb4Pv4d6
dzW+4E/+cfjvIW/AT4FBL9Dv4K9HfAvfh3gLvgf2PbDqLx2l9ZsfQ/3+8H5g
6rcj81vAz5Cvin4IyNcCxnjxPOgB/BUY9AP9EPMHexDzA3qn87okxvyDf4A/
Ix8D8wmM+QR/w/eC34Be1X4BYcTP0J9GrGMSvR/zhfgB5gf9OYAxf6r9NUjr
BzKI7GH0z1bz3SIpnwj0iHw8YPBbfA/GD36k9uP1p3p2/N7ntjYf979NXvd8
bivyEXsktvmvWv0mkerxXLbzeTuE/0j1eC7b5rd5JiVRPZ7L1nTvnXG/Uj2e
y6bW2zttt5MCZqym/oguT2txP+EpU7s4N1K/Q5dnu3g/4aZtJ6xuTP0PXZ6L
YjyEj1xOeb+N+ie6PH3F+Amjn0Dban2ypZ1x0/pW2pkYVa6HW8ufdNnU/EmX
Tc2fdNnU/EmXbcygy3Wv5DzCz9vmP0kLHcnSUw/meZ7tCDvcLGVfjTY/83Hi
OpPXqb+WHA9Lurj1ZL4Bm1hcL/vas4ui+M5Jfs5GfBNvfajw6h5ro9jQyY06
5hywiY/quyf2/KIotnHkV8tH/mDlSyBfUX4Pg78B34vvOfFX/5RPQqNYmzJ9
u476wcoHKP3FsdMd8qSx9c32VCq/K5SfyN8wfvLnaaxVQO05AwJD+f8O1hzX
Pk8ar267k6PMrlB2d8yDcav6uOj+85OHPm0X9t/+CKMqjiq7qYfVH+GF7X1E
vrQI/vrerVYh7kjSLwbtnt+65z0mn3do5zM7PWq/dZft7i7zfokdLCjvwLAe
DqufJ/Lr7jqf/TR5jZs/P7F42qlO6WxWi4ZVeg0M5s8E5hKz8+J7uPwerR+D
y1OnfsPLezptJ373V7Onjp1Jlv8W+Wjy9yi/9q8DJYYERUSzGuJ50sdW/Jv+
LP8sq39YSsOUjlseWvEFn/nzl258aMU71HxZl03Nl3XZVP7hsqn5si6bmi/r
8owo9qavf+cJ1vcr+bMuj5o/6/Ko+bMuj5o/67Jp5zPZ1Hxal03Np3XZ1nV4
X2Vanz1s/pgGN+YUW8uDK5+OXjhyDyv65kPeUxlYzbd1epr+0mpdQHIi83sZ
+v73jOuvznys/yhD/E3td+/0qPm3TturNPN+if21fFyXR83HdXnUfFyXB/Ia
9PRic9tf/k6x+g2+Epj8m9AfQA/V0rbXXlztv/066pX61fbJnHCSR9gvDb/Z
+bTv4/+ev4v7z89dmmfKizQesb/k/ne1FjGfis8v5yiXwN73ObK6ae61fMqK
wxNn3d/NVmR54n8g+1qeP2pf8hK/eO5763BY8nU3+znok6azb8bzzu/Ktt/x
1M0Gz+zTM1+5BD7T75XTyL2Wpf5b69W8+7t5oTwHph7OvpZ1/rpf1Wz599H7
XyS4FgY120fvr9GnZvu5z63zAtR8ZadN7UfitD2dsP/8yNf9+P2ff1pxwG86
G/28fceHG/vzph3G3yq0cTrrMmpffL0hO3jP7J6dt25Hs50Vp77rt/IQe15k
576VF6x8mvjPtpS+P9LFkzucfvqu8hb2trXzl0JPonhqrds77pS1zlea1+Dq
y0XDd3L/eclNilZzs2xvfO7/FIb8U+u8pf51ivTe1SOSzlu60KN5iTJpEazC
TyubxbgjqX/Ow+NNR/d8/N/zCko3KJT42ZxwOq8A72toXCjZvaN1XsFCMR4m
x8M9r88sz9o6jcVVL+o43ncp3ycwl5hlPfbPpkz599H6rO1W/rMZzfbR+vTe
seKHSWf20/q+O9Lp0OzW+2l9wU9HjdmTd+G5EO5zlC816s8kekU9/auVET9n
rbOG3V3baPWOAtb5UOC/8nmWRTxP9P/cZ+UNv5tuPqnblKItb0TSeQrZWpUx
zjkzvi/fu5KhxxN5l8GZ4mYUW8vmn0+oMD05kZ96P6jUmQy8vanfgwl99tD1
axMibgaP3EPX4c+YHhJYrmihtbzr43F+R1IX/+d8qe/+OD690mDrfKkc7uDy
X2Rzs4BrKb86rqQwOT6+cf6ys8EtD7O6V6c1b3pkFeU/TdvUq3GZjPu/+fHb
bL8WtfyFlJ9ccGXz9hWiea/acX5JKVusfCDxPi7fxyaJ36P5QD6xfD+vJd5P
/plLD/tMW+Yzncn9zJMFpv39qHH5UXWMwZRPv13sBy73A/XTSsmc89r1kS62
R+wHLvcD8z/e4cdyDw+zxPrfr6q5eCXvJTCXmOVqfalvsyIpvNK2K++e/uf8
CJfn5OOWW0qnBRN9Zpk9fEGVhXPJv9Jg/fwn0ZN2sVmnS7V6P9jNXwVyH799
u9jeZWf6use7ebx4nuj57izzedKXsxRzd/v71n7mnjM86c5VN695dQX7Ptd+
FrXkz1Kfv3Jr+qzTA/3yZstJVT7cWc7m9spZtNHWpRTvSdzzMX78wYb4m1o/
4PCo5084bYnTzPs9iM8N/HVNpYWFj5B8icl9scLqtHT2qu/BHol+03nhbHzk
+UPprH3TP9bn3jid6g8kvbPNJW9snbXLslefzdsb5LmWRPsd/hncHxZ45++i
r/vR+zffq9yg2ab+9P731X7pP+sz1Os6NXvT4ZnRceG+EquTeOyAESfftHKz
yIGXa3fftISvefEye5u6y9mZMaE3W/+7hLccGzB2ov9yhn7xn+3u4Fkfuob6
l/k8KZ17/9M13O+rQSff5bXOA7u658z+XvdrkP3iH29i6i+onRdoU+sjXDa1
PsJlU+sjXDa1/1KGfq/US7g8ar2Ey6PWS1jyGVitl3B51HoJl0etl8iwD4bV
3jCn8BHSD74R8ozqJ9T6CJdNrY9w2dT6COg/Wwmr9REuj1of4bKp9REum1of
4bKp9REuj1ofkWHvKPURLo9aH+GyqfURLptaH+GyqfURGeNX6iOcHvSTlPLS
ptZLuDxqvYTLo9ZLuDxaP0Qb/FXyfR6135bThnz+pllGLR3TfCXFnyR/J3sc
8sXIkbnES3c6z7//8uY5n85iYY26r793LZ1v+yXbxSo/TSF7XPJH8i+CX7be
W/DmmrR0XqjZL9c2ZOgjQzsHbf/zUDofVnFetTcbplM96SbDt/7v/aL5p/uL
D2101upfeKRj3Rwtjh0g/aPYmf7BdboncckPWcM7rcb4fZfEJT9kaWtWrf80
Lo45Fi6Yufo3N881rFydzTPjmM+Qxo6Hh93kzxvzaPidsdnm8dYR+TY/H2rl
l2I95HXWUlyn/NKYHXv65A7wcPl+NvBO7VN9N3m4fD8rff/E7IBiR2g9e58J
P53itb4BA1eHx2Xsh3/8eY8VZfzJ3zJ55/2lC966eZmEXnPf5YhhkfE7Sr5I
WcOnVujUa1nOGDbsWaNCRQ+t4SXE95M8sInvJ3ngt7PC0dYX01imhTGTSz9c
xFPEfNB4s4n5oPEOnrrp2+750rmnZKup26a7WFfxPJfPs8QVPtXLtornX01f
uebGVTd7Xqhtq6MVd/Mq87N+KPDKzUp+XzR0xoYEXqrd9/8MKLiW1Z7xd5dR
03bz3Vu/aHrhg5v5iPkgeuwj5oPwkQueAl22LiX/0OKIzbHZf5tN/VfHC0z+
oNJvv8/+cEoaH9/DXrifsYT5CMwk5t8KeUn08VzIS6IP8I+cJYYP6FwhmnUV
+gb5z1BfG/LAd8ey+26qD4N+4fOp65OoPMmkXzypdpzdMgaTPPr7pybRz0eu
Y6nLJz91d17Dp4wf9dm2F6Hsy4rvwsYPXkHxRfn73N3j/fAu66385yzDNz+e
scvqX5OrzM7PZk9NZ313TJi+t9EcnkNgLjE7er3m8wn30+i8O+Qv1BpydIFz
xyJevtbb2uPuW/1O0S+p4kTH0aAdi6g/QfFbvUIW33dTvfy74DrPYnOuZTeF
fGNSvvGI7/5sUy8wieLRherljclVPp7OI7uY88jNxp/OYZ+6n61pm2MJjz13
/sz65XNofZLEdS6vszBxndYzR/CrwaNYOjvq32n1pMfzeTaBucRsQI2s5Qe+
3cqOxD74y9kimvfZdn5LlY1b2dJNdUYurx9N/Xsqnv5f9W2L3FQ/L/kLQ705
+A3sWez3LcPXFOoeMpb2O+xfvzzxfWdl8IuSE3+t9mnIWOIXqOeGvIc8frFn
f2zIW/18TKcN9u/9jY235a2zhid+mPv71LbpdP5mgsB0XrCaD+7wqPF1hyes
1NMMfn1V6mN6/yCHR60nc9jCtnzk71elPmawLHnL7nV0O8Cb7PPknNkimt3s
/2PVr5ptZqWL928WkxxF50dD/4e/5FmDM/dfZOiHxrHFUfv6ppJ+mCb4NenH
K1Y9Kb60WhpvMKrxqJp5Qqk/kVwffjOpyJBB/ZL5zQ/3F1/LsEd7ivXlcn1Z
N7G+XK4v1U9i/0aJ/UP7F/FSrHfW+H6do8v9QvRT7IfCE47cHMarrg6tMTFD
nh3sVKN3Pp/RtJ+KPnzcvc6d0RQ/+V48T/Q4anHo2ZlRybzxgn0TdiVn8I+a
48Lvxi77Tz+lov9EPPh3xQrmbpypxY7tVj8l+LOl/KX6zeUvn1RJfrqGXY/4
rECO01b/dOgD8jqf26bF8VynrXx79G/Jk+vf0f3SV7Ok15/8fubZTuYY/Oe1
d63cPDah7oWHt/YT/57Ecnga59pP/Bv6In6/vdBP/z/9nZw2Nd/WadsUe+3o
4Yq72faZta7mybAnfDov/uV+UE++IvnOD0vCp7Lm/xSPKflJJ37t+YqL2XZM
Ygm3ri1qaXTidw+66+4+N4mdHF+wRPuxzXlww4qtVwSPZuWaRM1cf6gtX/fX
kvYxDcYz+4kObde1as0z5yj6dO3DsSxTF/P9TL6fV3xhvp/J9/Ow2+b7mXw/
D5lovp/J9/PrTc33M/l+XuCk+X4m389PzyjbYNfhBF5lzrIvVhday/4K+PtY
1sKJPG/FLKUXl1jLxjaY9GTHTQf3zzpu+puU2eynh3/szpfg4OWmlhpxcu1s
it9s/TlgaRlPBn1fzF+65IxUshdKXyh2t+fEVLIXwv2LbClbJIXku1pv6fTc
Td6+qSJfwOT+4efr5hvw4ROr/rLu5ZihEZV3Ubz5qLif9ptH3E/xcTXf2UH6
PvQPnyKVatYtaNVzXvyz0j99FqUz+b28da6H+VJD0pn8XoqXTR3w+YlZ50L4
OkHv1E8d/QzBj7turlqy5Ookos/l7PP+L3wmEr8LmHQsLtuhMOq/hf6mL9qt
iCky0jrfpVelVc+TmkfxF22H5qlc1jrf5W7Cr1VCPljxuSwjZixZkv8I2Vel
t7be0m3IIl5kXq3PF3VZpp3/6vKo/Ymdnu25P+YnfPb/Oe/Vadv+rs7H63Te
q2/uJikzBtaj81zjOhbef/1cZYoPbc9uXqfz4OJ+NK9T//g5TT0nevQJ5Wnz
2vmGl1rBmv+VN1+DQOs8xbA7fqPzZz7CkjOFdpqYQc+jAv88fDPfERaSZd+r
ryMH8+5ftOyTJZ/HkseCn3PJzyn+nKf0AsftO8v5PyMqVtjd97/nsb9Z3rnR
Fxn0f+zXHvUXrLbyRxDfhb1QZEDeU218/nv+eq/bVUr0z7Av9gl+xOV6Uz+Z
hOo7OocdjWTTM2+r1qJAFJ0PUaPm5/1quiOs82dnxG4Zeymd9vuYL0NyBT1K
Z0X25Lp9a/sk3rxuO98sGbhkUGEjNGO/ty9ijJ43ey/po/VO9NsRvm0f6aMl
j7xqX7HRf89rLx2zzbk6dA07UTNH/7yvrXjIqAa7tn3RKp78J8uP1znWfche
4g+BZ/p9l7OUxR+QbxpQ5ODPmb5ezmKCA37bfCWE+vWhv7HPoq1Z65Vys38L
VLpaIMDD7oX6u6Mz7JVSQamdem7ysOU/F174NMNeuS34B5P8g0/66nrl7hNT
WcNAn13TMvSxW+7MJ1KinEzq7zzTuJFBmw7OIP0/XVwn/f7mWPM66ffw18Qf
2hL2ouEMdsAT/kNw8kDqZ3esy+NS/FU6u7A1S4/ZGfzSWPdlmfpv09mxJuvv
HM7gly0P+y34qatV39QxoO3ITl9a9UsNa90qUurDIjofCfk7vXKv7LJu5TLW
t4ZvhZpe8aAj+V1TZ3rtx9hr6yq/bbSLZY5tkPPXnm4edblMgwC+i8UeWF/r
fxPc3NMkdc4cr3hWypMXSRu99m/mDfbPxnj5t16b62vFM76rPfL359VCKR93
UMEe33YtfIR9c7l7z91X/PmRL1YPLV/gCBv27aY/5jz+ifId5HzxfXXnd5i2
38qnKLYrfHPziaVZ8Nkr/7tYxp9Hrirz58bIgsy/yY2vt1fuxn3/1yO0p1f8
5PvovVkivfjJiEqXWw54bfnPiq0138fl+1jkQvN9XL6P7Xvd5sr+Bkv5vAdv
W3wauJyh//OMUSw1S6konrlB+a9LtfqeOeK3XMq1bCTvFdyg643Q79ibvWMu
nigygk/5atizg+vqsqArz7M8TB3KN22L6Fdvpw8LG9jAMTbj+z/r5ynRyFWJ
vYr2RCTk6c+nf2u+j8v3sctB5vu4fB97X8l8H5fvY5tizPdx+T72WQ/zfVy+
j11/V7v4u+EHSH8PLNhw6dIcsBcd/HchH0g/Dny8eUQ2doitKfQ254shkdxz
/Hz3uQEpZG917N1/4DrfdDovC/kt7eMf+1wuuYC/yrfyyw2+Vr3Mgw1v/bIW
SeKxSU8aFZjlZjX7dJ8QX2Y0a3E86d2vGfZWQKOJFbf3H8taBLf37b95Lr+V
z7/TijajKL5Y7+jwT4K3hNL5QMiPH+3fPGV04xVs1pahZz8MP8BLuvvZl2bo
r+iXNWvPoFmHrkTxNL/JUTvqp3JpHzLfLIcrjzes8+tR/1shOTa0ypWlLPxD
zw5ZssYyOV5+9NyaorZasSwiKajB9QXW+faui/sehZ+KZknn970fOcM67z60
9b208m8D6PuRvyTnhzlvPNq5fN0I6r8Gede0YZWXqb/MZkXz+o9PyTWah45f
PfmPWnPYMfE+mm/oF5jv08GX2vAvw3iubn98OutDhj5cfMRnddem8YRJjdo1
6bKYpdTKMaDthjSeOyhzYp/vF7Ozc5NqvFoYyYtMr1ol+s8I6u8F+xT5n7DP
a6fOf7V7YVc6/wL2TtxVd6+fW//CCqeZ1+k8GNhH8jpHv7WcB89WjCu2li3s
6ufJOm0+5dfA/pLzz0eL67Q+qLfG+lR9dKXUw1Xp1G8T+UJy/vg68f1Mfj8/
LL6fye/nYWJ9iR7TxPpyub6UjynphzlyxfaJrZ/KitVZc2bq4BX8xN3XXbIM
jOZyf7DKCxILD7qTTt+PelB8P/qpwd5vv2HQunsj13FjTdsCGzqvof50mJ9M
65sF11u4mC+50X5mxeVhrPfgl68L/z6d/A/Qn6R/gTcR18n/gHw1+B9ODN62
oXHUIF6kV617rf0CmXPhlsoX/x3In7VZ0mTwxhkM+bfTnxa58OlINy/wIMuk
93EZ8l/czyf8naNw5L50Ju/n8Td2nai1ewn1F1s6zj5t1/kYtqFhtrLVXq/h
yDeBflNU+C9kvb2bV1vd/nGX/PDXuVivvDc22c5a9ZgTrkb6nx4ZQfGoW1Ma
PAyrvIv8Ib2F/kXv+/B4evjrkMN0Xgj6Rf5V/Ylfi12r2D9DbswZXhP+6kjq
zwf9KFzYz6T/Bzt+rDK0XzKT8VvKr+0cmqn5oWnR7EXPQRtL3BzGpL+Wt2zQ
puMXTYawv/bM2fEm00zq/2qfYBvTpcha6v/a+sf6kV+UWEv92YH73P25x9qx
ieynb55WyJ2B1+W7XqFt2VX8XaHcX2Q2VrG07E/b/Ru6gvOkQc0nVghn1Rc+
Kbow00rqZ+tXKX5FocrpbFbijNSNoxby0KW5Ny2vks7Cuo1Pq+W3kJfMs7Pk
gudrKN4Gfzr8JzvH1Z+dI2cMxc+uDpjUJzgD//3XyOcFD62h/knQv+4WLV/Q
MTGEd5rSqMaqf5excmlj23/9fQgvnD25Z6Ezy1ia59m5i1X6Un4m+iPCfk4P
rDXpt4uH6bykYvemThy75NB/zi+Dvrjv+Pyf27VJ4wXy24sU6LyU9fF/6b4z
eRbZP80EJvvfOJ1hph7cRfnqI+LOFG7tk07nw5+u83tCvlKJbEnpmh8WZMz3
H/V6t+06NJGxHpculc/A6K9/PGuxORszR9P5Toin//zp/+p90vQw6c/IJ0H8
+ZvxDx9/n5ZC+i/68YIexm1bGOE6nshOOE7+MbvYWl61b6a2M4rsZUfzrr+4
IeP6X9WjW/cZspdFuQZ/F11oLS88r+rUE1X3slPXT+fOmnHd2Wd9gYMZ+2f9
7dE/FJvgYkaBH4dVKJJC69Va6Itkv55cfalGn+hgJuePxwtM8/k+KOL18OxT
rflptd02Od8ULumJdQ/MXHvvpclc0hP527J8FnPl24z9deTr+l1f911F59md
L1vth7eXltP6oh9t7P8eTL/+10pG/Sv3ZsuxI+P7p4edTa3xSR9eoMjtcUue
OdmJuBZFMrE+PL5C6YhfPpvGcP76zNBnkfPmLWdjhH+ISf8Qv9ncndPvpoNN
uvN19vsZ9vOg6xsiBiY4WMM+p58lZ9jPa0rNsmcqbK13dIlXe+IP7aH1Lt64
w7hH2zawoz0LNy9QPYon1/9zaftcG9nG8isrOZpEUT8vPB9cIXbflsMJtD59
06rNtWXbQ+vzpO2YWNZ9OU+turx31cUrWfzuuLSvn4Xx091f5o7ps5LyRyeU
Dfcb/2Ax1Q9KzBbWyFk287mV/H3uiElDdoWzOSXD5of+2pcvD/huVtvj09jk
3wNfx8Un8aMDHH7/GG42uPfpn0KSknibK1dqNm5o9VOqPr/R7ca13OxDwpxK
+X616slRLw7/oLNs5r5dxs5kyYP3Hp4enWFHCcwlZrc/rdvwWZtRlM87xV4s
sWH2g2TvPiuUuW3D+6lk71dLTD5z0as/dNtPj1+LPmud34rzSWCf4DwSud9Y
yXon77Vvc4Dyrwu/yH/pxNFk/mfOKUHT1kezC8kd5m9JTuaV9/vfmbY1ms7j
kPo4w/kDuYYOj8mUoZ+r/aadtotmPqeV3+m/rHAZX6/rU0Y3Sl3i5Y9T+1M7
bZ1Ne8rKD4o17Snr+pPUe8fbePnv/iqRGPa11/U+tdaeXHbnZ/4g/Pl3q8YE
MdTrNO65v2rr7W5+OTXTRXsXzm5/cYm13uzmBWstaf8iH2c5mjSZ+M9uN89y
6bMOI4tztq7Fkhrt4t1c7Y/t8Awzx+ckfNkcn3W9RNrH8Vn+qcJffByfdf2r
sIL5f/ttKX/hyXy26O/Lmdpv2+EJNO0rKx9hkWlfWdeLVP5oX1n+8eeCPpik
D15d0AfV47UT9EH5v6hvkfTBB4p8GfKPoL5P2v+85+mKH/PfpH9e7//t8Gjn
Vdl6dir/8X7pn7fOl4I9PMSkBwur59O7PGk32174zgur59W7PHxI+WPPvLB6
fr3LM/KzRtUmeGH1PHuX52bTXocHemH1fHuXp2Gx4WOreGH1vPuM8Z/a+OUp
L4x+dsAH1u85FeqFMwv/HeVDOIS/i0t/F2t5bfSNlac2sX2Fplx5siGK57vR
7q/u4w7yXCUuzovyt84nlf5Dlu3aQNeCkmn8+eAlRf7tHcq2xLg6/RuC+LmL
4TyZSwuqV0qeZvVbtz1wLbuSby2f3ed5ng6tEtiXB89v3Zp3LfVf/y6gabuV
n67lo56fed/o991s9vZB6x9kXcs71i90sUGzLSzXuMx9tvwTxbsKfYjk1xKh
D5H8Gt+0acSWAltZ9auHLuQuFc2HhwcWnrMhgYV2zV94SMG1vErdxaP/HJ3A
dm0+cuJM/rW86Zi2JYZM280e7uk86tqHDH5ZIn9Urrm7Wfs3q1aHZFrL44X/
iepbgkz+YeWDZFu14assXvQ0UPg/uPR/sDTh/+DS/8HyCf2fSf2fJ38Slpit
SBL7OaVbu4IZ9uht4X+leqJR2SteSn6VTv78m516XG7wNp38+b1mNDV+CHaS
vlBN+GdpP/YV/iTajy2FP4n2I/pPYD+q/e5dnsNfrSzay8u/1LjTpwG/eV2v
MPHMH4O85iOm7YiR/3pddwp5QvGwgYlf/JReL4lL/xOrLs7zIf64zxH88vNy
cSyl+eaglxn8sEjFgLFRReNYv9bvjA4Z/LBm1rTK2XtZ/S98Bab+Fzh/SL6P
nRf8lkt+y2KvH/ns33ycy/czv68vLB5WnHP5fqb283fZSorvIxwpvo9wcZGf
SN+r9v93etT+/05Pqsi/5zL/noUKfzSX/miqn6D8H1kfACz+WvxhaK1j6b8e
S2Obuie3LPi/EG5vV6TZxQzcefmwKutbhHCcl4T5CJnX+WvPuViaj14+B+OL
lYvjUv6wYeOaxa8uGsel/NHOI3Da1PMInDbDrJew5O0+k39a1yNylK91xit/
ptyVxGMDva6r5xlkyGt7+vU8Xvm4Nyv2mbLK63rmTxdUzLzHep+z2ou5P3td
R/0l9A30ow+c2e+P7TnX8lqdJpa8H8HZV4/58YKRbn5U9Nfk3S+MKvRjezfl
myOfs7TQV6h/xHrXmIDc9vFEbzEzW/brZx9P9Kiex+C0HW5Z+0w9r+9pPCb8
uxiv6xXCRoY08YpvrxuRvfopr+s+bX4vf6FrOguyF3vS6JtgXlpgLjFbJ/Ll
qX7gdI+Xdxu8GM86Bsfc7ptxv3oehMPTpmj+epXuXLaFRP+SVKK/QfJ1fMNJ
V8Jn+fLCHWdty+oV7+5aYG6xz99Y8rXNtx/9VJc98nkGeSufp/6QMr7E9p12
TfveZfWHrOaXd0jzPmP4+F9/nF4n71yq71uXb/fuCe3nsNUlfhq8NWgjyR/0
W4H8QX8VvP+JiF/R+9XzLpy2FwXefj++dlOqx1ywZFHpb0Mb8ZBpHXe1z9h/
nq6vpr7v3pj7JkXV6rP1Z+bbpM3GFqHNeUj+iDn7lo9m8QXN56l+rU2o+TyT
z/MpfubzTD7PnzQ1n2fyeX57fhdHt2IuljIjW8zgwFDuM69104V8IZPyk58V
17m8zrKI6yRfH7X/KE+f2XDexpFKH/srfLC993k6dlNre8Y+jonf3yvj+uS3
A3I8acGRz3B32e/fTF5s8OdzPvanempb0DKhx5UZLfijEub7PDiv48jjHB/f
55HvY7dvfOxHkHFdvI8h30G+jz1vZ77PI9/HMo/t2f1uYhr1S6m6P7xLb8d/
+8N83q9ZzbjlbrZK0CeX9MkOT7owddCLjSwxz90bgydG8ZAfRlQb0PS//WGu
PCg5aff0KP7X9Pxvw7ZvpHr0eNFfh13LF1W2eHf9PBGXTT1PxGVTzxNx2dTz
RFy2AkL/YZL+eNqErwsuL+9mJVoVm5mwPpL3eJSwdeemKFbCPXPQ62qR/Pr1
00fiUlYzwy84skL7CO7PV67cbKxhEWPd3U/4rebxwt/DpL+HnxH+Hib9PVw9
f8NlU8/fcNnU8zdcNvX8DZdNPX/D5VHP33B51PM3XB71/A2XRzvv2aaev+Gy
qedvuGzq+Rsum3r+hsumnr/hsqnnb2R8n3L+hsumnr/h8qjnb7g86vkbLpt6
/obLpp6/4bKp52+4bOr5Gy6bev5Ghn6inL/h8qjnb7g86vkbLo96/kaGPq6c
v+HyqOdvZIxPOX/DZVPP33DZ1PM3XDb1/A2XTT1/w2VTz99Avu9Oa76V8zec
HvX8DZdHPX/D5VHP33B51PM3XDb1/I0M+0Q5f8PlUc/fcHnU8zdcHvX8DZdH
PX/D5VHP23Da1PM2MsZb9ei5HyemUz+g1gJTfpF6nobTpvYXdnjU8zUcHvW8
DKdHPS/D6VH7cTts3+76NyWu8kGeI33y1l5ro9iAHcfm+Zc/yKW9xOqEP656
/U0q7/siz6CYrMvY+BMrq1T4JI36feA8jU/rjC05rfhanvN8xZ49A8J50xKZ
Z2Z+Hc72XnJ0Ldykn8wXms6ShP1m0bOwBwkPFfYl4SRhrxJG/VjknuDkij3c
HOc3juw2LLXEyCh+VOQjUH0K+vsg3t5d1DeRf/x+rxclau7ZwYoX6XX19dto
ni7sPawPnT+9qN/EM0uWRvIXbzNV+uVEFPUndqXM/IY/Wf2f86fPp78pm7nV
ap4o5APr2vtiuV3L3bzkiHrL2jdOZ8H35+2v4pnPoxLLbElumc5mleq7fc1X
83kJcZ3L6yxSXOfyOp23CvszQfTr4/L9bM3on7auOjyJnl96ffLTxISJ9Pw5
cZ1+/zdxnX6/xclcxqoFe1jVHHP6DSpunX8t83dYJiEPqT+YvdnA6huqhVP8
IlD0I+V7mjzLsft0OJ2XHZYYwZ/6rOJ5CjYoPTGTdV52wcUdfB+WTaX8OJyX
XOH2661PV6xgqb8+nV1zTz++ptGOSjcaTqfzWGR+IS/cNiH7uC2hTMZXee24
pKiTscuo/gz7Qb6Pd+u6+LMBy7azNe8b+/2yPppfmLfsTI4H21n6rL+6bUuO
5vCnHCqTt7jraCQPfXqz98BB1vndXWf+W7NmAev8bpznPaPltikHykbyEjl7
d+4QlEb5qyUFpnxXnPe5PMxZoWEpN3esP90x/8BoVjlP1ftPh0Ty1sIfwKU/
gM5ne1ap0ePR6av5sUqFG/zd+b/neUt/Nj8v/NnU//+u8GdTfxDwA+nP5uuq
OTv3ckdQPxCc/339j2XT6xoRPLFnZ7/7IyNY098v5Wh4ZBX3HAkuvvz5GvZJ
jnxTF19YzX84eqv2w4WRLMeiYwM3/RnBi7HvP9lW97/nf7f757cuw5qvZJdf
//X6XAPrPPAXIh7DZDyG+4p4DJPxGO55OWNbyUNh1J8D55vK+l6e4Ni6cbJX
/UvXgUt+X+PFX2pe69OqgFc9zMkzP4yq7cVvukdXPdvMqz5m1YIXXy7w4j9R
pn1n1ctUNO07ix8dcfgV/WVbOpfxM+ac3Su2/6J0Lv35zO0X3zYlJJ1Lfz7r
/8fkR6MupfMB78bb4sKnslEiX4nLfCXWVOQrcZmvxOrOMeMblD/1+sWBgJmn
0vmLWtWfuZ852bjDA4aerGydV365XlfHnPFJXObDMNfTlj81fxrHgr4d/M+u
026eKe/DdN+hcazloO7zChx086QuI17fWxfLegRVzRof7eZPLpQZsfdcLIsq
07xtm81ufr1Pnqg05uHyeeZoPoRdPuTh8nkWkzmscyuv+ugWryZPHuml79m/
mbM+yGt9ttePdvb3ul5hdKuXl7zqqVMG1SideYaFj65u2OILr/WrtrFz2Zde
+uP3qe++ueZVfz1lZ/rkKl765Hyfq79391rf1nUKBxbyut7ftMeteu27pj1u
6Z/ZTHvcWv9A0x63rg8Tz1v6nXiecD7xPOG54nnCjcT4LX1DjJ/wIjF+wnYx
fsIVxfwRPizmz9J3xPwRri7mj/BGsX6EW4r1I9xerB/hnWL9rO+pOHTrba/+
DVVLtjudy0vfrtmhx4fyXvVbIT3Hnf3gb+HGyaM6dPain6hfg6vV9NLPVyyZ
lrm41/Pfzf2pyvde17MsK912ole/CHdwlnGrvPT5zQfzR8Z71YvlOVZlYojX
9X01Kj6/60V/JRsav6V46f+Fs9aJ3uT1fOzrEkeOe13/kM99pahXf4pGr0d+
7e9lL9gHzZoW4lWfln9yYq2WXtdHNt1V5aUX/X7d7c6FrV72hagXsu4X9ULW
9X8e5yr7vVc/jBFm3pVljwSHnJ850qseLse+xn9d9rJXjpj+G4v+m5v+G8t+
qWz6b6znN5r+G+t6sFh/S98W60+4tlh/wkvE+lv6sVh/wm6x/oTDxfpb+rlY
f8Jpov8IjWeQiB8QduSOb/vQq97vxOcnKqd7XZ8y8Wh0Ga9+Cpdn3A5489TC
Z1pfaH/d6/lxjZMnZvOyzyI6/dsq0Iv+3vcu9KW/l732onKON8296gtDSz8q
O9Tr+u3Ep+sKe/3+rO1//lbPy75bcOf6y3Zezz96+vbE117Xr4r+LoT7ivgP
4enCn2+NL9z05xP+V9APzecYQT/Wegn6IVxA0A/hE4J+LHtG0I/FbwT9WPxD
0A/hT/Ob+4dwM7F/CHcU+4dwIbF/CI8W+4dwDbF/CJcT+4dwP7F/CGcT/IPw
OsE/CG8V/MPi54J/EPYI/kG4tOAfhIsI/kE4XvAPwo1Ffx1aj+sifkb41MuT
Vz941ZO2nDUjvbvX9b//+BDU36vfx467tRqU9LLHoyaVunPP6/kbA+7Vrul1
vUZwt3Nfe/Gvx5Hz593yst+v1hz/7S6v+tWypZvMfON1Pblzy4VtvH7/08ZF
LoV62fsFt1erke71/O8p/jecXtcnif5DhPeK+CPhX8/WL/elV73snIfDT130
un4vduCROV79TWLSVwQ08vInLO8eWDm/1/Pnm9vHdfG6Xml4UokOXvzz1rTn
R3N5+R/OFLo84axXfW7RDxsO+3hd3/3tjhOjvX7/33KTS+/z8lfkWLR41COv
51PXplZY53Ud+Tm0382/1vqi/xTNp+wXAfyXyAeQ9OT0jBD5AISDRT4A4Rxm
PM+6fsSMf1n9Xpqb8S8rvhNUb5Xjmlf+9PR5w+snecV7Hor5J3reLOaf8Cox
/4Qvi/kn/FLQL+E4Qb/WfhT0S/iOoF/CTsG/CV8V/JvwWcG/CU8Q/NviD7ea
bXrqpb9Mf9w78Dcv/9CkhI5+sYMsXGLrd9POel2PFPyf3pfJ3+T/hF8J/k84
TPB/wncF/yccJPg/YZfg/4SfCP5PeLrIh5bjcbCvBD3T9XuCngmfF/RM+AtB
z4T3Cnom/E7QM+E8gp4J/yromXAdwU8I/y34CeGbgp8Q/lLwE8KHBD8hnF3w
E4ufCn5C+LTgJ4RhHwKjfwlwB9GPy1ovu5nvxGS+Ez8s8p2YzHfiV4U9RfUF
g0R8l+oLgoV9RfbR2zymfUX2UcN5g6v8diyN1+z4+Kt8/wth5TbscF/KwMcj
bS02tQhhUaI+Qa6f0xYj6hMI344x6xMIX33jc7691/UDol6BcNzZmH+OjLfi
mRUEfdP3Bgr6Jhwg6JtwSUHf1v6R9Vu0H1tezLd0YhovGtotz+PeS1iMwExi
vl3UY5D9GSHqMSgeXvfJjVJ5z61kM7Mc7T5wV7jMM0wifwj6hYTf+KdQ9u9n
8MjTTyZeTBpI9RO9km9cejhyO6tZY3qHeysy7F2Rf0X5juK8wnQun2f+/4+u
M4/zsXr/vyRJthBCjEjqo5psqTRnkuSDNAlJ0tiFmIRsMcbS2N92xjZm3mNP
9nXMmWGYGVSSLVSIFFmTlO3Hfc7zen/v8+k3/3i8nPO+73NfZ7v265dtRYdv
yZF4lSaLL0Y/F5ujrH+6bjZh+dYOH+Wodj3yr3172Whd9LS+NLBPjhqeurje
0wVH66amXdt2VcS0a9uunrn0Z+snLoyS7//D46cShf5dPX4qpL+N9/ipkD00
j8dPhdqpf1F2Q+ybqXPGSv0Li9Vc7/eheN/S3u9D+uDd3nrqI3ivt55C+uEi
XrxLKD44/4276ynUXqL63fUU8o964Pu76ylkX0Vffqr8rv2p9ZN0qcqttr4Y
2CbxdY+VunFmYmqWxDPtm7dm26G6WRL/UOP7EqfHLNumrb+ianCk5k+Xp27T
1l9RNU3dt/Leox/payuq3rjvg5Gqe6V/Kux6tavec/DbqgXuGaEGFB341m8b
u+pn5rfYlfPsCEX+/G/zDU+aeClB/R4Wk1AtfLq+GHy0SJeRCSr9qc3nf769
Q+IFt5v4F/G3SzX3n9C/trn/BHd562jvqQOb6puTE5/WBfqr+K7hvRdEv6UL
tcqVOalhP3Xr2k8dRl1qqKOi2m4I79RHNWjq9Ve2v+7SzeuvbH+d9o/XX9n+
OnpnRnbhj7MkPqdNw1nPvqa2KZtvUDcx/gdy3+42/geClxn/A8Hhxv9AcIzx
NxB82fgbCC5q/A0Ejzf+BoLRt4KLG/857puICsZ/TnAtLz4pZF+fsLHw8xcH
hNrLxpbY0XBUjrL+g5p81azvVpv/PrMofonKevS1WcHoJN3g28yzU3qG6tuV
9fLuZusHztRLvd1jiordW+bqqxM6Wv/pYZJ/vP3O3+PHzk1WV2weGfZTm3aV
dw5tGpD8nVEGS72tvj9V7lE9I1u9+PG4UyOTJ+k+NTemzUrNVvV//3TshIxJ
elqThU9XmLRG/3q5yk/FE4PqQJ4VR87N1YIL5GycGjiWIefTmU8WtEzomq3e
UAuf+n7dFN3QfI/kbzJ5hLOV/R6d6/OX+o26sl3iWwoM2lCh/ZwdetKfT5Rr
s3q2ijPxTRK/0W7IQ2XGDcqUeIxqJj5I4lOoJ0h8ithLTfyP3mrifyQfcrvc
xSoOe3Sr3vr9jF8G9EpWO9e+1ObP0lv1jVw1Tj/fO1ldNPE/Er9CvgHiV/Kb
+s+695Sja19oEFTV7vm+esman0s8S90Pnv9n6B8jJZ6lhGmXeJ/Kpl3iffA3
GZNT9+bfYXNUp3kvl1q8Y7a29evUhXI/vb5gSjt9f/fVn7y/dqjqsXn5uU6b
N6ol/4l/+IHSKXfG90argQkb1ZG2bffPfCRFY+8lPqZ24QnpBf4J5R9fZPLL
62OtTi36KXy6mj2j9KOtp2zV1t9OXTH1sPQ7+x/7+bFNySrs2qGFJzdmaFsP
SxUf+07w8PFt2saTqBIGS3xJie8u3R6VHWP9iT9X5J/fV/i1bZM2J+l8L4wo
uvroUqm/2vTIN9fTn8i2eaqnqUqm3pf+ZELDTXubTlMdzHwpO196t5kvZedL
Y88lnuxF871Sv4B80TZ+Ro18/ouTz3TLUeX+Kdmv2MHRerjB2mKVZ1z0B2MO
ZUv9uxIbmp849XW2euHJcu992GCSzm3apd5dcdOubbv62PgvCj2r1//6drGl
feT53QyW9+P/OrZe7mKDm3+i8I+1WMf/kjquS4EJkk8a+6ilj+5u2oV+5H+H
flHNh1dpsjpbReaa2nzlzUl6UKuHBrzQaI1+9bu2I5pPDqrBZeOe7v3RGv3f
J9a+NGVmUO3b8/6QC2eXqCt7LvUo/mmSHjz3geJ7yixRP03svCv+9SR96Mpj
nyQuyJL4J+zHS9J6fzL2zv76Y84PDz771ErZbwOMf6Oy/o061rxf2ffrOPN+
Zd+vw89lVuoQGao384zBUt/hvTntRj70+5eyHtZ+o2c2uPqlrIfL116bsP+U
lu+7WGv/kYRtWr7vQuDgjW55BsrznpjoYXlfE0Mvbemlzr/Z7Z89xbL0sOiU
x0bfTlB7W5x78NBXU9Vn68M3Fvt2pm74de6max6foWy7/nrfi7lyj8yWepp7
DLb5cqbovr/36qbPrFSR71b6vVX+oD77y5raWs/QazIfeiPxv7NUFRM/J/GH
dU38nMQfVjbxbBLvRz124v2urdRt/tyRY/2l4pTxP16rVq97f9QfO4Pa1LdM
0xar4mZ/SHxZadNf2huY+DPZP7HVL3/9RMUMGX9kVy9+TeLRLpr4NYlHm2vO
F/HnLWTi1yTera+JX5N4N1M3KUdZfzIdbFLw9ZZVRgn9frz19LDdbbK0pb9K
qz21/ZQT3Ww84gipn3Nj28DsZ/qPUP0/G3wuetx0/c63nZ/4Zk2CGmfi4eT8
+r3TfT33Vmou9X8yN+3bWurFJpb+fdXuzl671O8Znuq1S773uk9PzT9/aJbE
25Urs6zGq5NypP6Oqd+5TdvzT/V+L396qwrbpN7n6S3vP/73lSy9Jd/rrY89
MV1VuFEprFHjO+f/stpPR5+arUp78lx73Wf3m43Tc8ep5i2PzBw8p5P+5uSe
7PzDhqlJnW4deHT9FKnvudzk55N4efQt1p9AnXlv9H8X3l6rxyZM+X3iwaDk
/86uXv3x3QeC6uhjUZnnW23TfYu89Ue3/knW7rZNz744YtTGuCR1tHbarJJl
sqVe2fX1iS0GPZwt/m+vj2re9tPi2Trm74OLE0dNU3UX51pVdGSOxKdkmnoU
usG+QpPbVwmqsjXCntxyPF0nf96yxsNVg6qn6nGl9MF0XbfA1580ey6ocs34
ru8Tz8/S5a/FvVC3+2xFvtfXCj1xz9/xd/iFiREDu0ydpW29ZJUe/1GrRdt3
iH8W9X4u/Hqjy+LjQd13U/38Kc9uUXvCPo8beSWomzy17dVxjbeob/JciVl7
KahvrJ/+3849t6jho75d99j5UH0T/N8vXGp3Y/OpzeL/Ptyrz5CqMnr3qjb9
3hS9s8SNg9duvyX5/ZaU9LDkr62e1HFYh487atW+8q5t9wxT+ANt+HJPzeH7
ktVp46+hrb+GOmjs99ra71VrU89ZnZu1fN/LDYL661wlmyduW6WKtLu/0R+R
QV2v3s/Xfv9ylZp0pG/FyDpB/eszH2z9OXKVal2mz829YUGdZuL1JN6M+mzQ
Z0fdN1+d0GqdWvfDlf5bTgT125GlDkdPv4NbP3LP/N+COtfMu/5n64V+cXMP
zFxWs7WNpx6s9r50tMCEN97TA9ZP29uw82B1Zd/28DUF3tVLs554eGSFz9Qb
j2ZOfX7LZvHff3zcfec2nlmpN0Zfzf9B/qDNX7RKW3lZDX58x/Wso6F6PnFe
ffgdYt/PMvVvhb+83LJAlXPfjlFjtlTsV67gVMlnmafT3jxx5+7wnyUDfx2t
P0bqSxds7MXTSXzmZBNPJ/GZse+HTw/cSlUXh94s/PjfQd1u/IA9J77JsfG+
Q3WvS9/vfOerO+fVR9MavP7NUH3ioweqHpuWrb4P5j5RZsVk/VT4Uw3XzMqW
fG7UU6xR6I+s1h0n6zomHlL8CQoY/lLmt37RQckPX0uX+autvfhNef9lE5+n
bHyejlznxecpG5+nv2gbW+qHaem6St2XHs18M6j2b5hePHh1mp779DfrB36Y
oN4u12u33jBNT+v2y7LnGiaoY2b82o5fVTHjl/xzM8z4tR2/GvXst88mfZmq
wteda/fT7Tv7adRDi+5ZmKoK3c775ZRcKZr4m5pdl/QtkxbUZ6bWuffeWmul
Phf+dbZdjdxSOm+B66H6f/jT0f6L+b20lzb+GBJP2uHIgnG1s7ZKvMm3A2Or
fb43VTUaVPTAzRtBvaJIvh1DDmyR9V2xmHp2+cwtsr5zfxCb/6sPUiV+Bf83
/M8bG/2KxP/vNPknlJVv9a72Jbu8/Vm6bl6s2pWX3wuqokZ/IvqkL56qXv+P
G311eNdtZXvMG6O+eOO5a7t69JV63bc8/UpA9BGDPf1KSP/hr4cdk1bbsz+F
9CWpnv0p1F7L6CMkfrKh0UdI/OTJzoUT3++9Q/xbiUfC3ybX8OALVbrvEH+b
TfU7x72bkyXxxWsutj58fE+WxBe3M/QX/54tQ3NPu/xShv45f8VVV+6cZw0f
jpvY49UMXWPq8AsHryWrYia+U/Qlm018p+hLrv5Zudfgautl/zV9p0KNDya3
0a37N32yePFY1bVPYonS1xpIvM1Tn3pY8h8lGHlWWflVHzL1tJWNF9ApBw8c
+LzNelkf+A9e2bWlV70Vsap1hR8zro3NViOLXivb8/fJusWX5X78I5Bt+dvJ
upVp17ZdNTPtNt/EZFXJ6Isk/oj6JcTHtXh97Ja4fTmyf4+NbDp8zHc5sn97
G3ldW3ldfWLkdW3lddXicL5Nv/44Wu17fv+D++/I3+3GtJvUqsgYFdvh0vqJ
2VOkPjj6hK0P9eh9flc7Oa9Gfr+4wQsdO0i9p36vn4zutyFUH21N4OFyf07a
Ifnlqa+Gv9v5uNu9V8Vl6H3ly+fZerc+nrlvtD2vFP6kZwJL/qxXPaiznyt4
/ULCKmXjXXWVJ6dsH3pyndy/A2ZpvTBjndy/TZ8Ma7V+XbrcbzPufzHfxPR0
ud+Iv+P5+4o8/nnhXeny/Ga5R827vCNU7zvJ+s09/eTxU/rF2eqNk9+1Pd6h
g/DLo8I3dXzu23Sd9MbA8i/WCKpUs97Ff2udWe/iv5UrZ+Frbbtvk/qyZn7X
q2WNWux67s75ly/X/hovLF6vPm29fPmN3Cn6rKfPC/nLvOr5xywS/dNwzz8m
hCd7/jELBTf1/GNC7dzHYp/y/F3WS3tjz98lhJt5/i7rBK/x/F1C7eirxZ4S
mJG/mPjXxKYtGfNgucelPTbtmSceWv3cdyHcpurceeX/TzvrhedFh536MFb8
bWLTwsu0/GzSZyG8Zt37Ree9FcInN5+5Nfb/tFOvuUvm5UJtR92Z38dXLWv4
T47w68cabHt+x585or9Mzal/ferNHNFfGj3aNvVGyZInpm1O0gUenFppfZVt
ytZD0VPerV71g4rbVK4iD+85vzhJ6kcXKtVrUdT6oI56a8S7395co/7a+2eP
GquCUq+S8WV49qXJcv7mrnjXvjRJ8EOefWmi4D2efSnUDj/D8/p6+s1QPu5/
PP3maMGlPP1mvOApnn4z1E79K/S9USb+WPSVC0z8seATXnz0QMFHvfjoUDv2
JVvvRU819e7lfQO856N/j077x3t+D8G1vPjmboLDvfjmUHsur354VOg+8/Sx
zaU9x9PHRgke6cUzvyb4+U139bGh9vpnCoZNmrhNPzb+1uaRryepAuPuPd9t
0DZt402k/i30WW3mT773imcfnCT4XjN/grea+RMcf/n2N6+qbdrW21Gv1My9
tHahbNG/3jfui/fK3JGP4t74oH3fMdPU4TFVXuhSa7Wy/ILOY+Rfiacqmlmo
1IhK2/ToN49M+2tRkir1wMUH331um/61Ue/CF+YkqZURNcc/lidbh73e6eNB
R6dJPvH6y062b7ltmrqx8Z0Ga+/P1u1nvbOx/85pKqtV+IIKt7J07dXLDg/6
Z5oKPPPbo3fzMpvxh2l/femYtFXdDx9vfq2m0DPhqxF35a+InBatp1foG+bU
n46OSPjq07vtNs4xTFX70Pv9/7Tb36tpHl+/VNnv0/cdzrpVXy9V1l9fD487
f2Lj7KXKfq/N17NM2/2rJkYebzt/31Jt96v64j8z66Q9kS36shqjdoWPK5ut
Brbb+teVD6bpTT9+Pirv71/qOse73jekF/UMV2jrb67i5l/d+9TtDF31p1Pj
fx4Zqs9Y9vqSMk0DyaqJJ2dvVHW/Pvbw/JIpukn/My3P1tuonqx+Ze2hO7hS
j5uHEj7aLvFFQ7qe3dSlw3bxpx89r8Gs6Gah+pcbPP/5TLV4be+/V3Sar09s
zHy/dfZ2iT9K+P75olu/2i7+9mv+c+FYxzk7xL6YVFKtm7YoRX2cP+a3cY/O
18Szkl+3aPsf+31ZcYHU32yyveX4gy8uVC9k1ivddfx8nVZlbMqsIgtlPPm9
dbpAxnP5/ZvX0m5m23qeAV3rSJs3Bl7NVkuX9xvyZ/WJetAv/R6uezFb3fvw
3sr7oyfqzg3O/TVgynbxH6f+Iv7jxMPj750975e1O7eG6j9Oico37oGyOarj
yIUDH3okoA9/OrnOqZI5ln4Bq99epa18pHYa+Vdb/kAlTFn2wpkvV0m+DeJr
LH+gMg3/Ifk2Bt349D9lj5EvbbCOvDSx0+/Hc5SVX3WBcg3L9vglR1n5Va+q
48m30r5vvyffSvvXA/Ylzsydof9o1TOrV5mg6vf2u3XnFciQeh+RhZoWL/tw
hm5z4OkxOx8KqgX5N3wQVSLT1nWer6uefGpVl/eyRX4lvgr5teGiamsf6ZAt
8utTpr+2/RXxYLa/amD6Sz3QA0Y+lv7ks6X/yRKefCz9Z7fc1epKMEfZfMF6
R4uTfUrOz1HWfql7hU088NmXOSrP7Fdqnc01QvfY0vGneV/kKGu/1NVaevy6
svy6Puz504Xus5aeP11IXmn2+vLGdV5JkfqxVTz5L0Udmbblpy33zNfNBn09
+Wi+RUKvqT/1OdbxZFDd03TZtdd+TtS/ePWYt6pmh8onbqiXrKPfP3P9o3e3
Sr7sdkUGnJkXnaOs/KUblj9T6aGOOdb/foyONu0inzUw7SKfwb/ZfEz6758r
J/X5eJE6Uyeixrqf7uy3Z09cfb9QjtpVcOErC+MCukqryY9H3pujHrxVOevD
AwF9bVSer0aXJL9flN65vUCZzcV3qseicj1fLixaL3tqepMRd9pfGbrllVVL
o3SD5JPDh/yWrd6q8Xeno4GJunTNIRVLnci23z9Rxxv9qOibn7ne4nZy4e1q
ctMzyakLE6XeKvEezT5a9ftHtzIl3qOpt+6XC73Sd7XPm3fkclU1+Nz+v6ol
6x7G/17yvRSq0jh6338z1apdJV7ocef82PtzmYNtl2fK+XO1SO8FsyaE6v2e
LBn7ce3sTJnPFYPfDRTckSnzueHl0gXOl9+hmjT6tV3ZpnOl3iv13Kpc2jS3
Z+kdEn9UOXhk4/VXd0g8B/VNieegnuOKTYkP/XIuWa1rH/nS9//NkHrdRt+w
XNvvVRvM92r7vaqV8b/Q1r6pUi9WKPvUjW0yv5UKH97SJGub+mt6RufXiydZ
OW+bqv/53EaB+5P0yF7P1CzwfGs5T/Y1e7T6zUWheq9xy1/4e8GSHGX10zr+
Qpnw5oXFH0UfNvYVyS9B/evuzV841PHzCTp/51d3RB/Jkf1EfiL7+4gq3xX7
7eqnofw2z8S+GlZqY7zgM0d35SQPzRJ9cdb2sg3O3x4m9q6dpyusSZk1XFl/
Hh3zQOLtOQnDlfXn0UtNf7F/LTf9xf+nmekv/j8jv7jv2/KnAvrIzR9HLrtv
utQr1qvXxbW+w5+0fjB4pPDmgMTbDfD0oRPFPkl8FfLDPhOPH5KHTDy+4Gom
Hl/wOhOPL5j6ddQrHOLZ04eG5BkvX8SwEP/j5YsYKhh7u7zfo3coX09Lj979
BH/9aonFD6flqEUPbRlacdgw3ePF73o33Joj9ZabXbtbjyCf1Vc00wcev3vP
5VKHrv3wzJU7+79yjbv20Hxq6/7NR1PfaqZ/KPpgqwKNH1KTXk09UfGtljou
9e56ekBFZDUsXfp0M6lfznwXWTPgqbKSXzUm4j9bm20bIO0xEc2Oeu+3+pNm
6sAD3vu1fb+qXMp7v7bvVz/k8d6v7ftVXKL3fm3frza1v1vXvqa1l3TVZ84k
fJxat7rakf2f3AUTP9QxuS6sqZBYXW28v/Ts745+qBsvafBwna21VCB5yj0x
33fTQ9747Xq7Es9Y+0onneu7p7b03BOu8g//50LlC5315YVxtVIeDlffXFh8
emTXzjrpyVfOXej6lCo1/3zmrNodda0vYl/6oENVVXD3unNVbnfUL0Z747H2
na6q62lvPNqOR128cf7ueLQdj9q9wBuPtuNRQ+p747H8eycV+403Hm3Ho3oF
vfFoOx6V9Jg3Hm3Ho2ot8Maj7XjUznVF78376VY5X+vtjMr3STX8NxOlHjbx
mHtPrXjhePUcHX9gxO2sleNVQ5PPVXefsTDlq7Lj1dxdy3+aWTtHm/NxvGpp
5GNt5WPV+MnfV3x3U+sTqeWrHhsfVGtevrZlWJ50nf5bSqfMsUH1otEfaas/
UvWN/khb/ZF6/KM9qwPrlqm0sQ2bFv4+SU+r8kbBq/2XiX2d+tTL/5P03+++
StKLavV6fuyV7RIv9+UDBVZm3DnfnvlpfpXi/QL6UfM8bZ+nxpvniX9CrHme
ts9Txcs++PeMrtkyvnuHjjgytHO2jO+tMeOeebJihr7Retz11vmDKmvFueCX
j2Toq/1GjmlXOHiH78z+In3UIjWx26dRx07N17eK1uiQcCBHWf2evmXuC/Xk
1l7hZ84l69+f7Fzr0ksZKrHQ2IyrN5J1Y6OvVFZfqS8njus/vvRGVSR/xFcL
S6To87HLl99fY6M63vZ6i453+P+PNx17tfi1dP1I+R8L7A8LqiGb9lyudjld
HxqR0vSbikEV80OnRs8Xyhb/nKvG30LtOXrlnic2Jeszbyyts3d3hiqd9+H+
QxYm6xWPXPh9eUaGOpmec3XY8mRNPPt36+dcW14qRTfw7vF0nStr6NNHXw6q
tPSPnz32ZbpeUmdkj6frBVXnH8s8Ui07XQcjkn9MqB1UUf8tvGfvKa1GfnOt
z9uTg5p6nNafSFfz+IoM/VixrrsGLUtWg6q8P6/ytxl684PVL6cH79yXW/fe
9+jqbapR7gsxXz2RpOt48cOhfGxTPH/oKXK+7Pf8oUPytOHztTr21K/6vsVB
3Wpp+a+fGK3VvOEZf65ODuoakzOL1x6oVb4na5R+dUFQ/551cXTPt7Ta9/Ov
01//Iqjzf333fHtPztcO3vkWLfLpd9759p7g5z8uV2vCsQzd9+lH6p2+c5/n
vzJ69M/Xs5S9j6Qetr2PdOMqz496/J5sZe8jvcT4yyh7H+kOze/mVwnpG64V
vZtfJSQfR/z99936WBGDnisS17NnuEZefidvz2CP2DAdfNv7vcjD/Qp7vxcc
0f/q3d+n2d8r5GX7e/XXMwfbvvnJclX9/a8uD302WZN/ifsxzvMXXyP30wnP
XzyED3v+4msFD/D8xUPt5B/keWNndGz3j/inx6b9njTkpQPnQ/hyzU3xbSqG
9H3D27aqffz/tCP/8bzd7w0JnBF/9di0G9EFPjvUJ4T7bc/76675Idwgvf/1
H/5P+08Xfz3VrWy6Ovfys4smDwvqKHO+KXu+6XXmfFP2fNNTDP8h8039V+a7
q+E/ZL7jDf8h851m1qu261W1MOtV2/Wqws161Xa9ql/NetV2vaodD97N96K1
1R+qsNx7v3y5utZWf6g+M/H0wr897vm3h/xrT3r+7fMF7/f820O4hOffHsIH
/luv8qGvs62/6iQ99M2F6wtl38FPTZ//n76T9HKP/14j31Ni0fMvnV6wRr6n
TvqkKwfWrpHvGT6m0+B5P62R7zlv6hNLPeRUE58v8f/LLmZ+vWFTb+sPO1qV
aFq7cdUOfXTPDzp92mjZaJXUe93Iwvf10X+9+kPBVr1Gq0Gf16x/NLy3vr20
Rc2950epj8v0uKf91SXif3BwwZElXestlXrSc00+GfFHOGHyyYj+ffvNvpP2
l1ki+r7lJr+M6PuoVzz2/Fff3TstSTcINh57YcJSVaRh+odVZyXpNQUPjr91
YIKy/g16zL0rSw8NCyjrz6BnmHbxf/jMtIu/Q8uDlVtN77FGX48d98X2mUF1
5fTxnmHD1+gWA5M+mTsnqK5eWLMq4emlqmLjovO/GJGkH/PkyqWqU2zuK53H
Jumu9bMGXPt7iVozePj3NQckifzL/kE/A8a/B4w9H4x/Dxj7Mhj9Ehh5Cpy4
eVVWs8/SVdGSs+6NfC+oxx6aNOytAjulfscb7wd3N8+zU/IrjTftUv8j7q/d
uvNzaeJvkidq0foDLXKsfWmszm2wzZc8Vg03+jdl9W86uVa3xEdq9ZP28IMJ
29vO3qTqP1eg4JBHUvRFo5+yfvYB1cmzs21Q1T+qXbBjgRSbr3K9Cq9Z9MzW
vCm6n+f/8YU6vnJHq46X7shv0WMyd2XO01b+VOm5MubOj7yzn4Y3mHmo1TwV
MP4fOvNkWr8jhVIsf5Kqrb+Hamf8S7T1n1C9jH+Jtv4RqkeOzh7y9sg7/G7n
3mtvTtJNDdYWq89nLTjTevYX6qsui2+l5k3WnVNPbopfNlS+Z5LRh2mrD1Pv
r026/X7JOxdEw3pze/w1U23t2fK+KcOn6nZ/hZdJXDJTvd+1fpmf6y0W+TSl
UrcraROGyO+JH7D8ZsRVo4+wOEpR38G2pyVsqTi6T+l48WcYbLD4Bww149d2
/Kq+0Vdoq69Qq64Xe6xBiUyp59fC2GvEfypiUItS5S9N1OrB228cXzRdkZ+B
9VfX1oETe1bx6rveLrpT6smUu3rXv7iUXW+tNfnIOA/L/eq12/XaWg06MaZj
vwJ1rHzeQ38w6hldp0Ilu37b6Rs/eu3Wn6WH+iDOa7fnTzs18tojfX745RPJ
Z7PytY5xOUun6aJxT41PfDVBbfX0MGvEPjV76qMHSw/L0BGLbpWI3ZesGg1q
+UHOlEHCz4+uUTFuZIWe+uvJw4oO2j9SDTPtyrbrhHU7tzZYkG31L5PVnuET
o1ZVb6n35B4a2yRpkFoxwsPKYt30wc2Pltw6TuV+51KZXeun6loGa4vVL2WT
u94zO0fZ9+nZ5vnWz2uyTjPjF/nhn1Ofzn381xzVacD8jwJ3nl+ic8yNIRfj
ZH4Pz6n6ctEbna3+abiK+GvdS9M35Fh/veF69pu/TT15vJvoP2p798ImlXNi
fr4epVN0lcQJsxpc2ST69DDvPNysUjeWr7iveIru9M2L/Q5mzdFP/b2hzocj
5qhSr327ucW1mbrxoO03yxydpfJ9fN+aM4+0tfslVpXIzvrleHaM+N9FeP6R
G+V9Lbz6fxvk+bVWhn3VI2qmPnT7+sSy42dJPmvWD/604FYeHhLyxzD+eYLb
eP4AG9SqP7JrlHooRfLrsJ4bmvUr9Y4am/Wv7PqX/Dr0J/8KuI3Nqwa/0Mic
v5Ifb4GxVwq/QT0Oxk88CRh7ODjDky9mCibfDbijl/9pjuAj5nyW87zdvrvj
2Gvz3dXWYVbPCf/f7sr8u+027qq22jHh3iUl89S1+eg/ViMnetjaIz7WHXrf
Pc+vRZj921jvGXk3v9Rvto5gPd2hjteeZtvVnhJee5ptt/m2V2grX6mk9bkC
Xaev0Fa+UoXD+j+78osV2spXalOtb6cmrdyhrL+hvXdS5f446emXV4n/Yqlq
/V8vEdws872i0wNr4j/frA43W5CnS9EUPXbiP5UvTt6sIt+88NXBO+1GL5qh
K5+tPLHCP8nqyTH9v2pWPUO3n7j6+4X3BFXfZ4dX2NxptC439OqnMWOmqCt7
66vur7a3+rk4u89C56nJz71K5L/xb6yMPTCnkzq6v+qY3MOG6Y2ePfmw9d/a
pq96+YIOCq7u0WmfYBNf8q3g9zz77teCyZcEfsvYgwVTXwJs/E9XCKa+Npj4
GzDxjWDiG8HYn8HE74HfN+MV/LH5HsFmXewTbOqBHRRs6eViuz4zhH5g6AeG
fmDoB4Z+YOgHhn5g6AeGfmDoB4Z+YOgHhn5g6AeGfmDoB4Z+YOgHhn4Otvdp
mtAPDP3A0A8M/cDQDwz9wNAPDP3A0A8M/cDQDwz9wNAPDP3A0A8M/cDQDwz9
wNDPwVZ/uUnoB4Z+YOgHhn5g6AeGfmDoB4Z+YOgHhn5g6AeGfmDoB4Z+YOgH
hn5g6AeGfmDo52Crv10n9ANDPzD0A0M/MPQDQz8w9ANDPzD0A0M/MPQDQz8w
9ANDPzD0A0M/MPQDQz8w9HOw5S9WCf3A0A8M/cDQDwz9wNAPDP3A0A8M/cDQ
Dwz9wNAPDP3A0A8M/cDQDwz9wNAPDP0cbOWPZUI/MPQDQz8w9ANDPzD0A0M/
MPQDQz8w9ANDPzD0A0M/MPQDQz8w9ANDPzD0A0M/B5OPWOgHhn5g6AeGfmDo
B4Z+YOgHhn5g6AeGfmDoB4ZeYOgFhl5g6AWGXmDoBYZeDiY/qNALDL3A0AsM
vcDQCwy9wNALDL3A0AvM94P5fjDfD+b7wXw/mO93MPKJfD+Y7wfz/WC+H8z3
g/l+MN8P5vvBfD+Y7wXzvWC+F8z3gvleB/N85Xyvcr5XOd+rnO9VTjy88ucb
iVX+fCOxyp9vJFb582nEKud7lfO9yvle5Xyvcr5XOetbOetbOetbOetbOetb
Oetbvh/M94P5fjDfD3bWt3LWt3LWt3LWt3LWt3LWt3LOQ+Wch8o5D5VzHirn
PFTOeaic81A5559yzj/lnH/KOf+EXmDnPBR6gZ3zUDnnoXLOQ+Wch8o5D5Vz
/yrn/lXO/auc+1c5969y7l/l3L/KuX+Vc/8q5/5Vzv2rnPtXOfevcu5foR/Y
uX+Vc/8K/cDO/auc+1c5/J9y+D/l8H/K4f+Uw/8ph/9TDv+nHP5POfyfcvg/
5fB/yuH/lMP/KYf/E/qBHf5POfyf0A/s8H/K4f+UI38oR/5QjvyhHPlDOfKH
cuQP5cgfypE/lCN/KEf+UI78oRz5Qznyh3LkD6Ef2JE/lCN/CP3AjvyhHPlD
OfKvcuRf5ci/ypF/lSP/Kkf+VY78qxz5Vznyr3LkX+XIv8qRf5Uj/ypH/hX6
gR35Vznyr9AP7Mi/ypF/laN/UY7+RTn6F+XoX5Sjf1GO/kU5+hfl6F+Uo39R
jv5FOfoX5ehflKN/UY7+RegHdvQvytG/CP3Ajv5FOfoXoZ/VZylH/6cc/Z9y
9H/K0f8pR/+nHP2fcvR/ytH/KUf/pxz9n3L0f8rR/ylH/yf0Azv6P+Xo/4R+
YEf/J/RzMPpe5eiflaN/Vo7+WTn6Z+Xon5Wjf1aO/lk5+mfl6J+Vo39Wjv5Z
Ofpn5eifhX5gR/+sHP2z0A/s6J+FfmDqh5n3kKc7XXAu729QHfwH/Tig/fXI
Qu257F+C9327xP8YTLuh5y4NJp+n225/r8g3QTv5JcDk9wQzH2DiV3L5/uR7
hB60QA8w3wtmftzxW3ooh34yfktfyY8B9stzicov/y5y5IPQfLn6Anc+kF/9
44nV/vkJyaP/Tv9Y2Q/+9s2C2Q9gxvPv9A7Jf7TwfWD2g/t75BXoCT9OfTZz
vy/QFb33j5D4YlPPOpTvs423n9Kkv9kfOyWfCNj2l9/bdnW/eb7U72hlnmf5
nwX2PNkg2M/vLHCeH+uML9bhtxYo1jfrAcz3s75ZH2DWxxS7rqifBX3Ip8b3
kC9urF1H+Ef55dVFmnoyfA+Y97GfaOf9rE/ex3yyv3g+2K+vypTx+9dvouh/
wOb8y5L5p79fn7NTvt+vX1qkosz3CP39+yFRsCvv0/6neb+sD84Hng/2y5tZ
8n2sB+YDzPOoP878+PdH6DwBM598j1/ftkieR7ufXouEfn594E4ZL+/ne5hf
nsd6c/V10B96u/oAvpfxQ1+/fDvb2U8BRx8boh/nPecv4/vMe06q9SdJ0cST
UF+nv2m3+aBSZP9Bf/Yb9HjT+55ky0/NV7W8cayR5yeZfEOWH5yrsz3/CPIJ
TNJmPtbI+8hPZPsrU0+NfFyTFP6n1O9pYd4v8Zdg9gf7kfczP5yPzB/nn//8
jpH+nMz0//fzPkZd89b3evl+zgcw32/mc6zm+yyW/JTMF5j1YuZ3k9Drinmf
YOq58z7OYzD3Cc839em0/J7zHYy/J+cbmP3R1uu/3PJbyfqo3Wdg4oV4H5jv
2Wf3ne0v8U2cN2Y8y6Wd+4/v8esPF4k/PuMFM94hnn9Qhnyfk19d+3Gs5nxj
PTj51x2MPjxD+jv52R0MP7JB+jv52x0cK/Skv1N/V/lxrMwf69PPPwWc8ype
OfV2HRwr9Od58Gf09+NYBf3p79T3dXCs3A/057zme/38Y8C5X+O1//wM0ZP1
x3pz1zv9OZ/B/vvcpV+MnEcGRzv3Z0A7/KXLnzn3e0A5/KpjPwjIfDJfTv5y
mR/anXzmMh+0O/m7hf608/2cdJznfK9/fayQ8w77I+NZYuvYmn575HnIe3KS
er/b7ayvPTI+vz0koOjPeP37cYVg9LHO8zXzb8fnvC9WRXjn4zfyfGc82umv
6f/v+3+F8tu7Vsj6a2LjiOnv15dvkHbWm2s/ZD1zvzA+7heXH6C/uVe3ynlt
4v23ynlL/jETV5ci9dHJT8D4eB75yGx/Wa/ufcDzOV+Zf85PMM8H83swz/93
+Sle/e3lh+0j9yvrkZ7sBzDrH8z58/95vpw3tDCfYM4T8HMe/fvI/U88GvRl
funPfcV9SX1c8iFQr5Xf+/WrCYr3sV+hh8UOvxOt6c/76e9+P89DHmK/gumJ
/OnKo7Qj79AOpp37hPtcGX5F7n/OU/rDP8JPU1/Q5j+U97v8Kfw19xH87ePe
+t8u/CUY/pLx0u6/v5BDdgj/yfPBtPN+v31stuSjYT7ZL2DWJ+ujrucvvU32
l1+/lyzt8PPUo2X98D74r8be7yfberMzhb/ge+H3oBf1a037RE3+Qc4D6uva
dkU9TfIbUK+S/ATUc2Z81K/medSHBsP/0p/8g2Dmi/UEhj+sZ+gj5xXyFvPj
txfOlvhH5BG/vWiB6umdLyvlfAQzX/77PsbOK/qZfo6+pp+rr1Fg1j/rg/n1
86+JytBvh8hX8Lv0r2jWt8hzfnvWAv2JGb/sH7ArL3M/cR8Rr+u3d01z9E0z
RN4j35PfXjdNOfobRx6fIucX8qWj/1FOfzkPkS/9/GWMyMecj2DozXkHPag3
zXrzy5uxch6T39Z/n/Rz5NFYzfiYf6e/rL9/l2+j1Vz7XoOjRL7me8Du/VTD
xg356TVcxs/8MT7mh/OD9QXmPPPfRzHOfRTjrO9EWT98n8P/aYf/c/Rf8Y5/
6QI5/9iPYPYj64/z1c9v9XPkpX6OvNrPkUf6aT8/vkhzPpn4moWC2V9++sQq
6t2QX3GC4TeFn/P7HwXUAEOP/9Hfsr/96ytRxs988XzWA88H83zmD3qxf9F/
8H18P9gvH64QjLzA/Yy84LcXJct653wh/zP8EPmx4E+deurCj3NfxMJne/lE
kvUWbz6WCOY+4H7jfue8R/8FPeEHoaffvp0g+gXaOY/ZH5y/PI/7nfOYegH2
eyW/laHvdMHU9yCflW2X/Fa2XZl8cKlCj66GHxDsX48hfQTjQZ5mffn3c0CF
23vB3u/Cf3M+cl5yf6A/pD2f9WMAL7J+6YzPrL+NgpGH6Q//wvpEXmB+f/DG
21HqBcBvs56wY/O8n+xzyKdNfij4F/L/wr+c9+ieJfxTQ+KAzPtFH8vz//HW
10Ibr5Sk2U+0o+/je6m3xPdcNO+z8ZUzNfwG39PDyG/a7g9VwIzX1nOYo54y
3yPzxf3urjfOf9YT5z/6Y5H/7DkGP/iH+T6b/yhJxdl7Dn4w4q2ub1avu8bm
Zwtq9J08j/niPmpl5le+F3mY/mXNeSDfi34CesKPsl6R3/g95z3f69f3T1P9
8Cu387nOnB+C63jfkynzeWvG3XyzWbJ+Whh+V+h/w7SLvPKi+b3Qi/NR9oPN
z87+R15m/OSnY/9z3oORfzjfeR7nB7/nvED+5vuYX37f1VsvE6W+F/wD91eK
N3/N7XwPFUz9Ne47+BXm22JHXo2SenC8n/7/Lq9GKfhru34c+9hwTfw29Yvo
D7/k50+ihT+B/+S+IV+9379hsugX4T9eMeefzBcYfoTxML6h5nwSfhPM+Un9
JvYr+i/eZ/J1psv70P+Daef9nOe83+EHhf7Qi/UDvcHMhIknDb0fzPuoDzVg
2Ok8T7cMqtwmn7Jg+A34d/Yv+fX9/i2TpR3+nvlx7U+M52k7j9QjgR/g/kfe
ZT+z3sw8d3H48y5CH4sdfr+Lwn7CfIKZz7re/Hwp8+m3T8Ro+AfWIxh6+/Wh
MWL/oD+Y/n59ZYzcN/QH099vn4jR8AP0B9Pfb5+IUX57XbRg+kNv2sG0+/XP
MWJ/pD+Y/tyntINp9/OnMQp9E/3B9Gf/0Q6m3W/fiFF+/VG0YPqjD6Id7I6P
9TLD7Fe5D/z2hhhl+CXsDdGOfTjase/HS3/uV799fri0I//45fd+Cv0x5w2Y
/W3qk2wVfgT7nt8es1z6c/6iL/XrY8bKeW36jdaMD32v359grOTvsP0df4YY
0X+xfsHQ3x+/EiP6cvqD6e/X98cIP0N/sH+/rpD+0IP+YPr77TcxCvmI+QXT
3y9fRGsw7cjDtINp98s70SL/0O63V8XI+cZ4wPT3269iRH9HfzD9/fasGLFf
0B9Mf+43xgumHX6VdjDt3A+0g2mHv6YdTLvfXhgt/Cr3I5j+fntNtNhvaEce
5Xlg2uHXaQfTjrxBO5h2v34gWsOfw2+B6e+3N0WL/Yl2vz4tWqOP53lg+vvl
zShF/UiDIx37tmt/JI9dumD/+RvtnIcxznkWr/z6ryka/hZ+GHkA7OePpog8
A78MPcGcV0auHO/EIy/QrF/OdzD8APIG5yfnmX2e8uv/AsqxNwn/AfbPd0A7
9jLt9Nd++T5W+B/qg/jt4VGqm7ffx8v8wY/Ab8HvWXlP/F24D7gv6I/8QTv0
oB35Bn0K8j/yFPMJPw5mvpk/+Ecw88vz0A/6/Q2iRZ5jffv1rVFib8YfjfPI
6scEo69Ev8n4/P5pU0Q+gZ9FP8d4ud/B9EeeZf0jz/I9/+5PESvf8+/66JA/
NeuV9Qj/7LeXJzr63ETR52Jf8es7Ex19Z6LoO5lv//mQ6PhrJCrHX1boy/j8
/qUzxP+B/ozf75+8R/Yn9n+ex/mOvpL7EX4e/o3fs5/RRy23fgnki/Xr8wPO
+RyQ/cP5wH5EP4A8gT6V+q/oj8iHh/6F/Jhgzi/WB+Pl/KQ+Jvu5bsy9hQop
LRj+GX61mZdPKlQvlvqZ9Df6qDWCm5r+kj+b85PxM7/u/mZ/cN65+xv5kHpU
5IOnfhX1M5Fn2T/oR9g/6DPQd/B9ZnyTtdHnhL4HeYH1UMPkD5V25EfkbeRl
5GHoYZ+vdpv65VJvvZ/Rx0j9rARTr0Pqy5KvlPllPuH38f+gvZ6ppyr526iv
arH4fzB+7L/gaG++hgk96hks43+Jc9bmV0ce5fe/2HXGfJC/nfnivhlwM3/X
95+eLvpkxu+3J40X/or7k3z+Nl+/ftM8T9vnqa7mPvqf+UJe4fxmvAZ/KfsR
jD2e57EfuU+RT5h/5Bvmm/XK+nL1Gbzf0DHH2kMmiH2a8ZAP27Yrvz4jXnGf
wZ9Bf7N/p2ow9xHzYdsVmPsH/YrJb5ogGP04/jjQl/sE/mKER4/mUr8RbPWH
jr4lXrMeXH6U98Nf0s7z4FfYzxY7+sdIeT+/p38u35/0l3renOfo77kvsBdw
/1CPHH0r9gPsLcin6HPbmXruUs8afTr3C/UbqEdB/R57Hgi/xfpkPbA/4P/A
va2cyv6H/uwv+E8w9dF5H/MBf3bB08dMt/VCQhh+C3md8wL5FP14Vy9faZbo
n5GP0NdRzwZ+EezXT6yS85X6e9xXYOhJPVnbX3c3vxeMPYD5Qh/GeOEn4Q/B
rBzuF9rBtENv6ln7+fVBsn6pL+u/T3o79v3eMt/29w7/P0jWO/U5/PaY3g7/
11v8xVnvrBfq29c3/IGcz71MfUfRv6JvYf1/3Wpk7V6dtkm++z0Gy/NZ/5zX
YO7nTV69qDVSPxV7HvIKGPpyflAPi/uf84/7gf3G/HD+LbB2bMY72GsfKOft
OoPlfAZzXoDd8wX/APJtDvr0mW/G5U5Q3M/k70Q/5PIfrHfqP7K+waxv8h2z
nqlvCPafl7Eiz7N/yZ95MfhokS4jE4Sf5bxDvw6/8ru3L7bK+eC3v8ToVV4+
auw1vR37TW9pR//u90fqIvYZ5HfoA8ZegLzOeQOGP2R+OZ+5T8Gcn+jf4L/9
3xMr42V/+fWbgzT+CdyHYPgFv396tMJ/jvUMZv3gryT2cVOfXvYf2JXfeB78
G+sTzPP5Hu5rf/xUnPbb86I169nMQ0tHnmzp6Bui5Pzg/gW75yH0YH3a5zn2
l5aOfTFGxkP+bf/5113aDX06OOddB+1/f4y8n3zfzvOk3f7eOY87OPbQSJXt
03OFi3zC+YQ/scELBKNP2urd0xtVux+3jzz+QYrGf5j+YPqv8eZzk/T35x+Y
K/612K/RD4BpR3726wOjNPwf8+n3t4uS85V2+Cf486CXz36zjM8vH0eq/qZ+
p9DLf35GOedXlPKvxy7av366CH8KfbC3sp8G+OL8gxr+nnYw7X5/wHjl2FNd
/l/WB9jvHxjv+rO48oR2fq/3euddaD3483skiL8Q/Dn2MvSV+OeyfsDQh/3J
fvbLFy01/Df70c+/t3Ty0ySJvzb+x5x/YH98SqLYx6G/I0+7/iTir8b3QJ9D
D67N2vyz68+ZKPpO/BP9+Tjmiv0I+iF/ob/Efw1+FPuB6Dvt89GH4f+B/gn9
Pf51YOaH+YO/BjO/6D9Y7/711EXmj/OP/cV+8K/fLiJPcb4hb+P/BkYfxn3M
/ejPH7ZI5teNr2b/oK+jHfsw6w9Mf3+8cLycN8y/3794uMQP4o/oj59aJOsL
+jM+9rP/e+JlPll/fvt5ohPfFoofZ/79932s+O+IP5TVLyP/LzD1PpR+9seV
C5eG6r/Cj8LPIJ8buSlb9Cfwk9AL/R38Av5mzCf1RZGf6nj540P1QVsY/aD8
nnru6HvgJ9AHoh9C38d+xV+I9Qw/xnyKvsb6IyEfG3lhtTrYpOLUiv2DOrvi
wELvpoUw9gXoI/HZlr/me9A/gNE/oB8FU0+T+0riey1/i3yBPpH7DnmlxIbm
J059nW3lm0l6nZFftJVf1AZTP0ZwcdPfjn+S6H+Qv9H3IL8bum4VfSD7F/2e
//yOV9TXpn7qUoOl3in3Jfwe/D/6FpP/favoHwz9twn/v8NgbbHIS4wXeYjv
IR9/h70F3qqbf5bI8678jryy3ehH5fl+fm+Qw68NkjxLrFfkI5HvTX0cZevn
6LIX7tbLCNWLNfVTskT/ynrh+dRrrDElbnTDntMV/Dfrkf7QM6/nrzlNf1+3
6wfDKyaI/ZPx0R/5Av4QeRWMvo77hN+z/+Enqd9AfUnkM+Qb7kfuV/hLcObi
dxZX+S1d6gXDT9Le255rF8u90mfGe3PUKm89Jdi6AbNVSysn2HqPYr9BnuW8
cPX76Ic4P9CXxnj+zV+E9qPF2A/4fvYj/CXjxf8VejI+6mcgj3PfU5/O3V/I
5/ze1ieQ78V+gL4f+qGvF/8we+5zPlS29xb7X/wv7PdKfLwzHs73fR4dQvoV
+Bc5T61+jfPU1E8I7Wfxh7GYdvQ31MdbNDq1euvVyaL/RX7j/ANT7w59zU5T
D0ww+iHGW6ny3Xqb2bJe4f95Xgkr55dbdjli+vGZIk/RTr1yxof8zn3IfoZf
+dNbb6+JfFHTO0+oTxfu6IvDpT/vo38u35/0l/g45BMwPfEXpx1MO/Yb2sG0
419PO5h27JO0g2nnPKQdTDvxGLSDacdfnnYw7fgHoK/afazdd69MTNf2fFQr
jL4BftXxR+uipnl8b4j/QX+IPpb1Qj0y7kP0Kye8/b5B5CMw54Hhf9ZLO5j2
Lp4c/IXUG2S86Fv9/nW9hT9kvWG/Y70Rfw29wNDL7LOQPrSoqV8m/CBY8m94
deFD9Fxi6t/I/oKfwf8DftDIE2OEnwfTjnyJPRF/E+yFtr/484JpR76lfiD8
DfUAwcQzIM+DoQf0Qx8Aph37Fe1gOS8s/0U9QOr/8X7qBYHhV9BXgHke9gza
wbRz/9EOph17N/OL/wv38YfmPpPzF8z5S71B5pf9BL/k1/+PFfsO84N8CKbd
tVeyXrhfWB/Ii2DaWS/wA6Lfs5jv32vqM8t5C6Yd+xj8nfhPWnpQ34z6imDs
V+jrOR+w3/A85AnGB+b9fv63lxP/0EvuBzNfnzj+Ar0ce2cvuS9sf7GncJ6Z
79qmLZbzDPmhseHfpB4j/BznHeMx52UDR//aQN5vsaM/baCQRzhPkDfR1/j9
1aM18UbsVzD08/urR4u/A/3B9Pf7q0dLfDj9wfT3y9vREo9EfzD9se/BH4Ph
vw55+yrEr3MeEw+GPzuYemYNvbrDic55nqipV3bAO5dD8fDEM4LRL1Hvz9Sv
niv6AfpTD83wUfPkfDb62XFyfoM5fy2W8xnMfgdzHoDZzzyP/Q7GvkZ8HPoL
MPXqrTwg/dF/pJvz0NZLmy32cvRbxLuD+3n3aJbYo/DHIv4KjH4K/xMrr4o+
iv63zHmt7PO03580VvgR5Em///kgaYe/px3sj9eP1sSDsT7BrE9/vqloTX4Q
+oOFP7DxYfQnfwL9wfT355uKFns2/cH09+ebipb4GfgVMP39+aSiFfpj+oPp
788nFa3Qt9MfTH9/Po5oRfwd/cF++oT8/9Ev8b1g+rP+aAfT7o8XiNbYB+kP
pj/+F7SDaffHE0RLPCz9wfQnPpZ2sP+8XSHPwz+J/mD6w2/I+rKYdn88QrRC
XobeYPqjP6QdTDvxm7wPTLs/P1i0Jn6V/mD6wx/QDqadeEvawbQTz0w7mHZ/
/EO0wt+S7wPTH3su7WDa/fER0ZLvh/5g+mPvox1Muz9+Ilrh/0l/MP2xV9EO
pp14QegBpt2fXy1a4x8o9LeY/sSj0w6W8dj4dNrBtONvSDuYdn9+t2hNvCX9
wfTHPkM7mHb0jbSDZf36/I+jxL8ReQNMf38+pWhFfDy/B9Pfn18pWuLV6Q+m
vz/fUrQifp3+YPr746OjxD+CdvzX+D2YduKfaQfTTj4D2sG0o7+lHUw7+X1o
B9NOfiPawbSb/w/5v1DvG34PDL/nj5eIEvsE8gCY5/vzT0RJ/Km7HrH3NTD6
X5HXwfDX7E/8QcDoK340+jbR9/n996P084ZflPGCGY8/fiNS5AfkLTD9/fG+
kWq0lRvp74/niVQ9jLwl7WCex/2JfRJ/MOwHptegOtjHkZ9sfWSRX8F+e3I/
0e+b5w9w7OkDpN3W13be19fxj+0n/iD29459fYC0U6/beZ7wk9AHDD389uwo
Bf9LfzD9/f4skaJfRv8Ipr/f/yFc5frSvMfgMOWPv41SZz1+bJG83x9PG6Vy
zbzLT62Xdn98bJTCf4x2f7xrlBrdrULahM92SHvRzEKlRlQKybfoo9HvIi8h
T3HfoY+r78kzG9V9xUZfPRMRwux39CvYH/BfAVO/uVZ8TrOlj8wReiOfwF8i
j8FPIs+AkV84f/AvAGOv7uT9bouMv++m+vlTng1hzjd+D+b3Uzw5JeQPM7zK
+20ODkkVjH6X34P5PfNHf84r7EX4m+N/D78H5n7Anoy/Ov758Ndg9Mmct61W
fzKpc8F00U/59bv9VA3vHCBeqa/kK+C8RJ+JPs4f7xql/fGgUdof3xml/fGZ
kepDazdif2D/BPvjzaOcePEoJ947SvnjdSL1K8Y+IfsT+zz6KuG3LfbH04U7
8ZHhaqrX3kP2L/uL9Yg8yH0D5n65Ecyp8cA7GaIP9PsnR+r3rJ2N8fJ8/G+I
twSj70f/AT24r8Doi+A/8Nf2nw+h/DroN9Cv8Dwwz8NewvP8/oiTRL9Nfhr0
IWDON/aD8VdYL+dJEW8866Qd/orxwO9gXwQzPn++v3jxB8V/i/GC8Xfh+dh7
eD743+sHxDj+tNGChZ+z/gL4X3A+4r9HvXvOQ+YX+qIPwd7q129MknhV8v0g
33AecX7hb+WvV5Yk5zP5p/zxlYmSf4h4SjDxlMgL9n3KyWfm5k9w9DuhfBns
H/YL54/f/2OyrC/WG/IM72e+0X/7/Zfj3XyGjj455A8DPdHvkM8YTLwp+Tug
D/kHwMRDsh7GeOPdLevFv56iJZ8xv+f7jP1qoYyX+4/vQd+GPR+M/IO/iV8e
ipXzlvvA7w8Xr/zyUKycx3J/2P1Jf788FCvnNf35Pf5dYPzNuL9Yv359T0Cj
n2A+/foKt/5pwIkPjtd++dmtjxqQfEL098u3sU48dozk48E+6uffoyUfOP5t
8Dd8Lxh5iPnBP84/f4sk/g76+esxxct84r+GPEY79KbdXz8lXuaLdvId8D5/
PPAKweQbRF/J+B/z9LpLVZGG6R9WnZWk5xp7hvCffB/6fuJPOG+Zf/pXNvYY
ZflVfd+4L94rUzxbt5/1zsb+O0P2GdqJT4G+o0/Vq5jeNMfym+N0vMGWPx2n
iOfkPsAfzI1HhB9KtXILv79i1znPh97wX/C/nP/YQ914Q56Pvh35rbRHj/bW
fhYn/pDo15F32P+jPftOKD71VtEaHRIO5Nj7bZjYA9C/S35a2x/7BfFFLxp/
KIl/ApN/DIw/IZjzIGpQly5NOobs46uM/Vfo09S0y3owdpsQxh/P2o9F30O+
ut3GH1Gen2n8EQUjv+JPWMLTR6xQ1j9FF7R2PhtfI/kikP/RB8AfcP/yvXkb
qvGrB+fY+Rit8xgs9lHWn7EvjZf1Z7G0Y++lHfsx+iD8+7BvIM8j3+Mvxfrk
+e2MfdfelyNlvTIe7CHYd7Bnmuf1F2zsNwMFm/XxqWAj//RR2Dvt78X+aX8v
2P5esP29nmTssWKf5XugB/6ByEfYb/A34vugJ+cD/mjYb7Hv/lVu+v2/bcu2
75ukr5w+3jNs+Bp94vagj6YuCaoB3frMPL9MC15h/Jtk/ax7Nr78O69mSXxW
OTM+8e8EI/+hP2D/LMr4eFelP7LEf3HutPIHlyRu1dbfReL72C9LTH9l++sC
4+49323QNm39J1W88YeUdvxV2A/kI+B5rF8z/2Nk/Vos+Qc4n8gnAG5n/HNk
vPgD8Hv0Uzx/ufH3lPE+lThhVoMrS9SawcO/rzkgSRcy3yP+oOwP7J/sD+yl
rA8w80//F3eNW9O+ZJb4t1Y1/oXK+iPr88b/Vdl2zfmFvRGMfRF9JucT+kXo
m2jmT/yVoC/+wGZessQfmv2Jvo39hD4NjLzOfkE/BkYfltUqfEGFW1n60Wrf
fN+pwHS5P/CPxD+A8eL/gHwAP8H64D6AX+A8hn9Gntna6nCxb6fOFnkCHFej
xJS++3eIvRn9DPoj9DPgy949ukU1GlT0wM0bQZFnaEcfA/b7X/RTfn+Lfprv
N/4++IOG4rV/9fypVynrHyryqOS/9/Rp62Q86HdoR5/B/j6x4qkKnR5Mk/7/
NG88b+W9oe/hPrbzoRPefu/Ty0nZ9v6dLBj5Z4fx/5Xx4W/JfQ62/rN6hvm9
/b7JCky+DtYj8hL7Hf8j4l8Y75nTNRsNWR0aP/o28BevB6/VG5muq3x43xuL
uoTyXbL/OQ94Pvpt5CP0legDkQeJB5V6AHa+Bnn80Xp5P/OP/x/zTzzrNXOe
K3t+i78J/ufoJ2S9effkuv+ZL+j7p7kvLH86SW2w32X2S8ifn/uJ+WG+wfij
v3iw/pncH2Xo9hVqNPvvn8nWv3+V+Ctjr2H+h3v7KTQ+9I9g/Efpz/h5H/sV
//Cx1i+jfOUSwax1s+W84LxDX8N6r+WdX+vVP23Dy/UvmKJXXRv058uzQhj9
NvPLfgGiv3bnH4z+Ev4d/QfnXz/v3Nwp/AcY/qO40XcL//ChT+7PlYv9CkZ/
CMa+y+/RB8r3WP0+EH0eOGZCw0UDX9umrfyjkFckHsUb32pl94vsP/zn0M8j
3+xXd9dzTdFHNq/jYctfhzn+0WGa/oyH/rl8f9JfBYx/7//IW/i7kd8C/0j8
u8FNPH1XyD4AZr34/ZcTdVKRV+sc6bNd/LPQH6D/2uDJb5mqhufnPl+wqx9F
f5nw/fNFt361Xfyz0FfSv4p336eotF6NhxR+Zb7Iry7m/fmtnov3g3ke+j2z
jgOi3wdPKhv1xvf/ZNvnT5T+6BsKDW24YXflHPv9AbF3s9/Rj6E/jizUtHjZ
hzOkHcz5aP7NFPkAzPegL+V7iG+x/Ibo18Bxy1/4e8GSHKuPGSn6UH6Pfhd+
Dv82znv2P+MBM57LVs81sdunUcdOzdcnPX+WRYLR32FP8OeLjtJFvft5wR05
OL5w3nbzhf7oW6G/Ge9Eweijsb/Qjv4D/bpZt9vFHmbmIVMd2Hf72T+S54t+
nfWwwpNnM2U9sZ7BnPfEu6F/x95l6LxD/A+5/7gPDP++QuSbuE2Xn6mfK1Po
RX4W6G3uyW2qUe4LMV89kSTzyfyy/siXQX4h7BNgTgryR7P+iJfBn5t4GeRz
4gexL+KPiD0IzPPxj+P8GeLJc0PFHgOmP/w97WDa/fxAMye/QDMNv439Bczv
/fxDMyefQDOHP+/q2Ku7yvlr5N1u2s+/d3Ls1520n5/v6tjTu8p5b5+n/Px+
J8e+3kld9fidTNkfxCuiD2hp7leR38Dou2ZbvtDyM5JvCf1HvMd/L1P9dzTf
O+VcKB4W//hY065tu7rZPOm53N2z5Xm3zPoW/guMP8bPdUsMf/xKuu6xd1zV
zZWDch8hv5t9G5K/G3j7NCTPgDk/n1w2t33tVel695yc1JWvB1XnH8s8Ui07
hFnP6ONYz8g3+EvyPuIt2V91vP03WdYTWK7a+wc+cz1WC/+Z/+u76+09uc/B
dJ/g7esM/U9w7tljSaH4KfSbxKMhXyLPs7/API94N9rBtHMf0w6mvX/jah91
KJWuRtZ45Ye5o4KiD2c8N/J63yf6kc+Mv7ScJ2DhjxofPVxsRUi/QjwF/F4p
y7cbfcpohf4Y+RR9M/plv346SnHf8z1g3s99TjuYdn8+XOKt1kp/MP2RF2kH
044+nuehP6A/mP7kC6IdTLs/H2+Ugv+hP5j+3C+0g9334T8AZj6+NvEtou/A
nwB7CP4E5Cvw+2t3V/77PMbqLbEf93Lsyb2knXwJ/nw+3SU+HnshmPML/3z0
f8i7Rt4ZK/wLGP0G+kX4cdsu/vtgfz6HsSLf0o78C8a/FPt2+MGE7W1nbxJ+
GQy/zPuwR3J+W/5S6jGA8e/m+Z28+NsN8nwwzzfxlyH7O5h28ae1+u9+nn4m
FH8H5j4gvyH1YcDkt8E/zvI3kh+X/pwPln8X+yf5PYx8slnb7xMs9aeMPkja
wW49JqnXavRP0h9M/15GHyXtYNqZX+aH+DTmA/8UMPNn+X9VwPBf1s4REH6O
+wR/Mfi5fd58L5Z2f3xcQCG/8jynPoHYK+Cfwex/7PNg//6Ocp4XpZz6LWKv
F/86i3ke8eX4N2GvBudpd1e++Fz0X/h/4t+Evyj4V08e+Vz0W9CX/BbsD3DA
8P+Wb5iobpU7N/OFqpn/I2+gL+T8Qb8KRr/q9yfp6+QTiVLEE3HegqGHP/9N
pPAf8LNg+vvPz2gZD/my/PnbOmh/fqZo4T/NedVa+E+wPz9YpOY8g58BMx6/
v2O08KP2eY6/QmsnX1SMjMecDz1kPGDazX3Qzonna+fkm4qR99vfK+d50m5/
7/h/tJP8LeQfJD4FjL849+NWbx2G9ONg7kvyc8J/gpHX1730SvOrM0LyHfTB
3oo/Chj5xPiDfC7+gOhz0ceb8zpUvwdMPK6bfxGMPtb4C00V+c/NxwjuYe9V
21/yuZCPgf0PRv604xf5G/029nA7XvGHBBNPwH2fZugt8guY+5/zkf3PeQxu
b+RJOQ/8+eiGS/4IM1+h/FZgvpf8RuhXbbt8P5j1hv8Z6xd5HPs0mHod3Oe1
vf0e4hfA3NdVPPtZqB1MO/5hPC/M09Nslv5gN58I9zWYfHQdvft0jl6ydsPU
EXPmSH5Z9MnkqwNnePzMTN3k6bN7rz40W0V49AvpC8G8n3g2xtvCWy8hfgZM
f95PvCL5bA7dvj6x7PhZMh6wPz9UpCbfCOcdmPPOn08vUuzH9AfT359vNlKz
X+jvz68Xrlp5vx8i8iCY5/nzmYarGdYuSX9/fsNwNdro76UdzPPIB4G8fLZ/
heURs0P2G+LZwW288zFEfzD099efilLE53K/gf+dv4gW+YF8jf58Dh0U8bei
P7KY5+G/TjuYdn+9nSjdxldHIVIw/RkP8eZ+/8teko+V+QTze399lkjJr0R/
MP39/peRYp+hP5j+7CfawbTjb0Q7mHZ/fY1IzX6mP5j+/nx0YzX2fOQn/BHB
/vwtkRr9lTnXa8t5CPbzB+E6zM4T9gww4/Hni4kU+4h9nnKeL/e/4dc/lnYw
47VYO+3O90TJ9xh6NHb4qcbSbtZvPUf/WM/JdxMl47e/d/inxtJuf+/oI+sp
//PCVMyXhi4GF3HqeUQ69X7oF9I3+PULkbI/4bdMPqJVcn6Y8ySknyaflfh3
e/LORtXi6e7Lez6TIvYc5Bsw9gH0F9iHwNh78CfAXgzGP7Ze7pk/DtI7lPU/
EHs19wn2bMYH5jzjvEJ/jz0JjLyB/If8zfOIJ5F4EW9fpEo7mPeh32P8xO8S
L4+/KBj5Gf9t8rVQb5bzDuzP75Io8fHI5/h/cb/DD5OvGX8r8z1TRZ5GPib/
H/wwGH4Y+7TE01j7NfQAQ49S1fq/XiIY4k/AtJt5CNnDwPDXc78fFyxaK0MX
vb/p7Mz7QvUuyE+N/dd+j/C7fC/2e74X+RH7BvYh1gMY+xH+g+izyV+IfyUY
f1PyfTF+8vvh7wDG3sp5ib0Y/hSMvGDsjiFs8rLFi70Q+Rf+m3xwrD/8SaEH
57M/f3W4irF+Apw/+73+AwQjr5IP1e+v09LJRx2uHzf2djn//f48LZVfnu2u
/fJnd0U9EeSDF0qvXd81d7rom8lnhf0C+wY4cXSn+Q82CuWz4rxDnjP+eavE
foB8Y+mrsadj/8A+Aka+wH+UeqPsP+L9sI+km/Ut/hzk05P9Y+93+HF/Puhw
XcOz/04RevrzQYdrf37nMCc/dpj6ymtvI/eJP59a6H7AH97vnxCu/f4L4crP
DzTQ/vu7gcRXEG9C/hniPcDo88i3QTuYduxV6C/Rb4KhP+epvx5sotT3Rl9J
Ph76k0+B85Z4OfYrGPsF+RSoX0H8CN9L/gm+B8z3kH+CdjDtxEfwfvIvYJ9D
/sd/GnsOmPxebj5Z5HX0U66+Dn0E9jP0c/542ljt1K92+K2h2qm34eiHBst+
N/MxRPxp0Wf585G2Fvs7+ih/ftLWjv4yIPl9sI9jLwD7vycg9gDqUaBPA6PP
RV9OfSnyj4GJf8A/E30H8hjnGRh9h1+/G5D8b7wfewIYfhr+238e3+HPrX+T
yz+Dqe8i9ais/wqY85LxEn8IvwZ/ZuPfxN+T8wx+DQx/wv4Dw7/AD0EP+B/W
P5j9x35j/6Af4X2HPT3BZuFX8ceB34C/wD6NfwTfD3brf7fz+YlJ/Jnof/BP
oR4P+9WfTz9e7g/ud/IBsZ78+uJY0Rezf/z2tUHan6+uu+wn9LH+/dhD+/PT
dZf7An2rv75ND1kv0AP/RuQH8okxX+QP4/vZX+Qv5vesL/Lj8jzOO/gpMM/3
x2/NkPpWnHf407BfsfdDX/ST8Efk4+H8hJ8Ho5/H3xb9If7gYOLPnHpcIu+B
uf+J7wQTf44+L33xPSUPxabIfHLf+tdTA5GvkV+ZT+5jf/2GBpLfAPkU/QX0
ZT+C/fLsbNkPxDdh3wGTn479xPwy38Sbog8YZeIrRZ/kjz+NVv54nclyHoKR
58h3TLwN8w398O/x3zfdhV746/jvm+5ijyLfL/p5MPIW+YE5j8nXjD6J8w/M
+Ud8MfraRG897BJ+zF+ft4t8L/Y0Jz7ViXeO1knmecK/o+/D396v/4sR/pD3
EQ/LecT7sLfxPrA/30nArYfm2HfGK79+NkbqezFevz422tG/Rks+dOQLv741
yqFPjJ7k8fchevj1r7HKqa/n5nOXfADw++ijwX5/52myfpFP0XeTX4P1TDvn
F+cBGHmc9Y18ynjYn8gPPB/6wu/66Z0o38P69OevixX+h/Xirw/bT76P/eCv
3zrNyZ8SqofO73kf+OGIJnfXT4Sd37SHI0rcxWkWR0TPmXd9k+TTDEQcLvj2
7DckX2YgYtmNAgPSJR9mIKLe5tN9d0m+y0CE334QG/FL+qBh80S/FkhrbPoL
Hjzkndglom8LpK0wzxdc781+8+qK/i2QdtSMR/DOHzNvfSn6uEBaOzN+wejz
3qzaNm/2AfKqpasnVm1Keqx1UPvz8QUinPjqCCd+OsKJj47o3eXHWj89sFMf
jhh3MXtaT5WTta3Albw71Y7XMlOfa/Kx7mvalW2XeGs7HpV+dPneQh2XqrVt
olIOTbzDnwxoFfuKXqobby8+r3VKkur22SvNHui4VPdqt3HN4YlJaknP/8zs
+XooHph4bPs9Ep/O9/I9e850yLxnWpJqUr5dy16vh+KZypX5ev/bBbLVwtc2
PlFx9TS9p3CddZ89nK0aDaoxquPwafq/26r1bVogWz8TcTpf+dXT1K+9f+87
p21A+h/+rNult2ZwvoXykfaq3KvC0taJYv+/GnFrbqHsufqf3041mhRMFP/e
LuvHNX7/NyXnh9/+H5vm1A+P+HW111/0rfEFO81oHROyLxOf9Wvs5c6fzQ/q
K3smD93XPEeNbFDnyTadxurLBmuL1WHzPdp+j/L7KwTSar5Q58eNzUPxz2de
uxSzKv1/45/t+yQe58zW0l3j5yar58zv5b5P+DvncuGRoXixzDqZzb44F4oX
CBs3buqScxnyPn++zkCEPx9nIMKfbzMQ4c+nGYjwnzeBtB6lrreLbtEv9P2+
/JiBNH/+y0CaP79lIM2fXyAQ4c//FYjw5xMIRPjzBQQiFrx968mhbTeqcb1f
+nlUqRQ9tsr+5Ak9N6qS128X3HcH+/MJxKbVG9howaCMTarVX9NufXun/dqB
nnlOHCov96//PoxNc+rHR1zL9voLv+PP9xBI8+dzCKT58zUE0ohXZz1dXfbm
wD8yQ/F91wz+n3h11kPV7BU1JledLfpr8m3VfnRXxD2jZot/PfulzrOrLrW7
sF32B/Ih/Q+Pnlpg8NVsPXdL2S03q09UYZWv/JjvsQ3qVtud8+o9mKIHJ+zo
P/LsepWQ52L01vtTdOGk1Iwprdbp8FM7ZmScCKqP4++p9/nJdbrFzQpNV14K
qg9HtH2/0GMb9IhW12IjH0xRWX9Xvzbm7HpdrMDWITvuT7kj57V/Km/hVHn+
1Q2BCfGvpcrzn2tbrenoKznCn/jvv9gIv/0uNuJSvy2He/7TXp/9uHPC1lZx
6pMrTZudW9JB13v701PFlsSpd3qlrqvddaV+//60Vad+SVarKg+52X7WdnWl
xKrUWUfmSTzDuoe+KHe2Z0BnvL3/0s0qX6gbjWMHFruYpLOq/7LydIWQfnbM
S8f+mvjRKh09JuPVklXvyNvXw852noG9M2QP6FCzxAerWycKf36kdf3S5bPn
qkqdZ722KJgo/OS5b+p98v6F7YLRh5V7qdimh0bNFn0Wz6sTeaTse80yhT+Y
YMaj7Hh02j8HZt7XOFutfaZkzDftpupUg7XF6r6v/1yaq3CqzE/KuxUfGvZa
qszPBysTXh9wYIvM782dzbd/3niLzC/naa/eGwtO+H6SDtutp0a+MELWK/Ll
tVlzP76v5nz1a8or81YWWSjj5fy1v1d5zO9l/V8Jm/Vzq5NBPeDdwSUb/pwo
/kB5G5WP/D72zvcVull22jeb9Dsf5lo7rFSKGnd4Q6W4jE16360ujx64g1fU
a/V7v7Ybpf14v7knx/bcKO3oH+ImDX+sZLE78tqFvq12ZuEHM0P4qxe/+ybu
iQ9nSHxQvuDYimXyBtWg45m7Yn7KVHZ8esm46YfGNtyhah0bWr/ezjmaemhD
l7apW/5O/2ffeD7vrpKrRD6W+iZFZ9VvWilZt6mxtlV6Zsi/c5F5nrbPUwPM
+4Qe5Auxz9fVzfOFv/zhXNuh08PilN3POsNg2d/n61bsVTPyQ/G/WWH2g7b7
QeSnzNwPHD/RM6A2mv2g7X5Q0d+8/cZj53aoTS+8PKfa5Fm6jcHaYpW/8Q/t
XiuRqZ/48qeblzLnK38+wEDa3gsNvyiXPVbWZ57PPxr/5IRQPO9LC8ddTB6w
Wo3c/2ijWx8G9bXhOqxV6mq1efqBdsFPg3qd+b2s519Her+X+M88pYLv/nFq
iwqO+ij99LGgrnYsQb2cf4tKmnLw0YevBR15JDYN/vJkwwFP3j49U41u80DJ
V5aH6uFs2njXX/52BPZop15mmqNvjdg01OufhjzTadf8JyYUD/kTLnrwaKV5
2TnqWrttrTe1itPF8+qeh7fnqKb1vlv44JI48b+y610tK/vz8pGrQ/5Pl8ds
jk87ni77nXxy9J8x/PQfJf9pL89f9luVl15b2kGef6vqwA4jH8LeEKv9+XRi
0oY1m5Bael66XtOxx97rjYIqsdOPNd5bOkXPv/rX/U1qzVQHek872fjvKbph
n0F9+kfPlPotD61/O23htPniTxt2sdyDWy7N163+02XvzYKLxd58bOOBLW3O
PifyXPQ6D4u87LcHBCLYf2DsFWDqU4P98vEd/t4nzwTS/PnvAmn+fJCh+xns
zwcZSPPnxwuk+fO93ZEPutdYPKp4yN/mWXOfSbw88aaMV+oPWYy+1M//LA/x
q1bfxfv8+QIDEegzwX5/nECEnD/29/i/ibxDPhaL/fkHAxHkJwP78xEGIjj/
ZPy+/ISxacjP9r6MQF7mfZxvYOLjwf58hLER2Avs89L8/kCxEeTfqZen19Te
9UP58+35LvmwuF8i8+Uu/VcwRxfe8uOyUfeOVDNeeW/hb8dz9JcD8x59svNg
xflhz0fNeDgvG28uenJ+do4u9trA44vv8CPdWsSvOLg9R3evPKbq9cVxkk97
aWT4C9+2T9b3bnmk2yuHQvl7djarla/B11uF/yh1oMPYmu+la3seqjqnG/Vu
9WK6tuehyp4/Z+G9a9eqmAnjR8z7Kqjzd3+s5rIRa1VY17ox53YExZ7S+/xH
p/vkHaMbzy207Eq3UD4C5sO2q4amXfIHLFq5se2Dg9K0fb7qdLrGvnZL07R9
vip3ds/ng8RfPTHigwOz92f+n/kd1Gne7LV39sOf0bp1QvloyXfw2aqzU8ff
COryG9qMvplvkUpct7Ls1cz5ekil5m2mP7BIdb/8SrGS2+fr0ub75T6IMN8v
90GrVZV2Nz6arXJNWPRZuXMTdaahh4w3r6GHjPfDIUuff69Qjk4r22jIl3EB
1dL8Xtvfq00JYc9UaLRO/ydu1vyfjwXVlWJvNtpdeb1+ctx9t4tcC6qyL5ec
NmzxBv3oWy//2bFoiqox7I93eg1dr9cvL1PvyO2gCjP0kPXY1tBD8M4jaUXe
WT5V9NWT5y5bc/9Xn4u971ODRV9a7sbL958bnK0/bR1VvH3kFBVmsLJYP2/u
S1kfV8x9KeuD8+OB0h91bFEpWbU0/Ibo+yW/6+/hK6efDUp9UPiLsHsD9yQV
CMULXqz6jToV+aHcR390fjX5Ss8FKmvmZ5eCLebrwZ/2eujLq9PU45Vvzvj0
w1B+J/t+HWx966N3FobyO+X5aNmFYatzhB/JX37VQ58PyVHtVvaL2/zKKJ3P
YG2x2n2i2pV+Z/83vrh6193jY1dO1BWr36jR92y2+Avhv125f8zu+JUTxZ79
yKk2kyafDYr9+ubYmpfXPJCiTpr7Tdn7Tc998WCT2sND8Y3FahdclL/iupD9
7YGdJ+veO0rdG7w8/818U/Sa7w8fWDhzlMxPumnXtl3NMO0yn/nGXvuwl8pR
u6ObzxtwYZzOa7D+f2VddzzV//eXtCVJKqm0pD4N0R6OlnykkrYWKm1pRyo7
okKSHdclLans5Fhxr5YGLe3t0/5IKuV3vV/jfT/f31/38Xyc+369x2uec57n
HIph5dBmvR3rU6As7X21u0UC2p99cKb/yRQ4cmr4xojRCcj4FwYVfw8+G8zs
B2eRri88/z1bb5g+y+b7mQ3xHRaFbOPznem/tuoZDr6K9ULP5crApiHbRH8K
jW9n+z3bj2uzL6WF1Evhv3xHd1Om//5zcuLZtsPjMadh/829M8V4sSyCeXzX
f/PFOuf9N1+sc154ty+K9fopPY+Z/W98Qt7/xD+Yhp9pXN+f0vOYGai17XnR
eWEhTsrNa+VjkQAvV0wf8NeU09C9y4opyQUSXg+Dnf+ZveTr2Mp/ahXnQ7Pr
hyW5DmL+LxlZr/n5ODLmc5cjA2U4dvPEzcbqYWAqfK80oP2DL/N11q5eXoAv
G/45/Eyhjy4h/Yu0f2Eh6V+k/cvrE7L5KyHzh89fVm+D9XezjOXzEnrt4uOn
81TtnWUv1+OAY2FDXRT7WdHcocs09Lfw+dTpw6dFw9+I9aTGk+v5eNx8OOye
j6QAJx7M3XmhQLF+GG+Pfpt2lPuPmH2807fY9z8iI0E6UcXiXKqM+3eY/5ju
v8DOJxHfP/cv+BIPz2Pba7asKOL8DHYeoHLcP8PiRuuKIn5+ZPw69dY/tiyX
H4P8n01uVn49D85r7j77PU2KaVkjHn54dYmv367QMm9i60t8/WbnRXZ/G3I+
5ff/b/5gd9P/+jPcTU+lPbtaYpAJqT4mT9UV+oT+vMO7/vFbgpEFb6aGRu8F
829dkvWazMVnNZFVzc+5QtarZ8GWZnPxbZF0ROZ9V7i1Q0vXZps5Bo4zsIoM
3AK9Jkl8jl+eiUnVoTbJY3eAdfnsmUnTrFC1ZacviR+2gcp8oX2g7aNBrdA+
0PYx/LXQPtD2McRFaB9o+/h8stA+0PZR85bQPtD2scKr59gLJVnY3/9o12Md
EqHa7d/rzbRzsK2BWvfDuomwbazr53MvndGu2XbPX8X7YNWH25kaWc7Ya283
p1uJ+3i9hpRNbkd65CnGd1W77npepVxf6P6w89slLqVcX4i20znTU6eY7+/s
fMbOh28LUk8Z4EGg8wcfjNBY2dAkkNcvHfE4eV2soZhP6Cr5P59veeT/vL7y
f/1Lzvy8z84f+jr9jEdo2fHzV9Xdft/sg+VA3xetWn/QKA2RA31f7o/eu7Jj
ue/9EEwi453z+Yj/O42vxwtOD9DTO5bPx2cEdFxRq+/C1zs31+vpzS+H83yA
KTQPbu2syGSdjRJkfIOl/WJq8s0lWDtznbphz5Ocz/s260r/kAamH25FNSev
0NB2Iv+ve4rVmYVrg1EnwKRj8PyjwOpxsfP0f/mF7nmpbRrzzbRn/rn/4Qu6
m6b+Ht4oZ3xCMGozqdjLcRSPF06fo33p+X1DHh+X2kKQ8/jk9OmCnMcb+E/O
K19sH4aygFlG0d0iwby6rcZYb7Fecfgb2y3tVMugQCVsrotiPG/2vlvyUqMM
QtRy6wbFrcFFXS3t1TTE+uFVZD1Hup4Dszerdz/o/PpNBH5zMuiT6VDKz1/M
3v0rYt6Erorxf/3K4tEHj4n1wRk/k+kLOivb3pmhL/KTWL78pa/7665Q6Be5
ZD1C2t/A6u1kDT43L/xqHHiqnh1ooSnh/ruhxh2XG0tjuT9S3SvtzLZHcj7f
t/YNae33UQ462a1fv0p1RfMRs4zUFFjPT9ssTDHfbXTMtgTsu8jPo6PKl5+L
PpvLz6N6ZXU2BhMSOV+O8T26J591PxYWD+XGLVe0/Sn6QzaPvXC267QMbj+J
uDH8+qK1F/n64F25fEyrbuL6wPyXbjpFm1QGRUByoNu1009CKP81nPNz9INT
mo3qJoUfmv2earrlwbswO2mCQl/p5lc6d8mpPIjYpH3oi0JfeU3WD6DrB7r+
9dxwkUspjPPWv+ChOI+9kqqWF0vcgZ7fUWX7Rr9TRV78/C8ncn6+f7lNkPPz
PbPXZFw+E147zgsK86KnBhY4cn7o9fmfumGdHB6mqC3ep1gvzZL69hhdL4fr
k46/KVGsl5YltgdXLRDrt89xm7lxbt9gzicYZ/JKp1uDWL+d1Vtc2iZqflLU
UXAYatTHWMkfVNYuaK+P0nxMe5ZkWD/hAqimjW11ZYkUJY97jHXDC5BWeNzk
751SzJtU6u+v5M8q/lybf1Jp/qqesG6/Vcm+9VPoX9GfMWbYxps1A8N4PsTV
WotHLtAugyGPFy3JfGKHZV2PreutWQbrR5667f9pFY+vo98Lc0ccmO1xSawX
3/lC9Glzl+4QeO/J31U97DAuppGvqwV2k14MSjVciEZ/Lw5bouQ/GZ9wUS1O
aT1x6vfYcuVP0X7WOVFoD2l7EHdIaA9pe5D7c8aTS2OPYMD7eoum3hHA+Hxe
m6FUrZsEVcf2HtRt2nhwzjjzqPXRjbg0cOyCF2Fj4NfFrVXlOk6456/1X4uS
RoDfkxq1D6Xr8NTZxnwl+hDuONZ5m+L92y/P050Q1A/qEvJis9RXoOdIoT2k
7cFjP6E9pO3Bn35Ce0jbg1PJQntI24P2i4X2kLYHz38P6/J7QyE/v3trjTty
pKWYr+Em2R/4+dj702mn5nAZ4jvUt6pdG4d5Nx4s2u9WzPWtOctWOCYZyXl9
eZb/yibjk/5jvYNYpxHV94SRnPO53p+ot22mk49p+Z8naPpKwdh+0c6MHlvA
4kb+7ysKfcttgotB6optYBFoY7Ti9H58pWE3N3LGZu5fHHV1Q5PAM2E8Hy6L
x9piZ168ZWIk+J5Zd69hQyHqSZdbH1GcXxn/1zd7te/lJxKU2e6WnBtdilQ/
BCO1EsMdZmL8gwOpZ459CtLC+j85AtENS2arNUsD+rx49X58J1OTNIjN9xv7
/KBUrB9Ylfsx+k4C5D/I/bPRq4Dz+cOs3sl617vx92fxqvT7gPuLj+cjkpyQ
1edh+93kcf2/l+7aB53a2u0obr0Fw3Yc233bxB+uk/b492bnC/a9KwIfzcC+
4dh64e2mvg2K83AXp/YjEmWY5Tph1qT5h6HYpOXKmSdk2MZPNcd+/GG4tz9/
aN2hONTxHNA/4W4sj/dg+imvf0L182GlB+oyDy3g+VKZvpP+VLp0k9Uu0JYJ
cs43ZPoRlfN6eq2K7hmkd06EQwts85p5HODxGkz/ot8ftxA57x/GZ2f9M+Dj
k24fYuS83gPj89Lvh0nk/YG+P5aQ9wf6/hhO+pePRxnpX6T9y+uJ0PEDzq3T
7NNGl0Ln4fGVe9dEYvnbn/PVHBOQzg8wPJijvfqNnL8/4/ux92f5Lpi+b3Ni
ddK7jUloFj9T88S8eM7/Zt9H5fiUwFGHDmPoCxsfg4hwWLbm+0/tm57c/sDO
T9S+gJOInNsfGF+b2R/K15w9MVGyGnWWmryzsvUG90NnDKt+OOLXGaGT1pz0
ony4C+D5Redh041S1Hyv5vonXbH/k//jzn9basflyoH+HzNeXCg3yQyl8z4C
jmy39rjwIBlOjGvec+DPeJ6vn51vOhH7BY+vH3jM5tP8diKfeWnbF6dM7zF7
lTvufBpnV7ExlvujXu0Z+yHc8AK3hywj5y/eXsMnz+ifISWc38T4/NWDP9ta
XIiBb2tf+G8wZvbqOM7PZ+ejaKI/8/N/oPP0/uuWFwD13+J7Uu8c54WpmF/2
SIDaJatP6r5cD9Rei5ZjZ8zpOmktVGf7n/ul4oMsPs56p+nW+TqJWCjsZ9lg
NX10XFfdREwT+Ls5HNu/3bQ4cVsOrBrypU8bBU7SeN5nZs8Y/N2hTVdVsxiQ
tfgy60dYJGL+anOXPtEw+NDnTodUonj8tW2/jMgOhnLwzfEqPbn5EIYdaXMq
or8cwhfukJnYHkI99fN6B2viub+N2dOZ/eT89tH7WrZK5v6zpytd7QMV+N/q
jTVal+M5n5qdv9526q3l7BKCc/dMGBrz4yj0km2zGTQ+BLVbFCzpUHkUZHlf
71f1d+D5r1n8BNOf5d4mrteqSng8d+d3e122hV7m51PG52XnxdwbBzbNmiFD
zXbWOprzjoC93Xfpm92+XP+ZQjDX/80qFGpqkVh/wCm9UttKX+THVwy/maXR
LQdCuxs3HFR879ujls1csC4HYPGjR70V2JnUA4cbzTr7n1RN4PWZmT99U9O/
RzWZLMbzMD4J8z8P2fHh03hZMT//Mv4uGw/bzx6KDbqRA+XOt27v65yIAxxU
ZnrpXISrbY9XnVDIqwcnWNmvvQiSoDVjEjokonbAgL3lAy7CnecVbZop5O72
xzWLFPPn+OstUzvvDAIzzenr++gU8/6yIudFrr/eOvZoqH1CINDvhxkE8+/5
xy/254YWe8XvMy3VdLfGHqTjCRZ5qw67+Gg30vHE7W1q7ZOfjFTMr7JBoxf8
dIjhfMIHPQdOrX8UwfuX8VfT/n7v+bw6SqzPebF5y3OK9/cMv1c6tIk9auq8
3h761R3K0y10VMAeM/p0j93V3gNYvL5P2Ne4gIAI2ErsQ0DtQ/jSXNrK9qUz
uL4Z1OIfhf68+vmJWMcsZxhnX/G1QKE/x3fztVbRFvs7QbcuO+NyNu/vLhNn
b/949gRcXaJtrjlYggWj7x6xaX0STvaO6uc8ScLzNbDrA/uk5Z4pyeL94yAb
uN+0eTbvn88zt6bBoggsHRCxbMDhKMjITJcN+hqOFYu+t0m2j+Lxijt7Rtvu
eH+YxydSDIeGtuqpej8K/7SJdV17IRr89cIPhF1xwAi3Mb4zb3jA7pveP9Mz
8vHqSmfbb2ZSWLOsYlVIfj7OePLEeOI4KedXDz4w4fVEEyk0ZPn307gi5ndk
+eGYfdC9p6rD/G0+ULDmYolngkKPIhgphtdNR4z7OmMz56/vse6cM65FEdd3
v3ZQnTnun1Ku7w/MKais+reU6yczm954lnCvVNRPhHxUpVw/IfEkhUjnG+iN
uvXOZkYhr+elXdvuUfnVArzbao+fx/EEeFgw+8CZggI0vGT3xiMlAUoIfx/p
eRwYn7/1ug3JKorz+X/j5dxNqwQ+p8jvtDuq3cNISb5ny4TSUCV73H/j6dxN
5wn6lMgPShP0KVH+ufTdjRlK9rtq3ZzwQUpye5PEW0ffbML30TVjYrb68fz/
E5dcGmCVKsXHpSpV1vMRXnd9BFanpahlEmpTq4HQctIkl2+ZUlR71H72xi4I
SRahQ2dlSP8nvs85b73wfO4cPxaeT5TryhqfT7RPaXdtfD5R/le4Vrtr145g
bZ7qvU43I/4nXtA5z1vQr0Q+QrCgX4lyHcNG/Uq0j9eQ8QF0fOBgMj5ovpij
OIuMD5pP5ijNV1YKdHygI+HLcPsIqw9C9X9cUmHQyH+j9nmj/4m/d877b3y/
s+mSub0b/0/t80b/E+8YlLdWGA8iZnwDhmUvZz4co4QNSP1cjnFt7+tflTA7
TzO8sf2EgTuVMPMHM/xy8tISRyXM8n0zPK7zhm39lfB/8y8rnv/Oyb53lDDL
R8tw4fHsO2FKWJXY7zgfwpnYu5Dau8Dy2ZYXUXdOQW6HPU8+n5CgxotZ1Yu2
F2Fr3aoAiZ0ErpP6Pkjth9D8mWPQQT0Z1qwJ1fmxLAzOJAfN/RHC/OdB1K5e
CI8ODu5X4JGAz4X4miwwfR909IlGIu6zr1GfPS0L+hY9SElpm0jtYZkwxm3y
rKimibi5pvLPhJuZsC919fH3zRJxzugOVWOnnIHW21Xtz3yT4AJyHuL7Vyg5
D/H9a8fkybFnNFNg8NPLD9t0S8AN0d7a/ieyIGxBO+21WonYf8ThLXe3ZMGF
02Xlle0ScfLWmbprPTLhQ/a8zc8aFOulbjtJ6/2ZYPMr5liISiJmEPsTjQ8O
Rz9h/RD5IM1jTvylpjSeHIn9A6n9A2TE/oHU/gEa5PwP9PyPBU3Cc5rr5MOm
4oWztBT66Gtif+X58De3MHhUUCfn9vyXcxc/Hlsv5/b8pV6TzaYGuvPzwkBi
n+Xz0YHYk/h8tCT2JD4fWbwom4/biD+Ev0/JX1GdlirZlybObep2TUnex6Xy
9mql75E802njDyW5O9lPuD/MMafrKvmofKT2J57vlK2Puc6B3zv2Sodi89N+
3xXroY6B2zZJp3RYbvXbbLZiPTRuJjNssVRO8ykEoBHB9Dwi1juh7cEDst4i
XW8h7XlZ+x8aiLR9sB308PD6Loi0/f/JtxBkqkfej+M48n4c/zc/R1Ae+57M
PsbOAwyXEv49Uv49hBF7NFJ79P/k7xDjAxgmv+L6sM7kuvzKdRmcWlRgqfV3
CFrP0plSpcDzItb3P24RgqzeC/seIQHzBuXdT+PfY6l+UUbnXulI9x9Yv31K
xrFO6Uj3H/hvvkJ3U+afY9hMiJcQ99tcYf0U5bEte5tUKvFnej3Jue6oJGfn
R75fW8ufqyvxcV8a2O+JUZKrNj1ooJottuc+sHb/JiX5GnK+5+cNlt/D22f5
7dRWiWgy10Xvn1iEvz7hDa04KbJ43EUPN3eYbiPlfHPG5+xOzis8n+bxoK1u
bax38PGW7GO5fLn1Dj4eWb4t9jwllsMqRym9z8St0WOSleR9wjeGTFLybyc5
tRh8R0muP+Nm74cL5OBn3fnzhCGB2J1gpBiSCF+exw9ULP7+dmztDpgTmPza
QfH/WyR/BN8vZ3RqN6rfm8emIQm78nVXmPH9dcc41yfRvkaoPcf3bDMlf/cC
zf2dO/4S99cZIxvtVI/z6PXA9lt6PViS+CSk/iXIrQjyGB9URPNvSGCgbdu1
5vZbcceV6Z7D2+7n+VeTNDIzd9r4wzHdVWtS/E7y/SeJ1qVj+08G8V/x9j8T
/xVvn9nH2fer1awfv2PYZJ7/6WBocPeRYRMwxGPOBRvF/MtbULf3z6KJaJQv
MbFP2QRGk2actAgzx5B2sf65EVsgQ0u4nue3nREmXA/0etxjK1wP9Hr8PFm4
Huj1+PrAfOeFnYOg2Kt58hrvMNQPsJp8CA8B3T/xHpEjlYMakfP99aNN4376
1ZTFe5b1a5Wg26HB9I/+l22nrKwV8zg549JShXx3/cqWny2Q8RneHr05ZPdh
M6zxb8xf+MX0oGXW4ideFvhRV2gvj8WDln1q2dheHm0PXr9ojM9VyEl7wPgO
tD2omSW0l0fbA9VtSxa9zZHReEvFenMpev4yZzGfXwap54cdl08xTo+QQgwZ
n0jHJ5S4Pty7uvYk5Ki/fbHGRYIhU50Grpx8iscPJZH80fDkvZ5rpqcEqz3b
1YennuT1pTJIPSp4piHp2WWRBJl9iK3PTF9imPF1GGb+K4Y1yfkH6PhD2c5B
WhG9paA7rbNP1vE4XPwxK+X8KQnoSn1W/xwYh8+fV5SlFx8DM9vAuD42sWiH
UVGnzeIhdpt0UbntMcwg9h6g9h6sJPYeoPYeHh/P7s/tzxQzPhHDbPwzzPy5
bD9g6x3DrqQ9jpl/kWGWL5O1x/gqDJP8zCKflPFDGGb2TYaZPZhhxh/i78fq
OVPM4q/Z8zD/KMPMvsT+z+x7DLP1hmFmX2KY+UsZZnxJfj5h+ZIp5vYL5k+j
9dQZtiXfQzyPUz4Uw4w/zZ+P8Bk4ZvZihpl9nuFeRN/gmPG3Gd4j8OlEPizL
38C/N9Wf2HmDxTuw52P8CoZZPQyGGV+ftcfiTbl+QvlaDHuS5+GY1TtimOXT
YpjxAxlm9my2XrP4Gf68A67en+4ixttbEcz5RSw/Nbue1Qtk+x3Ld8cwq7fJ
vg+rZ88wiw9n+93ICz+K0w2LsKV8d8rSRAmsPHc9wK53EVJ9CYZHfxrw/Fcp
OtSqr05udhR2lEf179NExutnmAv+i2xoOnybnkeXRGz1wGDJErdonKyr6qP6
MxouPnJeoD1JrO+WT/Q3cTwTfZDjdUS/5Dif6Kscs/ixuOzAAoPFYn3WjQvX
l+pulOBVwkfg8Sms/iTzty8i8U3cPv7P0lpd4+xz0EVn6dOf9QkoJ/oe6x+e
by14uUtl6JE4rK1X6berXMLzvwUV+wzBz8d4fRSW//GB/FdP1WnHeL3XBcuq
el2IkKKe06ijNhPlEPhPwKX+eQdQktPjTIGlHHy7OaTG/3UAdYkcqRziiByp
nNeDZfonqwdL24f4LatSYkpc+fVHnu/+kpPlwq+/T+T8/teInN/f4lZrs5iD
2TCgpf/y1Yr+ZPG5lL8DKmQ/pPXqQsB6iuPgEwPF+rEs31P2pK8tMyuieT2V
8JxY/KIfg+paY7u7qETxentah2cbfegp1pNl9WX7vP6Z8iUyEkqvfNlnnL0c
4yec6/dinFhflvILUXtmVovtZ8J4vdlh6fmSW2livVk2H2h7uHDB4fYrj6ZC
/J+JtruOJ+DDgKOVLd+ngty3euHZggSeT+9yj7Zdgq7GYdiXl8scV0t5vZ0F
Pj+MjTUlPN8fy+fpZXl2T2HPONRttWzebD8Z56/qEcz5rutJvhGICHfvM66b
FJ2PV8xp55gAhuoD/vmyNg6tiD0AqT0AmL76td+ET1vkx/B6P+2x/86L5/Wk
GD+J2rPxAbFn83w2b4k9m+fnY+sBtWdj0kD3eUulsbQeZQyyfODPbx/1HGEW
izlL5tn+szEWJt981HJcWQzmlQV2iaiJhyYtNfYefngMp159NezDoThoGXzd
8dTdWOwM45ucHSHmO2HxBbO+XZu/3jwKHv+s/nl/bDivd1lL/DFA/TFoRPwx
QP0xmPfd66ze5f9fD5jG92KWc8rJ3UrxLwscQ2/GK60vxs/sp2kqxcPcqpy6
eZjSerMoYcC9KUrxMTEHa/seVFp/JIJ+J8bLGAj6nbgelTnbdtp1Vo7Ufwbu
+5amrQiWI7Xng9Q2Y2ZxiBypPR9W3N79cfMjOa78vcM0PXovbCZ8JaR8JZhM
+EpI+Uowwl/wb3D+1M/aQjefO3KsNRn8VfrVHbaXrFx3y/CsWA941AJn/x35
SPkwEPTFcpX5l3TwG7nm24UKKaq0/SA3WpcOlqsXBWgWSTF/vtPPd0lpsNhv
QLOMBCl+ftjD6eL9NJD0MJ8547QUn9urS2SQh/R6cDZfC48v5yG9HpJVw+dN
U4qPtqjbvXuj0nnPeoj/cT+l/kkdneC+QkneZ8u074+U4qmLVw/truol4qvH
xll0Veq/gSfn9fyudH4cX/p7yDOl+Os95+W7+yudJw/oP725SKl/rYZre3dQ
kq8Q9HExXvutoI+L58/mgj4u9r+3oI+L8vXkevF8R67nWINcz/F+cj3HE8jz
i+cN8vwcB5Pn59iaPD/HBuT7cVxCvp943iHfj+PB5PtxfJL0H8eWpP84tiH9
x/F50n/i+xisS3mtlL9hgN6sitZK523j2YsbeivFb4Us2X6vwU7EEws2z56n
NH4kVwIHGiudzyNDPVS7KF0/Zv+q/uOV5GpHu890UcoXIQ1U2x6jdJ4/XdQu
LkMpXkz9en+XECV57lCDmrdK409vnNm1YqXzv3az4QmnlK5P+6lbdkNJ3qAh
fdJJKT/FhJ8bB9kp6QvWq309QpTi09rtzjGxVJJvnHyh/3el8Tto4ZuHKUr6
BYkXEv9P4oVE+bdPrXuOV8qH4STwrkR9JDDkgc9GpXi4lrkTqx8r6Stlgv1G
HP/mgv1G1F8MBfuNeP1JwX4jygNJ/4vnbdL/HA8j/c9xKOl/8XxM+p9jKel/
jqNJ/4vnc9L/HMtI/hH+PKuJ/4Bj5zYZMz8oxfuVdyw3lCvJ97hcTeihlE/h
sddrt19fRFxp9dDmudL12ycWuDRX0s9i5/6Y5q00/v4s69DXTklfqzVs+ctc
Kb4wrPvHnuuU5K9zviRpK93fN/XutVFK+t3BN8+/z1K6/uOX+vJBSvKnJL8L
xw7E/8OxJ7Hni88XLdjzOf5Bxg//nlvJ+BH7i4wfjjXJ+OG4nIwfUZ8h40dc
b8j4EdcPMn44btpOmD8cTyHzh+M5ZP5w3IHMH463kPnD8VAyfzjuReYPx8vJ
/OG4OVk/OE4i6wfHKWT9ENdzsn5wnEfWD467k/WDYx2yfnCcQdYPjieS/Dq8
P54T/xnHd77fetqgFE9q6eslX6Qk//d2g98KpXwf596ajNVT0sclrt3evFO6
/sXKd8OMleRDAxfeH6S0fn2KOxDwSkl/f2q8Y+QFpfjVnt0n+fxSkhfMszw0
Q+n+TSfqPApT0ve1UgcOlStdf7PY7oW7ktyV5B/i+CLxP3J85d7oXn2V4mX9
P2y4U6Ukf5fmWOavlN8kWR7pNkHJnhCxyNuwndL1D8ytt89XkvfbkK87W2n9
fOVRc7W1kv2hssPjnfeU4nM7NZwo0VeSZ448V75F6f4/eu3unqtkr2gZfHjz
R6XrSxNL+yQpyRk/h8934Vfs3w7EPyJ+T5ovguFqwgeg48k9z4nwATgOJHwA
jlsK/jxRXib4v8R8L+aC/0v07/iNinF+psSf9gzYMDpfyd/zgXx/Pp5Pk+/P
cQz5/hw/Jt+f4+9k/HKcTsavOB/J+OX4DRm/HLuT9Zvjp2T95vgeWb853knW
b3F9eDXl1Bel84vnp2Xe15TsQ65Zc2zTVotYN2WMxz0leRxZ/3l7KnbC+s9x
HVn/OQ4n6z/Hb8n6z7EfWf85DiLrP8efyfrPsSfhQ9PncYa/yHjm8ndkPHP8
gIxnjruS8czxRTKeOf5NxjPH6mQ8c3yFjGeOh5P1hON/yXrC8UuynnDcl6wn
HF8m6wnHLch6Iq6nZD3huIKsJxwz/ZBhlr+EYVY/m/eXtcB3Asp3whLCdwLK
d8KnRJ/i8QWriX+XxxcEEv2K60f16oJ+xfWjcQFr+l+7LkPjOZ/+0vg7BHqd
OCd9pMA34kwtTlmEgITEJ9D+czdNJvEJHL9OFuITOH76S/+BjZK8kMQrcJx+
L/lb2Q7Rn9mHjG/+vt5kfHPsRsY3x3pkfIvzh9U7YvPRskrjiIsMO4UtVP+0
LBSSCQaKMZXEY3D9M5bEY3B/+IjPL7q1vR8FPmpXFzleiEZWb53ZQ1i+kOgX
3zq0GO+FcRWfXaryHXn8xNKCF48+bEwF46Ges99FKvRdwr/ifEeWn49eD3av
i7S8L8l5vMqME5/thrrLgfLTcc6hlMIVG+Tg4NQ6ffbp/aj1Br/s2iYH79wT
kwe13Y82RI5UDppEjlQOg798W9zvkz9//3+F81Qc//5rhfOUaL/1E85Toj9U
TThPifL9ryb3zreRg16W+8zcmED0IxgphljhejHeV1e4XrQHXxXG0zaObwnj
SbQPawrxLmJ8cOv6xvEkynVMGseTyI9qdb9xPIn+VWYvf9XjSkWuuQQ7G9gW
jgkS6zv36lxfHZxbyuOZ7hxLK7o3sZTHPwy7r/Mm4HQRUr4iWDwc/uTrkSKk
fEWwyb1zrmnVBqxLHVjfbJkvrO/zs+eVSWux/O7NgepNfMBVa9esd9lrcXD8
vCvyIT68ntLNlt6S4C+R8F7fOdLY6CitzxoJ+QMufnzRUMLjBS+T+BfOt8sl
+x///qPI/sfx6llVW4/sssHfh+MGoboL+K012ppkNws1bFWKQyx3wp+6Jyv8
v1iitbV9lpHjNrCwEf4P9P+4ep3wf6D/x7yfwv+B/h/tygpk7TaV8vicpZZR
Q6ZAEdB8gziD8A/4fnuV8A84Pk34BxwbEf4Bx86Eb8DxV8I34FiL8A04Pkj4
BhwzeyvD2oQ/x/Yb056EP8fxCCE+SfSvH8puN/KzqyjXc9cpsfSXA+UPYi7N
W8bGt+3FH9XJfiehtNuUKKmdBC1uFv8TulHG8xWxeh+tqifnNjiFgvutrrWT
Dq3k+WhZfr7lZe/9AmMTeP1tNp+WOhiUedgE8XrN1gTzfJ7bnxg4mRTIYMym
A698E0Jw2/DsvKhcGZi/3xF4qCAEw2YcH9QzJA3ffjV8oh0nhUq11IcfYpFj
dXn2kaCnBXx9qt6StCByrQymw/EB9zNC0ZK8D8/f1J28D9D3QZV9Y3f611zm
8S3qblk9l8eUYMi3ft2XXogGTxLfxOM3HPa273rArZjHYxiT+CAen0LmoYzH
p3B/KYn/wUIS/8Prfziodujt1a0QC++Hv3bdnABl6WOXftMtxHqVYW9Gbk2A
zyT+h8evsHwDLH6F1e/aGlqVPtpCCsZN7pt0Gr6Px7NMXDbyp8e/vjyeRYfI
ebyPAZHzeB/GNwmQT/z9Qz8GHI+N73yiJBppfnb41P3J1KRQB2yx/sKWJeke
4HQx5YPjxWw4+Zdfx1a6iYrnm267KzIbHtrbV0R0SUTm72XxMaPaHcpX/1lI
/RkSSC7YdKXPv6X41PZV8hOjoxAdrtttcWghUr4dr5c4v6LXi145CaBfd+/4
y+wCXl9IO3C+9MGzIqTxJKBDMI8v0bn9pcFf5szrJ7L6HnfaTSkKuSjBlqN9
tC5UnQJabx5tHt74ld9PrPfYh9Qbxy2HLHNu2YTBCtJfQPsLr5L+AtpfyPy5
LJ5sDHlfnj9ai9R3Rho/A74jz7wcvE4O3X922tnh7n70JhgpBrUDdssC7sko
DzKE12cZ3b/7ojUWIahK5LyeIav/SOWwifAX+fc0Mb/e0OHUNt7+OoL5/Rn/
NXCyaoc9c7fwfP8Uo9/r3AOr1Q/xepHMP0q/D64ncv79WD089v2s53obzrgg
AzOVI3PP/Q5BN9v2rqOnpeGk2/Y+cw9LYY+e56CtG9Lw737pY0MjpHCnfMne
T/+chJryL07aOyS4J7aVdnnXk/AkeNUVv6kSvFfTa0tcUimPf2L+45N5W7cE
KubXvzGP2gwZcI7PN1fCbwTKb0R3cn+g90dPcn+g90ejD8V9VpjJqb/mAA4m
mMZzHIBFMQ6+7d+f5eMh/QZGWNSe5ePha92UQxWvkL/f5xEVDyOLkL/fp6C7
9evUdvH2+gULmN9vBvleSL8XfJy57md5h1L0skvstb8hEm7N+9Dm3rUjsDvT
KLvDzQi0vK5qk9Y3HKgcr98Zo6LqK+P5vcsJ5vV2t7/fvA6rz4HZwj7vbVtL
8Z/XaaMQwzGtuP30uL+jwJDEz/H4Q1ZPgsUfGpB4Nh7vN4bEs/F4v7pzuPRb
iRxZvmtWL/1CxhL/f8ukaPO4i4PZoTykmNc/Z/FluuT/XG5B4s/4/HE3+Xq9
X+8C/vxma4X4NR6P9pnEr/F4tFiyvnA+rwaJX+PxbttJ/BqPd2P1wimfDKUz
2k5dYOjPv9/jP4O8ri4tRfr9IW/UkeWhz9fReEQfXm+pvmiXbLCLD7js3vPB
7sBRnH9zVb8baZFwgMTD8fXrvWOzjbf6zKX+WVcozrlT2HnMDPr9t8PVVYKc
1yP2zhXkvP7wxEFHWsd7lPJ4u+5dTw+bFCLWX70j7NtFSNc/2Lqodb5tT8WA
JOsfvLm0pO+PmlK81HLq4qf9jkLP+j7606wU6//pUYPsXkWDLqkfiduuzrTK
V/WEuQseRuyJccQbL8tlrb28IMTxT2W3zFBePyGF5Ofj8fLM3kL5BFC9aP/f
xxvSMTAy9H3wXSkw+4vMxKTv1UopVPWyLv5oW4TbNWf9u85FQv1uRRj92cc/
21MCVaPyojp1Fesz/cqMm+fWUcb5b1P959rv0Jah84+7J+L8w2DiCZXzWr5i
fQVWT8Dijsbh5YZS0Bum3//Ss3xM2LdgWMeBUtgITjW6d/Nxovr1LXOGSkEl
/Pb2fiOjsEed5+iJ66N5vYMpGv2a/PBTnBeCTXetPhKFtN4c5PttsE2+XML5
WY6kvjh8elu/+sQzKW4n9cShXH+fp2+NFGcMKJp0wOoS3FCrcU7/IsX6zKN/
r9p4Cbz9b2b0+ijFUFLvnPPfP31xqL/46iLnv3uTeudQsHWz8dGmiVimU3+3
rmEWz+93spOAef5aE8lKrxWbViIsN7hS1MQLGB8o62z5cO87CfCG8DWQ8jXg
LvHfI/Xfw2JhvzsPH6JS7oy3kOJ1lU5z44rOg6ZDi2n/mklx8uQXde/PnoeQ
h9t7m42T4tvBywpfmJ2HxV23/b6lL8U8Eq/H4800Bb5dBv8+JRNnTjpkmwEZ
j2pcLj2X4myzzg/sjirw4i5N4t9JUSWikX+Wyb+fZ2xlxOnhi1m9ILg1tkr9
0PRF6JoZdsty1R6ouXPZKE19IZ4q7dfRt+dumN6t+MjISxc5f7/vgWYfsqvP
YbZdbetlraW8XgnVl2FP35JfpVUl3L/P6g0y/z6rJ8fOl18XqBt+uBkAAZd6
7+ze9gjPZ6nmeEvN84Pi/Nkp6HuVeQCNTw3FtlZCPB2PzzxM4ul4fKb7EqOj
QX9y4bPH73Z9f0jR4aBr+fMbclZfADd/uV82/5pivdoQZjH1hgc+39Bq4NMw
GdyXqj7vmnoYBxgNsEyLEustR85etOOrRHE+1vi3dPHKwziOxENyPoE6OV/y
/jXXckvoWJfP+28UCvGb/P5fSXwe0Pg8NMsQ4vOAxufhGXv3zo/C8tFw4thu
xTOlUJF1VFtaG4axg25k7loTCbO7b76KWWEYtu716aGWkfCUPD/S5wdD8vw8
/1w4eX6kzw/+Q24OkZzNBaOMDw5PGhTzyb99cpPjuaDR0PxsqEoisvib4WtP
bu+aJ8XqI+OaNh2RzusVMn4dlYPvJd3m6r/yeL0Rxqdj8tfkei7XJXwMHk+6
4mHSgVGlhTze5OYud+N9t3JhmptW5e96KaZqtizZW3mJj+/eHWBISsQlPr5V
l7m3vrYsl8evMP4b459bEfsKj/8vI/kngOq3eGV5p9Wzd+fj3A7GNeMXSUGL
2E+4PenMABPzf+u3o9HaIj2nYwFwZvrQuitO26n+HgB/BPtKELdH7BHsK6L9
g9ULZ3iU4H8S7SW5gv9JlI8g9ggeP2lJ7BE8fvLlqnZxS7aWcH4ri0difBsV
b+low/Vi/agc81WeC+WlPL447fPiB8/KS3l8sQP5/pzfc8lDNezr2AJ80br3
+RrFembZ0TPYaVIBDjvi/eluXQJ0IPGd3F5ykcR3cntJ7TeDzXuMM/n8s5nf
c9iyw0txsYtNf21td1i7LU5Ht86Cx9sM2CFgnv8okuizQPVXvCfsxxeAxgtg
4t3Kyn1LM/n4YPzBmiuXNk9OdYfFpD4M+GrV6W18fxjnne3++N8gGa+/xurH
UDnMIXJef60PsRfx+KOthK/H4+PmTQ285HlHzufvU18b74Dbcj5/txJ9Ham+
DluIvo5UX4d5D1rmvH28H+6MrGhTodC/HQIcQmw1A8B9xZfMYFkorx/J7AmF
7Z22frziwNcr3/snLEavXMHqo+DOqS/tdmaVcP5aWlDH7t9CxPqu+9f1zDu0
u4Tz3T56Nmw971mAd3r0UCtsrJdJ9huk6xUwPml10Mlvk02kKBva9tenyPO8
nqJh/9DLHi8z+P7rGoV4vCCD7782/fVtMzPy+f4W3mJMy+D8fL6/sfg71v4d
zb772l3J5+3PUfU/9rVEzt+P1XMe1P/ZKxwTDdNf3rZ/tmIFPy/7G+WsHHoz
HyXTd/UYM0wKuWS8c/5WBhnvnL+lIj8+xX59EVI+O5D+zYTT0+ZdGapY/1qq
VAwbfSITdixOSalXTcR/BHueyJeZJPBjkrn9yVvgx4j4sMCPOc6xjcCPEeVs
P+b+KYHvksnlVgLfRcRzBL5LBsdpAt9FlDN7NfenBIW37sD5Ne55JwPadO/L
5e55g/u1vzD0toiXDow91kNJzsYLa89O/9Uad863cc8z6rpgd8huEadlLNE6
NkvELy9W/wlUktte2BKyqm0+rC7+qmHvr+jfvudPW/6U8/P6U4uikSXf5Nx+
mSs3/3Xkt5zbL4kdrQimd+r0POyiBNXbHOmTaVgEtB4Khi40GbisdxGoaHYs
/3hCgieFOP100Oi8Odk6U4rWs3wW3vydBt9vfXMadl6Ka2ieevZ8BYJ/6TBf
f1V7N/qXQjhuL/iXgjkuF/xLopydZ1h72wX7ppiP+6dg39zPcWfBvunHcahg
3xTlE0j8Mbf3WpP4Y26vTCLxxxw/F+Kjd3FcJcRHi3LmX6L1XvAIqRfL7+cq
tM/s73Z5P4X2nTgeIcQ3r+PYSIhvFuWsvhnfzwR77Fwulwv2WGuOfYV45ikc
j8xptMeKcvPqtvohwUXY6+Cfi75TJaB+oOnHdW5FSONNYBGtU8C+zwXSf/x9
awT/YAjHTUn/cVxI+o9jv68NNyZBEdJ6OzBhuOqpURoybn9tduDMoq4K/chz
+rLl2wPC4EGA4ejVIy4APS+gGtF/eTyVVrFGZ58+Rbh/5sOw78kS6Nzqc5uF
Q4vw7bSt7T7FSOCc6fCDvdRkqD/VcZNbVRjPJ25++uXyBUVhUJ893yK9hQyX
R83PdikLg1Jbo6Sef0px1IXTD9x+hkHQ4HfdGvMyk+fX/596sc5559c/eDa3
bjj/npHXfBr1L1P5vMVHe27Xx//Wm7Uzjby2o1FO4xz1wXiNcP3/k9PreT1g
+n7Y7EHpH3M8BZSvj96eH59nR58C+r7I6vnS+QvBZs/s4++cQjpf4cxfEePy
+sm4vWyY/xWjA3oy2OVQ+L1mWRjmPN7n3/z9WRz3bG2zvZsTgMR7pCLlm4Nn
fO2tAQ0FOPDJq4MvfBMgRa0x/2EB6v062dUmKAFmCHp2Nky8/rRjfKdEnOFS
veCfydnQ36Qm/Z4C93H6fS9yw2UeX7R37T85q1eI9dT3H7OIsptTTM/v8bz+
+on0rT9SHePxeXbxksWyyzz+iNVfZ3z7tL8+PV0ZU8L9i5JOkBGWnAibWju/
O9AtHlk8K8uvq7X88c6zvZN4vewZlxccvDvmOIwunqy79mA85hkGJkZpHufP
05rWwWXP83XJ77q83zJaXzsIRzxcOn1XrQxOpezc+80kGN1e7+w48bMMmna8
ZVBhF4yrLD58dw0V68VLNCeNe7jtMuePs3h4xveWHXudXlZ4mfO9Q61bHmil
J4eVvsd3te8ShA92HB73qpOcfr8gat8+j1Q/gjKi/yI9H0Bk6OnR1WfP83wb
LL6Gng+gmJw/eL4Nt/odf+k9lfP6nGZfgh3fP5MD1V9RvbulntNrOVD9Fc+P
E/RbLr9TIei3XH7d9U5chGoB/mu7sXRzVynsnL1w4jF1sT66mYaNtl7HAlxa
OSigrL0UklpnLbPWKYZhcWPz3xXH48CXA86vXiTj+iuLr2L6q2WycXqXFTKu
vw4g/0f6f2DxYPT/YEH+T/NhhkIl0Y/5/1k+W/b/lzqCfsz/H73gim2NVA40
XzCWzHu5rVO8HKj/EjfrB1fuPisHtegJI/5R8UGnSyufHDsjB+q/ROMFwnkd
6HkdHwh8OnE/WyDw6UR9Zc7UFKtxExJ5PXdDQf9LhIdhl55cahKPc9yuH65q
mcy/15En256ufCmFJjan66a8iOP13efc6xGXNTkB7ZZU/9qwsJDny3bQdK0+
ZicHqn+hZY/qPu1Xyin/PgDtiJzrZxZEzvUzdn6j+ZjwxwsDybZNyVA9znRY
xhPFfBvyvHaJhhyutD0+4bhnEBraHu5r1lQObf4YlK6pDMI6f7Vr+zux/H7W
WHZZvetF7TLoZa0ysru+HZ4ecHSGj0I+wePShPOnrNEi4aX33ncymDXsh2NV
UDDqDt/bu/NzGX3/YPQj9lFubx78a15DQrvLcNimOiH3eByy+DAW7zFnw/n3
G/4U83gPG2Hcp/DvlX9lefPmvikwUDq04rtxAjoR/j3P96JhaGV35+9iOH9F
Z7STYv249aLrXfuUYr7+1GpuTYo6VMzXm5ed3DeNkhXz/kzdszCobUkx78+s
8brqH3uUwIxpbx30bGKRxc+zem6GX3JiN+qW8PgjA+nD7F+TSng8B1nnS3g8
R71UPqzV/AJMzYlr//pDAmQsNxt7/+8CXN5z2Jy/vyn0T/K+SN8Xssj7In1f
sCX8C6T+Tcj93FNvQH0R798+7R5cmlFaBN+PFqyaqi2hel4RmO+LnRbUQoK+
mwcPVx+5mK8nd+Z0M/mdLKf+Sh9k9eqpfRr9PnU1mttOrH/9gPhXeH4JDQ/L
rKsGclg/d/S9lfsOYetVk0rsHsr5fGL5iej1poa3O7yr3SHmtxnsPkm/c7Yf
x9VVV+QJHqXcXlx6Wc/iY4MX93eVvemZlhjlDZTPg86t4hpiIr2B8nnwFPk/
93+lkP9z/s8c8n/O//E90+xmj1dB+PD3Y9/TzY7y+pV4IcNzseJ8sriN9GG7
i0E83s5VsIcGc/8ki69i+sMdEo8v6kMkHp9jYxKPz3EGicfnmNWvY/UK9wr+
dA9RnxHyRXiJ5x8hX4QHx8zfzu8vfG8xX88C4Xvv5Pj6JJ0THfPkkNz+kkdv
Ly90GnN7q2WhnOohXjinrrEeQUtqr5iDlX0b9zkVuFf3aHCNYv4bDGv0h7aE
woqLVbmz5uAjrTa26lbtIWRS7vPesxagZ27jeGoFpqWWurpv5iDzf7D+1kxz
HaDH86s6m/5VOKfIlcudTedUCfen9pM5UNlKuD/S+4NBZ+H+SO8Pj9SE+yO9
P3jGCfdHen/IWW7U3aXtcFaPF6urIzflTjSBEtlfqm3j1qCzyqe0nnEmkN1C
N/p21Rq0OmnRcVzhCAhKCG3ifH8d7p3+7peDzmDqX3FEldsDLm0sN4LW3j8/
GXxahV+Pe45I7GgENz6deOO7dhVK+k/48GntAOgc/7E4atRKHHHGfeyyFQOh
7dWMD4YNK3GMnfA8rH4wrH0jPA/S54HP9R8bnwfp88DVJOF5kD4P7DUXnoee
3x3B/YbwPEifBzZLhedB+jwg6SU8D9LngRFJwvMgfR4oy9Bq2nxHIV9fJ5dZ
t9xizPibcTSP8GUej3nrVeroZyZy9Kv0aSg9d5DXD14ffjzxmt5BiL2S8iRi
lJzWHz4IC4h+jFQ/Bqv+71Nv/0Z8nttj4NODUkgbX3fJSy0f898lOhYHSmEM
sR8htR+BObEfIbUfQd8N5ReCMk5DXqClTbv7EgwznN621uU096/7Cf6P05Dy
l+Tv29ckmDxi88jAmss8Xu5sK/VzBYr1bfCTeEPtnUHYjbSHtD04SNrj/AR3
0h7S9kBbr82P8LUy/nxNPXweeqyS8eebFXBgcP/eBVi/+MCvxa2lUJr6QXq2
SwHW7vQNcGgnVZw7ZWfy/ZMheN0O66ev4vGP1rAVkZVyoPY9/EP2C+hfuNmo
+kMCvu+/asSXsQUQpxFYUFufgFbEXgnUXolf4w64HNTNBs3WpteO6yTiR/eU
lBbDsuGZ/a95KxXn/005Tydp1+Vjlx6P1Sv0pbA3p/yr8dd8vOeTaHOjtxSc
HzlOG6kh4/ycWsK3gPKqmib9chKwevqpcbeuFoBu844ue48nYGqXT+9TCgrg
Zb681islAVk8++3MmLqUzoloIezj+ahS6jGoarwU8vI3DXl6Nh9PjvN1GjRZ
Cqsed+1iLMtHqWnC48hRUrD+u135rVcIvjfqts0+LEVWj5PyidBYOFcUYK8O
a6+4nU4AN8MlxwxuFuDFNiZf86WK/bLwVrNuF4pgmuon52v9JDhOiB8W87GF
CnzoUL6+VAh8aFGfJud8hKcD3mKzE1K0PdXjer/9CMe8C75dSJDisMPF2qN2
IbTsP0x3UpIU35d+3r9xFsKdF2+PTj0jxdbXG9e3RXx9XSGsb3ZcP70trG+L
OB65qfuIQ08LcPugLpPfKPbz1jX797/4VQp0P+L14ul+hFaGI/37NpEB3Y/w
JOHLAN2PcMXcxvwqor2hTqsxv4qoH5v++NFYH8vUbaim58aNRsj05fnNN0qd
3PVROlu4nuvDO9sJ13Ns6lLbeH0evR6Yvkyvh++D79rP3JICJkuuffUYkoAs
/xLbHz0Fvnga35+eC3xxET8Q+OLpHLsKfHFRzvIPsvYCw1c6/OT8dPe895K9
Yys/ivjr8By/pb1Fe5+3ve2oZ0pypv+x9q4u2htUzfnq7nn1duq7720T8c7L
zd9eiRexRb7Lr0dK8ief375ap5cPH8YPST7sJUVrsr4BXd8wg6xvQNc3DCXn
D97frP4r6++15PzB+9uPnD94f+eR8Yp0vMI8Ml6RjlcwIuMV6XiFt2S8Ih2v
UNKmMd8LIrUfgr7qrbPjTRCp/RB2k3h6fn7rK/DbRX7tS4HfHs9xhcBvF7GO
wG8XceXfkw3uXZdRvmoIesw8nqkhU+ABR+P/2h6CKcL5O42/j07yyLFvktL4
+4zLD6mpTE/j7+Md4Ljn2JM0/j4fSX1iXg85l8Tn8/j/05+Lr2flbKV82P2g
YzPKauCKbbhxmeOOaaf3g2Rrhm+7Ztvw+6RHbW037we3fcPNq4y2YsOpecNv
ffSHTV2dmiyvPcn5B3eTHp5cO/kUrycdS/LJcD7Cc5JPhtvfL//eHlLR9SS3
96WQ/DLc3sfqFQd+vHa7aZgELaRWgZ8OnQJNy/w1A6MkmNb27sE/lYeA8hsw
oOk5XQ/9IKB8Bgwncs5/2E3knO+w4K6B7VGnNPzlfuDM5Qgp1Lx5tlHfOw3n
7ZJsiY2RQu2ntPORg05Bbyut+DM+Euwl6JWnwNFdtWZVoATXmpe61v04CWl7
vO8Pd5Vw/ZfNH2afYZjxexhm/nyGGb+HYeZfZpjZlxhm+hTDcRfPl87ZnQ9a
naKami2SYuC9EK9Z6mW8fsf0JdKrc9XKeH6lg0TO6394fr+Kq4bmcb6JmnVy
ZuU8OfUvBaIqwTRfciB4E/sbUPsbJoxYF9dlxE4uN7obedk+OgfMh6q33dsl
ET8T+xTl2QeBo+BnywKTDaParlRPpPkqM8FouFZ1YfNE3CnwP87As3Mltiu/
KPQ3u4DiK8XHkOqfkK9SEBtvpphP3hYR92yPQRDhf2Dxy7ydDzUS6fkkFynf
AxwIvwQpfwI2E34JUn4EOMlRtne2r+K8u2pr+u8QtCEYKYZ9UUnVi6PPwLXV
J/7kNk/AVbkvc/xOe/D3CSH2MKT2MFiSLmlY0kmxQVhOjnX6HgGFGxc0C/U+
gg7fjbrGnYyAJWvNu76YfILrp4l91tXkHdrLr2fxA/S8aVpL7BEUWwOr70Dl
eZGXeu/fpuvH+Qx7COb8AA/y/EifH8yJvQKpvQLO/+rQy0KnmNfzm0f8NZw/
Zeo2r3OPL8EIbRqmP0s+Ciw/Axt/E2kdOO7P0ja5MlurjNeT6V7byC/uTMfb
YmT5yNh62P2tIKfjdTG4PQ9YuVN9HNXPnXCZ/2Ac17MPHb8OWP9YkFM+ixMs
8xTkdP1xAN+6Ltsevd7C89mcm7LSU34qDLU8BxyMmxQJhYIdJo37p6KPdLur
61WApsl/dNzvJMA0twXL5KFu/Dy/f1hvT9+eG/H6YS8ttwpf8CJyoHKMzCgr
tEiSUfvLYSj3DrY+b7IAy1U93GdI3CDVR8BAMdq0uditU+EBUJ3/peuVzCM4
gmCkGF7rJaxtEi0Hej+MJu1TntdhzCPPz/WHn692xPZ9KwdH1/gNQYr2dVY5
1+/97Mn790HMwPFa9auo/ckbTL9njD2aJad8PW+MnvnuyMtn67j9Y5SwL+SA
/Hl8SyfdRDSMOxRlUZPD7en6wnp4EXKze/S+o52IjjfG7LxbGoMDfmSNW+MT
A52n3Lw4ry4Crdwu/+5aFQUtNzVLq+5iT+eLO+jISl8/kzlz/p2pwI/M5veb
J9T/y+Ltjzinf83JOgLvNfwK1jsYxfNZs/HD+LQM2wp4r8jHIPw8jpcKfIAs
OP+vbFjn9ok8vw4bz5Zk/PJ6R1Zk/AMd/zy/Dvs/y7/C8FKaV42dF6aR9Zfn
x0si/kp+3mD1ONjzs3gShpk/nOECQb+I4Jjlu2F4pZD/KYbjh2R95uu5w53G
57hF892NQn1q52Tnf4ea+EY5jbsaBSWHmp7spDaR5qPfBL7BAqb+iE24Ymvj
el5nSuavFZb7NuaXekfrCE7GFeMEeR6VQ7mOIM+jcppvOxWpfgWSTJWgtUdT
kepX0E7fZci5M6lI9SvIGXHziORcCVC+Id13cvn+8VKwL5/n/MXOxi5TdaQX
eX+nOrZK89t3ER7MSVJbrZWIgcE/DT4fvghmMz9du6uQE7toARr8YxDc82cC
9A9wuTbHpACXB1+4f7yJFLYP8e550XE/dveo3eEcEAo1t8xh/aTl1D7nSeeZ
uJ6S/Nznuf53cPo598oYR6iqGBig6uWF/wdxHfNA
     "], {{{
        EdgeForm[], 
        Directive[
         AbsoluteThickness[1.6], 
         Opacity[0.5], 
         RGBColor[0.560181, 0.691569, 0.194885]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxMnQWYXTXXha+fe+/ctjPFvRSHosWKFS/uUNyKO0WLtlDc9cc/3N3d3d0+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           "]], 
          PolygonBox[CompressedData["
1:eJwtnAncVdP3xm+997733vee8ZISUmSeytCEoiJjyJQpQ1SGZMiszJoHRbNS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           "]]}]}, {
        EdgeForm[], 
        Directive[
         AbsoluteThickness[1.6], 
         Opacity[0.5], 
         RGBColor[0.922526, 0.385626, 0.209179]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxM3XXYbUXVAPBLI9Lvyfec8xL30h3S3Z0qIQqCoHSIgAHS3SmNAkqKdCsC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           "]], 
          PolygonBox[CompressedData["
1:eJwtm3ncVdP3x29JpoTqmbq359xz7zm3KJEMIXzNVIZCgzQnqRQhRUqZRZSK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           "]]}]}, {}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwl2He0VdURx/H7QBCkvUfvUqREQFA6iqAYOtEgoBhLggJGVqIUG0SqChJ6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         "]], 
        LineBox[CompressedData["
1:eJwl2Hfcz/Uax/FfIdstaUoisslWyK6UeVP2prhxa9izTlHcWRmJygjZyh6d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         "]]}, {
        Directive[
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwl0D0uAwAcxuG/RBNdqwNJO9hJuEEl9a2qn8ymWjgAN9ATcAJu0J6BI9BW
Ka3WR8LeJzE88y/vu3RyXj6biYgCT6mIR35IzEcsssI6NU65pMkNd7R5oMcf
yXREljU22GSLbXbYZY99ChxQ5JASZSpUqVHniGPyrJJhjl+9Lve0uOWaKy5o
UCXHMgvM8m3fF59MGPPBiCHvvDHglRf6PNOjSyf1/9cUPMYweQ==
         "]], 
        LineBox[CompressedData["
1:eJwl2HfUlcURx/EL0osmUmy0FwQhUgTpINIx9N4MVRQpgkkAxSgkIE1PTuga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         "]], 
        LineBox[CompressedData["
1:eJwl2Hf8z+Uax/GvjHDKLKvsGcoJDSsjiqxjZ++RbLLXT8j8obJHHCUjK0Lb
FhlZWZ06lQohMpvO83qcP16P93Xd93Vf9/X5fO7P576/3/wdejfslSKRSDRK
lUgsyZdIfJc3kchWKJH4lh7Kn0icxPdFEokT9EzBRGKumJ4FEokeKCUuBX8j
tojZQKdrm4a39b8mR2F2G/aL+irxj9Jj6IFPCycS27AVhfSVM0dBOlOuVOzr
5ruGLdqWaPuntmPsWnIejzZ9k9k12WfoV0jGVExBcXNkN+ZZ/VvZH8mxjT6E
nPpz4Vf9fbRfpX3pV3J+lieRqMeuj7qYq+9fdA6djxPseXSW65qJqexp5niV
dkQntJK7JQ5r30A309J0sPgh2MUfRoeiTNTNn80eaf4RcV3sKciCAfhTTa9r
/4P252fGJEzEtKgByciI9vhc3Ay6n3agmTABr2A6RiMJGdAO+8SNo3tpW3ov
RkU9mOz5TMBEtEQrtMZONbejbdEGnfiT6PK4F3QFfY3e6351Zv/Hfe9CF/Cn
xHNwn4qjPDu/e1CB3m2+L11nGlqOn097SvZgY1LTgbE26CD6sVp70d6oZZ6a
eBbD5ExjXGpcMd9d+lMiBZbJmVlbMnucuPSYzX5S2wT2E7Q8f7E8Z9hv0NN0
hTln0+JylkA3/gnzz1HrHPZwjEAhfQXRit0aFYx5nF+Rjo0Y9oPsH+iPGI5h
GIp71HYw8tMnzPt8rBV2LfGn6HN0KE0T9429Mt49ta6iN/lFjC2KjsYdVtsB
9hG6mr8GS43LIu9bNDN9ky4T8xbe0b9QjkrsBXQVf4Ox38jdHqO0j0YSPuCf
oz9hDLLy99JS9BCdHO9uvIP0Bn2ZjsVUtd4l9152CjqFP4adhEnxbvMn0v0o
iYP8h+llebOws6Khuhvhotpy8S/FGlBrA/zhWfyOX8QXM+6A/qK0BNJiNz8d
vaL/KibxfzE+n7ZM2MPPTDMiKz7jZ6Gl1HqdfQPXMN419UU/3K1vPU1Lr+pb
x+6PN7EUq+NbqG8GrUd70d7og638tXQNeqIu/6y6tqupK+2GQmikhsZogIfi
HtAitFhcH26J36etA7sj8sR65temdZDe/XqN/xx7ejzbeJbu0yp2ZfZKOoq/
UZ6keJfM+Tjm6DuPC7iIn+ObJnYunSl+O7saexvNFPcOGXHB2Iv6L6GQebNr
y4kcyIvvtH9trgns0fEOypEOX8tzINaJeqdgdqxrult7Df17Ym5j32HPZf8j
3hksMSaDuEzIiAIxRtxWczS3Lu7Bev46fCL+YxQw9zPGvSt2A9KbK2XUQdfz
i9LfxbyFQfzvzfdv2hTNMF//m/RH7UvpsnivUIa/kC7CAtzGLcwT/5d6mrAb
o3N8L6Ne8V1o13jf0Rx/i0tl3uXxDcXbWIWVKBt7WdxzfIrvYq9GC313jLti
3H/5PTAJE/G0MY3jHaKf03qoj+74xLgX6JfiGsQ+zm9Ij/Ovxv6I9rG20BaP
yt+OPhL7MUphl3mz0d20rvF1cF6On93vC8ht3pHyZDNusL4hGBr3VN9Z/IAZ
+FDcY/G9iO9XfLvweqw1zMLuODOYZw8ti9zaytA78n4Tawq/qaG1mM2xB9Mt
8a0Tlym+cfLPM+/+WEf0c9qRdkB7zMTr2IzUxmbS/wK7W3xzzPM+vRFrEguw
ECfFFJO7k5o74yf+MnUcVcd4OY7HNxbJxk6LdaE/g/g3Yp2IW4QaxtXUtjf2
Rn5n9jH6qPyN2aXprnhW8u2kY+RJwnvYhLF4GS2MP61/p7gz9OV4jtrHxPON
9aX/knzNYl+mr+IkTiCDMd+K+yDWIO1N+6AvDvC36T9IW6IF0snRly7T3o9W
jP0p5uR/EPsi+0M6ll87zn5Iwsp452nTOO/IPQez4lr4i/Vtin0BU11/MqrH
OSjOQ5iGq/xfURDXcQ3DxN+it2P/xU3ciGcReyA9iFz4AofiPCU+jTnvjueM
dEiLQbE+MVod7xq7kb2ejuIPZL+EmvF9RA08G98Q9JevpdpaoYL8LWhz3DS2
M+2Cp7R3o10xIdYd7YRK2jvQ9hge7wry4BHt+WheJIkvGN9SlNJegObHj/Lv
jbMbcsZZL8596Cc+heu5CwmkQkr0V/8AjIx9ythN7LV0RDzDOP/iaXZ1VEE1
VEVf+ZqZ73mUl78pbYIbxg6kg1Atzip0MCaJH0BfQlXt/Wk/DMP9yIaS2nPQ
7Bgt/gH6IB6OZ0VzxndB/l383RGLz7AHfcT/ac3+hT9wB3/HvhpneQxX8xpj
32OvpsP4vdg98RS7MiqgEirG+VG+RuZrjHLyN6QNcD3OFrQ3qmjvS/tgovge
tCcqx28b2h1DcS8yoHicuWlGjBKfld6HEnGmp5nxvfzb+NuRHTuxA71iPbue
27iJ3/EbXlR/DwxV8zvGrmWvokP43dkvxO8QHOcnx/XG+ZWeivMsXYBF8ZuO
v5B+aewg7+Jy/mBaGfvjfcfe+D5iH56JfUO9+1E73id6AMXi3Ef34bl4PnQP
DqFWtOFJ7XViHMbLc5989yMrsiMb1qmlnv66uKymLa71/fhdZ+wKbctx3tgP
tX0U50+8Ytx4tNOek+ZCDjyIB7A+frMZVx8HYw2odYXrHE6r4Asxh3EII2I/
lKepMUfENKNN0BzPx16n/6i4YziCkXF+lHNlnKHiWtW5Os4lsd/JU0hMYRSM
cwSK4FS8a/rXoJGYVvyj5mpNW8YZlV0SxdGGf1HMQ8YVRzGURAl00VdaTJl4
R/lV4xyvlmq0Mh7TXjZ+b8XvdZxln6Y/y3ebXuD/Fudy3MJ5/k3aUP/JqBMn
cAanI79rHYdV4sbSK+aaTtfyZ9Aasc+Lu4hzuBB7f5xn4jdOnI9wNvY+cT/R
6jQZa4yfSg/Id9n85+IsTi8hh+ebO+aK3wLsnfEd5Ddk56E74tvC3k4f4DeI
31SxP8aeE78LaX9z9cPGWBtxDbStmubH7xvMi/NmvFfxDLR/w25DZ8n5p7bZ
sffE2Qk7Yt+MPVj7xagr9iEUifq0FaYVsFjfu0X+/z/K/wD7+cYf
         "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox["\"\[Theta]\"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
        TraditionalForm]}, AxesOrigin -> {Automatic, Automatic}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, 
     PlotRange -> {{-0.4077471967380224, 
      0.4077471967380224}, {-0.1529051987767584, 0.1529051987767584}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"Wel\"", "\"Niet\""}, "SwatchLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6619549559772615`*^9, {3.661954995578226*^9, 3.661955057210723*^9}, {
   3.661959918704606*^9, 3.6619599248103228`*^9}, {3.661959999117434*^9, 
   3.661960003635033*^9}, {3.6619624047665663`*^9, 3.661962426422761*^9}, {
   3.6620206323510337`*^9, 3.662020640185216*^9}, 3.662020713016124*^9, 
   3.662020763663613*^9, {3.6624734912164974`*^9, 3.6624735114107995`*^9}, 
   3.6625504387083564`*^9, {3.662550491913067*^9, 3.6625505131120777`*^9}, 
   3.662550565548233*^9, 3.6629045849454775`*^9, 3.662904620982012*^9, {
   3.6629046807813854`*^9, 3.662904709169501*^9}, 3.6629136883122654`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Image: Trajectories in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"\[Theta]", ",", 
     OverscriptBox["\[Theta]", "."]}], ")"}], TraditionalForm]]],
 "-plane"
}], "Subsubsection",
 CellChangeTimes->{{3.6618644251357975`*^9, 3.6618644648472953`*^9}, {
   3.6618709463905716`*^9, 3.6618709494307175`*^9}, {3.661872013250246*^9, 
   3.661872027793524*^9}, 3.6620280148132925`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", "=", "0.15"}], "}"}], ",", 
       RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"Cos", "[", "t", "]"}]}], "-", 
              RowBox[{"1", "/", "g"}]}], ",", 
             RowBox[{
              SqrtBox[
               FractionBox["g", "l"]], "r", " ", 
              RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"Cos", "[", "t", "]"}]}], "+", 
              RowBox[{"1", "/", "g"}]}], ",", 
             RowBox[{
              SqrtBox[
               FractionBox["g", "l"]], "r", " ", 
              RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotLegends", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<u = -1\>\"", ",", " ", "\"\<u = 1\>\""}], "}"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"Cos", "[", "t", "]"}]}], "-", 
              RowBox[{"1", "/", "g"}]}], ",", 
             RowBox[{
              SqrtBox[
               FractionBox["g", "l"]], "r", " ", 
              RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"r", " ", 
               RowBox[{"Cos", "[", "t", "]"}]}], "+", 
              RowBox[{"1", "/", "g"}]}], ",", 
             RowBox[{
              SqrtBox[
               FractionBox["g", "l"]], "r", " ", 
              RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}]}], "\[IndentingNewLine]", "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.15", ",", "1", ",", "0.15"}], "}"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "g"]}], ",", "0"}], "}"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", "g"], ",", "0"}], "}"}], "}"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"PointSize", "[", "Large", "]"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "0.2"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\"\<s8\>\"", ",", "True"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.658049837432005*^9, 3.658049839632566*^9}, {
   3.6580809054998455`*^9, 3.658081348431593*^9}, {3.6586415147058306`*^9, 
   3.658641575315761*^9}, {3.6586417069750166`*^9, 3.658641719881383*^9}, 
   3.658642491979531*^9, {3.659091413722051*^9, 3.659091435377348*^9}, {
   3.660281517286807*^9, 3.66028152564974*^9}, {3.6602815570659876`*^9, 
   3.660281653641365*^9}, {3.661864367377393*^9, 3.661864417857692*^9}, {
   3.6618647870638313`*^9, 3.6618648565443993`*^9}, {3.6618648982993565`*^9, 
   3.661864950719672*^9}, {3.661865021649726*^9, 3.661865184533743*^9}, {
   3.662015977026682*^9, 3.6620159801308746`*^9}, {3.662020443194192*^9, 
   3.6620204491334696`*^9}, {3.6620205640559387`*^9, 
   3.6620205652866664`*^9}, {3.662913820677286*^9, 3.662913821173071*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123c8le//OHCbyEwqKcrKSCSkcCG0ZFRGUvZW9orsnS17HfMc6yB7vuw9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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw123c4lf//OHBJJcooURKKVFaKkPWkIkUokTdZ2St7FbJ3srL3Osfh3Mie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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123c8le//OHCbyEwqKcrKSCSkcCG0ZFRGUvZW9orsnS17HfMc6yB7vuw9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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw123c4lf//OHBJJcooURKKVFaKkPWkIkUokTdZ2St7FbJ3srL3Osfh3Mie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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123c8Vv//P3CVpndIRUMRopCSUEZPI6MSSVGSkWyVmRGySZFNKHvL3q7r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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw123c81e/7OHDkXaRQSosoUmZSUdaFIkVIilRmMlNmVkZkVRJC9opC9jrO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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123k8lN/7P3BatShKlFTKVpKl7OSiEllCKlLKXoQkSUK2LGXfFVnLUsrO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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw123k81N/3OHCloqKIkFQqe7IUZcuhjSwhihRFFBIqWUoispUsJbJl30L2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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123c419/7OHAhFaHxTiWhiLKKijK6o6WyFZIySna2UMkeDSmRlYyMkL3X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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw123c4lf//OHAhI5kNZRdvRfYs6xmVlKIpLSsyKzu0ZEaUUQhlZUQZmVlP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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123c81e/7OHBpUN6VtEmKkk1JKXFFJBRllFT2LhllpGWPkJ2RPZJC9si4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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw123c81e/7OHBpEJVRFA0jJEVSJOKKqKRUqISSqGSUkZFKSKKo7Jk9kr1l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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJw123c4lf//OHClIi2ZrXdUKJJISiVP0lBIyS5EKYmyEskuSUYKSbaSvfd6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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJw122k4ld/3MHCRUKkkUREKURmLTFmVpEKIyhCiUMpQIpEhZIhMDdTXkHmI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         "]]}}}, {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          PointSize[Large]], 
         PointBox[{{-0.1019367991845056, 0.}, {-0.1019367991845056, 0.}}]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6], 
          PointSize[Large]], 
         PointBox[{{0.1019367991845056, 0.}, {0.1019367991845056, 
          0.}}]}, {}}}, {}}}, {
    PlotRange -> {{-0.5, 0.5}, {-0.2, 0.2}}, ImageSize -> {300, 200}, 
     AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], AxesLabel -> {
       FormBox["\"x\"", TraditionalForm], 
       FormBox["\"y\"", TraditionalForm]}, DisplayFunction -> Identity, 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-0.2519367816547815, 
      0.2519367991845056}, {-0.06065269132249233, 0.06065269247448627}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"u = -1\"", "\"u = 1\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.661864418222609*^9, 3.661864788558481*^9, {3.661864824998102*^9, 
   3.6618648574638524`*^9}, {3.6618649066896935`*^9, 3.6618649112352324`*^9}, 
   3.6618649520754147`*^9, 3.6618650241446853`*^9, {3.661865061853396*^9, 
   3.661865077055634*^9}, 3.661865112462414*^9, {3.661865164425003*^9, 
   3.661865185163419*^9}, {3.6618720322406826`*^9, 3.661872085192032*^9}, {
   3.6620159781454825`*^9, 3.662015980868405*^9}, 3.662020450013859*^9, 
   3.6620205681513186`*^9, 3.6629138247292213`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure: Solutions with Hautus\[CloseCurlyQuote] method", "Subsubsection",
 CellChangeTimes->{{3.661864329792008*^9, 3.6618643352162476`*^9}, {
  3.661870934030847*^9, 3.661870934767357*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"hautus", "[", 
    RowBox[{
     RowBox[{"-", "0.2"}], ",", "0.2"}], "]"}], ",", "\"\<s11\>\"", ",", 
   "True"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"hautus", "[", 
    RowBox[{"0.1", ",", "0.03"}], "]"}], ",", "\"\<s7\>\"", ",", "True"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.658050063718145*^9, 3.6580505718833466`*^9}, {
   3.658050615429164*^9, 3.658050632824479*^9}, {3.6580506647600775`*^9, 
   3.658050913539132*^9}, {3.6580509549834642`*^9, 3.658050964220001*^9}, {
   3.658051010913044*^9, 3.6580510814779835`*^9}, {3.658051124018086*^9, 
   3.658051249365795*^9}, {3.6580513287659874`*^9, 3.658051338799087*^9}, {
   3.658051387164315*^9, 3.65805141527721*^9}, {3.658051452469531*^9, 
   3.658051540820055*^9}, {3.658051571586829*^9, 3.6580517817799625`*^9}, {
   3.658051856133581*^9, 3.658051867984968*^9}, {3.6580519212876897`*^9, 
   3.658051989362866*^9}, {3.6580520422062626`*^9, 3.6580521928939037`*^9}, {
   3.6580526651260986`*^9, 3.658052671935918*^9}, {3.658052716998809*^9, 
   3.658052723051092*^9}, {3.6580527681610155`*^9, 3.658052831741011*^9}, {
   3.6580530677700467`*^9, 3.6580531636829243`*^9}, {3.658053212949788*^9, 
   3.6580532171507626`*^9}, {3.6580532766298556`*^9, 3.658053397518408*^9}, {
   3.6580750422993107`*^9, 3.6580751019398885`*^9}, {3.6582127911103115`*^9, 
   3.6582128413587823`*^9}, {3.6582128944002247`*^9, 
   3.6582129181589947`*^9}, {3.6582129501025453`*^9, 
   3.6582129942577143`*^9}, {3.658213069223634*^9, 3.6582130711740093`*^9}, {
   3.6582131049068227`*^9, 3.658213140798159*^9}, {3.6582131861121454`*^9, 
   3.6582132052226367`*^9}, {3.658213251750549*^9, 3.658213421053059*^9}, {
   3.6582134821011553`*^9, 3.6582134957888174`*^9}, {3.6582135737578564`*^9, 
   3.6582136288287315`*^9}, {3.658214995304558*^9, 3.658215034573278*^9}, {
   3.658215564018862*^9, 3.6582155776875095`*^9}, {3.6582157954293737`*^9, 
   3.6582158011143875`*^9}, {3.6585572183782816`*^9, 
   3.6585574534142876`*^9}, {3.6585575158939867`*^9, 
   3.6585576602138634`*^9}, {3.658557704748543*^9, 3.6585579065019803`*^9}, {
   3.658558012021842*^9, 3.6585582113956633`*^9}, {3.658558523562334*^9, 
   3.658558526553446*^9}, {3.658558590503599*^9, 3.6585585978077564`*^9}, {
   3.6585597061344976`*^9, 3.6585597078196874`*^9}, 3.658560559128165*^9, {
   3.6585607014256134`*^9, 3.6585607386468997`*^9}, {3.6585608387655745`*^9, 
   3.6585608672066402`*^9}, {3.658560909862751*^9, 3.6585610553364425`*^9}, {
   3.65856111643958*^9, 3.658561116541648*^9}, {3.65856132818972*^9, 
   3.6585613464125843`*^9}, {3.658561378669355*^9, 3.6585614337732525`*^9}, {
   3.658561469453439*^9, 3.6585614910767035`*^9}, {3.658561854843489*^9, 
   3.6585618689624557`*^9}, {3.6585619086895*^9, 3.6585619152561455`*^9}, {
   3.6585619622843328`*^9, 3.6585620288493223`*^9}, 3.658562062556117*^9, {
   3.658562227322033*^9, 3.6585623837234488`*^9}, {3.6585624236406155`*^9, 
   3.6585624863271117`*^9}, {3.65856253522363*^9, 3.6585625385900064`*^9}, {
   3.6585650145983353`*^9, 3.658565073029593*^9}, {3.6585651228377533`*^9, 
   3.6585651263262053`*^9}, {3.6585651764686117`*^9, 3.658565178068742*^9}, {
   3.658565251308442*^9, 3.658565263500037*^9}, {3.658565301731042*^9, 
   3.6585653018501205`*^9}, {3.6585653334914465`*^9, 3.658565425677822*^9}, {
   3.6585654945874395`*^9, 3.65856555553606*^9}, {3.658566075753166*^9, 
   3.658566101412278*^9}, {3.658566140916164*^9, 3.658566177814211*^9}, {
   3.6585670957672243`*^9, 3.658567176999563*^9}, {3.6585672227168355`*^9, 
   3.658567236804782*^9}, {3.6585679349285917`*^9, 3.658567963320634*^9}, {
   3.6585680102077312`*^9, 3.6585681209809284`*^9}, {3.65856887062711*^9, 
   3.6585689864298553`*^9}, {3.658641865141292*^9, 3.6586419392496314`*^9}, 
   3.6586424860888395`*^9, {3.659070986195177*^9, 3.659071111966017*^9}, {
   3.659071153977691*^9, 3.659071154043738*^9}, {3.6590715352830276`*^9, 
   3.659071538539328*^9}, {3.659071577722005*^9, 3.659071609731615*^9}, {
   3.6590716650977235`*^9, 3.659071729972548*^9}, 3.659071760586172*^9, {
   3.659079356423388*^9, 3.6590793789933305`*^9}, {3.6590794091956635`*^9, 
   3.6590794117944994`*^9}, {3.659079444282448*^9, 3.6590796200756197`*^9}, {
   3.6590796535532675`*^9, 3.659079654584996*^9}, {3.6590796876413455`*^9, 
   3.6590797301593776`*^9}, 3.6590798357506757`*^9, {3.659079868088518*^9, 
   3.659079869190296*^9}, {3.6590879225493317`*^9, 3.659087979765733*^9}, {
   3.6590880159833155`*^9, 3.6590880558324633`*^9}, {3.6590881371522846`*^9, 
   3.6590881844647036`*^9}, {3.6590882174660144`*^9, 3.659088307125852*^9}, {
   3.659088366741004*^9, 3.6590884237722883`*^9}, {3.659088469637686*^9, 
   3.659088473524431*^9}, {3.6590885203905354`*^9, 3.659088652419795*^9}, {
   3.6590887184184127`*^9, 3.659088760876403*^9}, {3.659088804526236*^9, 
   3.6590888615303545`*^9}, {3.6590889017377553`*^9, 
   3.6590889528658695`*^9}, {3.6590891278380537`*^9, 3.659089142472391*^9}, {
   3.6590894609853735`*^9, 3.6590895122585897`*^9}, {3.659089576141714*^9, 
   3.659089632421468*^9}, {3.6590897486235476`*^9, 3.6590897909534473`*^9}, 
   3.6590898329361024`*^9, {3.6590903248702383`*^9, 3.659090581376423*^9}, 
   3.659090622819214*^9, {3.6590906640463357`*^9, 3.659090761432126*^9}, {
   3.659091460673204*^9, 3.659091492504689*^9}, {3.6590915725852547`*^9, 
   3.659091587473771*^9}, {3.659091854481373*^9, 3.6590918622898884`*^9}, {
   3.659091916594246*^9, 3.6590919378002267`*^9}, {3.659092068463567*^9, 
   3.659092068638691*^9}, {3.6590921767548504`*^9, 3.659092246717718*^9}, {
   3.6590926462239103`*^9, 3.659092646277948*^9}, {3.6591649019107137`*^9, 
   3.659164917521741*^9}, {3.6591650092185116`*^9, 3.6591652643877516`*^9}, {
   3.6591653161833377`*^9, 3.6591655744797864`*^9}, {3.6591657132197857`*^9, 
   3.659165740316926*^9}, {3.6591657711146803`*^9, 3.659165812393838*^9}, {
   3.6591658746758313`*^9, 3.6591659808388195`*^9}, {3.6592661839612255`*^9, 
   3.6592662000786085`*^9}, {3.659266238423694*^9, 3.659266306654889*^9}, {
   3.659266363662157*^9, 3.6592663715437245`*^9}, {3.6592664084437885`*^9, 
   3.6592664191123247`*^9}, {3.6592664495908527`*^9, 3.659266451037875*^9}, {
   3.6592664905257673`*^9, 3.659266499493102*^9}, {3.6592665370796514`*^9, 
   3.6592665377741413`*^9}, {3.6592666003523445`*^9, 3.6592667413149137`*^9}, 
   3.6592667960282803`*^9, {3.65926726690705*^9, 3.659267289404086*^9}, {
   3.6592674139162235`*^9, 3.659267440899481*^9}, {3.6592674943724947`*^9, 
   3.6592676269349804`*^9}, {3.6592676623259797`*^9, 
   3.6592676746977196`*^9}, {3.659267744772233*^9, 3.659267916774238*^9}, {
   3.6592679502178717`*^9, 3.6592679502589006`*^9}, {3.6592680155750265`*^9, 
   3.6592680156370707`*^9}, {3.659268136578537*^9, 3.6592681402521315`*^9}, {
   3.659268281131181*^9, 3.659268283127591*^9}, 3.6592683545360303`*^9, {
   3.659268434659626*^9, 3.6592684379889784`*^9}, {3.6592684914067097`*^9, 
   3.659268511845146*^9}, {3.6592685879138775`*^9, 3.6592686029575043`*^9}, {
   3.6592686724305763`*^9, 3.6592686940288324`*^9}, 3.6592687389345517`*^9, {
   3.659268782557365*^9, 3.6592687837011733`*^9}, 3.659268842836944*^9, {
   3.6592688916854486`*^9, 3.6592689551342793`*^9}, {3.659269036574802*^9, 
   3.659269142698753*^9}, {3.6592691847754736`*^9, 3.659269188583163*^9}, {
   3.659269221280259*^9, 3.6592692258494864`*^9}, {3.659269265728655*^9, 
   3.6592693019462376`*^9}, 3.6592693501961637`*^9, {3.659269389907214*^9, 
   3.659269392876322*^9}, {3.659269443537096*^9, 3.659269452410363*^9}, {
   3.6592695312820745`*^9, 3.6592695621298637`*^9}, {3.659269631566911*^9, 
   3.659269633021939*^9}, {3.6592697418488092`*^9, 3.659269783525247*^9}, {
   3.659270122862941*^9, 3.659270138459957*^9}, {3.6592701913573213`*^9, 
   3.65927023382732*^9}, 3.6592705793193607`*^9, {3.659270637514467*^9, 
   3.6592706603516083`*^9}, {3.6592707277391973`*^9, 3.659270740950529*^9}, {
   3.6592709164054623`*^9, 3.6592709458982944`*^9}, {3.659270981011097*^9, 
   3.6592709821789217`*^9}, {3.6592710144256997`*^9, 3.659271051111613*^9}, {
   3.6592711659927607`*^9, 3.659271283821989*^9}, {3.6592713509574103`*^9, 
   3.659271394670287*^9}, {3.659271424691493*^9, 3.659271498217429*^9}, {
   3.659271556361498*^9, 3.659271577121162*^9}, {3.6592716134178*^9, 
   3.659271619072795*^9}, {3.659271650833229*^9, 3.6592717191805058`*^9}, {
   3.65927177715946*^9, 3.6592717896923127`*^9}, {3.659271847990492*^9, 
   3.6592718615540724`*^9}, {3.659271938235237*^9, 3.659271991366767*^9}, {
   3.659272031024779*^9, 3.659272033948845*^9}, {3.6592720899584064`*^9, 
   3.659272193919346*^9}, {3.65927226332946*^9, 3.659272264088997*^9}, {
   3.6592723458857746`*^9, 3.6592723698296866`*^9}, {3.659272415316817*^9, 
   3.659272434552404*^9}, {3.65927247366303*^9, 3.6592725480785937`*^9}, {
   3.659272660627753*^9, 3.659272711676196*^9}, {3.65927274261893*^9, 
   3.6592727543292017`*^9}, {3.6592728111811876`*^9, 
   3.6592728949173346`*^9}, {3.6592729402283406`*^9, 3.659273119334818*^9}, {
   3.659273153289802*^9, 3.6592731833240166`*^9}, {3.6592732287210817`*^9, 
   3.6592732395967655`*^9}, {3.659273274183017*^9, 3.6592732751086707`*^9}, 
   3.6592733228644032`*^9, {3.659273359425228*^9, 3.6592733775310173`*^9}, {
   3.6592734191844378`*^9, 3.659273458695348*^9}, {3.659273495702489*^9, 
   3.6592734991799445`*^9}, {3.659273531512783*^9, 3.6592736170451994`*^9}, {
   3.6592736535349736`*^9, 3.6592736636241*^9}, {3.659280712706061*^9, 
   3.6592807333766465`*^9}, {3.659280772663397*^9, 3.659280840465289*^9}, {
   3.6592808721750345`*^9, 3.659280913990571*^9}, {3.6592809654068894`*^9, 
   3.6592809890575953`*^9}, {3.659281041951962*^9, 3.659281234642137*^9}, {
   3.6592812810499177`*^9, 3.6592812975145473`*^9}, {3.6592814993292866`*^9, 
   3.6592815323886385`*^9}, {3.659281575289853*^9, 3.6592816426853905`*^9}, {
   3.65928245219884*^9, 3.659282505175583*^9}, {3.6592831196952057`*^9, 
   3.659283139502115*^9}, {3.6592831897530775`*^9, 3.6592833044068995`*^9}, {
   3.6592833894957485`*^9, 3.659283445272044*^9}, {3.6592834849990873`*^9, 
   3.6592835195456243`*^9}, {3.6592835885442624`*^9, 3.659283590664838*^9}, {
   3.659283679839989*^9, 3.6592837012750998`*^9}, {3.659283740109933*^9, 
   3.659283742585045*^9}, {3.6592838088372054`*^9, 3.6592839078699303`*^9}, {
   3.6592840522863617`*^9, 3.6592840815091248`*^9}, {3.6592841439994173`*^9, 
   3.6592842524707785`*^9}, {3.659284294620903*^9, 3.659284316963542*^9}, {
   3.6592843622933064`*^9, 3.6592844042145457`*^9}, {3.6592844626056304`*^9, 
   3.659284553864355*^9}, {3.659284611298345*^9, 3.6592846162521086`*^9}, {
   3.6592846480271645`*^9, 3.6592846489484887`*^9}, {3.6592846914825277`*^9, 
   3.659284691540707*^9}, {3.6592848797318125`*^9, 3.65928488573808*^9}, {
   3.6592849361562967`*^9, 3.659284954040275*^9}, {3.6592850156847773`*^9, 
   3.6592850694724264`*^9}, {3.6592851400964494`*^9, 3.659285177647271*^9}, 
   3.6592852086955404`*^9, {3.6592853562157526`*^9, 3.659285424680995*^9}, {
   3.6592854656551857`*^9, 3.6592854747992287`*^9}, {3.659285601349262*^9, 
   3.6592856713751082`*^9}, {3.659285748567379*^9, 3.659285953198592*^9}, {
   3.659286001136063*^9, 3.6592860508894835`*^9}, {3.659286087528105*^9, 
   3.659286102894159*^9}, {3.659286146206592*^9, 3.6592861630094624`*^9}, {
   3.6592862141280184`*^9, 3.6592863338376913`*^9}, {3.6592865072088957`*^9, 
   3.6592865250871005`*^9}, {3.659286584645933*^9, 3.659286621041543*^9}, {
   3.659286664473302*^9, 3.659286669749282*^9}, {3.659286734707989*^9, 
   3.659286777213964*^9}, {3.6592868291019883`*^9, 3.6592868503738256`*^9}, {
   3.6592868843271294`*^9, 3.659286886379381*^9}, {3.6592870121955585`*^9, 
   3.6592870168135195`*^9}, 3.65928730830084*^9, {3.659287912856897*^9, 
   3.6592879801830173`*^9}, {3.6592880813189297`*^9, 3.659288087126811*^9}, {
   3.6592881391761427`*^9, 3.6592881456859627`*^9}, {3.6592881853890805`*^9, 
   3.6592882242850513`*^9}, {3.659288272285493*^9, 3.6592883274218063`*^9}, {
   3.659288358381216*^9, 3.659288383318555*^9}, {3.6592884159779415`*^9, 
   3.6592884932527313`*^9}, {3.6592885687932577`*^9, 3.659288584518077*^9}, {
   3.65928870519248*^9, 3.6592887053104143`*^9}, {3.6592888323332353`*^9, 
   3.659288838737336*^9}, {3.6592888720978484`*^9, 3.6592888854737425`*^9}, {
   3.659289291377777*^9, 3.6592893331326666`*^9}, {3.659289426323991*^9, 
   3.6592894277322226`*^9}, {3.65928956932146*^9, 3.659289570031438*^9}, {
   3.659289734610774*^9, 3.6592897361846485`*^9}, {3.6593288003231363`*^9, 
   3.659328821167861*^9}, {3.6593288926993876`*^9, 3.6593290757226667`*^9}, {
   3.6593291698461514`*^9, 3.659329181851631*^9}, {3.6593296576807356`*^9, 
   3.6593296710952106`*^9}, {3.6593297265854177`*^9, 
   3.6593297521134496`*^9}, {3.6593298897766433`*^9, 
   3.6593298933231483`*^9}, {3.6593299609058857`*^9, 
   3.6593299687944574`*^9}, {3.6593300288798995`*^9, 
   3.6593300786290507`*^9}, {3.659330112745138*^9, 3.65933014458663*^9}, {
   3.659330334242594*^9, 3.659330366779577*^9}, {3.659330426507766*^9, 
   3.6593304670193815`*^9}, {3.6593305187459183`*^9, 3.659330537899448*^9}, {
   3.659330801624731*^9, 3.6593308507854557`*^9}, {3.659330889295658*^9, 
   3.659331046958023*^9}, {3.659331086656065*^9, 3.6593311117317767`*^9}, {
   3.6593312006695986`*^9, 3.65933120101184*^9}, {3.659331308769837*^9, 
   3.6593313944483566`*^9}, {3.659331473046874*^9, 3.659331474525919*^9}, {
   3.659331506070201*^9, 3.659331520048074*^9}, {3.659331553895983*^9, 
   3.6593315541021285`*^9}, {3.6593316117608557`*^9, 
   3.6593316311775713`*^9}, {3.6593316925329094`*^9, 
   3.6593316982639575`*^9}, {3.659331731880704*^9, 3.6593317351170073`*^9}, {
   3.659331789621467*^9, 3.659331849895042*^9}, {3.659331890008376*^9, 
   3.6593319150760827`*^9}, {3.659331995573943*^9, 3.65933200947276*^9}, {
   3.6593320442052937`*^9, 3.6593321728451595`*^9}, {3.659332227629857*^9, 
   3.6593322873990746`*^9}, {3.65933233798981*^9, 3.6593324623996873`*^9}, {
   3.6593325045644703`*^9, 3.6593326071489315`*^9}, {3.6593327239563313`*^9, 
   3.6593327437002783`*^9}, {3.659332889610342*^9, 3.659333059542385*^9}, {
   3.659333207359786*^9, 3.6593332394144382`*^9}, {3.6593333116574574`*^9, 
   3.659333330479752*^9}, {3.6593333741305847`*^9, 3.659333426445549*^9}, 
   3.6593334743113585`*^9, {3.6602824254477153`*^9, 3.6602825165492277`*^9}, {
   3.6602825914222355`*^9, 3.6602826091457863`*^9}, {3.660282642912698*^9, 
   3.660282674352962*^9}, {3.6602827058122396`*^9, 3.660282708133896*^9}, {
   3.660283736737271*^9, 3.660283776750594*^9}, {3.660283811755383*^9, 
   3.6602838131493716`*^9}, {3.660283903793559*^9, 3.660283962245951*^9}, {
   3.660284051192938*^9, 3.660284075542198*^9}, {3.660284285557912*^9, 
   3.660284289126439*^9}, {3.6602845178083787`*^9, 3.660284552084649*^9}, {
   3.6602846422955217`*^9, 3.660284733338002*^9}, {3.6602858081708574`*^9, 
   3.6602858098770657`*^9}, {3.6602868416084585`*^9, 3.660286842290942*^9}, {
   3.660289301356753*^9, 3.660289314270898*^9}, {3.660289438109593*^9, 
   3.660289555823951*^9}, {3.660289592025586*^9, 3.660289595509053*^9}, 
   3.6602896633080645`*^9, {3.6602897872788525`*^9, 3.660289804663163*^9}, {
   3.660289909686545*^9, 3.660289953981902*^9}, {3.660289987595705*^9, 
   3.6602900261890345`*^9}, {3.6602900675583286`*^9, 
   3.6602901048097086`*^9}, {3.6602902203565316`*^9, 3.660290220461606*^9}, {
   3.6609717081814585`*^9, 3.660971802581127*^9}, 3.6609721843888187`*^9, {
   3.660973028673951*^9, 3.6609730811680307`*^9}, {3.6609734048886924`*^9, 
   3.660973435239132*^9}, {3.660973484231736*^9, 3.6609735483810487`*^9}, {
   3.660973581599513*^9, 3.660973640238933*^9}, {3.660973670574361*^9, 
   3.6609737026560216`*^9}, {3.660973750781015*^9, 3.6609737852123356`*^9}, {
   3.660973829900902*^9, 3.66097397714791*^9}, {3.6609740350157857`*^9, 
   3.6609740482861595`*^9}, {3.6609741098766637`*^9, 
   3.6609742473496203`*^9}, {3.66097505734794*^9, 3.6609750789301844`*^9}, {
   3.6609751161404676`*^9, 3.660975146913205*^9}, {3.660975179458193*^9, 
   3.660975424241096*^9}, {3.6609754570112553`*^9, 3.6609755084015436`*^9}, {
   3.660975538811023*^9, 3.660975574038907*^9}, {3.660975774784115*^9, 
   3.66097578562177*^9}, {3.6609759212645817`*^9, 3.6609760493570604`*^9}, {
   3.6609761622628117`*^9, 3.6609761706937675`*^9}, {3.6609762066141396`*^9, 
   3.660976212556337*^9}, {3.660976336749061*^9, 3.66097635475578*^9}, {
   3.6609764173329816`*^9, 3.660976488331132*^9}, {3.6609767692385516`*^9, 
   3.660976816026601*^9}, {3.660976848250362*^9, 3.6609768956408367`*^9}, {
   3.6609769270350122`*^9, 3.660977010456595*^9}, {3.6609770529956317`*^9, 
   3.6609770702088013`*^9}, {3.6609771058549795`*^9, 3.660977173391674*^9}, {
   3.660977242576543*^9, 3.660977262880885*^9}, {3.6609773347926917`*^9, 
   3.660977472134692*^9}, {3.660977838269887*^9, 3.660977901610628*^9}, {
   3.660978026004591*^9, 3.6609780437060947`*^9}, {3.6609781022674603`*^9, 
   3.660978231444705*^9}, {3.660978263474329*^9, 3.660978275708971*^9}, {
   3.6609783698904963`*^9, 3.660978449245549*^9}, 3.6609785086194882`*^9, {
   3.660978555179376*^9, 3.660978577104863*^9}, {3.6609786401664066`*^9, 
   3.6609786683122883`*^9}, {3.660978798698387*^9, 3.66097879992025*^9}, {
   3.6609788366081643`*^9, 3.6609788381592607`*^9}, {3.66097888498934*^9, 
   3.660978940830783*^9}, 3.660979270650752*^9, {3.6609793418480425`*^9, 
   3.6609793761612797`*^9}, {3.6609794267820363`*^9, 
   3.6609794503827066`*^9}, {3.660997191827567*^9, 3.6609972259120464`*^9}, {
   3.660997320174635*^9, 3.6609973460457*^9}, {3.6609973823390293`*^9, 
   3.6609973866829443`*^9}, {3.660997513298703*^9, 3.6609975191174307`*^9}, {
   3.660997557901595*^9, 3.66099755796025*^9}, {3.6609980203377223`*^9, 
   3.6609981303126454`*^9}, 3.6609981648890514`*^9, 3.6609982632336664`*^9, {
   3.6609983003930073`*^9, 3.6609983019202566`*^9}, {3.6609984025432515`*^9, 
   3.6609984034375906`*^9}, {3.660998452601548*^9, 3.6609985349185534`*^9}, {
   3.660998632928383*^9, 3.660998635718605*^9}, {3.6609986910547886`*^9, 
   3.660998694978345*^9}, {3.660998796182028*^9, 3.6609988166611657`*^9}, 
   3.6609988578107753`*^9, {3.6609988897682858`*^9, 3.660998889805953*^9}, {
   3.660998957672005*^9, 3.6609989602232246`*^9}, {3.660999019936376*^9, 
   3.6609990656576557`*^9}, {3.6609993167526813`*^9, 3.660999321810959*^9}, {
   3.6609993643289404`*^9, 3.660999408416887*^9}, {3.660999502343001*^9, 
   3.660999509199308*^9}, {3.660999592679251*^9, 3.6609997327051477`*^9}, {
   3.6610006174516754`*^9, 3.661000652051133*^9}, {3.6610007008372374`*^9, 
   3.6610007030292583`*^9}, {3.66100106122025*^9, 3.6610010635603433`*^9}, {
   3.661001263178605*^9, 3.6610013025607014`*^9}, 3.6610013420668564`*^9, {
   3.661001382488591*^9, 3.6610013825531282`*^9}, {3.6610014428976145`*^9, 
   3.661001459952879*^9}, {3.66100149834319*^9, 3.6610015002818403`*^9}, {
   3.6610017520928936`*^9, 3.6610017861178217`*^9}, {3.6610018265614986`*^9, 
   3.6610018313197947`*^9}, 3.6610018791817737`*^9, {3.661001941312721*^9, 
   3.6610019413721266`*^9}, {3.661002112816922*^9, 3.661002151652444*^9}, {
   3.6610023773464813`*^9, 3.6610024103799863`*^9}, {3.6610024768024817`*^9, 
   3.6610024801079044`*^9}, {3.6610025111073713`*^9, 
   3.6610025246139655`*^9}, {3.6610028286652355`*^9, 
   3.6610028310846014`*^9}, {3.66100288233961*^9, 3.6610029234829316`*^9}, {
   3.661003055979699*^9, 3.6610030660020447`*^9}, {3.661081227931846*^9, 
   3.661081235693327*^9}, {3.6610814721553545`*^9, 3.661081474201789*^9}, {
   3.6612432147985544`*^9, 3.6612432148903527`*^9}, {3.661492380263281*^9, 
   3.6614924060000267`*^9}, {3.661492447802528*^9, 3.661492450095145*^9}, {
   3.661862726281089*^9, 3.6618627496740956`*^9}, {3.6618642711394787`*^9, 
   3.6618643261446047`*^9}, {3.662015996376341*^9, 3.6620160006964083`*^9}, {
   3.6624616016354074`*^9, 3.6624616074404573`*^9}, {3.6627262278789587`*^9, 
   3.6627262308135457`*^9}, {3.6628788577832775`*^9, 
   3.6628788600475693`*^9}, {3.6629138280995464`*^9, 3.6629138551249905`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"Final time: \
\\!\\(\\*RowBox[{\\\"18.884126605450632`\\\"}]\\)\"\>",
  StringForm["Final time: ``", 18.884126605450632`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628788705409856`*^9, 3.6628788761951494`*^9}, {
   3.662878906866686*^9, 3.662878929586425*^9}, 3.6629138336439734`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"23.556433726549376`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 23.556433726549376`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628788705409856`*^9, 3.6628788761951494`*^9}, {
   3.662878906866686*^9, 3.662878929586425*^9}, 3.662913833645975*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{GraphicsBox[{
       GraphicsComplexBox[CompressedData["
1:eJxkXXdYVbnTRkTsig3RtaJiWXvFRixY1/ZTV13sXbEjYsOOiKiICAiIwIUL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        "], {{{
           EdgeForm[], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6], 
            Opacity[0.25]], 
           GraphicsGroupBox[{
             PolygonBox[CompressedData["
1:eJxNnQXUVUUXhm+cuOfaLSagoCgmKoqBgCJSIij+JmILKnaiICgoGAgGgggq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              "]], 
             PolygonBox[CompressedData["
1:eJwtmnngTtX2xt/3+573TBJlyDyLDM2GpEmITBlKxspQ5ilKKtIVKlGaE1cu
Ta5+0mAszYZMt1xKGVIakCGRQv0+T8/9Y7GevdbeZ5/z7r32Ws/+Vu41tMOQ
gkwmU4V/Av6/Ms1ktkaZTPNcJtMZuRV9UpjJVMD+PdId/Dw+7fOZzDJwLfCT
SITvJwxwBH0VUh/cGCkeZzJnIYPRm2GvgG00/avTfw79B2ObgJyNbRC4GPpq
pCm4ND7HkkzmKFIV2w9IY/p/Dd6K/QukDL5/Mb+zsT2AVMP+EfYPsX2EzMQW
07Ymm8mMRYpgu5U+pbH1R2ZjT7B/iO0+5H5sIfgCxvoM2QcegJTFtxMyHH2f
+mB7D2nEeCfx76pvhX0/uAv4K2wlwUvQD+JfGFwdGQEugyxH34/Uxb8O0g/9
CPII3+Yz7FcwXo73H45eKvK33oc0QH8Kn9bY2oB7gWeBO4ND8EDwgMjvqndY
w9jngVejH0SuRh+C7EX/ivl1wN4e2YH/Fq0BbH/wjrdgG4xMxfY6bZWYT0fk
DHBRZDf+Ef5XYpvD+40Hv4vUAU9BMviupn8j5rYx8lq4DBlF32toi5lvC/Ah
bA/T9gq+p9N2nGdfjxQDd0f2Yn+L8T9j7DI8rwDfxeAt4Irga/H9GmmD7xTG
exD/exi/bt5zTMEvhP5t1yKN8R0L7ox+LzKH8V5E3qT/UfAV+P8T+7is10xl
PY/xNjHeVp73L+yvYn8H21ZkHPg+5Dds5zPGMfT12L/N+puPoH9F+v+GrTjz
6419B/as3gW5hPkcRG7A/r3eSb8d/hfmvecm0H9p6GdVUx98t4APg3PgGN+J
9DmBfgFj/In9ZewrsK9HamO7jTGexbZK76jfhz5XMf4XWg/4z8f/PXwfZH53
gwvwOQfbTmQcffciO+m7GZ/t2Ksi0/AtStth+rbHfzO+lcE/obfDfgb65Uhl
cA/6P4H+PvIy+q7Q76493Qzff4M/znrNvIs+GZ+5+EbM8Wvwz4zRHlsp2pqj
340com9z7F3xLcz7HMSWx+cdbO8iddB75Ly32yD/KfAeX6tYgDTA1hA5j/4T
tOY1f3B/5rMTact4T4P3Y/s/cEPw+eA9+P+o/QL+nD6dsH/AHL/K+huUwrcT
eAn6EPwPg4ci5fHvjBRBX0+fS3Pe44O0Npn/xbxLCcY4iv0Y0lXxizH+odiI
/8cFjpGj0f+Ffw/812o90v+qyGtbe3AW+PLIe1FruBH6Nub7uX4/ZCD6IOR5
9E8V49AvjDxWqG+C/jltG+RL/2How5FZ4HX41MNeEXw7eAzSBLwLvA39a+RG
fVvmnEevrTWNrV3kb1WY8X8Cd4gca7SmuvAuEf69sNUBt8Z2LbKpwL/Zc1q7
yAJsryHXYHuGPm3zfy+XTFts3yLbsW3EvzP2ixkvANdChmgu2Ptqfth7YJ9J
/070H8T7tQR/k3ju6xivD7ivvlmBf9M+fM+HdabpkAQ/gp7Q/4DGAxen7yjt
CX0vZAH438jb6IuRO0PHfMX6D5FD2H5BvsH2HXhT6Biv2P49bRNDn7k6a78F
345+UmsOfSTPa8KzXsRnUtZ74B7sMxJ/m73IA9juoO1AgeesWLMcXDPnmDNU
8ZD5d+X9r2WM09HPRA7TN8anO2N1S7yXLkF60v8u7DXx/4lP0A7bdci0wDFn
CvPpjc+f6OfovAU/j1zF2AX074btaZ5ZKOcY+Sx6McY7olik+MFYd+s8zfmb
DEafjk+rrMfYFXmPaG+0zXmsRyOP/feYPOuu0Gu3G/1HoN/P+Jcw3+b0WahY
jP8pnr0avE/xG3t/7AVZny3LY8cqnTEjtbYTx+prkAvwfYs+VdBr4vMx+ieR
Y+8vWZ8Fz8SOvToTFqJ/qDWo70fbHPASxtii/U3b59gmghuDi4DfBNcF/6XY
Sf8a+n3BvbBXxV4W+2Tt6Zxzhs3gx0L3vRrZAB6Pf4O8Y8ov4PngQXnP4TXG
e1/5TM4xrDK2KsjxwGuoKvo07Fnsv9N2jn5rpDu2U+CXsFUD/4F+DzIffHbq
s7y0YixzqQ4+EXhNHAIv1RlX4JznZvAY7LWYzxHWz0t6v9i5ir7pCnxHak7Y
a+tMwdYdXAJcEpkPPsEYNbA1YPxm+J/xv/i/HlmE/hL+ffE9xfhj+e3uTTy3
65C36f8Wskp7XesHfTnjdVDsV8Ib+8zQWdEdGU3fO5HZ2F5AsspHtEcYv5jO
TP22ib9FHvxo6N9Ev4XOlB/QX8H/Nmx/MvwOcD3NCf9xyGXYrkCCvHPsuTo7
Is+tkNYQz1uBdCnwHFth+y8+N+ccE7ei52LnQsoBlGs8yfjzA+ccz+E/j/Fv
Yvw9PH8StolIefpXUE6meKY5YN+F/++K19jvo//9gXP3BtizeefwHyg3Dp37
aQ01xjdQfoheA/8c+B3sX2b9jEXYXo+9N+RzXN82di48XvlJ5N9cv3U3pBbP
qp16rZUBj2Sskdh/5v26KMdXbIid6x1nzC/Bp8fOhU6AH0c/TTGIvnXxr0Hf
X/Dpk/OZWQQ8lfGb8j7XKSbi+xv2gTnXGGdifxx7y7y/eSGd97zTEmwNwKXx
v0LfUPslcK1RS3s655qjY+gzX2e9co7OyuWQ1sxtDHg3+l7VT/S9DvkE/Cu4
n/avvgn4PuQA/pNoa6O+yJisc6wO6O01Br/ldOWPOiuVn2B/AlwbfTjzr5j3
nOqB+zN+pPwWfAN6HdpuQ/+UMTYqViE5nt0C2c27dcVHxZ/O0HXYzkWyyrWQ
0xj7fOWEgXMsjT019tmuZzSMHbMUq0Kd58pdYj+7G/bP0NcqfmO7FtkAHqea
TGc5Mhk8KfZZpLYKyk3BSeCc+Y7QObJyY50JTyjfSb33hoIHR95D2jt/1zRa
f4qPgWuC35TrgFP0PYpn6E21ZvSu9G8R+4zX2a4+rzLea1pj6CV5h5bYl/K8
PTzvLnx2gL/BXiZwjtgtdo6q3FTvqN9qf+xaUb/Z9Vrv2M8MnFN0lC32b6k9
swpbT9XI2PsoRwPfEjv31poYFLtGVm2smuXH0DmNcpkY6YPeN/Za6KPfHP0e
5Tw8ezFtt8U+w3V2a867wN+Cy6G3Q/rFznmV626j/5Wxv7G+7cs6f3j3Mqn1
joFj0fv4XBk4Jv2ufCN2LVyqwGtntPZn4DW0Bf2/SKUCt32H/jN9KupbIRfG
ztmUq2lNZtHH0HZmzjXI5tg1hmqLVspvwBORVOezcoLYOYhyD9UcOosein1W
60zag36U/lXQOyD/ZPzZtF0sf8Z4QflD4li/MuuzdhZtFwU+cx8HP6U9ofcN
/FvqDNHZod/0jNQ1oGo/5VCPYnsMiQLv0VuVz8TObf/ifcaEjlmKVeJMdPbO
iL3WdAYvUH4PLqdvr/pD+SO4UIE5h2fR5yL19O0Cx7pXwPUDx7yToc9MnZXK
+Yoy3s7EXElH+q8EL4hde5+LNIr9jfVtNeeH6P8GuBF6j8B7YTG4ceA9sZP+
S2PnYm2Uv8SOsYqtl2JfFjvnUq51meId+krFUPTiyp9ix3DF7iban/RtmPjs
6cJ4H8WO+Yr1V9FWWO8e21cx/kjoGKrYqZi2RvEFqQ6uyxy2h45hil3ieHaH
XvNa6+JwLkLfhLQMXCPUjx2jFJtUs3wROyYrFrcOHPsUsxSrFAM/Ch1DFTvF
UfwndsxXrNeYil1bY/dVDPsp9Bmg2K8acFnoHFG5oWraY6HXqNamaogv0bch
hQPXxAdC7xntlUoS1tuLkXM15XDFwUPwaYLvr1rfsXNs5dZawyWUz9C2h28z
SDENfFbi2CCOoBi+pRPXwuKgSuJ7PLSvOLsTiiX4DAH30pqPXfOo1tEZNlCx
DTwgMIexAPxX7Lkq58om5iTERfTWN0vMIYk7Up+pir2JbTchR2LnADr7b0TO
isxJiYtSTa21pJipWKk1pbktVg4SeI4rpCMr0U/xzPfQ3xUWX0fbcvRlqqey
9hkYmxMUF6iYKFtB6lpKPgk4TZyriON7QbW0zm/si/T7q/ag7XrFe/wLoZ+W
OJfUnh2mWJCYG1QOMDI2JyAuQDHpQGxOSlyUxpjJ++yNHWsVo1qJT9Sa4zNN
1RpS7KVtMvpQ1RiJ95D2zgTa2iSuiVULrxA/odw8sq2oODdsLRNzPZORm7R3
kAcDn0HKBZWzKVdTTrgIfDUyBX0p0iTxO+td1acZuHlirnRpgXMlcbLiYpUz
rQKfw3gjtJ41/8Qch7iNYeDRoWs41W7iPMpiX8ic79D5rj0u/id27MjxzNci
c4TiBhUjn8V+MvbaVM40NnbMVqxWTGgee41pbWlPiQu5VDl1YE4kx7NWJl4b
+wLHvod1JgeOgZenjomKhcrZf1dsVjzK2aeK8uPEsf195KHInJe4LtXE5aUn
5pa0Bh9Ffyzx2t7JfJ9GfyYx9yvOeFbimlC14Ov6ZnoXrakCc7TPo89MbFsY
mFvriTwZmGM7gf5H4rNRbQ2Z//Xg6YpfzP8G9Edif0u13aj1hVRjfjnkXp7X
G/y09rPyt9BrXmt9lPYoc3uTMeflXeNNEH+FfY5ineIL9jfAy7UXA8eeP0Ln
BopB+nbKsZVb6xvOQF8XmWsIVGOg94vM9a+jf1/6torNNWbFvzD2c7G5l1dp
G5+YoxQ3qTn01V5LfDYqRxCXuJIx5gXmFB/Sbx0613kpMPc8JfFY4qCXxK7Z
VKvpzOuHbXzoXFYc6lDwEKQpY88Eb0Y/PTIXv1HxW2et9oz4K/AW9K2J9RFZ
c2uXRPYVx3Z/ZI5O3Nxx+nyC/ePEtbLuMEpE3oPae6pJlujZifeaYl5H9E7I
LnH3yEKtjcSxQnN4S+sJaZb1b7Ih8TfWt/0U2QjelFiXz/nY1ie+K1gj/pF3
HwCeEZgTGCO+JnFtrTsB5UbTQ38L5UhzE3Pq4tLfAK9DX5t4rDWBuZ5PE+vi
fCZH5qjFTYuj6Z/4DkF3B3qmavFtkWt91eS9Et856a5Ja3RU9L87n8A1Y83I
MUexRhxlffSnQnNnYwPfbVSn7Y7Adxw10Wskzu3V9lhqjlnccrO8a8OKsX8b
1YjiHltE5kLFQeoupn5k7lB3MuIWe0bORcQxtgB/I/4LPUV+SMz5iesTh1wI
e5o6lxenuCF0TFIsEmf5J/6nEsdycYDi9rTntNfE8ekurlvk2k53cuJGpqee
vzgS6dNSv4vatHdnJ97L2sO626iUOBbpjkO1ju5UdJeimmcR+PXUsUAxWdzh
sMixThyi7p5uicyl6Q5KtXaF2GeTam5xcU9E5prFyYXiPpCj4P2BubBpoblm
cWK6m1gTmpvQHYW4il8j352JsxCXppxdubo4NZ1N+dRj6YwS99of/+8Cc7DN
U98p6C5Bd04vY2tKW6h6Tmse/erUXJ/azkM/N3UsFCe3Bf/GqXNb7fmx4HKp
awe9g551FvhY4GeK23wmci4mjrMEuGTqWK0aqBT64MRcuPrMxrc8bYcC1zwP
6nxKffenmDWFuV8MVkEnzn4x/helrrUVs+cl5ozFFesOS9zGEdp2B+Y4xM3r
zk93feLof03MQYt7lo+49a7YdwXm2H/W3o59N6S2m7EdTLyXFWPqab0jd4NP
8hvMCF1jq7bWHcHqyGeOzhpxSC21nlKv/VH4F03NOYtr1jvfor6hY5fOOHGf
cyNzpeJAxWXpjNDZIE7rdvAIpEaBOY+h+p6pc5lyedf2w8Dl867xy6q+BZfN
O2eSbUhqX/ncKq4OeSBwzTxQ3Glq7l7P0F1ir9Bcnu4UdTenM0lnke7oxF22
D30XIQ5zALhfaq5Iz9zB+21PHPt1Z/1V4ppMtZhyEHGrWpNai+JYK2AvHvlu
XDlTtcR3FrqrGKkcBlw1sa4c9G3VtonvJnUnei56ucS51Z1ILfTaiXMp1Qji
IrdHjoXiJLW21Ee++gDiat+LXBuKs/2HatvE3KHuyC7S2Zo4t9YaWBb5Tkh3
QeJodTd1Z2QuQndUujuYFPnuQ3cIuvvvHpqb1N8AfBCbYxW3Kk6hJ/YeqdeW
OOCbUv9NgP4WoJT2MHrX1LWh7oxuVvxJbVOO3Cp1jaraVDFXXOyPkWtpcbLi
it+IzDWKMxZXfjgydyzOXHcDuvPTXZ/uCMStDw99lyCO/dXYHLW4adXcnRUb
U69tccS6y6sUmVvSnd682HfcuttWzd5H60lrjPHL5M299U6ti4PrqHiZ+G8v
iuTNlXRIrYszOahaG1w4b863feqcRrmM2sR1taHttLw5rxI8v2/qv73QM7+j
f7vUtXk7/aaRawTVBtoDbdFbp7ZpDN0Nv504l9Md8f8DU/dAlQ==
              "]]}]}, {
           EdgeForm[], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6], 
            Opacity[0.25]], 
           GraphicsGroupBox[{
             PolygonBox[CompressedData["
1:eJxNnXf81tP7x7Ppvt/7/TEyEqWozFCUkIyEREZ8E9l7ZW+yt3ztvWVv+tpb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              "]], 
             PolygonBox[CompressedData["
1:eJwtmnnATtX2xx8Zkuc9z3nP8CIkVCrd5hKRcrtRKKFbKQ00TyjSpEQaSNxC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              "]]}]}, {}, {}, {}, {}, {}}, {{
           Directive[
            AbsoluteThickness[1.6], 
            GrayLevel[0]], 
           LineBox[CompressedData["
1:eJwl2Hf8l9Mbx/EPbWVESEQZLaOErJKQGYootIeolDRUSGlQitCyCy0hae89
7BGKMjKTUWTP3/P9+P3xeryv6zrXOff3c59zrut+fCu3635Ftz0KhcKEooVC
NUYJdiPapmShcDWa4W28hZNwcmKSatMT8SbWFC8UrqK/4wVjc/hPs59nb8f0
vQqFr+m9Yu2M3c4fzn+VvUtsv1KFQlkcgP3RRXyn+Onow95Ie9MHzbmJPsZ/
HA/wn7HWaDoe1xm7lT+QfSfKsvfHPtgP+6IiJhrrb/4e9Gu6J72N7uPZbem7
1nmVHo+BGITN2IQGONwaR+AW+T3RCx9Y41yxhjgP0/hH06l0Lj1ZzmZ2A/YY
659tnWo4hF8Bh2JHfpecifRJeo7YE/QwOoAWpcVRDOda7yUcKD6bP5NdOrnm
/oF7PWM2HUHPMl4f9bBJztn0NfEx5lzJvgLf87+Q/wPtSf/L/rHn0nnYat40
eVvyzsVvyt/J75bfjU+tdQ7dRi+izeTUoePknEr3wbvGTqcb6Wn0fjnDjG9k
P4Z72A+IvcseTe/mv8x+BYfkfOQd0ONwPO7gT6DjMQ7X8L+jLfy9LXMe+afy
/6Cn0d/o6fQv2tTaf9Kz+J3Y1+N2c+5AdRwsfhCm+zv+4U+j/+bMiBVwH/98
/gX4EB/gObGGtDO903ojrX8cbpTfGYPF9xC/i1aj1VEVx6IGnsteYir7Jfoj
ZrB/omuwGi9af5H537O30uv4r9B3aB2ciubG7qM3ip9CK+FaXJPzLFaw5iB6
Q347js27zx0Qbyv+eZ5DF8n/jH25+Be0Eb0Ml+Ix47+Z+yjtQW9GPTkXZk+M
X0CvMtYEvfhL+P/iOfY/dC/5pVASf/PPoCWyjmfuMOcz+g3tTn9EL/zC/5L+
SnvTcqkX9Gf+OrqblqXHpXbl3eRceV6LnB+MYZenPfCW8a/N344vcbnYV3RU
zjYtL/dg3Ji/mf88XkBXsS5IobyF9kSP7KFn1si9Mb8CrS/3EHqDsc5ZJ3ec
f7Z4RVqeNsDh7PtSm1I32e/Ruvz3aTfj3fGgNccZe4gOoHdmz/EyishrhcfN
aZmaI/8o7I2N8ifRd+hEOkdOazk/sJ/EQvYuY9Oss5MuyB7Rn1Or5W5gr8hz
6Ej+L+KN+d+bey37YfpIzgBu5+8pZxF7cdbGUizBFvNr05NwIurIOyXnPXfH
WEt2q+xT6rTYs5iOn4xVte5Y8Sp0sNgQ3ISuqInXMUBe3dSuvG92cc94m55D
jxFrjVZYL7acrqPN8zvQiT0q50XuValL+d2pG3Q93Y2Hsgd4M+dU/C1ahc6g
t6cOYQC+yh2i/VOjjM/KPWSv9oxV7JV4wbNm4jv2s3K+zV3gt6VP8NvlHMqf
IjY1tZdfS3wuPZGOEDsmey2ncc4thhkrKTY0dy/vL/2XvYAOzl7QIfS69MLU
Kv5aWhp7p2eLl8n5Qv/M4Y81vwbamdc+v1H8v+wznZX6hBdzpsUqpIagBn5H
NznljE0w/wD6MH3S2k/gHmOH8ivk/uBW/jH0bvTLOeB3kreNfkw/SR3LvmKl
2DK6go7wnCbyG2OnufPyN4u9buxX/gnYwK9JX859oK/TWukn9DW8itvk/0h/
wi78jN3pFeLrPWsDDsgZSm1EGzRPr0y/oZfQizELL6KM9TfnewDvYRPex1i5
H9GPsRV15X1C96Nb6Jn0Q3oGvQuDcET2JN8w7CXspTnj7BFii603nr8k315i
35p7Ne2IDlgl3jT3FY/Kb5J+kt5qzhk4M99PGI12aI8q6IgOGJ5vKXOeNrcv
PQlve0Zt+g7tl/ovr2/ed2ozKoofhhNwcvqfsa7sLvFTf/Pb8t0kPlZ+DzqI
/0b2BvuKzZD7bGoWf5SxM/OtyF9El8u/h70svTc9Br35fVKfzV1uzgr0zz6l
V7Bb56wbX4c1OFqsN56S04v2Mr47PSTvw/hoVMJ845XplXKOpPPk3ZU43TO9
Lv3LnM38NbR4eqw5JdN/aYn0W/ogvV7OavlHZl9Sn+nNmGS8e85+7gXqpbbL
fYPWQhnje+Pa3F20yJnNN0y+37KvmMx+JHuDFub25R/OLofD5Ven62m1nCd6
Cl2Ev+TO8Iy/6WL+x7R9ziSdKu/T9AX6C35Fp9xha9+QOoQ3xN5KTUzPlvtH
+gvmYjYOyp2kM4yd6zlX0Iv4F+KCvAuxyqnleQf5jsTN+XZO3ZM7nD2bVrLO
QHZX9qfsmXRh6gL7EvFt+eagF+MijDd+f+o5uxmuwh78Vakf6a+5s+ldmZNv
GjySbxpaChNzZrM3dK+cEzTIPeD3j59v99R1nJWaze+Xd0PrZ15qcfoxvzPt
ghLYnjOS808vo+d7Bw1xHhbkXKFY9iV7gofNr57+ShvxL8VR+Agv5TfkruZ7
wN9+hHn/sIey76bX84fRyeZPwVN4Bk9jJ9oYb5qzjen4Um5b2pO2oWvzDlNf
cUWQ/w3dgTsxCAMxRF4fY0PTXzz7+Hw3pP7wL/T3zaJb6FZcjIXZIzohfT1n
ElXSo/GneFFzD0YfeU3llBe7Mt96/GXiS1EQe57/H7uMeaVxS/ppvlvpt/ke
zbcD+uAP/lf0z9QzemB6FPug9OF849FyeZfsA1MLaQe0z73Ld6j8z3EZLkWj
1Li8b/ov/s5744+TW4f9EfuU1Pn0X+vNT3819ix/eu4s/356lPWn0Er0yNQa
1MYY41Py7UJvyznBA+KTxUbT+1NTUFa8IcbnzqR3pJd6bt/UZkwyf4Gxp+jk
7B99hk4Rq8o+Dd2teRJ/vvg15jRHMzyU/ileM3uKOTnn4o/jsdztvCvUz33C
++iXXoAT8FrOac4h3Tf1n36e+0s/y73IPmXP0CS1AUejafY7fU5OEfNm5mzR
Ybg7/ZVfiw7OnfL8IbRmapD8lbQifxldgeUokt5irBi7m3W3s7fRr3O3jZVG
KYxKDRAfJW8k7sWu1Na8s9zF1HCxjuiAcblfYkNzrvh/oTVaoSUqp0fjjpyj
fDvnzuNyfCO+mM4V35Eawi6CTekReZfpL/QLus74WszKnUex9G3rF6V16XBa
tajfvKc+5GpsLqZm0Hrm1qNN0BH9MAqTMBfzMB8LsBCLsBhLsBTLsBwrsBKr
sBprsBbrsB4bMAcTMRJ90QGNURfVcCjKFv7/v6X/AaF5c+c=
            "]]}, {
           Directive[
            AbsoluteThickness[1.6], 
            GrayLevel[0]], 
           LineBox[CompressedData["
1:eJwl2HfYl2Mfx/FfkupuL6VdyiiRdlQUyigje4sQUZSMlFISykgIScgMkb2l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            "]]}}}], {{{}, {}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.368417, 0.506779, 0.709798]], 
          LineBox[CompressedData["
1:eJw123k8VP/3OHCEkrXNlsgSpQVFq5xSSikq+5IskShZSkL2rd2SnbJnzb4v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           "]]}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.880722, 0.611041, 0.142051]], 
          LineBox[CompressedData["
1:eJw122k4VG/YAHBF2YWyJFLImiVFEt2UFEkLJVT2SGXJliVLUYQISVLW7MvY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           "]]}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.368417, 0.506779, 0.709798]], 
          LineBox[CompressedData["
1:eJxl23c8V9//APA3IURkryRRCi00UIcoshKRRDbZsjfZ2XtkvgfZ2bytl83b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           "]]}}}, {{}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6], 
            PointSize[Large]], 
           PointBox[{{-0.1019367991845056, 0.}, {-0.1019367991845056, 0.}}]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6], 
            PointSize[Large]], 
           
           PointBox[{{0.1019367991845056, 0.}, {0.1019367991845056, 
            0.}}]}, {}}}, {}}, {{}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0, 1, 0]], 
           PointBox[{{-0.2, 0.2}, {-0.2, 0.2}}]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0.5, 0, 0.5]], 
           
           PointBox[{{0.4009867991845056, -0.014760560581880973`}, {
            0.4009867991845056, -0.014760560581880973`}}]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0.5, 0, 0.5]], 
           
           PointBox[{{-0.19711320081549427`, 
            0.014760560581881358`}, {-0.19711320081549427`, 
            0.014760560581881358`}}]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[1, 0, 0]], 
           PointBox[{{0., 0.}, {0., 0.}}]}, {}}}, {}}, {{{}, {}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJwsm3c41+/3x5VZmZEGn8hIVhnJdqzI3rPIlplRRBkpyd6SbG8zyd4cmzeV
Pd4NKZLSnrT8Xt/r+vnndT2u1/u+79c5z+c5933/4ZDTeVPX7VRUVIo0VFT/
e+bc/t8fGf//CaGt3FNKnmRkb9SNtcsjg/fn+QyKAhlvHu3pZC8iw2/Rva//
PRnBswrJBy0qyJDsy93/678RfPMzs1y0mQwhJLadnh+G0epGhm1YGxn0Vhk5
pruHcbfw0Xs9nWTYg+rx6WeH0Vh/4z/ufjJUv50pGC8cwj/BMuyHx8nAXcxX
y+o/hHLTdNE0U2RQob3ipa82hIMq+2/OzJDhrbW1Q+OLQVTf9Z+CzmMyCPxb
uafDN4jvF5w4o1fI4Pqk66rzlwF8uGfr8cdVMvy5dP/Xpb4BXF5nP6T/hgxX
I5atbzkNIO+RfmHKezLUpgzIk4r70e1oH8/JH2RQ7arZzAvoxxGhY7OKG2Sg
qnERzFDvx7unvtII/CLDuNZl0aCXfRitlvNo5C8ZgBSh6FTfhwNtO9yit8iQ
J3GLTy+qDzlz3gRIbxuF16raL9j5+vDqNPuaM80oSIVe+/D1cy8uP3hrsEo7
CmIGB1Qme3vxja+egC39KLy6K8V23bEX3/2RFODcOQrsj1+N2kj24senMQb2
u0ZhZbumtPi2XtyQbF+9xTgKcScaLz8s7MGr7tddnzOPgk97QWqOXw8et7+u
855lFNhE3/S6qvagyQ+JnHeso/BLM0zoGGsPflXotnzGNgousant7xFRWtYh
HHePQthDvz8hZxGFf+iyprOPgtG4vy71Vjd+iqrfZc0xCqv0vo9j87uxcG30
PPOeUTgjrfWSSaUbBxJWFZsJPlpll538rAtD+kP8jTiJ9ZrmpFjCulDlyxrr
Y4KLb5W+TuDuQheOhf2We0dhV0r3O4bOTlQSXI/vJ3jv0p5L10534h7eITe+
faNQMVKAf351oBoVU1UAwYVxxpsXcjqQrdfZopHgFTfu0+/kO3Dazvfca4Iz
+DItNSfb8cOe9zrM+0ehfujSwp1z7ejyWZVagGAZjxuCX7fa8GDdt/QjBLPz
hkXp3mrDbZzpv7kIVt3Gfbz4aBv+WCqT/0fM1/3oSfivwVbMtaAxHCe4RR7K
zexaUWhcXj6Z4JFZri/3vrXgD7XV38oEMylpk3YktKByYUXWEyKeUtpb2935
W1D6Kc/OcwTXji2ZDLU3I+PaW8tlIh/GQr/mhEyb8W9TRZgBwUV1rXPxb5pQ
SW4jvIzIZy/1l8wvkU341+HS6Q9E/qeaL9uc2deEwXwj7IIEf3UWdSPfb8Rn
vjcqdAm9NEhzVArajegmZ3rgLKHnEquZb81iA2r5j3o4EXpHTO+ZLWFqwBeb
iiQZwh99p+mtBUvrkf5oYAot4Z+HF3h77yrVo3XO1JkBwl99XTw2I151aLYS
nc1M+PENTx3bWeo6PFe2d0cOwyhYBff0/86pxTAPgzMchH+ZZ+2NUjLuY3gH
771Z6lH4x/W+95xpNYomXt8V/4cMfNYHummi7mKpxLfyRKKeOONNv9TWVeGf
KgGJCKLejMcTDiuxVWKac/7OY9/IsFA23CI2WYr1BRN7+96Sgfn8uo/NtlK0
a+JTV1ojw49D3iU5kiRM4n3pWvqKDM/UxGvPpBXj3ImIQs0lov9E5GQ8rcxH
vYPMu1uI/uHi9uHNnV15eOFOmWzlJBkadhY+SPC5gw/eWbvEPSJD99fEMHqp
bJx9+Jmyf4QMT8vV18O6UpF22jfQp53oB72jP86HBeJQwWbMmztkqBvaFqO8
5YlG+175s2eTwa/drGhmpz2+It2qPZpBBoWr1lV+kybQmLcmJZ9ABgvrLX0a
qyvQ0lGfm3+ZDIHm6qMvfqXBhOYn8Woror8NjvObBGUA/ccv19+ZkuFT7vdP
lz5ngkhNvvVBQzJIb3eM/LCaDQJKTyMtNclQ8vJVs82jfKis8uXfL0GGIEXq
cnntUoh5P6DxloYML7/ekInaXgaQb9insTUCFMnfKoVdZRCzbel90uYIXJZ7
yXFaugJmpT9Z/3o/Apzar3b1cN+FpvTiBcG5EWB7UzxwIbAWKkOOu0+VjMBW
zrHKdZFm0PExF8o9PgLmjtJ07deawck9+4aV+AjsON6T6/O0GTQXYzNoD4+A
Ece2xmuJLdC6JPJQfu8IsFt/k3f70AqLCWcOU28OA+/dkwceV3XAhKA873/t
w+A7T5LNutEDXHnT4wlSwzAxow98dT3w/XOiS5nwMLgodKzkPemBrAjyiQbe
YTDOl6pylugFtc67ZWXMxPjeRxmHKb1wRHJY5fubIegKSx27KNQPot/2r8rk
D8ENn/J32c2D4Kfov+TxdxAcjg/yWr4chIUfB4fZvgyCc8XDuj9MQ9Bf+uzC
3dVBKB3fdZnWdQiytx/TbBwfhNtF8nnbdw+DQ0vsTe6iQVCMgdY09xHwpDt7
2lBtEEJZUsy0qcbgJq3yd+/gATAdb9f+dWQM9hso3j/jOQDTjC2i6SZjMC7Z
Iw52A6DFlnwmqHgMIDrhzlP1AXBvqErfUn8AMieCJEKZBqDw5+9VuoiHMDQx
8Fm7sB+Ks27WybwcB92eoSCvzj7gfBk+dmX7BJwdLYvBmj7Y9XGVZop9Aiaf
/ty1o6gPpvx/C1qemIDpgz+TrkT3QafW430DoRMQJ11rv2rQB9qJKeFHt01C
01VloQdPe6GReUXqN/UUWE7Z+O772gMRdTW1DexT8LnjeYDISg9cpfU6Zc8/
BY84Y99JzfZAWag9KVZ9CpT7HJyEWnpg6W6rgFzkFPTbLRoUhPYQ+2no73cb
U+Ag+qCkdAvhuoxCyeXn0zD7PXpzF303nPGfWk75MA2KKH9KZaULbDou3Mr4
Ow36etB3prcLQqicxN25ZuAl9VCq/eUuOE5rTSVnOUPsy3+PXfrQCRnNCtqR
IzOw2Onou2+yAx4wfVe+NDcDrGqM1/bd6wDT82d226/MwAEGOlW62A6Ympk/
9nVrBr5o72K/q9oB4X30oH5iFug+WnVz32+H0x8j270KZmH02Yxk0802eGPh
r6NcPQs3lytY7ji3weYMSeBP6yysTZzm9FNpA8HC0DtqU7PwSC/q3+uvrXB3
ZD79LfUcGCyeesVm3wrv+dW+3nOegx+2+vIux1pAs/2g9BDHPFwzvCHZNNQI
C9r787bxzIPImIaMe2Ej7M+U4BARngdB6f4djKGNILJ5iUldeR7C2Vyjj4o3
Am/Xm9OJLvPQGWruSklrAPezj4/H358Hz1OKe56erofUFiH5jNZ5GPLNTB46
Xg/LkwfWYnuJ+aweu5Uy1QOH1Tkpxel54GP5kqqKdaDx9vHHxu/zYH19o/jj
oTpIP/dpmEp2AYbi294mjt6HIbbzYlMqC0C39NOa7vJ9uFTq9T5Zi3jfe+m+
p+h98M0y95+wWABev2dLP+NrQP4Vz4ZL4AJMnPJfFda/Bxxevh3zVQsQ7dtG
t59cBT1vC/O86xbgrqPprPulKlALE05637IAg+s57aVCVfBkpf5Gw8ACnKCf
y/gYXQk0tC/0jZ4tQK6o9P5etQowHmNd691JAdnhW59jmkuB9OGBezsLBebP
q/nZeZZCZL+LYREHBQy+rG4XOlgK0s7+OgoHKZCq3MxyK5oE5iTqkWwJCkj8
tr300awE7oUVG9HIUOBU5IK2J30J2IzVStjLU+CZcWDU4/ZiYCl13XiqRoHT
iakrdw4VQ/9lmfN0phSwuerKVP6hEMIPWaSvWFDgqF/f6mRRIVj9C6aus6GA
KLd91FfzQnigwtbL4UiBlZEBK9mgAoihuRVFf54CCzFCXxiY84AqcXbeKoAC
xWYtIjOBueDCctcr6yIFflyhz0qm3AGTZZdTi5cpcMR255kFUg7c/LyvPDuG
Auq21+k7FLLhYCBHn20cEd/RbXJshbfAs06BeVciBSY1rurY0t6C2JMm0ifS
KPCguNptaDwTWBNWGeoyKGBfuvbf2+OZUO/3ieHALQrctNVh2p6TAXXf715t
vkOBc4Y56ywu6YA3tv98k0eBbye5btCR08D41t6UXYUUqHZ8ef+LeBrY7Rs+
vJ9EgZRgF4Z7P1Pgbb9qi91dCoT6a9q77UmEidAUru33iO95ckUPF+Nh+wWp
rIwaCphaDDcwVMRBM3PL8LU6CvDbzJacV7gJbwtVLi/VU4Dboj0qiToGJi2d
VEQbKZCs8S2u8EE0HGQZeRfXTAGXJ5WDhfbXQHb7/ZmCFgqc/6FllCIUBR6/
Lg8WtxLjX1+uvfgpEpj8rnaltxH+eFAvXBIQAQJtuj0B7RTQ2HbUXocmDKaX
r0xDBwXK2Ac9nmeGgtLE8o9fBIucXSt3E7oE1O7aIqROCvR5/A1car0IIynn
fRS7KHC2zUPYUDcQHFxMxMcIXuZMGxMp9wNJp+8zJ7spsG58n2OT3hvKaTlc
7hI8vttSLa7XDSRGXR//JpipajON8bIjyIuWyMoioW/ej390HtZwjHT9sh3B
DYufvpBb9CCitq/Ul+ABMmXHxEURcJw82uJJcEZ+u+TwphJeHKGtMSE4x4je
OmvMBO1PGMfzE5xEH+dZZ30GdfPAaIlYT9D38JsnAc6Yc2Z5M4bgLZsLLmZt
53BpMDv+AMFxadlTbVs++NvetuYWEU+UXU4kXYk/PnM1sP1HxP9gXo1PQOsC
ymzVFpsQ/C0n2k/mTRDa/oyYTibyVRGi+kQ2IQRDp9TftxL5fTBwr1z42BXs
JIV9ekDkvyTDmW7HVDi6ZjU+GyP0MevZzuHZHolNskVNTYR+E2cyqgd2RSGJ
fXfI//StO1Vzid3uGkYFKA5+a6DA977D8nFb0fgpNc8ojvBHPPXNC7XGMZju
tTKyk/DPztFw/+Gim+iX/k0y6D4FnrZlmj36EotzG43xDwj/HZCyURnQiMeH
Cd7zTNUUoL2Ta1GRkYCxZyQ5FaooYNHE2hXyKhH3mMmjWQUF7MryjP8bT0L3
1Zv5DmUUOFxAHa5+KxnPF4z9cSD8vpP7TnDlsRR0vLfjsXkxBR7XJhmXp6eg
OH8b1958CjzP0/569XQqrl6yeUqbSfSHblHue2/TcJqRzbGYqEfhzNkBG8N0
/PT6jJ9UCuGf45Ksv+rSMfWXtqx4PAWeFIZrcoRkIL9jVHZiJAVksu2py+my
0Cxft3wojAL7VJrN1jyyUJre3+hrKAX075q9OfAwC2MkqAKFiP4xFCbXYZp+
C1/6Jar8PkcBnm1Sv2h5buPua2VtpoYUYPkTP6EtnYvHDpJ3UutR4L7RXNpm
Ui4GHqCrrNAm/MdBzXznbS62P3+8MK1K6CUq4VJdlIfVQf7KVVIUiKCUPN3O
UoAVgcIj1kS/9drTXnHkayGuk7rf2bMS/e2i05FA3iIUeu5x1ZaRAtt/wWqD
QREO2K1SS9FQ4FCGYtPeiiI8zNxw1+nrAowezHvgeqYYm9KjIh6ML4DY6H0D
2v4SlPzU3CwytgD8wqp3yj+WYA5f8/XwIWI/iH6WoMJNwuAS/090XcR+80rl
p85FEsoauFreqVwA/Z05gjOHS7F4K3JhJnIBJLkLJwpiypD9R/J8vtACuA07
SrpAJV74z9Fx+hCxPpVuR6pHJaZ3cmj/41oA9Dpzui69ElXP6EjLsi7A/omv
V4deV2Lvxue3MhvzcK48e+VkchUGOSa3eAzNw+cT+59df3IXx8l8SX2n50Fo
kznP5VwNvmfk4Sebz4P60/8GKlJqMJ/scn3IYB4ePaY69rS1Br/Gv28vhXnI
Z84OZt1xHxfkHzv+4JsH6hQ79+qK+0hW615ffj0HZ36kyxkF1OJlGZafjF5z
oGUXMulZXoczq9J6mk5zwMe5rLqjsw5te565+tvMwQq9mFruRB2KZ3bQ3NOe
gwAek+6CzTrMPbEUVcU/B/YWQVJcevVo9cK2qp8yC54+vQ0L6/X449TRy7dV
ZmFpkreEQ6ARJ7W592cenwWXjPydYrKNGPGcUzlGZBbk1GTcTug2osXwNykj
zlloVuMd4/drRKXf5dm+72dAXoaNzqGjEQ/Rpdh/vj0DlQVX2cyNmvCBfIyH
7LtpkDCop6d4N2MFvUnYxItpsPL8oMoS1ozmDW/ZnOanwZam47FcYjO+keOa
8e2bBj+n4zvd7jWjA7Ox7bHsaWi8/8FI6H0zapiweZqoT0Prix9Kyp4tKFzR
8V0zdQoUjB+LX7ZtRZkbNk2b0VOwfE32FKNHK2qf4movD52Cm0OVdcnBrUhD
f736o/MUpOxMNvHJaMVRc+XXx05MAUNc+XLUw1b0cVjVCqZMwi7dcxqsym2Y
UMB12pBrEiaU3mdcZmtHRScRtuPMk7DjSbO9DU870p22n9lNnKftyLPrguLt
yG29XNqxOgHjfmFH40+1Y5QDz/mOugmQXLH2jA5vx7a7hucua01AntA5Z8nX
7WjET83zQ24CHjp+CPj5tR3rLqb5e4pOwJaFP96l6kAajo9MqqwT8Epr/v3i
/g48erRTQbVhHBg0GZp89Yj3/jSjQXOPwDXocIbY3Q58fdaHpaL9EdCsP782
1dyB3QY/Kx/mP4Kka8oibn0dWLYxIvjD7RE8/mUYYknpQJUDHuLdPx7CUa3X
MrZ0ndi4S25FgeMhKMwZPHp9phPPsPDme2uPQQq1xssPvzuRbTBcbVZkDCp4
jubupu3CoDs0748zj4HDkM1rfuYuxJxxEmVmFHjnLu1n4e3Co0HnUtsdR0Hh
E9VJeo0ufH5i6ujbEDJY3U4JDYnuwgV+g4djZ8gQ6aEUEpjYhTxfOTNLgQwi
hmqVtpldSLp7/60aLRlGbNlvfCJ14S3+w308KSOw4ny7Xb6/CwuqomojScMQ
3nssX+VPF76xkux6f2MYGKouVu6g7sYXFpmHzD2GYbxkvKR3RzcuWIsqMx0d
BrlftJYbnN1YxGQ6KdUyBE5X3NUjJbpRjJz/+/TIIEQJWo/+ONuNcT8YnNyr
BuF5+b6PSa7dGDqyZOiTMAhUG7QD7F7dyHY+ht7DeBCaJO75Ll/sxkc2gXR8
CwMwabDfJieuG5/P/CVXrfaDh5LqbufabmzlEm/yH+0HvdjPfiGN3XhWXO/V
8Zp+sBAXnAxv7cYLHPpmtRf7obNGM8WypxvFK0V5wmj6oXFb15L8eDd++Xvn
rdBaH/QEUPhGprpRdmX90vhYH5QUP7Y9OdeNd0f4/tuT3gdDAZ1ljM+6Ma2i
RenKoT5wAsvoR2+6cUX14zwzLXFv3P3ZYOZdN/pK/mzIX+sF+V3TVOSPRHzh
fj7N93vhHymPJ+J7N9JFTucPK/cC44vSfQepEK+nWm+ePNQLA6ZTO+9sR3zf
m7+7j6YX6kwrntDRIi68dOtpGOuBfxJR7Hd3IMY9re0Nt+kBnamTDYK7Eadz
d4y9U+qBaN69Afs5EFvUOdhseHugxOUb9Z89iJdOnheweYRwdjvNncT9iMz/
3aYIZSK8/m6Yp8SFmHFj742vpxGE2ee9H3MjCs1t14h60w31/8Z9XvIgJvOc
SztZ2w2v3Gxy9Q8h3undbUUX3A0VYiZppXyIm+/DaweUu+Fzrobhe35Eq7kj
3ZE03dBK0/WIXxDRujqhQGGsCz7V6uzWOYx4okfowpfULrh1IXCvnRDi2+3M
oWd4ukBOeNXaRBjx3aXidebVTmDaPpIuKYIYZCQyidWdYHkwJp5KFPGci57u
+cBOcJdsUu0meC7zbtB/Cp2Q/mG5wVMMcaL308VRqk44uqP0Fa04otxQj3vQ
cAckHY+bSyaY92qv16GkDqAVEIxhOIp4eyK7aMy8A9bi6DfOE5yR9u7IRa4O
iOfuFx4imLbU6dDBl+2glvCGe9cxxD+vCquGKtrBIZFxSoXgWGmDFd/z7aAw
3aXjSHChF9MHzhPtIMiWfD2AYCnvmNfdf9rgwi+2a/9jY3bHT279bRCqvnDy
f79nAtUjLHFtkJgb+PB/8+05chSf6bWBUbX9J1qCHaIYnlQztcELv5jxVuJ7
In0kSFfGWwEmyr2sCGbcQa9hkNoKbrUhgy+I+EIuvH9+0KwVTH82P7MiWGlc
s+QzRytQxe9vaiPy807Ot2lwrgW8TU7r0xPMNTmqcie7BTIkTpBUiXyqtXS4
B9i2QACzS5crkf+pncXWetwtQDOZnx1E6OO6vih/eLEZtOwLTwQeQUy8NC1N
XdgMJ3L5sk8TevZMLvm+dGyGR37Pu44Rel/nPMc+wN8MjH0pFR8FEPuWzikk
lzeBd0DruBThn1OlJKYQjya4kVfM1MyLGDW9uO4q2gSyz86xCxL++/t2ylPn
fiOYS/mHDBF+PcVudEbVvxFa2YWebBB+Bn7DXwrSjVBaVEi/dx/i1Us2zxRb
GoD59FA/J1EP83+EAtVDGuCa6ar5Bhvih9W/lgaKDRCYVNcwyIJ431Ozyg/r
oc1L8hn/LkRK8ZM3n4frIHBZ9Nt7oj7VR67b8sTVgdPh33RH/3VjlpHKGVP9
Oqh9pvne5nc3Gm93byRP1IKd2jHZi0R931/00qRpvA+q15pm2ta6Ub1hha1X
7j68+hWcbf2qG/dyzSTHd9WAKcs7ueUX3djwxnxBd/geHMvRONj5uBsVndMU
Lj+5C5E7RJ5fGevGwYZAkRqHu/BX7uu70OFu/M17Su3zqypI5ub/5tLfjQVZ
DDyVnyohP57t75/2blQYvyO/RlcB3x4X2ylXduPtsKqltRMk+DHqGrY9qhut
Q6Yt7AZLgMntIg13WDdWiujwrxD3eNpaTj2BS0S/vOk/LOxfDIoa7XzbfLsx
V4BTNre6EOYY5A3eWXejJqNd4l3DHJDkq+eOF+1Gv5HCTC7f22C9n/p3qmA3
tnUfN2lNzIbB2MzhGB5iPabfL0MeZgEdWURWlZ3IF3fvRVGjdDB1Hu1d2exC
zSKXP34tN+Hqvsu7t4j9JyS0suDsnxvwlG2n9I/OLnR2/VPTohYNzw3j/J42
dWHPw/xX5Q+vAifndqug8i68yZI5oDl7EUjHA/KXYruwcf9faVFJSyz5FE6T
rteFfX5etutjibhYcTY/qa8T765cSqq/k4zmFT7e91s7sd/f8YN3UwpO/w7k
6arpRGcWs42ia2nYPE1tWJDTiWIXL0tLcWehckBlXIR/J85Jq7S7Kueha1Fj
VhNXJ3YZH3DezpuPe6JurZWzduLjC16pJ7cXoC4rQ3IMbSf6mo4kLzoVImuz
wA/mjx0owjeiLyFQjO+qEv6p9Haga2hH7u+8Ugw9KTgv4tSBfnOu/51mLEMc
T6T7YdGBXr2gEBtahjlM1+nu63Rg5yE1XmPLcvwcfOHWWwni/JHEWRW5qxKP
Xyh5dfNfO46HvaoS967GwvSVPo+sdmyI/afvGFWHta41fzdb2/AOa+wzjaY6
VJ64ZzVd1YbB/T6WO9fqMH7tnmJubhtyMT+NVDcgzrXJs0N/ItrwiCTpxBnO
BpR0Dfq8ebINvYsy9+0vacRjIoWz7x614k+LTvUnpS1oFTquuDHTgnr2fFZ/
iadq+bPTswMtSPNn03mLuhWPqFQrljS2YI1a+pdix1b8qyjlxpbRgn2/ohpd
uNowPigoW860BY31t8zabrbjjmcx/zrGmrGpulz/iU4X6p/dcWK5oQlT2vNF
Vvy7cOLoASe+kiaUdW6hf3S7C7WVU0Is0prQL+KKh+abLtRSzEq95deErZ35
AW03iLpq8wtKEGvC/j1xs3UdiB2Vt7LUihtRsyqdUkzXiyy8XLr/RTfgkbjv
F4v39eLdLt/OdwENqK7toJIq0otROxtN6xwasLBeSFzJsBe7gg7sOaDUgLE9
jsFDGb2Y9Tt6r9eXeqQzzHclHezDS8Ommhx29fhy/PZLdcF+vFV4lvxApA6F
t/994HGiH22TI37V7qnDheMX4y9r96O2Z/W3WKo6/F0QaXvWox8fNciFHZir
xRfV9AeEqvsRVH19WyJrkZT3c/We+AA2Hxm89bj8Pi7aBfKFKQ/gpf/cQ3Wu
3Mc4iQuxJwwGMMjlakuJ8X3sZXtx3917AEtiTjQc2KxBmWUv2b7KAeS7dGp8
j04NslbFUhvxDmKTtk+izatq5IB77J1HB7GnteJSfGs18iTL1+xWHsSz1hVx
VfHVyCylffaKzSAmsf/NqZWsxudg2q6aOog2uxSbnl+5izfO0uZF/xnEzsS/
bCssVXiPf69lX+8QupbudrESLsd8H3GZhAdD+OI5y2j03zJMjLRKU5sfIs4h
IQzlk2W4n8u0zvfdEBoOkC/0hZQhx/yjt5N7hvF0/fLcWXIpsY55eovLMG6u
iPyn50bCH2vSD074DuMRqos0DfIkvPxjWqwoeBh5Tuy0Y2Ei4WfiSiAbN4z7
8g1GShtKsDlPOvpczTAGsXSb6lOVoKfXr++UL8P4mzowPetWEZroefLv+D2M
G2vfYk08i5C+T4uPn3oET98qjNuuXISkxNrwvewj2PW7mlX7ZSGyHJPh2iY1
guqLPL/PiBWid4r4w2mvEWQ7sHmqLCwPa0L6p+4FjGBxqcjo90N5GAnubgEh
I/hU60vJ8aFc9GakFe24MYKGZueOX2XOxWtnpsZ1C0fQzPRj0un8HMy2D2k7
Oz6CBxfdbDU6buF/lqLlgzMjaO/p8y3A4RZ6nRAb5nw8gn92pLVk0t7CMRra
tNCVEZR7KBTZZJSF/ryX/2lvjBD+Eox3Xs5AzjJGEfq/Ixh9q3NR8mYGWnT0
nq/bRsbD3pZvvollIN1apPLwTjJesbj+1iYoHenTOhJ/cpGR4ZgHUylDGuo9
nZRh4SXjhbym2IP3UnHjzNJzNgEy6mi/0U0yScWv5hPiC6Jk3H9rw8kkJwV3
JD0LOKdARskR5qU5yyS8tjW5Na9MxsytORf5gkRkeHvFV0qNjIcUn9IkvE5A
OnMu/gptMtKJM73ddikeHelY27LMyJgzx3pWMfsmrsm+qbCzJKMX64Glw0sx
aJz+LJzFhoxlLBYptEdiUHcvE520PRl38OSy5bZEY/JidmqJAxln/y3sMN+6
jsWZZhtUzmRM/28kc5v2dXz9sMj1ijsZb14OTlOci8IP5uiR40FGqRq1iZH/
ovDjcR/dEi8yKv1I49J3vYr0+q25F8+TUeL1xHfvtQg8a5bJCP5k1I1lKlUK
DkcNp9fmXwPICBLDmb9pw1CedtCTO4iMepaH3HX5Q/HQ/r4TqcHEfLTLz57U
XULDsyPzny6RsclGsO+sajBqRP/TVwwl48DNt4tzjy7iVbn4TL/LZCwdOb6l
ZncByU9malOukHGVSvxD0XoANrj5598JI+P61r7gnyH+mOTZZZcaTsbWFi5X
DQY/LDbZ88E/gowz22vpmMR9cKFo2VA5kviewSb5azqeaNljEPmVYIuxvJ9v
Xd2R8o8rKuMqGctZ1uZORrng5YoXZrxRZKw4vOCbme+IVgxS37MIbtN0vtd8
0Q5jPApdNwi+LeynJ1VjhQJ7e0ia14h4BOxXC1dNUOeMQP1lguUbz9nsUjmF
AmZMgQUEH8oxsT7tLovhldEaVQQ7nQlb/DL3SyXA6zdPLsFLPDgt0acAjHtw
50WCHb14D/qu64BbEheNDMGLdCcjniiYwaX/nBmfEuuv6Tf0fo6wgbHrlfye
BM+vvNv4OXAW3A/I6T4n4rl3cdX4O40zxD7MjVQkeKSN5ZKjkBso6FDLhRPx
M6ZyvkEdD9jnshhQRuTL4Q71aSZvb8iSLn7cQuTTepv/A52k82B+hN28lsj3
Mb6wDTlrfwg58OZ5MqGHiuPBF2pvAqBCN0mShtDvMt3YV/FdQRBnt76RTehL
leJMz5IbDA+nds5xEPrXsfHPLomFwN7P4rO9gWT8KLE/3dTwCghdOLT5hfDT
P56RK58WwyDG55DsLj8y+rOpcFw+HwHtfb9pPxN+PFT+l0f41FWYDlO+3U34
9U8lnbshaxR83zWrF0j4eWfTp3/uC1FQ2LbAkeZExoOdBVxB567DtVgvl1Ir
MmosaS1/jIkBxj8WvNXmZPz58FN8pdFNuDxXtiPHhIz10XqXzfbGwngAo7eo
Hhnbp1SEg8riICPhzdojoj4vHvF59d4nHra6unJsNMkYPhK8bCaTANukfa6N
qZLxc5pwcfmfBIjb+5QkQNT7B3eDwrX+RJjVa6hwkyf8pXfJQtQkCewvqH3P
kyHqJSFn8kpKEpzkWDj9UJKMp74cPdw+ngRylY/XvomT8VWbh98yczLISuvk
coiQce+ybu2GQTJo1PMHiR0m/OAz9WozIRlo7bTrNA+ScbrubPBZ2hS4+a+E
6+QBMt6VP7uvVyAF0h8ZtSlzEv2F/EN/n2YKzPotpO5lJvKr/dmqPCoF+DzL
jvsS/TEOlOQ0t1IgZXvLVgXRX48+Lnjq/SMVXqsNtYXOjeAln3Hm3expMMGw
beLkFNG/WadY7h1LA4nLplwjZKJff+aRGjiXBq93z10Max1Bnr1xLy88ToMA
g0XLexkjqHytXXu6Ix204pYPSp8awV3icyUHgjLhc2OOsozGCO4I7V+3Tc2E
wWj5XZIqI9jU2s6UXJ0JCTW/uvYcH0Hn57FFUy8z4YcY/8N0nhEkFf4zHzTM
Anr+WVHX78N4U8F3QE/gFtjMOG0LyB3GZ2/9jlwYzAbaGxIL0lnDqK6XcE32
RTb4TL9o+pA8jHo9K+fe/skGKzPGW0bXhvFdzp/Yg8dvw5SL/rluj2E0+Z4p
2l10G+61ztCYywxjnPnigbGQHFDVmlYMGx7CnRTVp3ncucCjNat7rmcIjzdY
dR47kQtC3jYf9NuGkFWi/UuNUS5cSBKio747hFnJDTwXo3JBbzVriy9pCHUs
68sPvs4F66YCoxNmQxh+vYEyX50Hp/zKrR8sDGKU44nN88IFUAXc/+2bHMTx
6Z1/eFUL4DuPl649eZC4d6Tt7rYsAC1vy6+UtkHMVFxW7bxWAA3F+QzJOYM4
FpbGNPy0AKw/TaR9sx3ErYX+59dPFoLAp6vZE/MD+G9VzPnzeiHU/1uUCxwf
QLWfF+L/fi8E7gnrVdbhAZRWurT8b6sQlH++C1NuHsDjvsMML9iLYH0j//iZ
DOJ9m3Agn2IRUDkHn2s0GsDHQS95M2KKoOrBmYAfff1I9c5Nfse+YsjYsc2t
oL0f1QL3TR7gLQadpZ8kzfp+DLw1Y8t3pBi0lmDv9SLi/MdEL8UuVwyPHr01
mI/oR3uORN/LVsWQ9x1+TSn246kkiX+OGcWQlTMzqC7dj/kOnDcn7hRDwV3/
w/dF+nGKw7PzeEkxOIoFtYft70fXiHd7FuuK4YBTZMuXH33o+spSqPFRMSR4
Wpmr1vXhsEzSHU+6EohelyZ6fh/mbtlySTGVQJr6M6bGgj4s/+/Jro/sJWCb
qO3JldSH2xpuSOgcKgEwMq0c9OzD2dHr/OGKJRBm/C8pgb8PNz6uxbz2KYH7
lfm+dOm9eGRfA0PBaAkMi3hm8cX2otabuZSoiRLwLMkZV4zoRX/uCkGbuRJQ
+6Kf7OrVi4fil52evygBGeOXf7I0erGpfHu70UYJKBryOwZ/7cEzs/X6XXwk
eNzZ2+D+pgcbuqP+jguR4P0Bh6sWz3vw6xfBm7NiJJAT4qkQHutB8cNFPG3E
PfgRo9yzxuIevPxfDMNLHRLcPu9Yf8akB1kivum2+pBgZqfuhJB2D/ZELWn9
9CdBSa7S9CelHjQOif94JIgEzYJ9xVeO9OAeYYqiSzgJbjb2aGz8Q+TYPO+v
kESCTW9zDd+3iD2b568zp5Hg7n664KVZRN1ekvhsJgmczEbut1Ujfkpyl1XI
I8E7h3WKqi1iTJwvxekuCTRnUt/fPonIfETSaKyGmE/doeCjBOJ5h3zNw/Uk
YOUM3Z1Kj9gaL13S0EqC1rsDlfcau9FJynVJdJAEKh8LM2yYu1Hw/FW1lCck
GA8XG331qwsD9Izdvj0jwRMj3dHzr7tQw8ypWn+JiE+51zKspwsvcf3IpqyQ
wP234kJEQBfKMZx76vKeBH91Nm//tu9CbH/y1eMjCdrXTCIuEvfqcZrngs6f
SbCaZ/PCWaALUzMV5iS/kyAqx0lBbK4Tq/knjVX/kCD8vxzjHOLefYvRQHD1
LwnUty4u093vRLZNElPkFglS3QruPonpxJbdyZwp20uh49ixnxoXOnHF9oIM
HU0pMD1/vV7l0IklT5+4+NGWgkew9d8L8p34tG/+My9DKRwkmUosCHaipToa
uO8oBWOVX3IKuzvRVXK8uWhnKfioz/389bYDtTKY731hLAXqT/oDNvMduI8/
VW4Hcyl4p31Pa+nvwCirlw/ZWUphQ8nR2S+3A3lfZ+2mZSuFoZtul8dudqCF
nUHPOsFdxnx9ghc7UOD+pQtDu0vhXnOTeoRjB7J4qh/NZC8F96dqDAsGHZjJ
NfPOiqMUBpZf/yeh0IFyJlb3mfeUQuGHkaSYwx14Kfv7hTaCObJ6ao5vteNk
qjDdOmcpWAftvxC33o7v7HdP+O8tBb8Xkr3P59uxPLDz9juCxTZFio4PtGOU
nYnT6X2lYPdckCe2th23Kn8d6SZ4uUlD61luO+atvnjHsb8UkvJLD0nGtuNi
ocS9swQf7fDuvH6xHdXdWD3yCe452n5owbEdu/qreCYJvmCjZidq2I6Pz/FN
/CSYU6I5NFyhHa8dvxO6+0Ap5PlA9OThdvQX7uY5RPDXB9Q3Bdjb0Vb3eA8/
wVsMIknBW2347XbZmQMEdzxdKB5db8OfB7q/0xDMQi07+d9CG+6b4E9YJuZf
PuEl4D/QhiydkbzNBItJ55YP1LZh2ouwhisEP6n/5Lovrw2tNQZOyhJM8Uv2
9I4lxq/8mX9FxMt6pKCn52Ibxg5NeN4kODBdK3CPUxs6vF/7d5Dgbz7ViZ6G
bWhx+kNGJZG/KwE/D/QotOFB9jjxIwR/O214mFOoDQP3upJziPwfyznyeJy9
DZ0DdiTQECzCbMcdR9WG94WfjToRetWzPL5I9bgVxZKT8Q+ht6eNYHHnUCtq
1lQHyRF8wmTiRkhDK8bsCqo+R/jDrV+35HtCKzo6xWWVsZbC903uT40hrbj4
gF2/kfDbmqU5z0W3VrS0GopqJvzo8Oen4Qa0Il0Nf1A24dePIL9/19cWZE4W
vjFFXwoHvtkWTD1vQcbDbpbX6UrBFt+dvvOghdj/B6tFiPrwYncrlihrQV8+
zw/mRD0d/TMb52XTggeiG+Z4iHq0aMh/q6zVgkmu/m8u/iKBTMDLGTbpFpR/
rxfTs0GCmIilgG7GFqSbmXaTJup5iO/ZL9GeZhQUuz2UTPQDKSfSzK57zbgt
sEwjbp0EDDmfE97fbsYGgVHjkDdE//Li728ObEbPqsn/ZF6RwGZxp7ejUDM+
8NLL4H9KAk/RIw4mHM1IeyKopI9CAu9/EKOxrRntWpu0LedJsPjA6vbRJ014
TfqrxekpEujuHV/nTW7C23t7e58OkyDhH/cd/itNGOdoWMNL9LskmZ/jRzya
0OnoDbDpI4FDh/pXBY0mVLqy3bqikwSn1GdVIn424ty+uNvdtSSg+e/FYopD
I8bNNx96mEUCDr+gP4f1G/GCyfNx1nQSuJZTz/TINqKNxgdN7WTi98qWr7aY
GzGRakdSQgwJek+zbFV3NeCPX9Irl4JJIC/gHfmIqwEr+vyWHpuT4CjzB/sy
+ga8zZArqW9MAuPBypGor/V4PmE6oFaPBFZ7eAJ0xupRG2vHTdRJsJF+PJ7l
cj3+XBdU3DhKgpaeau24J3V4InfX/jlaEmSMf/pdO1yH/h7vC4KpSMDFzs/0
rKEOX4hQ1Bh/lwD33HjwyYQ6FOH6/Jr5Uwmk5LWNWCvX4VoZh0wopQS24Smx
jMJa3LO3Pe1dZQk8dzcT85ivwfvtv63s1UpAMmL5yVhDDX6kDuNcViiB9Ydl
qQopNfhme8xuu+Ml8GpI1EFJpwZffuCZlBAqgV/cnzqmO+7h2r5JshVjCZDo
PGmcS6qx7npiY9lMMfx0bvqUfKUK13zc0xztiuF5evueHNsqlDo8RJ1pUQw2
TwQa6+WqcKhg/Vi3QTHI0Q2VsXyvxDnborHPysUwx3vTLdS3En8nWGQt/lcM
+qxBnvwuFdjS/7B06kkR7GI1tNI8XYaFSS4cWsZF0CG6qZAqV4aLZ9SpgrWK
IFyNcf7znjJMKVZOylUqgrJsqawPE6XYPPGsYvBIEVgXbvYsaJfia7u/USlU
RRAfs2pwXZ6E/y6U8jDXFELUPyOGabFiVFWscqVQFYL4nuDqPsZi/MHKPGy5
XgC2kawDI++K8KqR8+CrmQKYHxEr3HevCGm57egGywuAy4zRkHy0CKMqv6nG
6RdAxIRfSuSJQgzQfTOtlJYPNw7IOtTcz8XfJ7N0q5nzYJrVrMMsJBdXJ/n+
u/AzFxJOjbQLaORixNMwbdGlXBBp8jmmO38HTz3tmHevywXN8UPCZdvuoMiq
cjCXWS7Qwtff7fa38ZzC0KmQ9DuwdOQo/X+KWfi2aHItkCEH2mteDPjuzEIz
4Sor9Y+34d8n/eaPlEx0Yq5d2zZ3G6hOjJMiQjLRoOdRlXnJbUhN4ht43J6B
Xp786rrKtyH/6fbKLK10/MccYxblmw07tM4GvolKQbsruzbihrKgV+XuuphN
CvYlfqM7VJ0FVExj/wqPpeBySn1qVWoW/GH4nHyiPRl1HihaZZ/Jgps1loZN
F5Iwutldd+lzJnG+WtMQ/xOPhqa6rMcOZAIKOBcLWcZgu78Tu5RTOjT+bDks
yBKDs6JLn8210uHJgcf0sSM3sGWuVMJHJB0S6LyiryvdwAH7W7vCv6SBrDPV
J0PhaHwy93ORLyoNTjVTZVpwXsMsh2mFGwWp8Fj20zev8HAM/SkspVqWDEpN
6eaPqMLxEWWOTsw9GRLyX3OLXQ9D20OiV6iPJEPSyQ97niRewbkk3Q8XK5Mg
eC7zPfO9UBypeBPkczcR0m6fNGflCsaVHeMGY3fj4VcPXbX+vSD0aaJLu+4V
D0mZNYKxqkHoGrnGKCYaD+rzW9XUnhfxFr+ovlZVHIzdHzaiJweihatkcHV5
LNzu1aaLb/FD30P2jc4FMeBveHvunY0fvo2qf8BuHwMCli/Lyn6dxwQ+SnMj
dwyYP4nnsU/yRT7R1Wry7Rvw6RZNmMEjLzw18m9WMz0aSIcvFUbWumGGj+CD
0mvXQF+Ln4+O0w11vcWlgtWuQcO016ucMFdkXBHlUtqKAk3vzaqvpi64aGDB
VxQaBWf/Ucd6czqhToBNx1O/q1D19Fpq7rYzOOCrmRLRHA4DI1JUPw+exto7
hpnl8uHgdmZM4QuxK+3M0bre3RkGabuSQx8mWGPeAV659r4r0Bsl+03I1AIl
sm0KPz0MhX0PL5u27jXCfe+8JW69CAIJo1gxYz955Fw86E5/zR/w5a89bz1l
MSBCzVTypD/QkXfHV3rLoH75DiUaBn/I0XNv0Y+WRDGepJb8ZD/gPmt2gG+3
AJpnhF3/rn8ejtvtu9hSwwTv1/xjFl96QYhvbdPigAKczqTWbFpxhb5jyqem
+ZSgK1KIyvCGK/hpM596HqoMEyeFruwQdoX5n1tifYyqMD/3rv2pvwt8PW5z
JCRWHbxdP0cXsjqDZckQjG7Xhh8RC2s7Ih0g2IhDMeWGNkyJc5n4SjnAza0Q
ljX6U4DD1i+Sx86C9TkWDW9qHXgubh9ZmG8PoepVXAWLulDMEnh7zvYMzHV/
8nkvagjXTT+Z6wtZQ/Q7zjzNBEPwfs5fbF9hBV6C5R8L3hrCQO21ZUZRK/hG
l1RxucgIvjFJHxKTsYTZ2b10CleM4exR5by/p83hlfKAgkOFCWQuDS3IfDKG
FNbwqf2jJhCz7dmfXbHG4FbI3EOzbgIvGIVklPiNoWVqODZExBQ2Sya4ZVsM
QYlH6IBYoSm05eWcmG7RA5HLBQrr58zAcyUz8NQxLWA145mIDzeDpXOh9OPx
J0FGh9c/Pt0MjDUjC6+/1QSjVdb82g4zcM65+cq5RgPYVHIPTtCYA8NWy4yG
kRpIRMdcK9tjDuf4wrvSO1VhpuqO0HtBgqt08l+IqgJfHveZKU1zqBLh/jzA
qwKCF+/9d+yKObzReMb0YEkeWGqtqdtvmkNk08UXhx/LQWdCYm5/hjkstir9
E56Xhc+yDIdt75pDFzjIbD2RgSbGm41vm8zBr7LXoXP5OHQm00pv6zGHIb/T
P39+kAbmez5Kw1PE71fUbvawSEGmQZpr6BNzSA5OT5cTlISFiiMd7cvm4Hpc
SIxWRQKmbp3Z9/aLOdDcqHiz8kUM5n6PqTzdNIeBdRPvbXKicHcpct2RygLe
aYnbXLkmDLJvBIrEGS1gKmv+7Snxw8C/PpIUxGYByR4W+pfiBUBHhPuBNacF
TL9zSu39yAeDe0LGZg9YQGGyVTa77SGo51bY+nDQAqwj90S0Z/DA4Zo2Simf
BcQ9LR89cJUblORNH/4WtAB79j0TgiH7gUncXv/LEQtQ38ao33aFE5o2ZMlx
ohYgd13xd308O+jvUmgeErcAlVDTnE+lrPBhuju6/JgF3I3aGivI2gUNvbxV
RyUt4J/viozdT1po0mjPtJOygJqAuvUZHypgIb9ql5G2AInbNx9e//pdhdLz
N76V4Lb3b69e91pVORrw1e41wfcj0p6eViKp/On6wTNEcG2kJP9G+nL3nS3J
ncYEm5jGL2rv+tbtz9DnEUvMz3jjVjaVwL9udZM9BoHE+hnx80paO2lQzFno
HbOEBVCuOFfWfmBAvtfvUu2OWoCyptVaGDIh5w3bWAcxC6jSZjoSpMKGv9Zc
/tsvYgFwM44rL50du1upbt8UIsYrzm+aPt+Dod6yWrUCFnD6gz+l+dA+3NOd
z5l6yAJ+XuWjX7I9gA0NFluiRL4/6LrxrMZx4+ckRcEoQo8yxR1fV+oO4rnU
Y/cyCL3USryE/7jzYsMf1k6X3Rbw/egj+vyAQ+imXrNNfYcFeA3wvn8Ryo9W
EtQyFTQWYChrfKvRXQBl6AsPLmyZQwJ+SH9mLIiPDH9EZH83Bxfpb+Fn9gkh
3zHTeyKfzOFCTbbn8A8hvDav8Cf2rTlUOwiV1E8ewb3eLPYNi8R4t6YL0mEi
aN7063n4gjk4bCwxPzEQRUYa0dQDhJ+vLcb+OcIlhgUZpLLBAXNIz52fX7wr
jtEXzhRQVZiD8XDioKOZBEbVckc4F5qD+dWUjrkaCYzoVM7JzSbqkToofoBB
Ejt3TwtkEPXGMp4YyNUqibsHzr4yizSH+8a73yQwSWEWe/i1d8HmELjz4NcY
Ryn0Pl34q8rNHPoyz0eI0krjTHunwJSdOZwuoD/71Fwab9+482jG3BzETMYS
hUqkMVRyUuO8ujk84w5Nz1M8jiol9tq7uM1BqIGVKfyMDObyWT7m3W0Oj/aW
mgQVyeBQlu0vTgbi+7ZC+IVfyWDtAadd5V/N4Gu2bMaDcycQuk2yXMlmcKNN
7b6Poyxusd5qTuo2A90/+53zcmXx4HR2S26DGTzWmP9QMieLy06V0R55ZkA6
ZNagoS2HbuPuY7PnzeCB3OMUKS55PLw1cVDGxQyOil5muGIgj8+XWi+HWZvB
0H/epJZweUw4lyw2pmoG6akOdWyL8qiuz+fizmoGL7KjN8pTFPDauN5fLhoz
+OCX7UVpV0Bxxx0WXT9N4Y+r6vSeFQXke0U5MLJoCo15nWsd0orIXvU+aGe1
KXzMpvrGOqKIDTe97LnyTcHbYe789HtFdGoOyNufYgp09cEvU3YrYYvv1X1L
gaZwpXO74k4bJTSS7DCqdDWFUpuzaw9ClZBS/3LG0coU4nR8uLLvKGGi01ks
VjAFj7dRRRaPlbByZJVHTMwUaiP+dhhuKOEdu56Bsv9MwUyCZd1ujzIKbpub
8KcyBZnPidse6CsjV2JSleegCXRnX9JVqFNGy+1XrsQ1m8Cu8eo0hRFlVGV+
/z2/3AQu51l9ObeojN0MI+HlsSbwq88j8zSDCt6je2OXG2oCzKFh5YLcKkjT
/vtajJcJmMY6+AofU0HYYDupbmAC3L8fdrwxVUH1yoiF3SrEfMc5NqudVXCv
jU7Ek6MmUP4h6EZzoArKTB1WtGQ1gR15m12lqSrIWGXxlmGbCVD5GPxLLlDB
yTzOF42fjUHromAHuVoF+X9cp2xOGYPzKnnu+KAKqngYXEzvN4ZNkdExzwkV
dN6zmCDUSLw/2+yx+VgFp65q+jSTjCHWv+L3yxUVJMskOatmGoOhUfsD4Q8q
mN060jkYbQxJq7RHJn6oYELqtiGtIGM4LFhqvfBPBVe1tR70uxnD7426Sk06
wFdOJG5lK2P4bKTltpcJcN5DmKZB2xhe7b1CMWUH3LnyclxQzhgaVXwMN/cB
ovXig8wjxqBeL83KdBBQxkj4FPV+Ywh0eOORwgfYZjiZ5LvDGARkK8qiDwPK
dQ0/uf/VCI4LxLF9FAaUZXzmEjFjBDf2VH5/JAb4MfuvqX6TEfE9B/OFjgH+
9ddU3ZtlBAGdtJa/JQC3Sh8MLQUZwUOD4HP6UoCBGnWRlVZGsJ6TyPufNOD0
OfFNfzkjMKV2LT5PsEb0rVCF/UYga8t49iTBfXLhXtS/DMHaQpaukBhfbxol
+/CxIZx/YWt+VRIwuFhTN7vDEE6sr9OuE+un/XRlcc01BNezZ+cXxQFvHIr5
Ih1mCK0iItH2ooAtH0+dpbU3hDX53jGvI8R7Sf1eiooh3Au57c4gCBjULHm9
jscQeueE9pw4BLjDMIc9kcoQXii/SPnBDVgyfPiJ9wsDGLyjcEuPyGfZl2At
kz4D4H9WsXKCyPeG4HNWvVIDMKyorj7ADEjJfXdH56YBBCy/USxlALz/TM/U
0tAAhLHNsvGPCjJ7D4m5ShpA/NvCJkVC75IhucOhHAZw6Y5n1PmPKsjjYTnT
8lgfEksMGV8uqaDTRRG5F136EBndlctPUcGkOe39u4v0IXN7q9reSRX04q2t
i3fXh97ljfMHelTQDH3HX3/Tg0NM6u9aclQwY9IgwnJBD+h6jfnqUlT+93/m
Hx516MGToW47txsqWDvvMPMsSg84p/ZMM/gT9VSmqR/Cpgd7RRWVdDRU0LpL
/uS0hC4c2dEllvFUGePsSyq/c+hCOlVFef8jZSy8JbEhsKkDH/3cXnT3KONT
qeCDd3t1QG6oPYKbpIx7PSq5T5vpwNpe9Q/J55Rx+wmNAb+QU7ApZx3L80YJ
xf3zTYPtT8HyaCjl0oISnkh28E7UOAWfHK523x1WwgCIm1xjOgWTd+s9ikqV
MGJbrKFDiTZIK3+QeXlWCYcUjmj4T2oB2U69/NwjRdxZd/A0dasWDKhmZXJ2
KmJzaJ9eWb4WsEkWL1VVKmKcRBINj7cWSMuTem5eV0QB1TtfntFrQfFK/m5h
eUUc6G5sKFY/CaEpi8bB+Qp4uCN6ZnBQAyxXHunR2snjsPu737dp1MBpYttY
dO8J/HTrb9KOD6qgziGs0Fp1Al13ij9KnleF/rGj8+v/F8MBPP6TNr+/OrJY
4KpAP6NO/x5YZja/a52mc5FSQD/5lLE/Tgs2v3nipN5dTD8/zyNinOxVNb9/
kK/cYrw8P37vAEzL7zO/YF+9y+weOD+d/IEev0Exv5YBP1HHLDE/4NkPAcy2
Kb+C4no9PRIxPwJX2cqEkym//LYtm9f3MD8Hi9nPYXApvzWu5RZ5wzA/MSl5
qogqKb/nEafXalwwPxPqBIWJoCi/yeqa5tApLz/W46jMUJMnv+DQiY+RPiw/
fKNyTcSTJb942O2qCBIsP+aNLPr5dCW/DikiWb/lKz+sB8rnUlYlvyalXk/q
jSs/8is+Q24ZJb9TC9zMLuEqP6TL8ClJoSS/KaCQWTOTKT+GCKwtgbcjv+4+
kwuCaik/2z1SH+OaI7/WJ/LVC0IpPwUOFkhnfiO/DNgnlc/xKD99AYX81UUj
v7mpbNwPVCg/2cgRskrWIr/XuKp5Ly0oP1dydR+8uiK/InEG+ocGKD9wMTgX
T58iv5VNS5biuSc/LVTkWtloIr8Mqk4r5JMnP8dpUoHQTSK/PCCklR1uJz/e
+Cjn6DIiv07M2JGOSCc/bFqqeSIYIr96ynncNiMnP3rnGCZ9/SG/ol4O6Q==

           "]]}}}}, {Axes -> True, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, DisplayFunction -> Identity, 
       Axes -> {False, False}, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 600, 
       Method -> {
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True}, 
       PlotRange -> {{-0.5294589531720199, 
        0.5294589531720199}, {-0.2140874331572753, 0.2140874331572753}}, 
       PlotRangeClipping -> True, PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      TagBox[
       GridBox[{{
          FormBox[
           
           TemplateBox[{"\"u = -1\"", "\"u = 1\""}, "SwatchLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    AbsoluteThickness[1], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.25]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    AbsoluteThickness[1], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.25]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), 
            InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = 
                    True; MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                    "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.25`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = 
                    True; MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                    "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.25`", "]"}]}], "]"}]}], "}"}], 
                 ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{"\"Ellips voor u = -1\"", "\"Ellips voor u = 1\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{
            "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(0\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(0\\)]\\))\"", 
             InterpretationBox[
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\))\"", 
              StringForm[
              "(\!\(\*SubscriptBox[\(x\), \(``\)]\),\!\(\*SubscriptBox[\(y\), \
\(``\)]\))", 1, 1], Editable -> False], 
             InterpretationBox[
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \
\\(\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\)]\\))\"", 
              StringForm[
              "(\!\(\*SubscriptBox[\(x\), \(``\)]\),\!\(\*SubscriptBox[\(y\), \
\(``\)]\))", 2, 2], Editable -> False], 
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(e\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(e\\)]\\))\""}, "PointLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[1, 0, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[1, 0, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), 
            InterpretationFunction :> (RowBox[{"PointLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                 ",", 
                 RowBox[{"Joined", "\[Rule]", 
                   RowBox[{"{", 
                    
                    RowBox[{
                    "False", ",", "False", ",", "False", ",", "False"}], 
                    "}"}]}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{"\"Simulatie\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwsm3c41+/3x5VZmZEGn8hIVhnJdqzI3rPIlplRRBkpyd6SbG8zyd4cmzeV
Pd4NKZLSnrT8Xt/r+vnndT2u1/u+79c5z+c5933/4ZDTeVPX7VRUVIo0VFT/
e+bc/t8fGf//CaGt3FNKnmRkb9SNtcsjg/fn+QyKAhlvHu3pZC8iw2/Rva//
PRnBswrJBy0qyJDsy93/678RfPMzs1y0mQwhJLadnh+G0epGhm1YGxn0Vhk5
pruHcbfw0Xs9nWTYg+rx6WeH0Vh/4z/ufjJUv50pGC8cwj/BMuyHx8nAXcxX
y+o/hHLTdNE0U2RQob3ipa82hIMq+2/OzJDhrbW1Q+OLQVTf9Z+CzmMyCPxb
uafDN4jvF5w4o1fI4Pqk66rzlwF8uGfr8cdVMvy5dP/Xpb4BXF5nP6T/hgxX
I5atbzkNIO+RfmHKezLUpgzIk4r70e1oH8/JH2RQ7arZzAvoxxGhY7OKG2Sg
qnERzFDvx7unvtII/CLDuNZl0aCXfRitlvNo5C8ZgBSh6FTfhwNtO9yit8iQ
J3GLTy+qDzlz3gRIbxuF16raL9j5+vDqNPuaM80oSIVe+/D1cy8uP3hrsEo7
CmIGB1Qme3vxja+egC39KLy6K8V23bEX3/2RFODcOQrsj1+N2kj24senMQb2
u0ZhZbumtPi2XtyQbF+9xTgKcScaLz8s7MGr7tddnzOPgk97QWqOXw8et7+u
855lFNhE3/S6qvagyQ+JnHeso/BLM0zoGGsPflXotnzGNgousant7xFRWtYh
HHePQthDvz8hZxGFf+iyprOPgtG4vy71Vjd+iqrfZc0xCqv0vo9j87uxcG30
PPOeUTgjrfWSSaUbBxJWFZsJPlpll538rAtD+kP8jTiJ9ZrmpFjCulDlyxrr
Y4KLb5W+TuDuQheOhf2We0dhV0r3O4bOTlQSXI/vJ3jv0p5L10534h7eITe+
faNQMVKAf351oBoVU1UAwYVxxpsXcjqQrdfZopHgFTfu0+/kO3Dazvfca4Iz
+DItNSfb8cOe9zrM+0ehfujSwp1z7ejyWZVagGAZjxuCX7fa8GDdt/QjBLPz
hkXp3mrDbZzpv7kIVt3Gfbz4aBv+WCqT/0fM1/3oSfivwVbMtaAxHCe4RR7K
zexaUWhcXj6Z4JFZri/3vrXgD7XV38oEMylpk3YktKByYUXWEyKeUtpb2935
W1D6Kc/OcwTXji2ZDLU3I+PaW8tlIh/GQr/mhEyb8W9TRZgBwUV1rXPxb5pQ
SW4jvIzIZy/1l8wvkU341+HS6Q9E/qeaL9uc2deEwXwj7IIEf3UWdSPfb8Rn
vjcqdAm9NEhzVArajegmZ3rgLKHnEquZb81iA2r5j3o4EXpHTO+ZLWFqwBeb
iiQZwh99p+mtBUvrkf5oYAot4Z+HF3h77yrVo3XO1JkBwl99XTw2I151aLYS
nc1M+PENTx3bWeo6PFe2d0cOwyhYBff0/86pxTAPgzMchH+ZZ+2NUjLuY3gH
771Z6lH4x/W+95xpNYomXt8V/4cMfNYHummi7mKpxLfyRKKeOONNv9TWVeGf
KgGJCKLejMcTDiuxVWKac/7OY9/IsFA23CI2WYr1BRN7+96Sgfn8uo/NtlK0
a+JTV1ojw49D3iU5kiRM4n3pWvqKDM/UxGvPpBXj3ImIQs0lov9E5GQ8rcxH
vYPMu1uI/uHi9uHNnV15eOFOmWzlJBkadhY+SPC5gw/eWbvEPSJD99fEMHqp
bJx9+Jmyf4QMT8vV18O6UpF22jfQp53oB72jP86HBeJQwWbMmztkqBvaFqO8
5YlG+175s2eTwa/drGhmpz2+It2qPZpBBoWr1lV+kybQmLcmJZ9ABgvrLX0a
qyvQ0lGfm3+ZDIHm6qMvfqXBhOYn8Woror8NjvObBGUA/ccv19+ZkuFT7vdP
lz5ngkhNvvVBQzJIb3eM/LCaDQJKTyMtNclQ8vJVs82jfKis8uXfL0GGIEXq
cnntUoh5P6DxloYML7/ekInaXgaQb9insTUCFMnfKoVdZRCzbel90uYIXJZ7
yXFaugJmpT9Z/3o/Apzar3b1cN+FpvTiBcG5EWB7UzxwIbAWKkOOu0+VjMBW
zrHKdZFm0PExF8o9PgLmjtJ07deawck9+4aV+AjsON6T6/O0GTQXYzNoD4+A
Ece2xmuJLdC6JPJQfu8IsFt/k3f70AqLCWcOU28OA+/dkwceV3XAhKA873/t
w+A7T5LNutEDXHnT4wlSwzAxow98dT3w/XOiS5nwMLgodKzkPemBrAjyiQbe
YTDOl6pylugFtc67ZWXMxPjeRxmHKb1wRHJY5fubIegKSx27KNQPot/2r8rk
D8ENn/J32c2D4Kfov+TxdxAcjg/yWr4chIUfB4fZvgyCc8XDuj9MQ9Bf+uzC
3dVBKB3fdZnWdQiytx/TbBwfhNtF8nnbdw+DQ0vsTe6iQVCMgdY09xHwpDt7
2lBtEEJZUsy0qcbgJq3yd+/gATAdb9f+dWQM9hso3j/jOQDTjC2i6SZjMC7Z
Iw52A6DFlnwmqHgMIDrhzlP1AXBvqErfUn8AMieCJEKZBqDw5+9VuoiHMDQx
8Fm7sB+Ks27WybwcB92eoSCvzj7gfBk+dmX7BJwdLYvBmj7Y9XGVZop9Aiaf
/ty1o6gPpvx/C1qemIDpgz+TrkT3QafW430DoRMQJ11rv2rQB9qJKeFHt01C
01VloQdPe6GReUXqN/UUWE7Z+O772gMRdTW1DexT8LnjeYDISg9cpfU6Zc8/
BY84Y99JzfZAWag9KVZ9CpT7HJyEWnpg6W6rgFzkFPTbLRoUhPYQ+2no73cb
U+Ag+qCkdAvhuoxCyeXn0zD7PXpzF303nPGfWk75MA2KKH9KZaULbDou3Mr4
Ow36etB3prcLQqicxN25ZuAl9VCq/eUuOE5rTSVnOUPsy3+PXfrQCRnNCtqR
IzOw2Onou2+yAx4wfVe+NDcDrGqM1/bd6wDT82d226/MwAEGOlW62A6Ympk/
9nVrBr5o72K/q9oB4X30oH5iFug+WnVz32+H0x8j270KZmH02Yxk0802eGPh
r6NcPQs3lytY7ji3weYMSeBP6yysTZzm9FNpA8HC0DtqU7PwSC/q3+uvrXB3
ZD79LfUcGCyeesVm3wrv+dW+3nOegx+2+vIux1pAs/2g9BDHPFwzvCHZNNQI
C9r787bxzIPImIaMe2Ej7M+U4BARngdB6f4djKGNILJ5iUldeR7C2Vyjj4o3
Am/Xm9OJLvPQGWruSklrAPezj4/H358Hz1OKe56erofUFiH5jNZ5GPLNTB46
Xg/LkwfWYnuJ+aweu5Uy1QOH1Tkpxel54GP5kqqKdaDx9vHHxu/zYH19o/jj
oTpIP/dpmEp2AYbi294mjt6HIbbzYlMqC0C39NOa7vJ9uFTq9T5Zi3jfe+m+
p+h98M0y95+wWABev2dLP+NrQP4Vz4ZL4AJMnPJfFda/Bxxevh3zVQsQ7dtG
t59cBT1vC/O86xbgrqPprPulKlALE05637IAg+s57aVCVfBkpf5Gw8ACnKCf
y/gYXQk0tC/0jZ4tQK6o9P5etQowHmNd691JAdnhW59jmkuB9OGBezsLBebP
q/nZeZZCZL+LYREHBQy+rG4XOlgK0s7+OgoHKZCq3MxyK5oE5iTqkWwJCkj8
tr300awE7oUVG9HIUOBU5IK2J30J2IzVStjLU+CZcWDU4/ZiYCl13XiqRoHT
iakrdw4VQ/9lmfN0phSwuerKVP6hEMIPWaSvWFDgqF/f6mRRIVj9C6aus6GA
KLd91FfzQnigwtbL4UiBlZEBK9mgAoihuRVFf54CCzFCXxiY84AqcXbeKoAC
xWYtIjOBueDCctcr6yIFflyhz0qm3AGTZZdTi5cpcMR255kFUg7c/LyvPDuG
Auq21+k7FLLhYCBHn20cEd/RbXJshbfAs06BeVciBSY1rurY0t6C2JMm0ifS
KPCguNptaDwTWBNWGeoyKGBfuvbf2+OZUO/3ieHALQrctNVh2p6TAXXf715t
vkOBc4Y56ywu6YA3tv98k0eBbye5btCR08D41t6UXYUUqHZ8ef+LeBrY7Rs+
vJ9EgZRgF4Z7P1Pgbb9qi91dCoT6a9q77UmEidAUru33iO95ckUPF+Nh+wWp
rIwaCphaDDcwVMRBM3PL8LU6CvDbzJacV7gJbwtVLi/VU4Dboj0qiToGJi2d
VEQbKZCs8S2u8EE0HGQZeRfXTAGXJ5WDhfbXQHb7/ZmCFgqc/6FllCIUBR6/
Lg8WtxLjX1+uvfgpEpj8rnaltxH+eFAvXBIQAQJtuj0B7RTQ2HbUXocmDKaX
r0xDBwXK2Ac9nmeGgtLE8o9fBIucXSt3E7oE1O7aIqROCvR5/A1car0IIynn
fRS7KHC2zUPYUDcQHFxMxMcIXuZMGxMp9wNJp+8zJ7spsG58n2OT3hvKaTlc
7hI8vttSLa7XDSRGXR//JpipajON8bIjyIuWyMoioW/ej390HtZwjHT9sh3B
DYufvpBb9CCitq/Ul+ABMmXHxEURcJw82uJJcEZ+u+TwphJeHKGtMSE4x4je
OmvMBO1PGMfzE5xEH+dZZ30GdfPAaIlYT9D38JsnAc6Yc2Z5M4bgLZsLLmZt
53BpMDv+AMFxadlTbVs++NvetuYWEU+UXU4kXYk/PnM1sP1HxP9gXo1PQOsC
ymzVFpsQ/C0n2k/mTRDa/oyYTibyVRGi+kQ2IQRDp9TftxL5fTBwr1z42BXs
JIV9ekDkvyTDmW7HVDi6ZjU+GyP0MevZzuHZHolNskVNTYR+E2cyqgd2RSGJ
fXfI//StO1Vzid3uGkYFKA5+a6DA977D8nFb0fgpNc8ojvBHPPXNC7XGMZju
tTKyk/DPztFw/+Gim+iX/k0y6D4FnrZlmj36EotzG43xDwj/HZCyURnQiMeH
Cd7zTNUUoL2Ta1GRkYCxZyQ5FaooYNHE2hXyKhH3mMmjWQUF7MryjP8bT0L3
1Zv5DmUUOFxAHa5+KxnPF4z9cSD8vpP7TnDlsRR0vLfjsXkxBR7XJhmXp6eg
OH8b1958CjzP0/569XQqrl6yeUqbSfSHblHue2/TcJqRzbGYqEfhzNkBG8N0
/PT6jJ9UCuGf45Ksv+rSMfWXtqx4PAWeFIZrcoRkIL9jVHZiJAVksu2py+my
0Cxft3wojAL7VJrN1jyyUJre3+hrKAX075q9OfAwC2MkqAKFiP4xFCbXYZp+
C1/6Jar8PkcBnm1Sv2h5buPua2VtpoYUYPkTP6EtnYvHDpJ3UutR4L7RXNpm
Ui4GHqCrrNAm/MdBzXznbS62P3+8MK1K6CUq4VJdlIfVQf7KVVIUiKCUPN3O
UoAVgcIj1kS/9drTXnHkayGuk7rf2bMS/e2i05FA3iIUeu5x1ZaRAtt/wWqD
QREO2K1SS9FQ4FCGYtPeiiI8zNxw1+nrAowezHvgeqYYm9KjIh6ML4DY6H0D
2v4SlPzU3CwytgD8wqp3yj+WYA5f8/XwIWI/iH6WoMJNwuAS/090XcR+80rl
p85FEsoauFreqVwA/Z05gjOHS7F4K3JhJnIBJLkLJwpiypD9R/J8vtACuA07
SrpAJV74z9Fx+hCxPpVuR6pHJaZ3cmj/41oA9Dpzui69ElXP6EjLsi7A/omv
V4deV2Lvxue3MhvzcK48e+VkchUGOSa3eAzNw+cT+59df3IXx8l8SX2n50Fo
kznP5VwNvmfk4Sebz4P60/8GKlJqMJ/scn3IYB4ePaY69rS1Br/Gv28vhXnI
Z84OZt1xHxfkHzv+4JsH6hQ79+qK+0hW615ffj0HZ36kyxkF1OJlGZafjF5z
oGUXMulZXoczq9J6mk5zwMe5rLqjsw5te565+tvMwQq9mFruRB2KZ3bQ3NOe
gwAek+6CzTrMPbEUVcU/B/YWQVJcevVo9cK2qp8yC54+vQ0L6/X449TRy7dV
ZmFpkreEQ6ARJ7W592cenwWXjPydYrKNGPGcUzlGZBbk1GTcTug2osXwNykj
zlloVuMd4/drRKXf5dm+72dAXoaNzqGjEQ/Rpdh/vj0DlQVX2cyNmvCBfIyH
7LtpkDCop6d4N2MFvUnYxItpsPL8oMoS1ozmDW/ZnOanwZam47FcYjO+keOa
8e2bBj+n4zvd7jWjA7Ox7bHsaWi8/8FI6H0zapiweZqoT0Prix9Kyp4tKFzR
8V0zdQoUjB+LX7ZtRZkbNk2b0VOwfE32FKNHK2qf4movD52Cm0OVdcnBrUhD
f736o/MUpOxMNvHJaMVRc+XXx05MAUNc+XLUw1b0cVjVCqZMwi7dcxqsym2Y
UMB12pBrEiaU3mdcZmtHRScRtuPMk7DjSbO9DU870p22n9lNnKftyLPrguLt
yG29XNqxOgHjfmFH40+1Y5QDz/mOugmQXLH2jA5vx7a7hucua01AntA5Z8nX
7WjET83zQ24CHjp+CPj5tR3rLqb5e4pOwJaFP96l6kAajo9MqqwT8Epr/v3i
/g48erRTQbVhHBg0GZp89Yj3/jSjQXOPwDXocIbY3Q58fdaHpaL9EdCsP782
1dyB3QY/Kx/mP4Kka8oibn0dWLYxIvjD7RE8/mUYYknpQJUDHuLdPx7CUa3X
MrZ0ndi4S25FgeMhKMwZPHp9phPPsPDme2uPQQq1xssPvzuRbTBcbVZkDCp4
jubupu3CoDs0748zj4HDkM1rfuYuxJxxEmVmFHjnLu1n4e3Co0HnUtsdR0Hh
E9VJeo0ufH5i6ujbEDJY3U4JDYnuwgV+g4djZ8gQ6aEUEpjYhTxfOTNLgQwi
hmqVtpldSLp7/60aLRlGbNlvfCJ14S3+w308KSOw4ny7Xb6/CwuqomojScMQ
3nssX+VPF76xkux6f2MYGKouVu6g7sYXFpmHzD2GYbxkvKR3RzcuWIsqMx0d
BrlftJYbnN1YxGQ6KdUyBE5X3NUjJbpRjJz/+/TIIEQJWo/+ONuNcT8YnNyr
BuF5+b6PSa7dGDqyZOiTMAhUG7QD7F7dyHY+ht7DeBCaJO75Ll/sxkc2gXR8
CwMwabDfJieuG5/P/CVXrfaDh5LqbufabmzlEm/yH+0HvdjPfiGN3XhWXO/V
8Zp+sBAXnAxv7cYLHPpmtRf7obNGM8WypxvFK0V5wmj6oXFb15L8eDd++Xvn
rdBaH/QEUPhGprpRdmX90vhYH5QUP7Y9OdeNd0f4/tuT3gdDAZ1ljM+6Ma2i
RenKoT5wAsvoR2+6cUX14zwzLXFv3P3ZYOZdN/pK/mzIX+sF+V3TVOSPRHzh
fj7N93vhHymPJ+J7N9JFTucPK/cC44vSfQepEK+nWm+ePNQLA6ZTO+9sR3zf
m7+7j6YX6kwrntDRIi68dOtpGOuBfxJR7Hd3IMY9re0Nt+kBnamTDYK7Eadz
d4y9U+qBaN69Afs5EFvUOdhseHugxOUb9Z89iJdOnheweYRwdjvNncT9iMz/
3aYIZSK8/m6Yp8SFmHFj742vpxGE2ee9H3MjCs1t14h60w31/8Z9XvIgJvOc
SztZ2w2v3Gxy9Q8h3undbUUX3A0VYiZppXyIm+/DaweUu+Fzrobhe35Eq7kj
3ZE03dBK0/WIXxDRujqhQGGsCz7V6uzWOYx4okfowpfULrh1IXCvnRDi2+3M
oWd4ukBOeNXaRBjx3aXidebVTmDaPpIuKYIYZCQyidWdYHkwJp5KFPGci57u
+cBOcJdsUu0meC7zbtB/Cp2Q/mG5wVMMcaL308VRqk44uqP0Fa04otxQj3vQ
cAckHY+bSyaY92qv16GkDqAVEIxhOIp4eyK7aMy8A9bi6DfOE5yR9u7IRa4O
iOfuFx4imLbU6dDBl+2glvCGe9cxxD+vCquGKtrBIZFxSoXgWGmDFd/z7aAw
3aXjSHChF9MHzhPtIMiWfD2AYCnvmNfdf9rgwi+2a/9jY3bHT279bRCqvnDy
f79nAtUjLHFtkJgb+PB/8+05chSf6bWBUbX9J1qCHaIYnlQztcELv5jxVuJ7
In0kSFfGWwEmyr2sCGbcQa9hkNoKbrUhgy+I+EIuvH9+0KwVTH82P7MiWGlc
s+QzRytQxe9vaiPy807Ot2lwrgW8TU7r0xPMNTmqcie7BTIkTpBUiXyqtXS4
B9i2QACzS5crkf+pncXWetwtQDOZnx1E6OO6vih/eLEZtOwLTwQeQUy8NC1N
XdgMJ3L5sk8TevZMLvm+dGyGR37Pu44Rel/nPMc+wN8MjH0pFR8FEPuWzikk
lzeBd0DruBThn1OlJKYQjya4kVfM1MyLGDW9uO4q2gSyz86xCxL++/t2ylPn
fiOYS/mHDBF+PcVudEbVvxFa2YWebBB+Bn7DXwrSjVBaVEi/dx/i1Us2zxRb
GoD59FA/J1EP83+EAtVDGuCa6ar5Bhvih9W/lgaKDRCYVNcwyIJ431Ozyg/r
oc1L8hn/LkRK8ZM3n4frIHBZ9Nt7oj7VR67b8sTVgdPh33RH/3VjlpHKGVP9
Oqh9pvne5nc3Gm93byRP1IKd2jHZi0R931/00qRpvA+q15pm2ta6Ub1hha1X
7j68+hWcbf2qG/dyzSTHd9WAKcs7ueUX3djwxnxBd/geHMvRONj5uBsVndMU
Lj+5C5E7RJ5fGevGwYZAkRqHu/BX7uu70OFu/M17Su3zqypI5ub/5tLfjQVZ
DDyVnyohP57t75/2blQYvyO/RlcB3x4X2ylXduPtsKqltRMk+DHqGrY9qhut
Q6Yt7AZLgMntIg13WDdWiujwrxD3eNpaTj2BS0S/vOk/LOxfDIoa7XzbfLsx
V4BTNre6EOYY5A3eWXejJqNd4l3DHJDkq+eOF+1Gv5HCTC7f22C9n/p3qmA3
tnUfN2lNzIbB2MzhGB5iPabfL0MeZgEdWURWlZ3IF3fvRVGjdDB1Hu1d2exC
zSKXP34tN+Hqvsu7t4j9JyS0suDsnxvwlG2n9I/OLnR2/VPTohYNzw3j/J42
dWHPw/xX5Q+vAifndqug8i68yZI5oDl7EUjHA/KXYruwcf9faVFJSyz5FE6T
rteFfX5etutjibhYcTY/qa8T765cSqq/k4zmFT7e91s7sd/f8YN3UwpO/w7k
6arpRGcWs42ia2nYPE1tWJDTiWIXL0tLcWehckBlXIR/J85Jq7S7Kueha1Fj
VhNXJ3YZH3DezpuPe6JurZWzduLjC16pJ7cXoC4rQ3IMbSf6mo4kLzoVImuz
wA/mjx0owjeiLyFQjO+qEv6p9Haga2hH7u+8Ugw9KTgv4tSBfnOu/51mLEMc
T6T7YdGBXr2gEBtahjlM1+nu63Rg5yE1XmPLcvwcfOHWWwni/JHEWRW5qxKP
Xyh5dfNfO46HvaoS967GwvSVPo+sdmyI/afvGFWHta41fzdb2/AOa+wzjaY6
VJ64ZzVd1YbB/T6WO9fqMH7tnmJubhtyMT+NVDcgzrXJs0N/ItrwiCTpxBnO
BpR0Dfq8ebINvYsy9+0vacRjIoWz7x614k+LTvUnpS1oFTquuDHTgnr2fFZ/
iadq+bPTswMtSPNn03mLuhWPqFQrljS2YI1a+pdix1b8qyjlxpbRgn2/ohpd
uNowPigoW860BY31t8zabrbjjmcx/zrGmrGpulz/iU4X6p/dcWK5oQlT2vNF
Vvy7cOLoASe+kiaUdW6hf3S7C7WVU0Is0prQL+KKh+abLtRSzEq95deErZ35
AW03iLpq8wtKEGvC/j1xs3UdiB2Vt7LUihtRsyqdUkzXiyy8XLr/RTfgkbjv
F4v39eLdLt/OdwENqK7toJIq0otROxtN6xwasLBeSFzJsBe7gg7sOaDUgLE9
jsFDGb2Y9Tt6r9eXeqQzzHclHezDS8Ommhx29fhy/PZLdcF+vFV4lvxApA6F
t/994HGiH22TI37V7qnDheMX4y9r96O2Z/W3WKo6/F0QaXvWox8fNciFHZir
xRfV9AeEqvsRVH19WyJrkZT3c/We+AA2Hxm89bj8Pi7aBfKFKQ/gpf/cQ3Wu
3Mc4iQuxJwwGMMjlakuJ8X3sZXtx3917AEtiTjQc2KxBmWUv2b7KAeS7dGp8
j04NslbFUhvxDmKTtk+izatq5IB77J1HB7GnteJSfGs18iTL1+xWHsSz1hVx
VfHVyCylffaKzSAmsf/NqZWsxudg2q6aOog2uxSbnl+5izfO0uZF/xnEzsS/
bCssVXiPf69lX+8QupbudrESLsd8H3GZhAdD+OI5y2j03zJMjLRKU5sfIs4h
IQzlk2W4n8u0zvfdEBoOkC/0hZQhx/yjt5N7hvF0/fLcWXIpsY55eovLMG6u
iPyn50bCH2vSD074DuMRqos0DfIkvPxjWqwoeBh5Tuy0Y2Ei4WfiSiAbN4z7
8g1GShtKsDlPOvpczTAGsXSb6lOVoKfXr++UL8P4mzowPetWEZroefLv+D2M
G2vfYk08i5C+T4uPn3oET98qjNuuXISkxNrwvewj2PW7mlX7ZSGyHJPh2iY1
guqLPL/PiBWid4r4w2mvEWQ7sHmqLCwPa0L6p+4FjGBxqcjo90N5GAnubgEh
I/hU60vJ8aFc9GakFe24MYKGZueOX2XOxWtnpsZ1C0fQzPRj0un8HMy2D2k7
Oz6CBxfdbDU6buF/lqLlgzMjaO/p8y3A4RZ6nRAb5nw8gn92pLVk0t7CMRra
tNCVEZR7KBTZZJSF/ryX/2lvjBD+Eox3Xs5AzjJGEfq/Ixh9q3NR8mYGWnT0
nq/bRsbD3pZvvollIN1apPLwTjJesbj+1iYoHenTOhJ/cpGR4ZgHUylDGuo9
nZRh4SXjhbym2IP3UnHjzNJzNgEy6mi/0U0yScWv5hPiC6Jk3H9rw8kkJwV3
JD0LOKdARskR5qU5yyS8tjW5Na9MxsytORf5gkRkeHvFV0qNjIcUn9IkvE5A
OnMu/gptMtKJM73ddikeHelY27LMyJgzx3pWMfsmrsm+qbCzJKMX64Glw0sx
aJz+LJzFhoxlLBYptEdiUHcvE520PRl38OSy5bZEY/JidmqJAxln/y3sMN+6
jsWZZhtUzmRM/28kc5v2dXz9sMj1ijsZb14OTlOci8IP5uiR40FGqRq1iZH/
ovDjcR/dEi8yKv1I49J3vYr0+q25F8+TUeL1xHfvtQg8a5bJCP5k1I1lKlUK
DkcNp9fmXwPICBLDmb9pw1CedtCTO4iMepaH3HX5Q/HQ/r4TqcHEfLTLz57U
XULDsyPzny6RsclGsO+sajBqRP/TVwwl48DNt4tzjy7iVbn4TL/LZCwdOb6l
ZncByU9malOukHGVSvxD0XoANrj5598JI+P61r7gnyH+mOTZZZcaTsbWFi5X
DQY/LDbZ88E/gowz22vpmMR9cKFo2VA5kviewSb5azqeaNljEPmVYIuxvJ9v
Xd2R8o8rKuMqGctZ1uZORrng5YoXZrxRZKw4vOCbme+IVgxS37MIbtN0vtd8
0Q5jPApdNwi+LeynJ1VjhQJ7e0ia14h4BOxXC1dNUOeMQP1lguUbz9nsUjmF
AmZMgQUEH8oxsT7tLovhldEaVQQ7nQlb/DL3SyXA6zdPLsFLPDgt0acAjHtw
50WCHb14D/qu64BbEheNDMGLdCcjniiYwaX/nBmfEuuv6Tf0fo6wgbHrlfye
BM+vvNv4OXAW3A/I6T4n4rl3cdX4O40zxD7MjVQkeKSN5ZKjkBso6FDLhRPx
M6ZyvkEdD9jnshhQRuTL4Q71aSZvb8iSLn7cQuTTepv/A52k82B+hN28lsj3
Mb6wDTlrfwg58OZ5MqGHiuPBF2pvAqBCN0mShtDvMt3YV/FdQRBnt76RTehL
leJMz5IbDA+nds5xEPrXsfHPLomFwN7P4rO9gWT8KLE/3dTwCghdOLT5hfDT
P56RK58WwyDG55DsLj8y+rOpcFw+HwHtfb9pPxN+PFT+l0f41FWYDlO+3U34
9U8lnbshaxR83zWrF0j4eWfTp3/uC1FQ2LbAkeZExoOdBVxB567DtVgvl1Ir
MmosaS1/jIkBxj8WvNXmZPz58FN8pdFNuDxXtiPHhIz10XqXzfbGwngAo7eo
Hhnbp1SEg8riICPhzdojoj4vHvF59d4nHra6unJsNMkYPhK8bCaTANukfa6N
qZLxc5pwcfmfBIjb+5QkQNT7B3eDwrX+RJjVa6hwkyf8pXfJQtQkCewvqH3P
kyHqJSFn8kpKEpzkWDj9UJKMp74cPdw+ngRylY/XvomT8VWbh98yczLISuvk
coiQce+ybu2GQTJo1PMHiR0m/OAz9WozIRlo7bTrNA+ScbrubPBZ2hS4+a+E
6+QBMt6VP7uvVyAF0h8ZtSlzEv2F/EN/n2YKzPotpO5lJvKr/dmqPCoF+DzL
jvsS/TEOlOQ0t1IgZXvLVgXRX48+Lnjq/SMVXqsNtYXOjeAln3Hm3expMMGw
beLkFNG/WadY7h1LA4nLplwjZKJff+aRGjiXBq93z10Max1Bnr1xLy88ToMA
g0XLexkjqHytXXu6Ix204pYPSp8awV3icyUHgjLhc2OOsozGCO4I7V+3Tc2E
wWj5XZIqI9jU2s6UXJ0JCTW/uvYcH0Hn57FFUy8z4YcY/8N0nhEkFf4zHzTM
Anr+WVHX78N4U8F3QE/gFtjMOG0LyB3GZ2/9jlwYzAbaGxIL0lnDqK6XcE32
RTb4TL9o+pA8jHo9K+fe/skGKzPGW0bXhvFdzp/Yg8dvw5SL/rluj2E0+Z4p
2l10G+61ztCYywxjnPnigbGQHFDVmlYMGx7CnRTVp3ncucCjNat7rmcIjzdY
dR47kQtC3jYf9NuGkFWi/UuNUS5cSBKio747hFnJDTwXo3JBbzVriy9pCHUs
68sPvs4F66YCoxNmQxh+vYEyX50Hp/zKrR8sDGKU44nN88IFUAXc/+2bHMTx
6Z1/eFUL4DuPl649eZC4d6Tt7rYsAC1vy6+UtkHMVFxW7bxWAA3F+QzJOYM4
FpbGNPy0AKw/TaR9sx3ErYX+59dPFoLAp6vZE/MD+G9VzPnzeiHU/1uUCxwf
QLWfF+L/fi8E7gnrVdbhAZRWurT8b6sQlH++C1NuHsDjvsMML9iLYH0j//iZ
DOJ9m3Agn2IRUDkHn2s0GsDHQS95M2KKoOrBmYAfff1I9c5Nfse+YsjYsc2t
oL0f1QL3TR7gLQadpZ8kzfp+DLw1Y8t3pBi0lmDv9SLi/MdEL8UuVwyPHr01
mI/oR3uORN/LVsWQ9x1+TSn246kkiX+OGcWQlTMzqC7dj/kOnDcn7hRDwV3/
w/dF+nGKw7PzeEkxOIoFtYft70fXiHd7FuuK4YBTZMuXH33o+spSqPFRMSR4
Wpmr1vXhsEzSHU+6EohelyZ6fh/mbtlySTGVQJr6M6bGgj4s/+/Jro/sJWCb
qO3JldSH2xpuSOgcKgEwMq0c9OzD2dHr/OGKJRBm/C8pgb8PNz6uxbz2KYH7
lfm+dOm9eGRfA0PBaAkMi3hm8cX2otabuZSoiRLwLMkZV4zoRX/uCkGbuRJQ
+6Kf7OrVi4fil52evygBGeOXf7I0erGpfHu70UYJKBryOwZ/7cEzs/X6XXwk
eNzZ2+D+pgcbuqP+jguR4P0Bh6sWz3vw6xfBm7NiJJAT4qkQHutB8cNFPG3E
PfgRo9yzxuIevPxfDMNLHRLcPu9Yf8akB1kivum2+pBgZqfuhJB2D/ZELWn9
9CdBSa7S9CelHjQOif94JIgEzYJ9xVeO9OAeYYqiSzgJbjb2aGz8Q+TYPO+v
kESCTW9zDd+3iD2b568zp5Hg7n664KVZRN1ekvhsJgmczEbut1Ujfkpyl1XI
I8E7h3WKqi1iTJwvxekuCTRnUt/fPonIfETSaKyGmE/doeCjBOJ5h3zNw/Uk
YOUM3Z1Kj9gaL13S0EqC1rsDlfcau9FJynVJdJAEKh8LM2yYu1Hw/FW1lCck
GA8XG331qwsD9Izdvj0jwRMj3dHzr7tQw8ypWn+JiE+51zKspwsvcf3IpqyQ
wP234kJEQBfKMZx76vKeBH91Nm//tu9CbH/y1eMjCdrXTCIuEvfqcZrngs6f
SbCaZ/PCWaALUzMV5iS/kyAqx0lBbK4Tq/knjVX/kCD8vxzjHOLefYvRQHD1
LwnUty4u093vRLZNElPkFglS3QruPonpxJbdyZwp20uh49ixnxoXOnHF9oIM
HU0pMD1/vV7l0IklT5+4+NGWgkew9d8L8p34tG/+My9DKRwkmUosCHaipToa
uO8oBWOVX3IKuzvRVXK8uWhnKfioz/389bYDtTKY731hLAXqT/oDNvMduI8/
VW4Hcyl4p31Pa+nvwCirlw/ZWUphQ8nR2S+3A3lfZ+2mZSuFoZtul8dudqCF
nUHPOsFdxnx9ghc7UOD+pQtDu0vhXnOTeoRjB7J4qh/NZC8F96dqDAsGHZjJ
NfPOiqMUBpZf/yeh0IFyJlb3mfeUQuGHkaSYwx14Kfv7hTaCObJ6ao5vteNk
qjDdOmcpWAftvxC33o7v7HdP+O8tBb8Xkr3P59uxPLDz9juCxTZFio4PtGOU
nYnT6X2lYPdckCe2th23Kn8d6SZ4uUlD61luO+atvnjHsb8UkvJLD0nGtuNi
ocS9swQf7fDuvH6xHdXdWD3yCe452n5owbEdu/qreCYJvmCjZidq2I6Pz/FN
/CSYU6I5NFyhHa8dvxO6+0Ap5PlA9OThdvQX7uY5RPDXB9Q3Bdjb0Vb3eA8/
wVsMIknBW2347XbZmQMEdzxdKB5db8OfB7q/0xDMQi07+d9CG+6b4E9YJuZf
PuEl4D/QhiydkbzNBItJ55YP1LZh2ouwhisEP6n/5Lovrw2tNQZOyhJM8Uv2
9I4lxq/8mX9FxMt6pKCn52Ibxg5NeN4kODBdK3CPUxs6vF/7d5Dgbz7ViZ6G
bWhx+kNGJZG/KwE/D/QotOFB9jjxIwR/O214mFOoDQP3upJziPwfyznyeJy9
DZ0DdiTQECzCbMcdR9WG94WfjToRetWzPL5I9bgVxZKT8Q+ht6eNYHHnUCtq
1lQHyRF8wmTiRkhDK8bsCqo+R/jDrV+35HtCKzo6xWWVsZbC903uT40hrbj4
gF2/kfDbmqU5z0W3VrS0GopqJvzo8Oen4Qa0Il0Nf1A24dePIL9/19cWZE4W
vjFFXwoHvtkWTD1vQcbDbpbX6UrBFt+dvvOghdj/B6tFiPrwYncrlihrQV8+
zw/mRD0d/TMb52XTggeiG+Z4iHq0aMh/q6zVgkmu/m8u/iKBTMDLGTbpFpR/
rxfTs0GCmIilgG7GFqSbmXaTJup5iO/ZL9GeZhQUuz2UTPQDKSfSzK57zbgt
sEwjbp0EDDmfE97fbsYGgVHjkDdE//Li728ObEbPqsn/ZF6RwGZxp7ejUDM+
8NLL4H9KAk/RIw4mHM1IeyKopI9CAu9/EKOxrRntWpu0LedJsPjA6vbRJ014
TfqrxekpEujuHV/nTW7C23t7e58OkyDhH/cd/itNGOdoWMNL9LskmZ/jRzya
0OnoDbDpI4FDh/pXBY0mVLqy3bqikwSn1GdVIn424ty+uNvdtSSg+e/FYopD
I8bNNx96mEUCDr+gP4f1G/GCyfNx1nQSuJZTz/TINqKNxgdN7WTi98qWr7aY
GzGRakdSQgwJek+zbFV3NeCPX9Irl4JJIC/gHfmIqwEr+vyWHpuT4CjzB/sy
+ga8zZArqW9MAuPBypGor/V4PmE6oFaPBFZ7eAJ0xupRG2vHTdRJsJF+PJ7l
cj3+XBdU3DhKgpaeau24J3V4InfX/jlaEmSMf/pdO1yH/h7vC4KpSMDFzs/0
rKEOX4hQ1Bh/lwD33HjwyYQ6FOH6/Jr5Uwmk5LWNWCvX4VoZh0wopQS24Smx
jMJa3LO3Pe1dZQk8dzcT85ivwfvtv63s1UpAMmL5yVhDDX6kDuNcViiB9Ydl
qQopNfhme8xuu+Ml8GpI1EFJpwZffuCZlBAqgV/cnzqmO+7h2r5JshVjCZDo
PGmcS6qx7npiY9lMMfx0bvqUfKUK13zc0xztiuF5evueHNsqlDo8RJ1pUQw2
TwQa6+WqcKhg/Vi3QTHI0Q2VsXyvxDnborHPysUwx3vTLdS3En8nWGQt/lcM
+qxBnvwuFdjS/7B06kkR7GI1tNI8XYaFSS4cWsZF0CG6qZAqV4aLZ9SpgrWK
IFyNcf7znjJMKVZOylUqgrJsqawPE6XYPPGsYvBIEVgXbvYsaJfia7u/USlU
RRAfs2pwXZ6E/y6U8jDXFELUPyOGabFiVFWscqVQFYL4nuDqPsZi/MHKPGy5
XgC2kawDI++K8KqR8+CrmQKYHxEr3HevCGm57egGywuAy4zRkHy0CKMqv6nG
6RdAxIRfSuSJQgzQfTOtlJYPNw7IOtTcz8XfJ7N0q5nzYJrVrMMsJBdXJ/n+
u/AzFxJOjbQLaORixNMwbdGlXBBp8jmmO38HTz3tmHevywXN8UPCZdvuoMiq
cjCXWS7Qwtff7fa38ZzC0KmQ9DuwdOQo/X+KWfi2aHItkCEH2mteDPjuzEIz
4Sor9Y+34d8n/eaPlEx0Yq5d2zZ3G6hOjJMiQjLRoOdRlXnJbUhN4ht43J6B
Xp786rrKtyH/6fbKLK10/MccYxblmw07tM4GvolKQbsruzbihrKgV+XuuphN
CvYlfqM7VJ0FVExj/wqPpeBySn1qVWoW/GH4nHyiPRl1HihaZZ/Jgps1loZN
F5Iwutldd+lzJnG+WtMQ/xOPhqa6rMcOZAIKOBcLWcZgu78Tu5RTOjT+bDks
yBKDs6JLn8210uHJgcf0sSM3sGWuVMJHJB0S6LyiryvdwAH7W7vCv6SBrDPV
J0PhaHwy93ORLyoNTjVTZVpwXsMsh2mFGwWp8Fj20zev8HAM/SkspVqWDEpN
6eaPqMLxEWWOTsw9GRLyX3OLXQ9D20OiV6iPJEPSyQ97niRewbkk3Q8XK5Mg
eC7zPfO9UBypeBPkczcR0m6fNGflCsaVHeMGY3fj4VcPXbX+vSD0aaJLu+4V
D0mZNYKxqkHoGrnGKCYaD+rzW9XUnhfxFr+ovlZVHIzdHzaiJweihatkcHV5
LNzu1aaLb/FD30P2jc4FMeBveHvunY0fvo2qf8BuHwMCli/Lyn6dxwQ+SnMj
dwyYP4nnsU/yRT7R1Wry7Rvw6RZNmMEjLzw18m9WMz0aSIcvFUbWumGGj+CD
0mvXQF+Ln4+O0w11vcWlgtWuQcO016ucMFdkXBHlUtqKAk3vzaqvpi64aGDB
VxQaBWf/Ucd6czqhToBNx1O/q1D19Fpq7rYzOOCrmRLRHA4DI1JUPw+exto7
hpnl8uHgdmZM4QuxK+3M0bre3RkGabuSQx8mWGPeAV659r4r0Bsl+03I1AIl
sm0KPz0MhX0PL5u27jXCfe+8JW69CAIJo1gxYz955Fw86E5/zR/w5a89bz1l
MSBCzVTypD/QkXfHV3rLoH75DiUaBn/I0XNv0Y+WRDGepJb8ZD/gPmt2gG+3
AJpnhF3/rn8ejtvtu9hSwwTv1/xjFl96QYhvbdPigAKczqTWbFpxhb5jyqem
+ZSgK1KIyvCGK/hpM596HqoMEyeFruwQdoX5n1tifYyqMD/3rv2pvwt8PW5z
JCRWHbxdP0cXsjqDZckQjG7Xhh8RC2s7Ih0g2IhDMeWGNkyJc5n4SjnAza0Q
ljX6U4DD1i+Sx86C9TkWDW9qHXgubh9ZmG8PoepVXAWLulDMEnh7zvYMzHV/
8nkvagjXTT+Z6wtZQ/Q7zjzNBEPwfs5fbF9hBV6C5R8L3hrCQO21ZUZRK/hG
l1RxucgIvjFJHxKTsYTZ2b10CleM4exR5by/p83hlfKAgkOFCWQuDS3IfDKG
FNbwqf2jJhCz7dmfXbHG4FbI3EOzbgIvGIVklPiNoWVqODZExBQ2Sya4ZVsM
QYlH6IBYoSm05eWcmG7RA5HLBQrr58zAcyUz8NQxLWA145mIDzeDpXOh9OPx
J0FGh9c/Pt0MjDUjC6+/1QSjVdb82g4zcM65+cq5RgPYVHIPTtCYA8NWy4yG
kRpIRMdcK9tjDuf4wrvSO1VhpuqO0HtBgqt08l+IqgJfHveZKU1zqBLh/jzA
qwKCF+/9d+yKObzReMb0YEkeWGqtqdtvmkNk08UXhx/LQWdCYm5/hjkstir9
E56Xhc+yDIdt75pDFzjIbD2RgSbGm41vm8zBr7LXoXP5OHQm00pv6zGHIb/T
P39+kAbmez5Kw1PE71fUbvawSEGmQZpr6BNzSA5OT5cTlISFiiMd7cvm4Hpc
SIxWRQKmbp3Z9/aLOdDcqHiz8kUM5n6PqTzdNIeBdRPvbXKicHcpct2RygLe
aYnbXLkmDLJvBIrEGS1gKmv+7Snxw8C/PpIUxGYByR4W+pfiBUBHhPuBNacF
TL9zSu39yAeDe0LGZg9YQGGyVTa77SGo51bY+nDQAqwj90S0Z/DA4Zo2Simf
BcQ9LR89cJUblORNH/4WtAB79j0TgiH7gUncXv/LEQtQ38ao33aFE5o2ZMlx
ohYgd13xd308O+jvUmgeErcAlVDTnE+lrPBhuju6/JgF3I3aGivI2gUNvbxV
RyUt4J/viozdT1po0mjPtJOygJqAuvUZHypgIb9ql5G2AInbNx9e//pdhdLz
N76V4Lb3b69e91pVORrw1e41wfcj0p6eViKp/On6wTNEcG2kJP9G+nL3nS3J
ncYEm5jGL2rv+tbtz9DnEUvMz3jjVjaVwL9udZM9BoHE+hnx80paO2lQzFno
HbOEBVCuOFfWfmBAvtfvUu2OWoCyptVaGDIh5w3bWAcxC6jSZjoSpMKGv9Zc
/tsvYgFwM44rL50du1upbt8UIsYrzm+aPt+Dod6yWrUCFnD6gz+l+dA+3NOd
z5l6yAJ+XuWjX7I9gA0NFluiRL4/6LrxrMZx4+ckRcEoQo8yxR1fV+oO4rnU
Y/cyCL3USryE/7jzYsMf1k6X3Rbw/egj+vyAQ+imXrNNfYcFeA3wvn8Ryo9W
EtQyFTQWYChrfKvRXQBl6AsPLmyZQwJ+SH9mLIiPDH9EZH83Bxfpb+Fn9gkh
3zHTeyKfzOFCTbbn8A8hvDav8Cf2rTlUOwiV1E8ewb3eLPYNi8R4t6YL0mEi
aN7063n4gjk4bCwxPzEQRUYa0dQDhJ+vLcb+OcIlhgUZpLLBAXNIz52fX7wr
jtEXzhRQVZiD8XDioKOZBEbVckc4F5qD+dWUjrkaCYzoVM7JzSbqkToofoBB
Ejt3TwtkEPXGMp4YyNUqibsHzr4yizSH+8a73yQwSWEWe/i1d8HmELjz4NcY
Ryn0Pl34q8rNHPoyz0eI0krjTHunwJSdOZwuoD/71Fwab9+482jG3BzETMYS
hUqkMVRyUuO8ujk84w5Nz1M8jiol9tq7uM1BqIGVKfyMDObyWT7m3W0Oj/aW
mgQVyeBQlu0vTgbi+7ZC+IVfyWDtAadd5V/N4Gu2bMaDcycQuk2yXMlmcKNN
7b6Poyxusd5qTuo2A90/+53zcmXx4HR2S26DGTzWmP9QMieLy06V0R55ZkA6
ZNagoS2HbuPuY7PnzeCB3OMUKS55PLw1cVDGxQyOil5muGIgj8+XWi+HWZvB
0H/epJZweUw4lyw2pmoG6akOdWyL8qiuz+fizmoGL7KjN8pTFPDauN5fLhoz
+OCX7UVpV0Bxxx0WXT9N4Y+r6vSeFQXke0U5MLJoCo15nWsd0orIXvU+aGe1
KXzMpvrGOqKIDTe97LnyTcHbYe789HtFdGoOyNufYgp09cEvU3YrYYvv1X1L
gaZwpXO74k4bJTSS7DCqdDWFUpuzaw9ClZBS/3LG0coU4nR8uLLvKGGi01ks
VjAFj7dRRRaPlbByZJVHTMwUaiP+dhhuKOEdu56Bsv9MwUyCZd1ujzIKbpub
8KcyBZnPidse6CsjV2JSleegCXRnX9JVqFNGy+1XrsQ1m8Cu8eo0hRFlVGV+
/z2/3AQu51l9ObeojN0MI+HlsSbwq88j8zSDCt6je2OXG2oCzKFh5YLcKkjT
/vtajJcJmMY6+AofU0HYYDupbmAC3L8fdrwxVUH1yoiF3SrEfMc5NqudVXCv
jU7Ek6MmUP4h6EZzoArKTB1WtGQ1gR15m12lqSrIWGXxlmGbCVD5GPxLLlDB
yTzOF42fjUHromAHuVoF+X9cp2xOGYPzKnnu+KAKqngYXEzvN4ZNkdExzwkV
dN6zmCDUSLw/2+yx+VgFp65q+jSTjCHWv+L3yxUVJMskOatmGoOhUfsD4Q8q
mN060jkYbQxJq7RHJn6oYELqtiGtIGM4LFhqvfBPBVe1tR70uxnD7426Sk06
wFdOJG5lK2P4bKTltpcJcN5DmKZB2xhe7b1CMWUH3LnyclxQzhgaVXwMN/cB
ovXig8wjxqBeL83KdBBQxkj4FPV+Ywh0eOORwgfYZjiZ5LvDGARkK8qiDwPK
dQ0/uf/VCI4LxLF9FAaUZXzmEjFjBDf2VH5/JAb4MfuvqX6TEfE9B/OFjgH+
9ddU3ZtlBAGdtJa/JQC3Sh8MLQUZwUOD4HP6UoCBGnWRlVZGsJ6TyPufNOD0
OfFNfzkjMKV2LT5PsEb0rVCF/UYga8t49iTBfXLhXtS/DMHaQpaukBhfbxol
+/CxIZx/YWt+VRIwuFhTN7vDEE6sr9OuE+un/XRlcc01BNezZ+cXxQFvHIr5
Ih1mCK0iItH2ooAtH0+dpbU3hDX53jGvI8R7Sf1eiooh3Au57c4gCBjULHm9
jscQeueE9pw4BLjDMIc9kcoQXii/SPnBDVgyfPiJ9wsDGLyjcEuPyGfZl2At
kz4D4H9WsXKCyPeG4HNWvVIDMKyorj7ADEjJfXdH56YBBCy/USxlALz/TM/U
0tAAhLHNsvGPCjJ7D4m5ShpA/NvCJkVC75IhucOhHAZw6Y5n1PmPKsjjYTnT
8lgfEksMGV8uqaDTRRG5F136EBndlctPUcGkOe39u4v0IXN7q9reSRX04q2t
i3fXh97ljfMHelTQDH3HX3/Tg0NM6u9aclQwY9IgwnJBD+h6jfnqUlT+93/m
Hx516MGToW47txsqWDvvMPMsSg84p/ZMM/gT9VSmqR/Cpgd7RRWVdDRU0LpL
/uS0hC4c2dEllvFUGePsSyq/c+hCOlVFef8jZSy8JbEhsKkDH/3cXnT3KONT
qeCDd3t1QG6oPYKbpIx7PSq5T5vpwNpe9Q/J55Rx+wmNAb+QU7ApZx3L80YJ
xf3zTYPtT8HyaCjl0oISnkh28E7UOAWfHK523x1WwgCIm1xjOgWTd+s9ikqV
MGJbrKFDiTZIK3+QeXlWCYcUjmj4T2oB2U69/NwjRdxZd/A0dasWDKhmZXJ2
KmJzaJ9eWb4WsEkWL1VVKmKcRBINj7cWSMuTem5eV0QB1TtfntFrQfFK/m5h
eUUc6G5sKFY/CaEpi8bB+Qp4uCN6ZnBQAyxXHunR2snjsPu737dp1MBpYttY
dO8J/HTrb9KOD6qgziGs0Fp1Al13ij9KnleF/rGj8+v/F8MBPP6TNr+/OrJY
4KpAP6NO/x5YZja/a52mc5FSQD/5lLE/Tgs2v3nipN5dTD8/zyNinOxVNb9/
kK/cYrw8P37vAEzL7zO/YF+9y+weOD+d/IEev0Exv5YBP1HHLDE/4NkPAcy2
Kb+C4no9PRIxPwJX2cqEkym//LYtm9f3MD8Hi9nPYXApvzWu5RZ5wzA/MSl5
qogqKb/nEafXalwwPxPqBIWJoCi/yeqa5tApLz/W46jMUJMnv+DQiY+RPiw/
fKNyTcSTJb942O2qCBIsP+aNLPr5dCW/DikiWb/lKz+sB8rnUlYlvyalXk/q
jSs/8is+Q24ZJb9TC9zMLuEqP6TL8ClJoSS/KaCQWTOTKT+GCKwtgbcjv+4+
kwuCaik/2z1SH+OaI7/WJ/LVC0IpPwUOFkhnfiO/DNgnlc/xKD99AYX81UUj
v7mpbNwPVCg/2cgRskrWIr/XuKp5Ly0oP1dydR+8uiK/InEG+ocGKD9wMTgX
T58iv5VNS5biuSc/LVTkWtloIr8Mqk4r5JMnP8dpUoHQTSK/PCCklR1uJz/e
+Cjn6DIiv07M2JGOSCc/bFqqeSIYIr96ynncNiMnP3rnGCZ9/SG/ol4O6Q==

          "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {"ScalingFunctions" -> None}, 
       PlotRange -> {{-0.005, 0.005}, {-0.005, 0.005}}, PlotRangeClipping -> 
       True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
       Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"Simulatie\""}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxE2nc41f//P3DJjGyy9zj2OMdMng8ro1JWJITUW0YREUlSqZTskWTTECEr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       "], {{{}, {}, {}, {}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{1697, 1700, 1402, 1452, 1403, 1404, 1405, 1406, 1407,
              1408, 1409, 1410, 1453, 1411, 1491, 1469, 1545, 1511, 1612, 
             1567, 1681, 1627}}], 
            PolygonBox[CompressedData["
1:eJwNzKkzBGAcx+F3GYIjoJhRKI7iSI6AYkZRBEHBFkewCChmBFVzrXXu8g84
oyu5mis5miM4iiN5wjO/7+cNb0k01j6YFkKIECOVGUKSSVqJU0QnpxkhvDPD
FrPMMc8CcRZJsMQyK6yyxjbrXHFArT+zmKaDBM/ep9w2itnRvW4lgXt9RpIu
Xcq3fc0hQ7qObF70Ln12FREe9DmjdiN5fOgU3XYZP/YNRwzrenJ41Xv029Wk
8agvGLObyOdTb9Bjl/Nr33LMiG4glze9z4BdQzpP+pJxu5kCvvQmUbuCP/uO
CbuFQk70P3aJPhs=
             "]]}]}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{1697, 1698, 1501, 1535, 1457, 1470, 1427, 1456, 1426,
              1425, 1424, 1423, 1422, 1421, 1420, 1419, 1418, 1417, 1416, 
             1415, 1414, 1413, 1455, 1412, 1480, 1454, 1694}}], 
            PolygonBox[CompressedData["
1:eJwNyc8v0HEcx/Fv5tcpHcgytalc0EXqIgc0prb8HjY5JC6KQzr4MYb5bbTy
oxljM7//gZKjuPnRTZz040SX4qKax+Gx5/v1+SQ8ayiqDwmC4BIjzIUHwTyr
YUEwq1WMkkgR/Zz5i9WHtPLF/kmk+z4NrNtbHPKfO95qWXEvs8cPIrzdo55P
9iYH/CPFWw1L7ttaSB+n9lXNpoVd+4Y+povvdqkOEc44abxkzd+MVvKWm0yS
Tw+//E9pGcNcYYIMXvPZ/7RW8IY43pNLO1/9F+sAf91jmsxzFu2n+o5bFNDL
H+/lOkIMWTSz4/26PqKTb3aJDhLGXV7w0XuCPqGbEztKH9DIhn1Nc2hj3z4n
yV3Ngvs30e5Mmti24zWPDo7sUE2ljg/2MZfd6bziAsc/SdU=
             
             "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nfcjmUYBuAPkT2zy8hK9m6YRfb6kE2pCBVasiozRCGbbNmyN6FhVEZm
OysaZpGR6rh+/XG4zvO+H5/nfcb7yd+pR+ILSRISEhKTJiTE/Mgfj/CdPJrm
lMN2QjLuIDnbHfMo38vv0ILypGCH9Zr8IL/L41TgJ2tPcVtezivcyU5rtfhR
HkNLKnLC2tP8I3/Iq6TkY2uP8ZM8llZc1/uRlc/0SpyUn+FfeQW94/x9kLes
5ecrPRWfyLU5IY8jvWPG6sVord8w+5ONXXpu+zPkB4J+yuwcF4+i9paaK9Vs
8hS5HK/FddOHy/dSSl5lHrKeT54bn8msEj/T3Gw2MVPb/1SuQ2X9pF7IXKjX
Nd/TM5jj4r6Zxc2y5lqzkdnG/k15ANX07GZx80Nzt7275Znyg1SUN0a2ftrs
QhJW6dntTZXL0yfusz5CLsBhPQ2fxTlxSh5PW27pr5ODPfpDnJGfJSmr9b6k
ZZdej9PyBNrxMD9b60oy1uj9SMduvT5n5Im0p3LcP/ZYb8DP8iQ6UCWuFRnJ
RGaycBdZ2ev4hpyVJ9ORqnEf+TyuJ+fkKTxBNc5a68YdrNX7x7XiC70xv8hT
eZLqnLPWneSs0weQgy/jfvOrPI1O/K2/QU726jX4RX6OFKzXX493yL0YqRfk
iJ6TfXJTfpOnx2eOZ0UvEe+gftt8k1x8rt9jf5b8UDxH+q/m89zJ/faWmRvi
XOVpcoV4FuT1cY7xXspvy9XNQmZpc3XcA/Oo/fzmvHjPzKrxjJlb4hzNXPb3
y4lU0X/XC5uL4nkw34/7ZY6P7xyzZLxT5rr4frD3jzmQ3PH5rK8wv7CeR54t
Pxx/T//NjC+7lGzU34x3mQN6M87LM3iGmvxurQep2KQPjPeFg3pzLsgz6Uyt
uIZ8Zb0FF+VZdOGxOBfyxrse14J7KUBBDjn+cS7Js3mW2vGec9h6Sy7Lc+hK
Hc5b60lqNuuD4ppxRG/FFXku3ajLBWu9SMMWfTBFOKq35g95Ht35Vx/E3Xyp
1+Oi/CJp2aoPIZXrO0ovzDH9Po7JbfhTnh/vmGMm6KXiudXjF8lg+R72qfW5
JL9EOrbpQ0ntuNF6EY7rRTkut+Wq/EG8u46ZGM9aPKt6En2InIf9egMuyy+T
no/i3XDMdLkiw/Q0+jvyfXwd90WfL1eL517/2mzHtbhe9hbLC+I7Q54kl4ln
Kj6WPlTOS0l5pXkg7rk8R65lVjYrmZvMhvaumK9Q1VoGs5i53KxvbrefK559
vaZZKd45c4PZOH6H2U9rvqvXMIvGuZhr4meb38TzZX6g1zGrx7ttbo1/x943
Znv+ivtmfYm8UM4qT5bLxrOvJ9OHyfk4qDfiD/lVMrJDH05xvtU7cF1eRE8a
U4KSfGevIzfkxfSiCX9a600mduojKMX3+hPclJfwIk25au01MvOxPpLS/KA/
yS15KS+RyDVrfcjCJ/rblOFHvRN/y8t4mWb8Za0vd/GpPop0rsOYeCb4Nt5b
fUFc+/h+kbcl+f//UGXt/QcR9RAI
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1mXYFAUUhuGlG2xBBcVuMTHAAltBQbpBOj66QUJaulNAJUQFk+7uDumW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           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV1GWUVVUABeBHIx2CdDcIAoJ0d3cqCBIqpXRJd3fMwDB0d4coktKIdCgh
3Q0W3/3xzd773rXezFvrnMnYuku9zlFCoVAuP/rGCIVW0Y/+/MAABjKIwQxh
NUM5zY98EDMUui1ryPRMpjnziWCNd4cYxlqGM4KRjGI0YxjLOMYzgYlMYjJT
WMdUdrOe/7nCAr9jEFWYTWqa8at3j5nGBqYzg5nMYjZhhDOHuUQwj0g2Mp/f
+YnPfGYcxtOIcO4E30vWJAOb7PYyLyGu2oeDv5GWdjZe62f4me/sIsTlrr2Z
r/V8ROEP+wg99VIk5om9kC/17LzRz7KH7+2ixOOevYVv9E+Iyp/2UXrppUnC
U3sRrfQcvNXP8Qtd7WLE5769lW/1/ETjmn2M3noZkvLMXkxrPSfv9PPBedIr
koK9wXeQ3ShOAh54to0OegGicz04d7IqaThu95Fl+ZDn9hK+0nPxt34hOLd6
JVKyz+4uS5CQh8EZlLXIyHa7oyxIDMbSgBvBeZfVSMsJu68sRzIm0oQXwVmW
dcjMVL5gqedtZG6m809wzmV9Lgb3SlZmFqmYRFPmst/7HrIkM0nEBBozh0fB
HZK1CSMTU/iceezwvpP8lBnEZBwNuRncX1mddJwM7rwsT3JeBvdS1iULy+y2
Mg//6pc4wE46e1aIWPxln2I5K2jn2cf8p1/mILvo4llhYnPL/o3+egU+4lXw
P0HWIyvTaEEkK717D+X1nzY=
           "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
         True}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"x(t)\"", "\"y(t)\"", "\"u(t)\""}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "18.884098560991333`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.66287887324962*^9, 3.66287887871753*^9}, {
   3.6628789095204*^9, 3.662878932194415*^9}, 3.662913845279194*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"Final time: \\!\\(\\*RowBox[{\\\"5.327860564945077`\\\
\"}]\\)\"\>",
  StringForm["Final time: ``", 5.327860564945077],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628788705409856`*^9, 3.6628788761951494`*^9}, {
   3.662878906866686*^9, 3.662878929586425*^9}, 3.662913845292203*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"10.003858444648827`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 10.003858444648827`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628788705409856`*^9, 3.6628788761951494`*^9}, {
   3.662878906866686*^9, 3.662878929586425*^9}, 3.6629138452947025`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{GraphicsBox[{
       GraphicsComplexBox[CompressedData["
1:eJxkXXdcT98bJyt7k723ry0knhCy9yZkJYRsQkayol1SaXzKSiirpEd72ntl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        "], {{{
           EdgeForm[], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6], 
            Opacity[0.25]], 
           GraphicsGroupBox[{
             PolygonBox[CompressedData["
1:eJxNnXX8VEUXxnf3xt579yciNiaKil3Y3a0oKBYq2IGFhY0Y2AFid7dgYGIn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              "]], 
             PolygonBox[CompressedData["
1:eJwlmnfAjuUXx5/nfd77uddbdiKSVRmpFEqiUkopo1CkoZBRCCmjRaJhtlSU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              "]]}]}, {
           EdgeForm[], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6], 
            Opacity[0.25]], 
           GraphicsGroupBox[{
             PolygonBox[CompressedData["
1:eJxNnWXYVUUXhrFFOefs3i8qqNjd/dnd3WJgFyrYraBioIiF2N1igRigomCj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              "]], 
             PolygonBox[CompressedData["
1:eJwtmnnAVVP3x2+D6qX73HvumR5DJdGgNGoQikRpFlJCIxXRJFM0IVMZEypp
kFSGJFQklKFMDfQ2kCgqkVREwu/zfb+/P9bzrLXX2vvsfe7ea6/1Xady70Gd
byiZyWTG86c0/y8OM5m340zmqCCTeSGXyfRMMpkxyD/mM5nutLVNM5m7sVmG
bjPyc+jORu6fzWT+wOYs5Iuh/8LXQL8J3SrkLPyL0FvI50aZTDv6n1eUyeQZ
fwD6lthXQ/8surOKM5lbCpnMVMach3w28gjkd+lzGv3nYP8n9l8jX4H+SmgW
Yx3Efja685GvRzcLehL7bsgj4Z/BpgP8INawk2ftgt5BrkmfKoz3Cv0XIb+K
vizPG4h8Abr6tPWm/xpsPkCej3wMfY+GJiGvhP4Dvx/9e/Db6H8i/X+gfx/4
a6Ad6K9jjGLWeys2F2Fbi7YHGOtN5PfRTc95rBVQucBjLmP+aWLbnfT5GPk4
5NMC/yYn0H8AbZfS9yKoEnI1nrcC/UroSeTljFcG/iX0DyN/iFweeTZyKWxL
Qp/Cl2e8hejehcqi/xe5WezfVL9la+Tz4MdCe+Ab0NaR8S5iPp3g97DeIczl
TdpWM94GjYf8fux3VUr90X1H2z74gdjcibwUfUn0TyP/i64y49VFPohNHeZW
FZvL0S0Qoc8l3ivb0B9Bnkz/m9FN4fe9GfvvafsSeY/eIbp92E+Hr8pvcgBd
e8Ybov0LVYS/CXoQ/mps/kDfFvs28H2guvSvzv7rRt+h2MxEngFtYq3rkTfR
txX6e9Evoe02nn8Jbbeie4X+52L7IPQLc62N/Dm6JdgUYT+K+T6OrirPPB3d
r/p9Y79jvdsiqKH2J+P30PMZ/3N0n0ET6PtfntGesZpi0xd+LHQOuuHQDsY6
lf6XMfZX2FSg/9ys9+4prK9+4D38GfIFjH83+i30/xb7APsF6BZCGfTdoVHo
fmPMsfCLGb8Euim0PYH9i1AT5jOtyL+d+shWv2FJ+KexfybnM/o6chVs6gXe
g1fRd3XktZyBXAf+DKgP8jXIq+BfZz7HML/yUHPGCum/nfHb6hnwdaCm2J4Z
+OzfoD0Q2AfMRZ6PfBR9f2P9TekfYP8tfVtBx6Arn9o3rcV+kPpDK7Pec8Xa
H8yxO3xHqAG2DaFPsL8C+TWtH7kM45/F+vrCnxP5rGvNU+Bf5plHeNZtyI/B
T4QaIq/mGSOwvwP6ifFGoL8U+ybMr5n8hfaAfBnP6IKuFXQj/Ae0rYM/P/BZ
qqh3EPhMPYD8J9ScuXzF+MPhT8G+Z5HX1IZntUvtu7VnjqfvCdBe+g7Hpjb2
zzK/Q8hrocnopkE3ai8gV4J/BH2XvJ/ZGrkVdAF8K+ioYu9p7eXGvJMS8udQ
P50dxl8P/4V8kHwtVF5rgSag31pk315LezZnH/8aumaMOZKxrqbta3TjsXkM
21uhrcgVEp+t2yVj/zUUIe/Q+2Ktt6T2BTchN8N+MfpV8P9hzGsZ6xT5nKz3
xLzYe1J78S/k6xl7IPQp+rNpW4SugFxd+43n9cH+Bdoaw7+n8wf/HFQbuRE0
F74U9lWw38p4JRKvQXM/SWMgnwXdTt/xtF3IeI1i69ZhPwfbPcjHyx9j8xJy
X+TWOi/YZ+j7r94Z/Bbsf2dtJbTf0P8ADYZvTp/BWZ+Zq9BnI++lMTm/q9I6
z3m/swaMdzr0M7qnoJboastHof8c2oN9B8abmfVvuFZ3YeTfbqLOLLad+b22
8G63Z/1us8hnF/yOxyOXY/xTeNZmxjuRvtdC4+j7vvw1uu6McWbeNsej6xF5
ru8gXx37DpDv/wbKaW9H9n3bGL8l/Wegnw3fAvsWyOdB58K/TtsqdKMZYzTz
7QUNiHxn6a7SHJZjeyL75S3sOyDvQ/8LFCPvRe5C38sUf8Dvgp7Gfgv6MPAZ
GSX/BHVj7F3ywegvhy7Tu6XtOsZuJR9D3xj9GJ69Hfs0cMx0F/z30LHIPyHf
Dt8rcezVgf63KRZjjOq8zyuQ99L/fK0Rfe/AfXdAxYHH2M2zvkIupfF45nrs
y2J/MvLPjL8CeSnyaOQ50Eb549h3z1WBY43VtO3OO+bQXMcib8x7zl8ib4gd
i13KfKphf0Pod99Qa0K3Ufcf+jd4/zt1d0IFjQ0Nl2+B1qJrjnw3a+up+5vx
9wW+yz/BPh/4Tv+Q9bwP5QL7wP3o18inB96jZ2juiffGuVBf9M0Sj/1q1mvv
qjnk/Q7eYKy3absLvpzeqc4uchPFv9hXR1+XOa1G/hj6k75bsBnEWispBoM/
QlvlwDFkaewnh45F5YPvYqwO7P9ZBccUjZEbJfYl8vG3Yf8K/f+h7yOspyty
PeyvLviOj7Fdwnjfo6+peA7bccgXwh+g7VfsrwntS9dBo7AfCT1QZJ8yBH4h
NAL7WtqP9P8LOhG5Ec+4nf5TWN/fyI/rPsM2RX41sI85SXsduR62x9G/emwf
Kd9YIe9cYC7y4bxzgvnyh7FjzeeZz9LQa9Dcf5B/ZaxC6thCd/Ji9FHiWOWc
Iq9tAf3/znuNlzO/p0LfHYpB2sBfhP51+BmMP4G+4xPvLf1mt6E/Wf6S/qto
a4VcC31jdM9knQsoZlGsopygp2Jh9FX1e9DnEPr1zK+YuR0LnaO9A50T2Idc
g/50fp/r0LVXPoLcHPu16NZD47DtiH6O9FojcpnEZ7kfz5yitYWOVRUj/qX7
hDHawE+m7S/Fx9gk9K3IGIPRXxnbt7ek7XT05/G8L3W2oPtjxwSKBXSHr+RZ
P2Czh/Hupa0JtmdBn8NfSds8bN/F5h7F24rB6P8H8uzAPuVv7cXYe+sp+Sv4
gbFjpT94f/0Z+5LQucZdUB7dbPrfrHhS+xF5v/Ih+C7076dcL3TsdCfUDtv7
kdth3xbqEfs30LtfxvhbmeuRyLpK2nPwlWl7G3m5ft/E70TvYoCeifys4oW8
f8NPkT9TjAL/ruJbdAcY/wStP7Avfx05E9invwH/uNYTOKYdotyM32+T4mHm
cwPyI5q/Yi2ekY985+iuacr6ysE3Uv6E/l7Wdyb2g2LbKkYoi+5Y5FMZ74XA
vutf2hoU7MNKFPtM6iw2LPiuDLC5s8h35kFsf4NO037imfvhK+lORq4F/YF8
CJqPri5yVe2v1L7pBOaQYbx/Up9VPbMq76YFNk0LzgHyxY7pFcs3p60kcqli
z6UGY/6k3Aw6ueAYZLdyZ6i07mfaitD9nDpW1G++JfUe1t49QTmwYnGoDmNV
Kfi3345cueA9UJ5nHQPtRn8GbWXhyxU71/xO8bdiydTYQi5vX/MXcv2Cfc4R
+MOp16q27vCX65mMt03xAuudAg1TvA69B9+aOUzP+gwo95pL2y2BczDlEhuZ
/+DAOcWKxGdKZ0l9PoBvG9r33E/baJ51AfLdOn86k8gboI8U6yCvxr4b+nnI
DyJ3gv8osW4WbRMT55DKHfXMPfSdQVt7fv8arOc17U/kIYH37Hfov9We4N0M
1W+Mfg76CvBB3n1nQoMCjzE1cQyv2F3vYBZ8QJ+bdPfqPDDWXqhZ1m3z0D+v
OyDvd7IM24d0p8OXhh7V2YL6FPkZK5j7c8pRdNaY0yR0D0Jbc57zO4ljKsVS
ekeH4bOx1/Zc4FhiV+q9pJhCd/8m5OMKjgE2w2+E9uXcNhX9Pcj76ds58Nkc
h/xr4DOqXP1QaN+lnF25cyPm91GRc+hqyHV4flvFcgXftZcpp836zj0V+Xrk
bsKWtF8Z+1bls4x9EHoAeQTjf5x127TYe0C//e/Md5LyDez/1FqhychPQZ2w
P4L8IPx46EnG/z1wrjMhNa+cZzfySOSfkU9kvOPh+yoGRV4ifxk6RlJsJB83
Bn4s9Br8Pp5xJ/x0bP7Juk+dYmM0wmZ6s54qyCt1p/A+OiM3QO6DvhfP7o9c
jPw98o/KN5EbIQ9E7op8A/KZxc5plcsOR26CPC4ydjMEuSnyY5GximEFY3mz
I2NbwvRaFBtzE9Y2BnlzbIxG2IxiQuV6wuCEvSnnE/anHF65uzBAxVL3hvbN
iqmOlu9ErgZfJu+7d0Lo3EN3sLCNT4WBZY1xnKD1CKNCvhA5lr1yDN5HC+QE
eXvk2P585SzIM0Pn0h2RKxQ7xlBs0a7gWODqyFilYgJhQZsj5xbChC4sdk6m
XGwCcmvkncJTsH+g4LtmaGwsQ3fOY/x+E1P7lqXYvMh5eUmYYeDfZD58Dexv
C9z2nbCMxLnxE4HPxhRhYoHPSBd0O+UD4S+B6iuWSx0LK6b9Ad33UP+c+wg7
VE6mXEwY4mzkZ1Njr08pHlM8jv3DgX3ao8g7Euvkw/ckjjEUW0wL7Ot30zY1
sM//EX6X4sEit50mrJXnLUP+CPlU5JMj8x/Kn8ofJ/Y9ivlqoq+VWqc7b1ti
zFVY6yTd35FjdsXq9+TsGx4O/W7+5yOUGyS27RAYO/0c+dHAGOqaxDGEYge1
FdM/VMwQ+IzVhW9B23M5n5lhkWNAxX73KQdC1wXaGtinno3uYuRpOb/jirqr
UseOb2LTFf4yaE2R+1TR+lPfFcqJOsNfpPtdeE7gWEg5sXJhxUQd5VtS63Tn
tYa/ENoU2OcdmxpzF9auNVSVr02NPek3bKX7CxqSdZ/j4OPIvmZx4FizAfKG
wDFnS60vdGyvtsapMTFhYYqBhkeOUf8XmwoPQdc/dO69Tj4MXQItDYzB9BHW
gs1nyItyjqVrRbZVTN00dQyr2FU2OusVUr87nfkX+K12hMZSdSYizV+YWuB3
drGwNOFPyBdrT2J7SWL+MHPqodwc6qK9rfmxl54Xnh4Yk5YvvTQxdiOf2lXY
D1S/yH1KxR5DfYWhNMH+Kt35mivUHf6KxGevBX2uTIwJCAvoGvz/3Qr1CnzH
vkP/3sgFxuqMTcJadtHWM3BOplz9TWhM4Jz9LfiWrK9v1m2vIi9KXIsQRrYY
vlroWE7v5BrkfoljBWEg3RLHSIqNhFHUVP6AfY/AOdMA5GsVM2k/F7mWI4xA
2IBqOlrrGaHXojUPQm6aGMvSmqLIGIWwCdV87lP8nxgr/G/WWPO20Fi5MGfl
WsLkhcUr57pa8Z0wr8A1FGGNwoiFDQtzLEKfTY3Fv4Q8IXaOoNxAmHsb5Sby
b4HXoNrKN6FtVWNZIzwqdWyumGa/1h97rTNou0nxDs+7qsh76BDy7/IPun8C
505/Jo5llEPdkRjDFXZ7LXQn8tjEuc3AwFjN6MS8MJsMz/4XuTfjz5PPYz5/
JcZihNkegf87sW5u4FrGr4nnpprG4MQ5vnJ75fwN4W9P/OyzoAPwB6EPc/a5
y7QexdOBMY/RzPUh5Jdzjkkelu+h7Vn4Q+hf4l1cGbr2Igz7BXQ/JfbtwrxL
wjfGpq7qcXljb7ozdVcKgxO20Yu2hTljHMKC/wldixMmPDlyTKFYQjmP7qpe
scfSnVUP27ehC4qMqW5WvAxNRPc4dDO2b4Y+W8oB72W8u+Vzs/a5wu4HR74L
hOFfz/raIA/KGXMeiX5oZN/dA7pfPFSH8a7K+W5STKhYUHdUSP9f6POIsGye
tyE05ius99oiY4FfQdtzxgTlK2ok9gXyGcJyusXGPoXpDIuNgQj7UM3j9tQ+
Ub5QNYHrY2POwppVozpGuVtobLts3nfRotRYtu4k1W47o5+fcw33Y50v5rMz
Z0xY2FW12FiDMKzDsWNOxZrChF5mrmWKjd2fQtvB0DGzYuWJ2FfB/vfUuaYw
oUrwjzP+nJwx01HwNSO/yydyPjuPRq716Qzp3Q5NXFvTO56EfCvPeCPnOa9H
tw56LWfM8sXINRbVVhSzK/Z+hmdmCo7B340cUyqWVJ/T0U+NXTvsovwqckyq
WFR7urL2m/CknGNa1a4VAyr2Uw17IWOflBprUA1Y2N4eYUp5Y3zKvX+DKgbO
wc9MjQEo9xfGMgP+1di10xIF50JjImPpyokeRbed8e5gPW8hT1fsKB8QeE3N
4E+NvPc2QqMVu0SuxR+A7kAeERkrXAKtTRzTKpZVDW4U+mPRdxK2Bf0RG8MT
didM7Gl0T6bORYT53Qf/ROpcRT5AuZxiJMVGyulUO/419FxUQ5Yv7pAY25JP
niqsIvRadMZ1V8kHyffozprB2DOVX+VcU1BupJxKuZRypA3IX+o3zjpnXhQb
kxQWOUn4e+iYW7G2aixLEmPMwpZHBt47IyPbag/VD41pCMtQznVpaMxKWFVn
qBN9b4qNRapmfW7oM6yzqxzgusg5j3Id+fj7sP0qdG1seM5YeO3I71aY+D3I
N0aOdfSNwKXYXxIb61ONuVPkHEy51wDt4cg+Xb5cNcoF8KfFPmvK4XtHzsmU
i6nG3D40hibsTL+pfJtyLuVa8nE6exUir01n8KHYNTHVwuSjFGspplMsp5jr
9NhnVGezBs8cEbumoFqCfOI36D7APlJuVHAsMD7ytxSKCeLYOaRyx49pW4ru
7ch8OeHtisdDY386M8K++ifG3oSBVYyNYQm7EqY1i74zU+9l7RH5dp0hnR35
+Ba6q1N/y6AYdTH8G9CwrGvCz8E/j31p+FLQHMmpeeV8c1N/86BvHWSzFPmT
yLXuXMG1+DWRedXkP41dc1atWTWH5dqbqWs5+kZiAfKC1NiUvtmoEvkbB33b
IMxgn2odsbFBYWTLQ9fwVLvTHbZXeFns2l1J9NNZ71GxecWcnRPXFFVLFCb5
inJl4Uk53+EdYtcsVKv4gj43xsZEhIWo5n9AsXNqLEI1ly/hv0iNNQnT/hb9
J6m/JdGdUD825i2suxptVyjWTo2dKSfpAd9c9xnyd/oNkAenvgv0DU0v+N6p
dU/Q1jO1D5bvVZ8L6HttamxINS/FHg9Fji0Ug4xKXQNX7VuYRz/lC6ljK8W0
F+t+QP4x8DceP+q+iv2sw7rfU9d4VduVzS2Jv/HRtz2K+Vagew96ibEKytfh
a8pHFFzDX566hqnapdqWIb+dOrZQzfcj5ZqpY3GdCY21BkoKHnOY7t7U34bs
ps80+KdT147k01fCv5/62Z9kXXsamtpWNShhqztSY6PCWLcy/68Tr001kF/g
92qP5F3TU62gAX2q510zEJZ7dLGxU2G6qjW3ix2bqOZ8R+waomqHtZVTwHcN
/S2IvkFYG9onyBco51Bt/+HYWL9q/KrFXh67dqKabBvFeqGxaMV8HZE7xfaN
utP0bdMtsXMrfeOkbz3ax96r+uZjYeSasmrJ2tNayxeMl+S9pj6KrUPXEtV2
SPFGbN8pTPIg/LrQtVPdwfo2ol7svatvJPbxLtPY3zLpG6Xz4cfFrnWqRl4d
+1ax34Uw6VcSf+Olb7tUI9O3D3VC1971DYRqi/pmSN8Kqcaob9X6x8ba9M3a
J5p77G9HFMMrtlCMpthMMcbPrLde4m9TtGc6ov8pMrajGnrj0BiWsCvFjG9F
9qnypfqGarrefexcSXugEBvDFXarmouwvFWpfbUwPdWeo9i1GNWg9S1X79C1
a33TVQbbo1Jj6aqJCIv6MXJtWJhUy9AYoLA/+dh/dFckxpr1TdvX9P0mdW1G
GLS+LRBmJqxM3xgcjlwDEPavb462Kd+KvfeF4X4bO6ZRLKMal2rpu2LXglVT
74duf+RapmKC3yJjaMLOhNHuioyhCTtTjUvfGvSLXevVNwf/BzKFxHE=
              "]]}]}, {}, {}, {}, {}, {}}, {{
           Directive[
            AbsoluteThickness[1.6], 
            GrayLevel[0]], 
           LineBox[CompressedData["
1:eJwl2Hfcl9Mfx/HvnZaozAhRyEghKk2pRKVoE1LaG4mGUUYI2bs0kIY9Ukkp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            "]]}, {
           Directive[
            AbsoluteThickness[1.6], 
            GrayLevel[0]], 
           LineBox[CompressedData["
1:eJwl2Hf8l9Mbx/E7W0rRRCJEhahUIqShIpVIkaaUhiKSWSGRUUaSZKRUsqIh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            "]]}}}], {{{}, {}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.368417, 0.506779, 0.709798]], 
          LineBox[CompressedData["
1:eJw122k4Ve/3MHBRSEpFmmSMkGigUrKEBlJCSvlmnioVkijJkHko81xmMnMG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           "]]}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.880722, 0.611041, 0.142051]], 
          LineBox[CompressedData["
1:eJw123c41t//OPAbyR7ZIZlR2igrTyOUlezsmRkykuwte+9931ZG9riNY3Oj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           "]]}}}, {{}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6], 
            PointSize[Large]], 
           PointBox[{{-0.1019367991845056, 0.}, {-0.1019367991845056, 0.}}]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6], 
            PointSize[Large]], 
           
           PointBox[{{0.1019367991845056, 0.}, {0.1019367991845056, 
            0.}}]}, {}}}, {}}, {{}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0, 1, 0]], 
           PointBox[{{0.1, 0.03}, {0.1, 0.03}}]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0.5, 0, 0.5]], 
           
           PointBox[{{0.088025, -0.04083262377657314}, {
            0.088025, -0.04083262377657314}}]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[1, 0, 0]], 
           PointBox[{{0., 0.}, {0., 0.}}]}, {}}}, {}}, {{{}, {}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJwVl3c81f8Xx9Mgpb4UMiJ7J7Ky7rH3vO5NJZEoSkRGZsheyYisrIjIzLw5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           "]]}}}}, {Axes -> True, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, DisplayFunction -> Identity, 
       Axes -> {False, False}, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 600, 
       Method -> {
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True}, 
       PlotRange -> {{-0.22589170132043948`, 
        0.22589170132043948`}, {-0.09133961040320827, 0.09133961040320827}}, 
       PlotRangeClipping -> True, PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      TagBox[
       GridBox[{{
          FormBox[
           
           TemplateBox[{"\"u = -1\"", "\"u = 1\""}, "SwatchLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    AbsoluteThickness[1], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.25]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    AbsoluteThickness[1], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.25]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), 
            InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = 
                    True; MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                    "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.25`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = 
                    True; MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {"SelectionDeparture", 
                    "ParentChanged", "EvaluatorQuit"}]]]], BaseStyle -> 
                    Inherited, Evaluator -> Automatic, Method -> 
                    "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                    "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.25`", "]"}]}], "]"}]}], "}"}], 
                 ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{"\"Ellips voor u = -1\"", "\"Ellips voor u = 1\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{
            "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(0\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(0\\)]\\))\"", 
             InterpretationBox[
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\))\"", 
              StringForm[
              "(\!\(\*SubscriptBox[\(x\), \(``\)]\),\!\(\*SubscriptBox[\(y\), \
\(``\)]\))", 1, 1], Editable -> False], 
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(e\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(e\\)]\\))\""}, "PointLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[1, 0, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[1, 0, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), 
            InterpretationFunction :> (RowBox[{"PointLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                 ",", 
                 RowBox[{"Joined", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"False", ",", "False", ",", "False"}], "}"}]}], 
                 ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{"\"Simulatie\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwVl3c81f8Xx9Mgpb4UMiJ7J7Ky7rH3vO5NJZEoSkRGZsheyYisrIjIzLw5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          "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {"ScalingFunctions" -> None}, 
       PlotRange -> {{-0.005, 0.005}, {-0.005, 0.005}}, PlotRangeClipping -> 
       True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
       Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"Simulatie\""}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxV23k41c3/P3DZSovsu+NYsqdCss+EEJFwopRsSaUsSbZskTVOVKjsSyiS
yHYYJJWlJMmS7PuS7CF93/fv+rzPdf3uf+5rrpNz3ubMvGbm+TDCdi6mF2lp
aGiq6Glo/vt/7/VHeaOOUZq/R8dfJyVVgJ1uHsWOIh+BcG1yVOzvSqB5ofMr
7aEeUBDxMKGWgQI61dnOdHkMg6MSfZf3PKeAyCZlTc1Xk2CXdehTjWUK+Lfw
zcRbdR4cVDK53T5EAc/++vJH2S2CKxOijeMeFHDgpP4+nU8rIHeczSM8qQos
23Dk00uvg+vhDak61pUg91fL+03Dv0BmL6Xmz0A5SBkisX2ypIFv0hf2qoy/
AT+j1O5VzG2DWt30Is5dJUCTM/1drh8d3O2wsmehpxgw1yclX5VlgLbpx/4c
RkXAvGCHlgFihBpp/km2hQVgJ2Xn3c0bO2AAT/4JSmke6M+PDism7oR6MkIj
6TQ5QKYrhBRStAuqSHsLq1ZngHFJlrdSdnvg1tGCzEP9KYCvnPXv1AozPJPK
ARoPJgHrw2bT6DQLdG5MmpJ6Eg+Qf5/SbjlWOG/yx9HZ9x6wGs9wGlthhb08
AqFmcaHg5eChK/ltbFBnJZAO5fgBzY2NU5tP2KH4jl9bT9+4gT76uzwm9hww
5qF2K92GHVBM6y68p8YJp0udEZ2zIWg86yRzhoEL0j6fbrkjMVTD8qz2FvMA
F3wS57mvSEIHXRnuynj3hht+/Mi/fJDPBP3TlC3ZGcADe7+QnQ3MzNAJ2eMP
VSx5oXZmYnHnqjnqUE4/tyLCBzXS2ay6j5OQ8+EK2tJJPviqZ+n7zm/miPL2
sdf5On64Ovfq9dtGM6TnVtYRHykAa8MSWpGXKYosSqYpcRCEA6d/x0sPmCCm
vYjN7iABfs6yPc2ebYwSzqfRsa0RYCCNp3pliiHq0zBseN4mBF2WBH9q39JH
RSmJpZeNiDDDpJpy7PUxZHRp3nWhkgiz6GrHnv3SQgsSufx+4sKwf9MrJ8Ub
IkWv2xUtkcLwqJep+8M2dWR6/wiIWxWGKm5tYzfblBGz6t5ywnkRGOlINLwZ
fBi19+gSX9SKQBXK+fHt2fLIXcfetVBWFBavbIu//f0AeqmR/PrWfVEYTWF6
+fSyDEpxYS39s00MxjgFsFwQkUCZzUNOTiIVIMdjZd8+k0owZBjOxW/7FSif
211sHV4FVN/4D77QHQC9BdXi+fYUUHQn23BX/BhgOz6awNJLATqWCy487LNg
7JvGtfE1CjBbk1QK/vQbPJYwpWUso4Cr4nZpl3iWAd14gJksBwWwWRZeEvNb
A8wnn9Pu21EFjHPny2mqNkDKpYF7NPkVwP2sumfL1hZ48iGoavRXGQh1uHL5
gz0bNKg6f7/gXRDwnOOyNlNih9rn1H8Y93kCZpqjh3P+sUNXSgqpI/4KCG9/
OXz9Mwd0T3kyzXTaEtz+S7x2I40THthseufkrwymAx98ee3OBcsu76K4FSoh
jXcn9lwx5IafgyJUp5cMkOL9YJkJPh4IdIy0O5ZOoZzSSrGMaR54N97m3qKl
OSLLL68lVPPCya2NKjdAQsQjBS9Jd/ng6dQFeVlREnqwmacRQeKHA6JW8n7n
zFEwX17O2j4ByM1RarsmboZyTluUlH8UhYY3AmSbD0qhzkD07apIHtBYIPf5
r1aASyH1LsYLn0FbYm88EVaB7tHLhnIX+kDCbCJNyBEK0B6wav9NNwr4Hv34
+eEdBVy6z2khYzcN4hJW7xmsU0DezYC3t+l/g6K6X01lnymAie3XeW+NJXDn
T6hrkx4FpJn56ipmr4KzgiJDU2ZVICMk+FXwwjpglIoJQ4yVYE82farDvi2Q
nNwmceVqOZjPZrxssZ8NttNeft+edgewOYmN+NOxQ9ONlNvtBd4g53aK9pdW
dlgh/GU0q+s6KJ7m87+QxAHNr475X2u0Bl3Gf+/RXOeE6xt6ixc8tUHXNX9/
RnUuaKIK0x56SiLxN3e1KJzc8PshLT6dBj10snL/eOcENwz1bThvxnMKmfrc
cD5dygNjCwMEFEbM0PUDQu8nInkh68lfvTvESGj9iARjjjkfnBQbzl5RIyGa
pEPEVCF+SCuRdGnsqTkS+pW+9/kiP+zltri+5GWGpA3WFRILRKGmyIvvVXrS
6Pq0+43W7npge0B7IzizEpBJB5aZP3aCB85h5kebqkC4t35yfd8gkNjNcFMu
kgIEJX41iIlMgBsjfCFDUxQgLPQ5nKFhDqDsICeO3xTw16c9927iAli9T3iB
EimgVfXbEGlxGXhs099i76kCIecGwznM/oBwUaVh8KYS9HgwdUlcZoevYixa
fQ57AM/gYXHfQxywv+ThJZlUR2BdoXPcn4ETOkHKz+JsUyDyQufEWDsnpB3N
NAgoFwdb8flitnlcMK1FKcNvG0TmHWxd3EHc0OGWV7NevRHic/ru8ucED1Su
txM2LTZFf+a39c0K80JFrZMklhJzVHy4WVpvnhdGHSDfjTUkIV0lhTMM5Xxw
QklGL4KGhCRtRKxuRPFDD9u00FYOcyRiX6LYPSoKN82We26ISSL1aa+X7iJJ
gF7t7Lr8xwpQ7sN//2xkC+CzP9+ZzlsFokXSYnk+9ALam65PSEIUEM1cxnlR
fQQUdUpe5q2ggLX9z5pKIqZA2ALH3jisfpiXSEf6pmLrayCT2Fo3BXSFlarT
ti2CoyukCKkLFOD0ZfAwRWUVXPpx7VjArSrQ4t5coB2zDoyD/fulFCrB2San
10Xlf8Fcz3un3znlIKexY4LAxgbTFu+ca34UAgbEZJ5xTLHBwqV+ZrjPF7ir
tzaNlbBDGhZ17YBoV6DvZdJs4c8BZ5sYGQ+J2oK7t64S3ptzwid9lkz85nrg
pMNix0siFyyO2uToUeVDTwpFz4+uc8EX9kvXttProh/GdMc+feaGh8aiCjKS
TVDuj5Pkg4+xeqKZO+uSaob69ivK3XfjhflyOY1EFhK6pOxw6JMaH5SNmkw5
rUNCSpdusubT80PxXQahrJXm6PoZgk5IDz9cf8ohfDXNDM28bV4MSxWFR2ee
t+l/l0bw1MizbVcR2Lhx4sFtn0pQ0dbLwMn5DejGXJzlz68Cgwn26AjbIMjn
+1CXdosCHEkGOxLPjoPyiLuWucMUUFxlsxkzPQsqW9N7m7H9TW7FbZcQhQVg
teeu8sNcCnha9KTuZ+gyGGcs+ze3WgUMe/S8no6vgRntPU3L/dh+5hDLk+qT
7HDB7PEtg5CbQOsoWyGZhwPmX5M6eTPWCSwe83nkOcUBc+0cvrdfJIG2juIf
Lyo4oW+YuvSJd4eAR6SQ784YLhho/e8Vp68a+tDycgE6ckP2E4fiAi+dQM82
X7TOK/BAk8E4CQMLU2Ri9pPmAyMvfHOF0/t+hDkSVhy4/6uTF8pmCBJM9Ujo
tZJryP5UPriPMl/NwE5C1nKOJ/xd+eGjk6jotoo5GvkRuvThuyi8ulr47lQe
Vn/yFLbrrPwEgnoebIbGFLD+iibWv3kUbGcQtOP/gu0Hl+4Mp6vOALFGEfpL
WH3dUurYDLj8G4R6pj5nbcDqwYXRg5dKOKBLdUe8rqcVKK6elIg/yA23K2tT
Qi8fR/X7LCP6t/HAd3MhzsmRp9Amd4K+XxsPvDEVKTgrbI7+HdxpA7N4YZea
34MaBRK6d2Sq5/Y1PrjXV4un7yAJHbDa72uUNwS+y459MX1CAR1r8UGvJidA
lSdlvWaeAsjBGpx+T38B7z5FjTqsHkV/3cZG68gDJ1ISPqkymqGMmH0V7Bq8
0KCx/1FFlznSPvLmbQoTH3x3S6rH6gQJdR9e2d/XxgcJk0zPOqfNkc3kkMfk
oigMraaJE8+QQNtrp+0CRSJAhXzXtdhXFWBw+X26TWcTQFqNrM0MVWAUVr26
t9kDpjP2DpWxUcCrbIeylK5hMCOpsKRZTAFHN11CvAWnwLpp2Sn+VQrINwu8
tu48Dxo03nLE/aSA2nqeF7pJi6DrmE+L+hUKOMHycD8N/SrY9ucgqRTbfwxM
/pIRO7cOriVE6QzqV4JtfY+rTwf/BR5PPaP3NZQDmu9VucH0bDBPRm+xjz0U
6N8pDL/QxwbN3IhT1SO+oOuJQ4xbLjvM0OkNNyG6gTjN6d9fXTngfpFHmsTd
dqAvKsNRWp8THsu3df5FOg4i+/cH0rNzwRwbQWmH9t2oU9p9ynuWCx55eYbL
jfcYEuWdWzz+lhuKEQm128+boI49mhnJ0Txwd8NzppM+ZoijoMZ21IEXtt33
m46kJ6GUclo9uwNYPR1n3ueJjc9TxtyRB1b5oJfrZ+/O9+boYcy5n/Ot/NB4
0ymM8toMfQos+RqQKAoHViIO8xJlkHuM/Y5SXQrI6b2W63uxEhgzyzPzqHWA
m5dKVVyx8wWzhJuJ+4sBQCo0i2y/RgFRM6t5X1bGwLpEt2R4PwVsREi9MQuY
Bbkn7UXuYf2/ZfnVlG7bAvBwIKitv6SAkOmtg6Inl4FY3ulrRxkpQI53w2Xg
1RrQ7QDGmkuVYC853m+HNjvMdN5IvXvAE+Sm5bnx78b271kTgyKxl4Hmbs7q
hR8ccFsJ2W7m+2kgPjkpxlLACf2X4+bzuA+DIoaz4hcCuWCJkIhOuKAKoj2+
FfDNkhtmbNxtAq8M0Vxjgp+zBA8MZr98gFbCFPmGtLAd/sMDu71vbe50N0eW
r6+8027ihWOZf/W7tUlo6g3z47o4PljtytJwkZ+EvDl3vKOz54cSy2Jbiobm
6F3S9Y7aNlH4SOOXVeWMJAp8byxVIf0TbJtUCeDQpgDC8cKD5ZdGQbRF7Lvk
Zqz99kSy46dp0PehVTcam9/mnVIDW0q/QdCrGFfWJmy92RdoMZzDARNeM0dZ
85wHMyrKpRKi3FCb77qZ/GN9tGNeS9lqmRse3Os7H2B6CkkcDz07Wc8D4x/d
KpqmM0dKRQ/iHyTwwuNWbNsvyZJQQ1n4PKstH7RwFKZDSiR0bkp1d7j2EJjf
kPo2G4eth7FHRadDJ8Anhx1em7PY+mfC+Bke/AXGSjL1CHMU8DV5pvb2GR74
oEp1bV+fKfqE2JsDD/DCiXghNn5sPPm8gasLm7zwQNC13TbY/GZ580DbrYEP
bhncWPJYMUdHc5rNB2dEYfed8c8bQxKo6MJPlvnlKXDkdNjn9D/Y+OD4lrP5
ZR6Uyr19Tf8NG3eFeevq/rxw/nAybwofCR0sf8evqo/VD+HUTwGQhLRqnjpa
14yDjVfzIm7jFHBlNkGryWIOyNfZP8lcpAAxkfm5sxy8MOdJxyFyqjmaKiFZ
Pxnmhes9XxSHsPPYPfEqqb6cGZC/PFneg33+h1cBsjNFvPDPl4zbnKokdLrM
8N2kNx80eXvLgiRNQi9tx/pvGU2CqfOqO6T/e/+zlQVW9PPAkDnN6O8YBdw6
f+RZjgEvHGWWZlueMEe7y2XIBlx88Gg/z9MgbH8TILv+4Pe6KLz/fuXdgq0E
Sr785eMTEW+wM7fhWEp2BfBUIOTbb34E7D5vxyo2KgFb2wetD496QFdE9DW9
3dh5x00tvCpnGLB1DbO8KsTWU3vzQavxSfDe4z1JZQUbP6Iy/RVm8+BVLbdv
9QAFKNo0DU/cXgROe3PMUl0ooObldSmRyRXguVGrI3O/ClzZR3uVQ3sdXNqf
fjPZrBKYj72ul7r0F7jvOPTsSXs5kLvwMrzkLyvkOuZ8dcY0FPjJu/6h/84G
z8qXE68f8wNRhgfnlTLYof9Hv+sSV91AeboyA9sVDmjb+zHha7Ad2MFVs/PH
UU7ITd6tZGltACQFm7/J7eaCJ3cWcNK8pUGLTryHGsa4oO2S4kGvdB2k62/f
vL2aG8Z7bsWOqJmgK+KHZTpCeWDItqgRpktmqGjmjm+sNS/0vHyPjrRljirW
vpySleKDV+s9HiN9Evp51EnXfZ4PFm0nMNz5ZI4k83xlnr3nh2MfyfePV5sh
zf7ctxsPRGHDFo1Pg44M2rk/szympBIY7PdY7TlbCXj2n4/j/fQVnHtpLLdE
rgJZc6uJsd4DYOHtgeSPTth8Lf/kM9cwBhzV9U9Y9FEA8fcedqXjs8Bt6oGE
HrZ/zJX0b6gf/w1gSZtu1GtsPoUXOb1TWAYmQ3xftfdg55/yjqu0CWvAZlvx
iMZWJdACpNkCdXaoetnQiPeuJ7Ayufl1gAHbr8ywKPWyXAH2LnZtBzs5IJGp
843PQwtgeoPhY10OJyzU43G59UEJGGuv+kZ4c0H9WzO8ihNHEDEsu1HIlBsy
maf86zYzRKyye8ylhbF6dtrhqSSzKWJJfvvk6gIPfPNBbOXVRXO0tHCgf/Yt
LzR1YKl4e5SEGFb7sqKi+WDWcXuXc0IkxMh0Jkj3HD880SnWP2aG1ZM1uwb1
VlE4/Eb5WQGzFHpx+lzlYkMfSGaa9bXQwM7nHKHbvh0eBb0+D1RrPlCAlvSh
df3EaVDSPGLg9d/+JbvjVI3gb+C1Etj8q4UC7oW3XhFO44BXz+daj8+eB0xe
/RtuAth57B1jG8tBfSRLKt/L+4sbPtcNlHtx+BSi2PoNC1F4YJZA+l/dJTPU
/utMgeZ9bD9m+VnsjCQJ9a9abPSe5YNq2/IcXFVIaOFVnXk2yxDQCHjmmhRD
AZFWPEvbzSdAHuOfqz4zFLBZNiUjuj4H2LyjDuf8ooAVWrtENTMeaD2S67X0
3hQ5dO00L5PkhafYMlvfVpsjrhUG1uQVXpi2HkbHjtU3mRV7Y7UaPqh+wjSW
vIGdZ+hrdc5PikLOcQ7HTDpJ1NFYf60dTQGtdfXP4lh9yRsJ4KGUz4PLC5ee
RHzH+mfuOsf4LV4oXtgqHMxJQifWHojTa/HBDLm8z0FaJNQRceOIb/Q4+NSW
mZ8wSgEx5n6pL4TngPaS4uOGJQqoVB2/dX8PL/x6ZLta3QNzdHeJz+tYH1Z/
uwsG32Dzofhe6l3kOgOIGjU1+7H+d/ito/sonxeKxtHUMB0hIfdVvrbXN/hg
VfCt5wX7sXq6v7roAf8kcN2wdf2HnSed+c+UJ7X/ArOhH4RnJihgt6fcwT5t
XniLvkmEbtAc5a7O5y3t5YNmTF8admD9MR85F3JtVRSytXjErwVJIIGHURIJ
ZlOgg784dhhb/4O9FNQTD/PBqKy0J3+PkVCnyLEzbqWzoCj+onUFVr8oN7Kf
J7XxwhbvBenX2OvrVk4whH4GaHZyRNzFnv8xtm+ZSuaFC2zjRxWw/aljwxXT
T2UTwOLSx2dO2Pf309O3T5+OD5KSC+Et7Hmi1/683iM7DRKkTu2lw37e+CZZ
5/ckNl7syzs7DEjICXW2rP+YAVnd9IvXsO9H1r2STauMF94pux83pE5CAo/2
7rUKmATpjI11mlh/u3o5eqYJ8MET3WUrjdjPM39iyL65JQpbnQS3OLQkUBPl
aUK7yGUwH9A/lJxaAaDpcbmLsR/Bzry4/mcr2Hkl4WTUqH0P2LgQ94mRiQL2
fM+Z/3hvGFjaVC8PvsDqxaPGvUYtk6AguLGoBjsPSUfRJPLqzYN9X0Y+NA1S
wJxc5j8V10VwsjD1s647BXgGWEm87l0BeRyJS+ceVoGD2lGR0UpYPV/uer5o
WQm2rsBj8Wf+AvLHj69bu8uBjmiel9E6Kxx2Hxt94B4KuHZ+efX9KxscGG72
p/X0Aw6iXOm8qexQI9HV/hPZDRiY9TO/cuSAjSxxfJQaO0Dobf5RoskJbUZv
54eOGIDVqiSahh1cUNfsZJGdxXIN7Y5r5peHuaCim5HFJwcd1HWQUDZWwQ0j
rPnHBWRMUElxkYtLMA/UUZSPUDlvhvyjHcMdrHihS6/oKgGbP42JKhas4tj+
NN/J1xRbn7OryFnss3xw/a1ybPMXc+SutMs0uIEfMh2lY2CqN0OezJlVKvGi
0C+OsihtIYNOb9aTfacrwKRufXEwqRLcpribP074Cgw+M6a8iK4CLqZqGgSb
AfC+h/61uiMFjAuqDm8+HwPqO5kKlH5g51GxwKMScrNANPli8GOsnvuTzW6L
9P4Gi/QF1w1LsdctIkK4xJfBnMMhkyoWCjgTXnc5PmINvDvMeEeRrgr84HqT
HajCDocU3lWmvvIEipJWIW9psfNojvLLA6ZXwAqRqedzOwcsuXpc3W7ZAjgp
sz95nMkJE591/GzKOAIEht7lEDy54AKrsuug4REkJ/5nssGYG6qO9WzGixmi
jJ/vAROBB2bclO27t80UWUmBAcZfPHAX+/XACxfMUX0c20x9LS/kpyWYZ2D7
I7aEY/muEXyQdu7z4ePCJNQaHNQ/bskPX+aHixy2xM73EucpPs2iUKtrVKhM
SAppEYZpWeP6wB0K1z1XVQrw8Zm/PCwwCvYT3ujqvsfOf+czJVVvT4PIzPws
B2w+dezJ30lg/Q00mt48Ov0JWw9VPTxqn3LA+zusWprOWAMebgUhbl5umPbU
XNRmXQ/VbL+xsTrNDd//jPJjkTiFts+tSlSV80CWQREmwxkzlBarXskewwvD
B/adUREnoZkERFNnwQcrxBQXyrH9WDUnwx+F1UEwmZbyzjEa2+/U3TnHpTYB
Ejp8FV5NY/Vx+txZjv45oJR47a4Ndj4NLxUI4TPhgdtKb3ofqjZFhQ53E033
8UJ//VP5y+XYefzhhKD7Ii+8KnVTqAvbnyk/ajYjVvFBukOJRqzY/mJKoVL9
ybgoHJJYC2LkkESO64pP32ZNARZ/vmf9/42PE6Qv/C/mwQbh2fO3XRTAEnNK
mOLBC4W7E2R72EjobOKmzKQmdr6Njhl3w84Pyb9+pkbcGAfh8D0lYwTrr/C5
1mTGOUDzrNTdEJvvDO/tKLI7eWE3W1vo4VhzZP7gbwhfDy/kPjhWsQur5zp1
rKVFpBmA2vyTjLD+l78vYXb1GS+MfXhNxPkwCQUmBH9LdOWD4evPwgwOkNCu
eEneTNpJMDIMf9ti9XzLuHkssuwXiN+VOtY9SQEWtPkeXpAX6ti8tZv8YY48
E76++bibD7bXr/YpY/VTsnLC7/myKKxyH4rYGSeBCj/8JYUrT4H+sNu5wVg9
J/M8OXpbng9K9LSUI12snp4uC7N7PAtm5DW8xLHXI9nDy6+38sITBxsyW3Ww
ehzbc/3m5DRYnLfL/O+848RSfBc95oUVD24ZkeRI6IB0Z+WPlAmwle9jWIqd
N15wWU8J0mDfP7+ymTv2PARZ56Etlmnw3v/us29YvRbgvHGqcYwXlg39ibXD
6vH6gv7GdN0MSMlavPcMe32dNVmIu4QXHmu4/eWOGgmNbfjcuuw4CVbrvxDL
sP27Js/xOzd5+WC8f2ex9H/5499/T19visJf3LtHtk5JoI4DQ8VXaKcA6roR
VYCtTy8sr5zQk+WD7r3GLUTs+4ipfjKi4zALxia/n5vFfl9xM6N2nve8kONv
OW0ntn4XrdQ0W7yeBp/YJwNDsd9X/7Qo/Yc/vPClT6EBxH4frXgTMNgzBe7s
cgq7hD1vubnyVdcB7PzhcbbADKt/xLP7LT9FzQC9XYM3tmM/32PBnCzEzge7
m/TymrHndZJcYY0XmgHGgvlb3tjrLN8T224w8sEx8idvV+z91xvCQgX0pgHz
RjujNPZ64LeCIwKzvND38CJRBfv5ziiHFKa1GUB5IDixH/v8jK47l5uF+CC3
OMPt01h/dqbsKjhCIwZP3q9mPiwvgXDP1Fctu3WqPIXqmQFqh9s//E2gembD
ji83/t0lUz3T4I43f9hIMNUzU0Jk47/H2FM9k9tXcGpXvgfCPVMmt8S2yysc
4Z7JnbvLmfZzPMI984HR1JIP7xOEe2b/RDZp4Ecawj0zpqA5/RspC+GeqUsj
L8r1Igvhnrnyz7zMXTcL4Z75MGVL/8/rTIR75vaSl6waOzMR7pmWc+w13gcy
EO6Z63Q+AsxH0hHumdkxd4rG5NMQ7pmesrQ5B1eTEe6ZbGuXuY8GPEG4Z56K
7PedSk1EuGeeeN7LsJH6EOGeWfl818rFl3EI90y/7zdStKpiEO6Z7c/LKkrN
whHumY+i7s5ajAYh3DN3+LUGsyTcRLhnPgT6NlafnBHumTH2jkXj+nZUz/xz
QX/mYTmJ6pm3bCX9fsboUT1TdKk9ILbhINUzo9H1azEV9AD3zNEjhloGeXIA
90zBWPMuEoMywD2TFC6WsZamDnDPZO5aVw2d1QS4Z2Zs37v/50kAcM8sKM3j
q4/TBLhnMum9z69bVQe4Z97nyMk/T6cGcM/UX3icJpClDHDPXPKjf1+uogRw
z+wO3vsg7p8CwD2zbIci3fWXhwDumXsesuaHmh0AuGfGV8tcS8uTAbhn0jZ+
/oB2SQLcM3l35U140O4DuGfG7fUlxG8JA9wzgwtCrR7ZPKF6It8m+7ua5Ayk
Wfbh81vRbbAoyojT7msWijG5LvWqlBYyPXczN7mdhXKuJh+KNKeHZhZ6PT+2
ZaFXR7786llmgCp/m39ut89EuC+2PTsZH1/mh3BfDI0b4pzwdEO4Lx4LuPfm
t+Alqi/uFXjD8vjuOaovVp5h+jthYUL1xQnS8sPzwZpUXzyykNPh8IyH6ov2
OV/WrmqKAtwXle8M6hzVVAS4L/IphmWiAlUwQc6fylwVgNVfHeN7WDVB04VC
pqgmQSh5bFWH0xAAkzcHdqk+IEAbDsKRij0AVLYuD1s7CMHKtFOtB3o0wGdC
f3M/H/Z99sR8rNquDnCvlA96SavoIQpwr/wWIHZ6ak8y1Qt3TdBbW9Wko7kT
e3/r19DAY89/KH4dzkJKc+ZWh01pocVijmvZwyzkDlN9kybo4PDj2HizfVlo
wK9UV/Q+A/x6SnzqdnQmwv0wp3mxJEg4EOF+aJ3zcKVJ5gbC/XB2gWWxousy
1Q8PBeUIfz1oQ/VDURaGaacZU6ofarAxZWUoaVP90PRCi4ycizjVDzsWzcN7
RXgB7odaC/2VI/OHAO6Hut1Ll3ncVQDPtlf9/HUC8JnvT4+haxpAeod4aGqC
IGzU0+iPkATghd0qs7EdAUZslxMrVwIgl7P5hrKcEOQOvDLsrK4J+q1pvz/e
RoQXTrlOlgSrA9wjzx+3KlFUFgPf93oYKXb9A+TzE7LzPpkoRji4UDNiG3xx
95Vga20WGisOW5XlpYP9E8flhu2yEO6DQ3tHyj5KeiPcBys71cas61wQ7oOp
h4Ov/kpyoPqg5VNicd26JdUHa/bdt++cM6T6oG5Tg9R94yNUH7SUfco7J/Gn
BvdBI/bc2yZaUgD3QfGugT2C2kpg5FiRhq6lAGzpa1WUoqiBCmLWsoycIDxu
MDATSdYEV8qUYjz/CsKXezryvS0AWGJy2i7eSIDkGte4iE5N0BJKNA99LART
ei7r38H6F/dG/n8ep6zeiADcG+9a5GzeHk6met/QXmbRfqN01JhQHBQVRQPX
Isz2yldloZ0a+h63iLTQX+3kpkR6FuqSTiOmF9PByoBLF+SUstCtVAn399YM
0DvwxwHftEyE+1/Ci4aTL+iCEO5/eQMyly6weSDc/6xz1qKmDa9S/W9N0DXy
7BFbqv99MDhAe8LQnOp/sCRvfJJ0jOp/Z0fGfDV6Zaj+t0A8XLvtFyvA/W+X
d+zW9oKDAPe/mXf1sbz1yuCgimLP92wBuNViGfJxtwY4+2OwXspfEOZXne1W
YwagR7mXxfI4AW75z763OQZAWkWp2j52ITgcc3GX7GVN8OmvRMX8pBCs4qbn
21GjDnBP7Ojf6Rj1VAyIHe6yDbz6D4j8uWaZujsTOTrvA0Gnt8GGb3c3rZqy
UOU2XxaXcVroEfjE8qxrFsJ9T8RFSD1+3gfhvtcsZLXKmeuKcN8r4dOyP/3t
ItX3DgVd+UMsO0v1PUOb/R/eaxlTfY/jklv05XZVqu+ZcLGlOgUwU31P7cfT
71Xm4gD3vRzuvZJWxw8DhSJZdyEgAO3LkxqtVdVAm6XE/DibIHxuMCGWTtIE
j6MWmmlGBOFR2VClcTMARAYMmQ4WEGDj5u+1lkVN8FZql4B7gBA83qwozJKt
AXAvfCoiIRLCIQq4aJ1tGH/TwPtKTkf7e7OQtHjsX5UwThhEK090MHJHTU2z
cg9U+WExWBrZIawA2kL29X7ZLQB7FmdPfuFUBTQf949e+CEA844eCaxr0ADr
Clf0OF8JQqOy2w8r1AHwj2bfo+NLgCZf7fR4xQA4thwm4CFCA9Nv59AXTmSi
j7J7N0OJnFCZ65G1js0t9KhXgemamwBcOaYdE6OgDjImiBsuxwVhWpw2+563
mkB12MdkhosA9wm+/sx8GoBGhRAGgX4C1K3/7ij6RhPg3qdBY5b25owIwL3v
4G3rkH9GKVRvU6vU7nbhTEfyGvRNsu40MNvnR+WD8CzkMVIXmLidFj76u2Xz
MicL7UojLmYl0MHbihs29ppZqL5oICzpGAPkf3hGyiA/E+H+9jjM6FKcRxDC
/a2KzlkgpM4D4f52ZyPvofwuZ6q/2cw1a1XW2FL9bezl0m4BGhLV33QYEgoJ
LrpUfzPfKUb3JU+O6m/S6xpfuu13A9zfXFl3XvWgOwhwf0svl2Q/c1EZqH+7
+f1wogCc557xhl3qwL0RDV53E4Q+kh+OFm9pggXRVtY+dQI0FHsuL4mtp093
PU99wiAEhcPkJC/4a4LO5ApN4z4heEth/z/eXnWAe55b3ZEUo89ioFlvp7P4
4X9gWQS1w28ZqJ31VpiIxjYYKF8uNv8pC4nlLQmQP9HCOfqE4FFPbL/8P1+r
ybnrsL/DF+G+dvSyb909ZjeE+1rL4PWt5VuOVF97ebLnkMtTK6qvqffGCfB7
nqT62p8/i9HvstSpvtbjFdrHOMpO9TXdJJorDZ/EAO5r3fzk7QyNiuDs6JXd
0fIC8GsV3UW3ZVXwY8lp9hiDINydvrw0oKgJim+2TR37Lgh//pltkzYBQKVZ
Y2dpGgGGt101OrQNgBpfmsAJNyHI/mPSdx5pANzrCFLO22R0REHws+rcZ99p
YPxmsv1UfxYKUm08luzDCV2jpPc+qnJHo69in/Hu54ekE0WctlHyYK3C/qYm
jQBsXDw7evOdCth90WWo+pMALH6zOn//sQZgI+g7ns0ShNf2NvTbKADw8BYD
88frBDhSR5Yd2Q9A4laasN52GjhQq/5i8FUm4ljME6Fl54QlY6VFyTpeqJrF
PbPbQQCGUWrHhP+ogcIQu7VWNUFoO1my2J6vCUxbLV0O7SRg67Onjw22nvUR
PBnT2wkwdaC1rqxRE+De5n9uJbMrTAScXbBRmcqigRWvzrAljWehA/aKnfa2
nNBUiY9rV8oNpLVAlzUSKQj/rLUayAgA8NZocu9XEgH+PR9+L0YTgAbK6EIE
URDCWukEKQ9NEJzOUVA1LwgLtbtqzLD5PXQ8WrKtWhDW5YQeT9YB4FK68G4U
RoDMwac5rXkBeHSi/y+rhSAUV5N4rdOtidX5p4eeiWL7wSnm11FYPcR9LFwi
eGJJRgTgPiZR94IgdyeF6lN3XtPyyP5JQxN791+/fZEGtk+n2aq4ZCGp8i1G
qQ1svWjZ7HTMy0JZPTY/xCPp4OoLh3oXrSzkpFIdR6vCAAsMTUv3vcxEuFf9
eFdy/M+LIIR71VelmafGsjcR7lUPGVUeH3d2pnpVmUCcvyedHdWrtJN5a4es
SFSvunrZQUVmS5fqVQ+ifH8V7DpI9aqn7B7e7x/sALhXlW9o7nE+cwDgXtXI
0far9rAy0Mrk6nS4LwD5z6reXKaoA/8qOTfWq4LQLqan1mRFE/jz6salKhFg
kvvi+2wjAB6XZH/p3CLAxK5V+ufhmqDnWvC2v51C8GrLsTO+k+oA9y9+I70n
HRNigHBK1O0P7z9wzOaaUkhFBgofSZW5cXAbjLiwYr//Sxbq9juUSaynhUf1
BFcJPlkI9yjfgktc48f8EO5RBYWhQv5abgj3qEjnq6fDmhypHsX61yxvnOUc
1aOGyLriHEwmVI9KBF414nEaVI8alj/5IEqLi+pR+/MvuI5vFwO4RwUqVoQU
ByuCuX8RZ7RkBWDSBsP2hS+qYKieacZjSwDuLjV2eyaqCWquAJ+JNkGorWvS
0Iz1T0Ptm8hbjwmwc0eeyv3tAFDENl6JXhWCY05MWWKtGgD3rUb/2SOi50SB
ss/YibUmGtipdI5reDALvWgYnDT24ISx3W+zXBbdkXv2gP05cX5o03mcHWnK
g+iO4PqlP/yQfTPURvKpCmBTYBmceS8AbY7d4I4K0QAE9rLlzWRByMToXL1P
DgDiNf+YKCcCVEkRcL0mD0AIo5W+7eI/8Fp6KfLao0ykcnr1MNzNCaVtTLwq
3nghE5n787HWAjBmd87Qao8aKDGlW91UFIRD2wvsfydrAuv691tf6QiQzdIn
7gFWD5w4ft21byHALi3pUxWfsPr4P5/6Up7UvydVBLC8i+hTTaSB3pE3l290
ZKGzsyd9OK04IefpLOmF7zeQ8bi7QliIIEyI0dVy5ATAWNuO/PAktl+uyHrM
owVAU+Td3+W8gnDv4LizzEVNEPPojrr1lCAcCHk3qEsCYE5zo8y9TBCmHhD3
7YYALDx6HB0URIDpprNG3QRs/eIL3IQmgjCP+5WfE/Z8cnO76o4LEuDpZo5/
C+YA4J70+HNb7UctEeB3pXffD38auP3x74xxbD9dvC2s3suYExrXPpF9ddoD
OcqZ3+fTJsCAiyeOOuoDkBNoa5XZJwhHWhbjFUwBYJTq7izLx56vzclFXRkA
3a7J/hgWAsxW79b+idWvLCHlh0mvsHp8RghVjmYhzxfZgryrgvDht4EVZqw/
O80Fk/Y3YPubCCTFiL0/F71cBr00AV4VLG7pPgUA7kHZv7J3KXOKANyDIn+y
jdcmp1A95p+iiNL26TSk7X20dt8FGpj6ZuBeOHaeohcRNPi9tA2Ws9gHo/ws
9HuV5sulO3SwO/vuFXedLFR1W4anTJ4BZl066U/G1gvcZzZdOLKlPgYh3Gdo
skezi2xvItxnCkS95+WTnRHuMzyP5Gx4xO2oPtN44UsOIZJE9ZnfFXYNJ3X1
qD5zl3HuR8+lg1SfoaO9UvgqlxHgPhNi7QKKth0AuM/w7qwbzRZUBjo7L5E2
7wnA8I+yl/a8VAf0SmPlQ5cEYcx+/lNrvzWBzoPg9kAFAmxX/lDQZAwAD1Pm
FY8NAvy87KtYfU8T/Pg2ZtfxFdsPZ1Km0ufVAe49Rh2HEtKXxcCHby8X7Xb/
A4oycQkZzzPQsFHJbX7pbbDim/Un/fYsVDJ2cmyiiha+NqzNLffNQri/9O5/
u1Xj74dwf6lUoHzPPOeGcH9Jj798THjJkeovuhKZ7kmG56j+Qse//MLhoAnV
XygE1V3jTJpUf0EMpPDdHtxUfynrMR++nSkKcH9x8En9lWyjCJTv8QYKSgnA
nQc+m/9CqmBU6uzV3RsC8FtQYORXPqx/RlfqKloFoaLjvVDfEwBEqi02WSYQ
YO3abe0XOwFQ814zqLskBGNfmji8/KoBcM/pt9wZKekkCuKH11PSGmjgBykx
5R9D2H444leVhBsn7E34yXhv7w2kIsRU/1cEq18W2/f94ZYHnbZsk59X+OFZ
R6N25TAVwPnYxiakQQBaREoKGHprgKx71zU+PRaEpiW2a/YyAIyNV35yvkiA
nxhO5z1WBEAuarypafQf6FQooy0Kz0Qt21NA/w5OqFjmsvvtLy/0uJzIfdVK
AKZU2atlN6uBNxVmng8OCcJgn7le4wRNMKIeoJtNQ4DRgQW772PzTS5W5r3O
RwJkzfiS+6xdE+AeI29Ef/9Vvgi4KpdyYPg+DZQw/8be8T4LuRafPzFnwQll
HgwscS/fQB220r6WQYJw22WXlj5WADhqUto8T2Dr42LIeoM2AK2/O11NuASh
QB9x6tZ5TcDBqhZyYFwQJmnd9krH6o9HRfE/7RJBeMWgVfAbtv8pZ/3eYudP
gEHprShQGIDUoDbfrhPYfuiW5LumD5qgxOntDn4+AiTNDzpEYvUP9xPSxV9y
GsYi4PvXX7dCvGigTlaJBniYhT40PnhwypATyq2Uv+SP9kCyeeQvG4AAneQ0
yj8fB0B2gyfTo0cQZueyTqpg9SU6k0yIeCYIT2ecDes5DECLabqEzR4CjGSc
4pDC+utf+Inxo89p4DzxOu3zsSy0KX7+4tSiIHR5Mu1XhdW3c587BrZqBeEU
+zf687pY/fUfnfwmToAKFnwMFKw+4v7B+9nWN54oAhZMipTpjnFC+T2G16ZW
PJDyfJg8d4cgXDB1EGc8CUCXHksZ7XYCzMk9ZxmCfX6p1c2ouBTs8x8MFbNi
6+UOgZal6FlBWGwTnPAd64/cG+beXkQCvFd/rVIf69+n6t7zqac4YZtQisTH
Ax6IyJjP3j4gCFU6yle4sf1g7Xn5xGp2ArTVcBQNxJ5//tDcN711QUi58OOU
8X/1+H8+Ie7YmTDEJAJwn6D5f//NI9wn8DbuE3gb9wm8jfsE3sZ9Am/jPoG3
cZ/A27hP4G3cJ/A27hN4G/eJ/7Wp963wNu4TeBv3CbyN+wTexn0Cb+M+gbdx
n8DbuE/gbdwn8DbuE3gb9wm8jfsE9fn/5xN4G/cJvI37BN7GfWI/46d/8Tt6
Ae4TZyuzH4gSvgLcJ6wAo4BjQRPAfYLeZTepO6Ue4D5x/atITLFROcB9ImeQ
UkyzUkj1Cc3IFquDRhlUn/jQVX356D8y1SfS3u2wLWZ2o/oEmZPwQVDJg3rf
ak3b7bWvQSj1vtXSZa6Rs7TR1PtWNtl9nduGYqn3rdY7bmYrJZOp9616Bikj
noFk6n0rE50390/mx1LvW4nNn6p92XKPet/KizD10NkxinrfquujXzgrTQT1
vlW992W37tS71PtW5KUXVj6CIdT7Virfh520R4Oo961ouewlPh4KoN63wscf
7hPU+fE/n8C/H9wn8DbuD3gb9wel/QoKyVH91PtNWRsHVvM/dALcH57dG22M
o2sDuD9US+0RHTjXCHB/yOo1XWDRqgG4PxSl7s0xv/ca4P6w5Ol9/atwLtUf
7Hhzig5MJVH9IfBRbMsNgRCqP9QSrW9pPTyBcH9YMnNWvE4KRLg/OJPbJ815
IhDuDzCi0aLqVAzC/WEqzc5jzJ6MtoJ12OVCiLDUKCKDnE1GaXondMvmiTDX
TeBxrjIZsbfFXcmyFIbXb11M7/kYQ71fNVm+XpJcHkj1CLy/cE8480lwrpt+
kHofKe539JHcji6Ae8I3Hs8E+eAvAPeEx7unZ9PdPgDcE0RaFDVOfqoFuCdc
+xw5rNtZCnBPGPt5Jqnl8nOqJ7TpMc6cYEilesIAc21+YE0k1RNqA8T9SZ8t
qZ4QPmrcEvDBB+Ge0DLbQLEwCUO4JwQukSTldO4h3BN+nmu7aC5PRt/J10ea
nYjwHLPWVsEzMvK0SOnt+EaE2X9XpW7YkBGtn6A2GQhDopBh/UHNWOp9qN/m
zX+tjYKo3oD3F+4JApurZdVKfdT7Ru21wcPrgx0A9wRm01HOl7AV4J6wWk1j
W+bcAHBPEFnJ7FGXqgK4J5RcC2kacnkFqPeN2Dj5CnizqZ4Qnr7w5Qh8SPWE
IrFU7g0+P6onBPqNRD5+7YRwT6Dh1CtwWA5GuCc4CXY4XXoWiXBPMCcuFiQc
iEW1P6tqxRSJsEacs5kYRkbiN/m0yKlEqLBe78ufSEYfj6wXJe0ShuSHR2p/
M5Gp9502eNrJ3BKBVF/A5yvuAwGXV9yCXwxS7wd5MAx6e0x2A9wHuD6g7bYn
2gHuAztIAQd8Iz8C3AeunnA8RltcB3AfuLict2NrVxnAfaBgm7w5l0QB1Qee
7lvlYxhIo/rA/M4QaTaDGKoPFHH1CheuO1J9YOLe/W+Sj24h3Ad+eIV1epDu
ItwHlIm7KrnyoxHuA1NvpGWr2MmoIYGulc+KCI2fzSD+LDKyu6CXY/+BCO+q
ljz1dSOj9S92BxgVhOGAOtO0xc1Y6v2koseKJ+cSg6geoFh8bEDu3E/qfZ9z
VgNvvrR9A7gHiLWBp4bJnwDuAZ9o2L5a27wDuAfszJgYeFNAAbgHWM/HAyvv
YoB7wGnz72eZHuVQPcCzutUlKSyB6gFZTl+vaNEFUT3A9fn+U8+lbBDuAWlj
hAbRl0EI94AQ1UPqL8YiEO4BD+K6+k43xqAP/ka6wRJEGB7NwaV2i4zY/F5K
998nwlh/1ztyaWRUAjJ9JbeI8IoMiVVQhEy9b8TiJFPj5hKIcD/A5xfuB0kl
ahov7Aao+f/EwPx0vVo4euU28NzwuBA8t+saq+KXe+h7jespDWYitFuLMvh7
goymIro3/DyJsDAzvEUgl4yiTi6z6A4T4YC9LYu3ERl1DB6OTizF1scKIeat
e7GoXFNa7T0kQmbDbbbV8WSkej30zNECIswMYUj0u0em3v9peHrzrBgKoOb9
+HjH83r8+fG8vv/d2urrWz0Az+vT9/1sMSxpB3heH53NLJnH1wTwvN5NqmqP
jkQ9wPN67i9cVabPywCe1wtbPT5itLuQmtdfkNcWTnyQTs3rWa4U8kTtJVPz
ehrFmduvvZ2peX2ule/fpembCM/rzacWl+jbQxGe16fZ749csYhGeF7fcbL9
yCgt1h/8xke1zLHxTpyL5UonI8vhJ7ue1xHh38LR1+reZLTiF7qvTlYY1u68
/ZGfHEu9r6OtusOMBgVR8/mgNynB6Qs/qfdfSB5rskmGnQDP57USLuRFmHwG
eD6feHXcOaDvHcDzefOrr5n7b1YDPJ8/cUxhaBvta4Dn8wElJXxrZ55R8/kB
6emka6WJ1Hx+R3attGVUMDWfpyk5m6113QLh+fyMgYPYO/oghOfzOu2cNJpB
EQjP5xX5XjncvheDWoy5mA4JE2FazPN/NNfJKPzfnxTGKCLc8fE7jXImGeW/
XR1wWSXCekvHO4n7ydT7N64sl4tm4wOp+b0fYft1rtcD1Py9KHPAbuF9GHrx
9tveejWsPj+0ETKIvod6Y1Q4ZrYTYVFuLjZrsPG4R8w1y4UIt7RLWfWw8R34
9bjnvR9EyKN+MVnegozaFGTmmXOx+ZlWVUCwiUUU5sW/N1WJcOYPe983bDwX
/f7c6pRDhOa/kxX5sfGO5/EL7h85VekCEZ7H4+MZz+MNfkQzbFoMgsbzjxTi
V4Sga0z1z3BRMjLmqLBctCVCv69DyidysPpYGHLn637seZROuSUFkNHTNYc3
ZYlE+J5xpNnrKRl5MMaGkW5jr3ssNSpg63HJdVsvHj0iTCwls/zA1puGKdVR
3hJsfT4RqaeDrUd4/q5pceE69Aqg5uH48+F5OL0tk8xn1APwPPx1Tgn5z0Q7
wPPwOetE3lL7JoDn4eKGxUlv7eoBnodfMed0I26WATwPN+Hi43sUWEjNwyeS
ma3t5tOpefj686eiNXfJ1Dz8YNSF51O6LtQ8vEvhl0IQ202E5+FPd6hXN8SE
IjwPL18vMEzaH43wPLwrcbef9FIsWj53Y+ObCRE2Hlc21UolI9N9ujXGNUTI
bmg5O+WH9V/7o7QUKWG4ZU1Z1EuOpd4f4U0vreNvD6Lm31Fzdk9aNfup9zHm
gpaFuyI6AZ5/M04Or115/hng+ffdebLsuEAjwPNvp56Ewpu91QDPvyWLn28j
6b0GeP5N97JU+FL1M2r+/aOKKXnOOImafzsnOEXUm96h5t/YpDhjOWKK8Pz7
4HvZy5UFgQjPv2mqdPaoGkUgPP/mEPZ+tO4Sgz698bmyg0CEXic1OVguk5H2
UaEzj8Ow+WcEy3yw9TebISOefYkIm4XqDsopkKn3QQo3LymBnEBqPq6r1ljc
0jtAzbf1GwPIqdFhKN+57ehfRSEYvgIiM53uob6V5Jtv6Ynwjc8/YKVCRgIn
j0srOxOhfvALTXZsvvlyLkke6ibCKu5TqkNWZPTpxz4Rg3QhKOl9jvWQfiyq
8bS4YHSECE+su516GElGVxWWwzYziLBhetX55UMy9T5Gs+A/cRHOQITn3fh6
gufdNWXXTrMFD4Km/RdWjs4LQSU//Rf1/GTEdPonW5g1Efs+WBWMsf1/I9fk
SL40EYrL33YJ9SUjC9VIV8OHRNj089uIUwoZHdAvOTrpTYS6HsXfETbf3nS+
6/6lTYTX71SEXXz03/yySS0oIsIQZZlzN7DnxfNtr8sferOeBFDzbHy+BXRL
hhVaYPUtlEGoJIOMWqs7RtxjiHCzPYj9I7Y+ZDdvlbLcwPrrlw6rAdZflTkx
T1M0iJAx6RDDMJmM8Dwbf7+49viUCxeJ0F/5030u7PkqGi631gUSofKbQDlv
rJ4UM/7lOmpAhGvm1XHCT8jU+w0sjerSq+YB1Dz5T0KZpsBID8Dz5KHu4nV/
uq8Az5OXJeOGvcKbAJ4nn67xeloVWA/wPFmlce5bm1g5wPPk4i+ZjBJVhdQ8
uenafFUuIYOaJ/uIHon5Vk+m5skmMcaz/pau1Dw50XPrZ0GWB8LzZD8PVZ86
51CE58ldHdW2XDzRCM+TW9i2WUpMx6L2v6FdQiex+h6Kbmpj35+J7pOENAoR
dsuwqJb6k5HCbSHrPZLCUMS54FxbZiz1vsGx0k3mwt4gan6snbA5RLzYT/37
/Zq73zfk8joBnh8zSxT/le3+DPD8OKdl7doX9UaA58fK7g8SM5hrAJ4fD3l4
yoArrwGeHyuLD/rf/vWMmh+v6bP/PP00iZofOzU/Xz1VdoeaH8OI55teSSYI
z493HyOVUIICEZ4fz6sc/TgsH4Hw/Di8cTxvwQab/1Oy/B4CRGhacMoh2JGM
iEOHlEZCifBaf9TJXdj4zxBfdb64QIS2WnUdc4fJ1PsDrYvW351fBlLz5e7g
jkv68wPUfBjucrn++HoYkqpr7Xl8SAh6oaffg0/fQz+lTcQP0BFhm+LFZ/3Y
+63/stoefAU7H93//X0MG59eSsdp73zH9rMlqTFy1mRkdEi0ajwZ20+K+a38
UYtFKJ+JpeIwNn5NmRMGw8lIv2P7Rd10Iixwaw+ewuYbnhefoX94iJ8QiPC8
GJ//eF7s/U1TGCQMgpaHby14Z4UgjRq/yHtuMhpbmf/Vdo4Ia6MPxldh9e+9
wZOHXFJYfemR476E7ccUe58aPYwnwgmlV7tPYevH7slGgoIXEWo969Ncwp6/
bKdXpJUWEWr+in7FjdWjc63ufquFRIjMPGo2o8jUv6+nz/ZUtS0IoObB+Hw9
56PmsEYiYvNHV3gGm+/51uN1lGhsvJ59v/0uVg+CnVnjz7ph+5WK45nG2Pyv
6oFGO9Wx729OqMMuloxcb+T45tlj9fXs3KcybH4/uuiXvysA26/LXNf6gbVf
q758/0If69/5HZP0j8nUv38P4cm+mOgYgHgoNoRoUyKkGZs1VcDOF45pu/1M
IojwdY/szE9s/6VZqGQ0dw1bH7IDDRSwz8fzX7x/ZUubD2vYEKF8X3LZV2z8
mD5Ld0j1JUIuo3t5AVj/4Pnv0JXnb37UDYIP0jNdjR5EKC2x/7oK9n4lh4Lq
OC8RYaA8OckJ+/c/RC3mbwUTIe/p4uSd2PPj+e/Ac3F0Thvbr0hctatJxz+f
hsbdKzOidFiA2v7/82EaGjwfw9v/BynRAJI=
       "], {{{}, {}, {}, {}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{1208, 1210, 856, 906, 857, 858, 859, 860, 861, 862, 
             863, 864, 865, 907, 866, 1013, 966, 1178, 1114, 1200}}], 
            PolygonBox[CompressedData["
1:eJwV0llTj2EYwOG3hY4tpSFLZuzObXEspJF9RlJGmrIc2pfKUihDIksiI9Ie
MY2ZrH0Ae8dEzJSlfICu5+Ca+/69z//gff/zpObtz9oXG0VRDD2Ux0XR8/go
6qbGXmauZBxfdQ9HOaAXEfFON3Odcp3OeL7pFxzjoF5MDO91C5fs65jMoL7B
OfsqJtCvX3KcQ3oJsXzQrVy2ZzGFIX2T8/bVTOS7fsVV+yam80+f4LB9KXF8
1LfMbcyiTVeZ60nhdzjngn0NifzQt83tzOG1vmZuZgYPKWDY87tmLvNpYg8n
PT9iLqOFeO6zi0/Oas1sOphNI4V00e78irkhvCtTecBunvDH+R1zB53M4xFF
PKXWeYWZQStJNJDPgLM6M4e5vNE15hZSGdH1Zh4LKA73wUxjDJ91B9X2jUzj
b/ivqLSvZRI/9VtKwv3QyxnLF90Z3oFSTnGaM5wN9zHcB79bQQJ9+nH4Xi7q
TJL5pXvDnbRvZSb/9T1zJwtpZi/PGAUt9mN6
             "]]}]}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            PolygonBox[CompressedData["
1:eJwV0Ek0VmEYwPGrLBTRtmWHrVSGLRmy7bS1i8y+D5HKQig2VOrDwkpkXKbM
azSxLWNb7SVjv7v4nff5P+fee857rz+I3o9cCIIgjhhz8UEwz/TFINjgnBz9
mFbzMr+5qovpZlBPsc4Z2XbNPDMvsUeKvksXA3qSH5ySZdfEU/MiuyTrIl7S
ryf4zgmZdo94Yl5ghyu6kBfE9DjfOOa2XSMt5nm2SdIFdPJOj/GVI27ZNYR3
Ns+xRaLOp4O3+gNf+MdNu/rwzuZZNrms79BOnx5ljUMy7KLhnc2f+cUlncdz
3ugRVvnLDbtIeGfzJ36SoHNp47X+wzXzvfB93us0ZwlDrOiPzjJGOdDp4X9x
vqKBeqJEqKOWGqqpopIKynlIGb2UMkMP+wyHz/t2Kv8BhlxStQ==
             
             "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1WW4FWUUBWBKuhukuxukS5BGuttOVFRU7FZCKVtQBBURUCQVO1Gxu7u7
W9/1+OO9e+1958w355uZe+vPmTvm2IIFChTY60fqLD8Ks02ezzA6corZvuyV
L+MgCjHbrAjbcwzD6cSpZrV4Rr6cgynMHLN92JFjGMEifVvel2+iM6fpa/Os
vJRDuELfjS/ljRTJdeiLsjOfYSSL9e34QF5LFxbo6/CcvIw18kB+lQ/lSrk7
X8lb1Ylskterw/lHvludnuvP91GLcS+79JvU0SyQV6n9eJgf9dvVyezhQP0S
tT0P8qF+izqex1mnv1kdwqP8qd+pTuUp9tOfrtblfp7X36GOZXn2Tz2A3+TD
uEruwdfyZm6TR/CvXDT7Khfn7pyX1XJ/fpJH5V7LHfgo10VXztDX4wV5BYdT
LPtoVoJ7cgyj6caZZvV5UV7JERTP9ZmVZHeOYQzdOcusAS/lnnMkJbKOWans
eY5hLD0omXOal+Y++WzG0ZNSlKYMZSlHeSpQkUpUpgpVqZb1nKdM9lc+h/H0
ojpHmZflAflcJtA7a5o15OU8SzmOGhxtVi73Wj6PifTJec0a8UruUY6jJseY
lech+Xwm5f3Rd+Rj+Rb6Zm19Y16Vr87n2Je8zBXy7MkXMJl+WdusCa/J1+Q4
ajHXrCKPyBcyhf5Z26wpr8vX5jhqc5xZpTyb8kVMZam+E5/It7J/1tY34w35
unyOOhxvVpnH5IuZxjJ9Zz6V1zMg16Jvzpvy9flcvqe+J9/kmacuJ+ir5N2R
L2E6y/Vd+CzPOwNzrfoWvCWvYq08iN9zjuyJ3Itv5TvZII8kfxTrKfPUqjwh
X8oN8v78LM9gRd5NPpfvUiewIfdLHcpf8i51Wt7PfHe1ZZ4j3s6a6jhWy+vU
wbkn/KHfoU7hSeblfqi984zwnX6bOinXxhb97fk7kz2mYN5HZvB03kO/P1Gt
lneFPfrN6hgWyjeqA/hFnslKuStf5Ly5v/Iw/pYHZc/lVryTPcm5c7/1ffg+
e0EDTtJXz3eQFzGLwdlLs9a8m7VzHA052awGT8mLmc0QGtGYJjSlGc1pQUta
0Zo2tKUd7ZnvXDWzB/IS5jCUhWZteE9ek3XzvOn78oO8lY3yKAqxm5kF//9/
2cHv/gP0PdVL
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0nfAVnMYBuDzfV97701SUWlpUWhQNGkXSWS0B0VGZoXKbhqhNChalBAy
ym7vvffeW9fzx/Xez+9+zz6nROc+LXunJEkyzM9iUtKSZE5qkvSnNgVIWOK/
pSxjOStYySpWs4ZU+8617ZPUoSApkfp/5DBaU57Kup3yM3qx1v5pum/NT3G7
+bSsy03mA7K5nCobyouyEGXNm+RHPEZq9Lp/5XDaUIF1jp9OP888gHoUJi1S
/598g7ZUZL3t0+u/Mz8d10MR0rHBfxn89735Ge6gKOnZ6L9NbGYLW9nGdnaw
k13sZg8ZHecH+z1LfYqRIc6lXyzfpB2VuFG3S06kN3vtn0k339xMPhfXIs/I
VrKBvFkelNO4inLWm+U4upAxrl23RL5F+3g37HPszPofzQO5k6vJFNeoXyrf
5t64LvbbPov+J/Pz3EVxMsd59cvkO9xHFQ7YPqv+Z/ML8U65hixxHv1y+S4d
qMpB22fTLzC/SCNKkDXOo18h3+N+qnHI9tn1v5hfojHXki3Oo18pR9CR6hy2
fQ79r+aXaUJJssd59KvkSB6gBkdsn1P/m/kVmlKKG3Rb5Md0JUecV7dajqJT
fM8ctX8u/e/mQfH+KE153Vb5Cd3IGdehWyNH82C803iGut1yEn045ni5dQvN
g7mb66ig2yY/pTu54jp1a+UYHuIW6yNyOjXjeVvvkZPpSx3rE3I2x50nj/Ui
8xDuiX2sD8kvuZ6K1tvl+PhuzOdlD24zH5Mz432YL8vccd/mdXHNcqxsIM/J
1rKzvFUelS3kjHj38pJsK2vF+5Z741rklPj25AXZRj4u68qTsqX8Ot6t/F+e
cC95zX+YX6W++axsTi3zYfkVZahkvUNOoCe1rY/LWeSJZ229Xr7Pw/FM47vS
7ZOf8wQnnS+f7k/za3E/lCVvPDf9BvkBj8Q9c8r2+fV/mV+P66cc+TjtvzOc
5RznucBFLnGZAvb927ZDaRXfJvnjfvQb5Yc8Gu8lvmndfvkF/ahnfUp+E9+2
OaFdPDfHvQJ6PcDy
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV1HeAz2UcB/CfaKASiZTiktnQoKGUjJayUt1ln+2GNJR9IpzVUCGd7HVD
juMqohBaaFHaoa1pr16fP173+byf53533+f5Pc83KbV/u8wSiUQi1Y/kkonE
eFJ4iA50pBOd6UJXujGBVPbzLi+X8hleo5ga9GW2uV+ZyAq6M4ke9KQXvelD
X/qRRjoZZNKfhxnAZB7hCn/7gDpP7cFyNskz1A5cyhz5WbUNVfhNfoYR+ls5
gy/kIh6N/yVfyUH9ZubG58ky1oTSfCmv5LF4Lrk+h/Rb4ll4jpHGbqMMu+RV
PB5rkK/isP495vM8TxlrSlm+kosZGOuVr+aI/n0WMIVRxppxJl/Lr/NE7It8
DUf1H7CQFxhtrDln8Y38Bk/GmuVrOab/kEW8yNPGWnA238pvMijWLDfguP4j
FvMSY4zdTjm+k1czONYsN+SEfitLmMpYY3dwDt/LaxgSa5av46R+G7mxNnma
Ok69k/L8IL/F0Fi3fD0Jtst5TCdbvosK/CivZVisW76BEnws58d3pm/LBfwe
Zznugf5uzmW3vI7hsQ/yjZzCJ3JBfIf6dlzIH3EG437oW1KRPfLbsVf6B6jG
33EOY5/0jSjJp/IrakdqsjS+b/U+qrIv5uMu6e/hPPbKM9XO1Oad2GP1Qaqz
iD78Y3y22o165JJOVuy9ehP5lGI+PfnMXI7aiWXUYjH9KIq7HudLbR/PykUs
pDcr+NP8LLUrhdRlCWmsJCfeBeq9FFCJBfTiJ3Ovql2ow3p5mppMEv/Kc9RU
LmNknAf1Zk7lc3lZnGf9/VzMX7FX8Q7Rt6IyP8sb4g7G+ZAbcxo75MJ4hrhv
cYfiXsRZj/Mb5zHOg9+7hdPZKS+P9cY7Rm7N+fwib4wzqU/hEv6Ld4vancvJ
I4NVZJv7H3Vcurg=
           "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
         True}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"x(t)\"", "\"y(t)\"", "\"u(t)\""}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "5.327841279585983`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.66287887324962*^9, 3.66287887871753*^9}, {
   3.6628789095204*^9, 3.662878932194415*^9}, 3.662913856479701*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparison of pendulum solve methods", "Subsubsection",
 CellChangeTimes->{{3.662465612827151*^9, 3.662465618475192*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "compare", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"compare", "[", 
       RowBox[{"conditions_", ",", 
        RowBox[{"withEnergy_:", "True"}]}], "]"}], ":=", 
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"plots", "=", 
           RowBox[{"{", "}"}]}], ",", "ener", ",", "haut", ",", "eps"}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"haut", "=", 
          RowBox[{"(", 
           RowBox[{"solveHautus", "@@", 
            RowBox[{"Join", "[", 
             RowBox[{"conditions", ",", 
              RowBox[{"{", "0.005", "}"}]}], "]"}]}], ")"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"plots", ",", 
           RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x1", "[", "t", "]"}], ",", 
                RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", 
              RowBox[{"haut", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", 
               RowBox[{
               "haut", "\[LeftDoubleBracket]", "3", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"Placed", "[", 
               RowBox[{
                RowBox[{"{", "\"\<Methode 2\>\"", "}"}], ",", "Below"}], 
               "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{
               RowBox[{"ColorData", "[", 
                RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], 
            "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"StringForm", "[", 
           RowBox[{
           "\"\<Final hautus time for ``: ``\>\"", ",", "conditions", ",", 
            RowBox[{
            "haut", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}]}], 
           "]"}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"eps", "=", 
          RowBox[{"epsilonOC", "[", 
           RowBox[{"2", ",", 
            RowBox[{"(", GridBox[{
               {"0", "1"},
               {
                RowBox[{
                 RowBox[{"-", "g"}], "/", "l"}], "0"}
              }], ")"}], ",", 
            RowBox[{"(", GridBox[{
               {"0"},
               {
                RowBox[{"1", "/", 
                 RowBox[{"(", 
                  RowBox[{"m", " ", "l"}], ")"}]}]}
              }], ")"}], ",", 
            SuperscriptBox["10", "5"], ",", "1", ",", "conditions", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "40"}], "}"}], ",", 
            SuperscriptBox["10", 
             RowBox[{"-", "2"}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"plots", ",", 
           RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
                RowBox[{
                 SubscriptBox["x", "2"], "[", "t", "]"}]}], "}"}], "/.", 
              RowBox[{
              "eps", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}]}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"t", ",", "0", ",", 
               RowBox[{
               "eps", "\[LeftDoubleBracket]", "7", 
                "\[RightDoubleBracket]"}]}], "}"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"Placed", "[", 
               RowBox[{
                RowBox[{"{", "\"\<Methode 3\>\"", "}"}], ",", "Below"}], 
               "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{
               RowBox[{"ColorData", "[", 
                RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
               "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}]}], 
            "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"StringForm", "[", 
           RowBox[{
           "\"\<Final eps time for ``: ``\>\"", ",", "conditions", ",", 
            RowBox[{
            "eps", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}]}], 
           "]"}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"withEnergy", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ener", "=", 
             RowBox[{"(", 
              RowBox[{"energy", "@@", "conditions"}], ")"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"plots", "=", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"plots", ",", 
               RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x1", "[", "t", "]"}], ",", 
                    RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", 
                  RowBox[{
                  "ener", "\[LeftDoubleBracket]", "4", 
                   "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", 
                   RowBox[{
                   "ener", "\[LeftDoubleBracket]", "6", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Placed", "[", 
                   RowBox[{
                    RowBox[{"{", "\"\<Methode 1\>\"", "}"}], ",", "Below"}], 
                   "]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{
                   RowBox[{"ColorData", "[", 
                    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                   "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}],
                 "\[IndentingNewLine]", "]"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Print", "[", 
             RowBox[{"StringForm", "[", 
              RowBox[{
              "\"\<Final energy time for ``: ``\>\"", ",", "conditions", ",", 
               RowBox[{
               "ener", "\[LeftDoubleBracket]", "6", 
                "\[RightDoubleBracket]"}]}], "]"}], "]"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{"plots", ",", "\[IndentingNewLine]", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"400", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"AspectRatio", "\[Rule]", 
            RowBox[{"2", "/", "4"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
             "\"\<\[Theta]\>\"", ",", 
              "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)\>\""}], 
             "}"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"exportRaster", "[", 
      RowBox[{
       RowBox[{"compare", "@@@", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.05"}], ",", "0.01"}], "}"}], ",", "True"}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.15", ",", "0"}], "}"}], ",", "True"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.1", ",", "0.02"}], "}"}], ",", "False"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0.3", ",", "0.05"}], "}"}], ",", "False"}], "}"}]}], 
         "\[IndentingNewLine]", "}"}]}], ",", "\"\<s29\>\"", ",", "True"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.662465621219306*^9, 3.6624656963958235`*^9}, {
   3.662465726725078*^9, 3.66246572993289*^9}, {3.662466436893493*^9, 
   3.662466439690293*^9}, {3.662467236619155*^9, 3.6624672375383177`*^9}, 
   3.662467498459388*^9, {3.6624677108503666`*^9, 3.6624677111456738`*^9}, {
   3.662470367723312*^9, 3.6624704286965275`*^9}, 3.6624704630498695`*^9, {
   3.662470515128772*^9, 3.66247054543225*^9}, {3.6624711512650857`*^9, 
   3.6624711862652793`*^9}, {3.662471230936933*^9, 3.6624712441873217`*^9}, {
   3.662471318163741*^9, 3.662471577207307*^9}, {3.6624716171766176`*^9, 
   3.6624716212545075`*^9}, {3.662471680319187*^9, 3.662471717878813*^9}, {
   3.662471751665757*^9, 3.6624717835103087`*^9}, {3.6624718225199504`*^9, 
   3.662471832638129*^9}, {3.662471961647543*^9, 3.6624719797023473`*^9}, {
   3.6624720211667066`*^9, 3.6624720537918243`*^9}, {3.6624721941273937`*^9, 
   3.6624722321503267`*^9}, {3.662472298313218*^9, 3.6624724048707128`*^9}, {
   3.662472441958001*^9, 3.6624724893886147`*^9}, {3.6624725606150813`*^9, 
   3.6624725650221944`*^9}, {3.6624732466541977`*^9, 
   3.6624732468523383`*^9}, {3.662551950354284*^9, 3.6625519585861173`*^9}, {
   3.6625520034188848`*^9, 3.662552032130229*^9}, {3.6625520728260655`*^9, 
   3.6625522251469975`*^9}, {3.6625522765534234`*^9, 
   3.6625522806092978`*^9}, {3.662552315666139*^9, 3.662552317233249*^9}, {
   3.6625523601386504`*^9, 3.662552430097212*^9}, {3.6625524761298404`*^9, 
   3.6625525017209716`*^9}, {3.6625527077846117`*^9, 
   3.6625527180648966`*^9}, {3.662553032144103*^9, 3.6625530868078365`*^9}, {
   3.66255335676012*^9, 3.6625534079834166`*^9}, 3.662553438447002*^9, {
   3.6627097875283175`*^9, 3.662709787887573*^9}, {3.6627270037255*^9, 
   3.662727004109127*^9}, {3.6629048618436937`*^9, 3.662904863571908*^9}, {
   3.6629049608353853`*^9, 3.6629049681165333`*^9}, {3.6629051165816975`*^9, 
   3.6629051282589707`*^9}, {3.662913492725054*^9, 3.6629134942611427`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"Final time: \
\\!\\(\\*RowBox[{\\\"2.5933221856422937`\\\"}]\\)\"\>",
  StringForm["Final time: ``", 2.5933221856422937`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913495610086*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"7.269311167079227`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 7.269311167079227}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134956160936`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final hautus time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.05`\\\"}], \\\",\\\", \\\"0.01`\\\"}], \\\"}\
\\\"}]\\): \\!\\(\\*RowBox[{\\\"2.5933221856422937`\\\"}]\\)\"\>",
  StringForm[
  "Final hautus time for ``: ``", {-0.05, 0.01}, 2.5933221856422937`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134956711483`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100000", ",", "1", ",", "100000", ",", "6.121403506584327`", ",", 
   "0.001235641265438155`"}], "}"}]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913496822585*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final eps time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.05`\\\"}], \\\",\\\", \\\"0.01`\\\"}], \\\"}\
\\\"}]\\): \\!\\(\\*RowBox[{\\\"3.3642578125`\\\"}]\\)\"\>",
  StringForm["Final eps time for ``: ``", {-0.05, 0.01}, 3.3642578125],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134971025314`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \\(s\\)]\\) = \
\\!\\(\\*RowBox[{\\\"-\\\", \\\"0.03262997276269038`\\\"}]\\)\"\>",
  StringForm[
  "\!\(\*SubscriptBox[\(\[Theta]\), \(s\)]\) = ``", -0.03262997276269038],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497105533*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final time: \\!\\(\\*RowBox[{\\\"2.873340315695429`\\\
\"}]\\)\"\>",
  StringForm["Final time: ``", 2.873340315695429],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497113557*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Switch time: \\!\\(\\*RowBox[{\\\"0.8549821999465195`\
\\\"}]\\)\"\>",
  StringForm["Switch time: ``", 0.8549821999465195],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497116559*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final energy time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"0.05`\\\"}], \\\",\\\", \\\"0.01`\\\"}], \\\"}\
\\\"}]\\): \\!\\(\\*RowBox[{\\\"2.873340315695429`\\\"}]\\)\"\>",
  StringForm["Final energy time for ``: ``", {-0.05, 0.01}, 2.873340315695429],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497281319*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final time: \\!\\(\\*RowBox[{\\\"5.269137038062889`\\\
\"}]\\)\"\>",
  StringForm["Final time: ``", 5.269137038062889],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497309335*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"9.944786778183383`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 9.944786778183383}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497312852*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final hautus time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.15`\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"5.269137038062889`\\\"}]\\)\"\>",
  StringForm["Final hautus time for ``: ``", {0.15, 0}, 5.269137038062889],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913497377001*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100000", ",", "1", ",", "100000", ",", "6.121403506584327`", ",", 
   "0.0009005828813545788`"}], "}"}]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913498448306*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final eps time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.15`\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"6.2451171875`\\\"}]\\)\"\>",
  StringForm["Final eps time for ``: ``", {0.15, 0}, 6.2451171875],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913498756836*^9}],

Cell[BoxData[
 InterpretationBox["\<\"\\!\\(\\*SubscriptBox[\\(\[Theta]\\), \\(s\\)]\\) = \
\\!\\(\\*RowBox[{\\\"0.1300778627237128`\\\"}]\\)\"\>",
  StringForm[
  "\!\(\*SubscriptBox[\(\[Theta]\), \(s\)]\) = ``", 0.1300778627237128],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134987598386`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final time: \\!\\(\\*RowBox[{\\\"5.407821966333571`\\\
\"}]\\)\"\>",
  StringForm["Final time: ``", 5.407821966333571],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134987668543`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Switch time: \
\\!\\(\\*RowBox[{\\\"0.990107566649783`\\\"}]\\)\"\>",
  StringForm["Switch time: ``", 0.990107566649783],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134987708607`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final energy time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.15`\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"5.407821966333571`\\\"}]\\)\"\>",
  StringForm["Final energy time for ``: ``", {0.15, 0}, 5.407821966333571],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134989329634`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final time: \\!\\(\\*RowBox[{\\\"4.894351234314632`\\\
\"}]\\)\"\>",
  StringForm["Final time: ``", 4.894351234314632],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913498956991*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"9.570359200197855`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 9.570359200197855}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913498962984*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final hautus time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.1`\\\", \\\",\\\", \\\"0.02`\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"4.894351234314632`\\\"}]\\)\"\>",
  StringForm["Final hautus time for ``: ``", {0.1, 0.02}, 4.894351234314632],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629134990160275`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100000", ",", "1", ",", "100000", ",", "6.121403506584327`", ",", 
   "0.0011879021461349418`"}], "}"}]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629135000667667`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final eps time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.1`\\\", \\\",\\\", \\\"0.02`\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"5.9912109375`\\\"}]\\)\"\>",
  StringForm["Final eps time for ``: ``", {0.1, 0.02}, 5.9912109375],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629135003970003`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final time: \
\\!\\(\\*RowBox[{\\\"12.706175084435245`\\\"}]\\)\"\>",
  StringForm["Final time: ``", 12.706175084435245`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629135004310246`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"17.381098326637307`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 17.381098326637307`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913500440029*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final hautus time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.3`\\\", \\\",\\\", \\\"0.05`\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"12.706175084435245`\\\"}]\\)\"\>",
  StringForm["Final hautus time for ``: ``", {0.3, 0.05}, 12.706175084435245`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913500517086*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "100000", ",", "1", ",", "100000", ",", "6.121403506584327`", ",", 
   "0.0006188149947746246`"}], "}"}]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.6629135016899304`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Final eps time for \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"0.3`\\\", \\\",\\\", \\\"0.05`\\\"}], \\\"}\\\"}]\\): \
\\!\\(\\*RowBox[{\\\"17.3876953125`\\\"}]\\)\"\>",
  StringForm["Final eps time for ``: ``", {0.3, 0.05}, 17.3876953125],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6624715587762547`*^9, 3.6624715779088035`*^9}, 
   3.662471784197796*^9, 3.662471833541778*^9, 3.6624719260513115`*^9, 
   3.662471980284738*^9, 3.662472054128063*^9, 3.662472232600664*^9, 
   3.6624723025942616`*^9, {3.6624723493763914`*^9, 3.662472371982408*^9}, 
   3.662472405741353*^9, {3.662472466407316*^9, 3.662472490709538*^9}, 
   3.6624725652703714`*^9, 3.6624732490829077`*^9, 3.662551958770238*^9, 
   3.662552226444909*^9, 3.662552317347337*^9, {3.662552361203414*^9, 
   3.6625524303253727`*^9}, {3.662552476618179*^9, 3.662552501825039*^9}, 
   3.66255280230658*^9, 3.6625528387143874`*^9, 3.6625528794809275`*^9, 
   3.662553017505748*^9, {3.6625530785810204`*^9, 3.6625530870009747`*^9}, 
   3.6625533629965377`*^9, 3.6625534109365253`*^9, 3.662709789050397*^9, 
   3.662727007260909*^9, 3.66290486442251*^9, 3.6629049689441347`*^9, 
   3.662905128578187*^9, 3.662913502232314*^9}]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJwV13c8Vf8bAHAjOymKZK+skux5H8led7hXRokoEb4IaVgZIWTvWTIqo0Uk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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.560181, 0.691569, 0.194885]], 
            LineBox[CompressedData["
1:eJwV13c4lW0YAHAUSvEJEYmEqLTsUR4kI6NwJCMrJCNCRHZWJeK8xlkcOyUK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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJwVjwc01Y0bx2+E12qISsksXdmbpEdURllXGSGb+NdFRHizV4PsfX9+l6xU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             "]]}}}}, {
        ImageSize -> {400, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[1, 2], 0.5], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, 
         Axes -> {True, True}, AxesLabel -> {None, None}, 
         AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
         PlotRange -> {{-0.05, 0.001299937932983816}, {-0.0004782313736665723,
           0.03021696888401682}}, PlotRangeClipping -> True, 
         PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 3\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJwt13k4Vd/3OHCJIiJCb1HGzDLP3EXmebo3kcqUNBkyRkSEDInMUeGKlGSe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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.560181, 0.691569, 0.194885]], 
            LineBox[CompressedData["
1:eJwt13k4lO33AHBSlIpsIctLIUtZSygdhMiSPbIkRWlFQrZCtkRCVFLMk5Y3
yjIzdocZkRYkEVJCCxGJRMX3fn/X7/lnrs91z3PPvZ5zRtbrpJ33Ig4Ojtuc
HBz/fWr938MGjv9/zmjff6JJvGjR7KiJ8HL8J339BQ3iqHXK5XmCEvj6sW2w
GvHBoYuNNZZymCNokLqBuEF69fQefhWsOqL0WpH4g52Y96Uv6pjwhd9Ujnjy
+sg/y8w3oTSNa1CaeFW7pLD4/S3IiDIoECPO7Dg8Wrt0K9qoP88TIJ63r8ud
O7Qdfwc4spcRR7QLL3gPGuD5h3QBTuJdYmKXrqUZIcu15OKMJhtYRi86sgyN
cf/Vw5vGiDlkWmo8J0xQOvv70gFi3X01W6Zu7kTOsSGdZmJvYY4rob93oWZF
TEYVsa9wrv3x+5YYZeMhVUisXfzcRXmPNWK8elkysU1FzxnObhuM4nJ/Ek5c
I3Ja49IjW7z8R5XnKLHQaqsvnHF2aO2ykc+E+Cl9m1qmpgN+GE7pVCcuKVlX
WLbUEae1OF5IEDvK9y+pfeeIQQfDjcc12MBvGbHuzIU9qJLQ5HmRmOpKFLjX
vxdv+qXd8Ceue6B6eJzhiq0SO3iciIXttthKJLlhaGK9ryTxKrejTJnNHsg/
x+tzS50NiWX23hNsT6wuGZSIJF5n87hbXnU/NuwO4nQj3vRsMsDq6n6UbtNx
EyFO7vzBeeqYF15aY2AfqcaGOKNHoqLCB/GuwnSiE7HnuMyWvoiDmGK+4/tG
YuO9Ws5XPh9EjuNr7HpU2fCtqyC5t9IbV7nW71Mi3nZKyAI9D2Gisys7dwMb
Tm0s0+m/fwTfG6VdPUS81q3PO1PiKMp+EgnfSFwb+fDF1uSjaJV4+QRThQ2L
haa0HfyO4eVb+ktqlNmQcTPiVeXmE6j8M0YsR5HsT/UyxcJ3fqhppj7oQPxJ
60wDh6g/1q7xql1OLLwi5qXFbn80PzV0J2g9mY/oFs0n6I9fH1gYGyqwYeXg
yjqX3AA0GF378v46Nszd9Cju2xeIbnctGXbEmf0M/rtZgVieYFkwt5YNYlaB
pYdaA/GUh/erncQZe2LrWrafxskycd4uGTYM8ly6oyUVhHc1z+k1S7EhJGrG
2ulNMBaz3z78u5oNfpvbg0Z3hqGGR+t0KvF+j8rVc6Fh2FwuHLCO+OM1n7aF
wjB0thJcbirChpzRAwk/hMIxc+t2VpQQG5xujreEvQ9HX5Gg/a/42WC3jOvL
ytORKP7U16Sfh+xnu8Kc8ItziNczA/cSxx7oPCDx6Ry+uize94qbDZG2Ryqk
Fs7hjjXU3oYlbChqUpBbrRGFxvmWy29wscG1yrT3dUYUdqvo7VNYYEFMcdPI
Jddo/PXBnX53mgXbu7KPfv4Yg4IukUdWEEun77b99jcGn9684e03xQKL22kb
voucRycxOxXtHyzQ+EeubsTkPBbaS/0qn2BB2CCnUWH+eXzpK16a/ZUF1FLh
jycOxmIDz/Pkzn4WCPSMWbx7F4cPjvjKyhH7bmDLeP2MQ4OHHPN+71nAdU2w
5cPKeKxxuZG29B0L0sUjHnZsi8eml4s3qvWyIE6O73jC9XhM+KfBaO9rFngs
FRVb75iAp43+7VZsZoEZj9G6rU2JODLPXWH9hLx/tOm7cn8i9pv0Pz7VxILR
ZbLVIrOJmKZScrjqMQv+4fkFb5UvYN++4C4DFgtWnW/8uCHlAt6svBspV0Xm
d9Gf2WufhIHpfZI2BSzwdi5rP9R7EVsiDMWNLrJgibHF3YWeSxic0/vANIkF
N/+magh+v4TfVian7rrAgia7AoFUrlRcKfPYxiaBBX1FAlJZ4ql4oi6wyP48
C77PtqQkmqQi+3HyCr1wFhwfPHJ+4UYqVjj16MYdZUF0dB73xl2X0fTn8XA5
MxYo+7WPheSkIb+n4+pPpuT3zsV+f3YvDW3PvPt2x4QFPToP5CXpaTgwn+Gm
sIMFf5T8pehP0/Cadoua5HYW8LW90WfNpOHsRMj7QS0WeO116XWyTUdRVd7y
IWmyHhyvT3osykDh2Yp55mQ9WJSevd7iegW/+n85YvO9HlZMFKKOzxXcPnhW
cXi8HiY0bgjn+l1BHbX8q2Jj9WBfqWDpE3sFO70mbU9+rodl150/tz28go2z
+nZ/eutBIDIzTJozE086cXRdaaiHRhXv+KtUJjbtsXZ/mV4P7hdmbv94n4Uz
N78ISmnWQ8iNtUc4+a/jhMTc+GBtHUw2RIj7b7+B2TnXendb1EHhouCxfomb
+LHdfJPDHYSNKU0ZWx/fQu4XfClP02tB+OPpKvXiXPTLSikqulQL+pf9Wrno
uZj0hpLNTKqFPy9WRb9m5mLft+EJj5ha+OYnxw6szkWbai+rLwG1kE9rLqU1
5aKz+6x5j20tWH+8Ylbdl4uSrdbF+vy1wHUofsWnpXnY7Oe/VSShBiSDuO8I
uubhh5YazqCYGmClDh1muefh2iWKAp2RNRB8QjHJzzMPC5gCKzNO14BpYs9Y
k3ce3nF0i+U5UAOr3pSpHPDLQ0b9+zfP9Wtghvkq3iI2D6dNlIQ7JqvBZ18w
Y7AwD08/sJUd21sNVy6+LtaYy0N+ASkuPadqsA0Tv3XiTx6+fOyxO862GqoN
V/2+P5+HCz5fFKXMqiE8csOCBBcNN11K+rpjczXcfV2pM7achk+LmnmD+Kuh
bIQnyFiKht+5P6ecZFfBNnUVg8btNLRZLJLdolQFOeNd7mIRNDS851FhKV8F
+1x997yMpCFedjz2VKYKzI5enk44R8MByLncIFoFcntb/pmKoWGiXftA6ZIq
4L4jvrHyAg31bj0ejvxQCdlxn7WWXKXhIZMD3U+uVsKG0VHdrGIafqQLauhl
VMLyGzI9cqU01KpdWP/gUiX8u1hTpphOxntvaCoprhLKB1bffFxGw6z1YsLm
gZUgvpjH610NDe+Ii5UU764E4WMBQq3NNFR9uqV2O3cl5A0ecCvsp6Hxbtfv
BpyVcOaXTdnGARp2nlVCoz8VUG+UFF4wSEPeL8c3mExWwIP3O0zzP9FweErV
xeRdBXgJWXbHjNJQdJG9sxazAn7KjwtMz9Bw4afyqyfeFXBRWPvkvZUUrlHg
VkLPClCDiwY/+Sg8J/9cgeFaAQ3vBc8araKQda1OIte2Al6PrDTuFKTQMWTw
p79+BSzjNJoYEaXQnr+9ZYlIBVh/f/PxiSyFUcV7v06wy2H9fPDnPZsovBBY
ek8Ly8HPx7bEczOF1VSHXFBlOZQ11ckc1qbw3qrmvXNF5SB7reBLgA6F7H8/
Ny7klMOZgEaFkG0Upgsc/jofXA6zXQHHDI0pLNrcVdemUg66mzbmtdpR6OQC
88vXl4OFpApXoT2F7rraS3auLQd7SbHliQ4UZv5S9K8WI/0n8K7Ud6JwaPbS
09tLyqFj2b7eDBcKQ3TbWo6+LwP7FO0SLk8K9QK/h7xOK4Mtz461vTtK4URL
Adft5DKo6hwbvXWMQt4CUdeAhDKQemQXtO84hY/EKH++yDIQTd/b1n2Cwmcj
a82NfctAu84nv8qfwpyRPfN3oAxa/JN/aAVTqBtJiw3QKwOmydnxXmIvQ91+
/c1lMCWWuzc6hML8qMlVHcplIHyB8+zTMxT+ElM4Ni9SBpvVdi42C6dQRmKd
j8UoE27vnJP5dY5C48ome+HPTEhavko2Poq0aztK9H1gghFnbppwNIU7x1/q
nuhiQp11/VPlGArdMocwhcUEe96V6caxZH5qHFbNV5kQ1viR2phIoUFhM29q
OhP+5rU/p4gD6GL3nVKY0PzhvK/YBXIekr4lDMYw4d3e5/N/iOWSl3/4fYIJ
Ds9GbpRepHCr/Y3d602YsPpwdFPnJQrDdgzcW2zAhAOcb5M1UymcN1Qd+aDH
BG2/8DcXiUcGDivcUGfCmSrJ39suUyi22C2VX5IJ1TF3zySlUbiZ+XjT6Gom
xBgv9uklfnHYqeGJABM+0mu6lNIpTDSLuBPFQ9ovv7RgEf8x7IianGTAaYZ5
6IcMCpk7fS+0jDHA9YTzFfkrFK4zMI369wsDvhd1ax8m1oo+vNXrHYPsV+3K
YeKx64ajbc0MOBb9nq87k8IlccsCChoYILp4936BLAqXOekNxyMD4oZNt5oR
j0kdKtzOYED1871xxcQ/bvRnPchlwIuT78MDrlKovDBQGpfNgMELHvy3iM/r
nGzYn8mA9sEw5afEdfcZDaIXGWC8TfK3xDUKVaV1GJNxDLAqGSoyIu4b6Mh+
EcUAXfvO8UPEwp1jljHBDGhcVLfsIbGKoaaYRwADRuP/DrUQ55yW7dU5zoAF
uXHzb8TFpanm37wYMJt+pljxOoX9s2+mn7gzwPvtHvoO4vhot2zKmQFPlE4b
uhM7d+S/crZmQHTdzFwSMX+P1iEtcwa4n6OtzyN2zU6eXmnMgK2aou/pxFHa
ome/bCftl0Nkm4gnHm5ezNZlwEqFkW9dxDbLHGJzNjHAgOv6zs/EoYWvFoWo
MeBZSJnKNLFAilCEnTIDFG/5ZXNmU1iVEzC1QZ4BL1N+ZK4glmrd7csjQ973
PCG9mrhXmPfthzUMmFDh15QmvrGfw6pahAF7eRe3yxFz3btcnbmKzFcobF6J
mNkjqeK/nAE799PKNhK7jHJcs+BmQC3vvb9qxGmtN7gVOBnwRrGyTZ14SfDu
QI4/dFjVwa3xn+V4hsy1Zujwl3/YSpW4U2aDjM8kHZqtfBVViHl7A2eujtHh
xFxBnQLxA8vlbc++0OFLdPdqWeL8i9v+nR+kg6aDsMoa4o/FjnEa7+lg1hv9
V4DY+RV18GAPHeRid6UsJf7EE2iS9ZoOrNrUvr9kfc76CCk9baOD1HTo1+/E
fNyt/H+f0UH9imr5EPG5vz9m1ZroMLP85Y5OYjzQ+tmLRYdjjfEpjcTlux92
X6mhQ5JGyFUGscubvtYn5XSwrmzaTxHrSxx4qvqIDiVvxLXC/tt/LvvW/f+S
8Zkd2upN/HywqTsjnw5+ife5rIkPDwdy/M6mw/5NtA6J/7xtp5RqFh3WhlB9
HMT+g+0G+9NIu6Ha3SFy/swTd+U0JZD+xMLD7xFPMNo652Lo8GkhPiGB2DbN
WEz1LB3GZeiO/53vYYYSPeM0WS/2ok2yxNbKzs5eXnQYPXV5cRy5LxecKruv
uNNhn2CZlBvxu+EA72ZnOojZKc6qE0fnSeSo76aDsW/MTCe5jymdFVcWttKB
Z0BrtTCxd41+gNYWsp5BLSb95H6Xs865HtKkg61Qv84D4tDzIY6tinRYJDXv
q09s7ZMzfkuE2EX/jx2JD09ZCXodq+gQL3vPQoR47XR2xtIVdFjsytjXSeKN
4JYTwf6L6NDRYdnpQNxarM5hPF4Kxq3xnDtIfLK7nLd/9EkpbNk65jdE4l/T
mtwzlexSuFcevOm/eMj+IXM/obYUfi7wJfwXL/dnaNrI00uBVba2P5TE0/lU
h+Z9t0pho/tql7lkcn4jkmq6T5eCwNKvWXQSj4MW1YTd9yuFL/M5ASbEu7oy
9pw5WgrTY879HSSe9/rV+YrvLwWjc/mnxxPIfT7YuMjVshTY3C8vCsVTeNcu
1n1obSnIyalmiZJ8kdetJMeUKoVXZ6rLL5N8Ml10lS9BrBT4flr58RI32njY
bOArheqNurQZko9YjmZpQbMlIKJyeHV9JIVzoZe8BdtKIPjTkO+qUAqvFghM
+0aUwKI92WtoJymsXPP88tWQEuD8tWXHb5I/322Sd246VQLthbOb7YmnVfq8
5I+UgG7lv6ELJP++dksIGXQqgS3cv2LNj5B8ETv28ZB6CXR9HXpBHaTwzAuO
9vTBYmBPafkFOJP7L9es+eRdMYS++Fc3fw+F2tKRjX+6i+HYC91XnaQeQGZX
vE9bMdjnewRrO1IYzjgeuq2mGEy8fyV8tiX7n2/qOZlZDDfvCPxeZUGh4obK
LQm7imGbNs/haFKfYJd3ZK9JMUzuO+ycsZXCWyI/5lUNi8FU54hyvh75fsfT
h51biuHFHq5ANqlvytQkXirKF0M0zynaJKmPXv3OcX+zUARN7bHpEhsptKyT
ifJhFMEvLx+Oa5LkfIUOJNUXFYHenvqweAkKk+R3dUsWFIG5oPO7wDUkXvWt
0++gFcFLGHWxFCP5J69A3TS1CJgbs9S+CVFYIx2weMvRIhCb3xT+l5fCuNds
M2vZIjBliLyx+EVDyZ7Hq6wli+C6tJ7H3580TN7orGEtSqz0KbdwmtTT2wIj
dq8sgmWz7914f9CwoehbRsHkI3C1vMOkj9HQj1tpfpj2CFr03qq8IPWpYOti
yUmuRzDyqX+c7zkNDwu91nN9UgjXfo+cHrpOQzOuW+1aWAhCSz+0eV2j4U0d
ZcWVzEJoX3pXpj+LhqPiWXwsqhA+YditrgwaehhZdW06WwgV3zfLVKbQsC0W
nm/XLoQfLW7uVtE0NC96N/T5dgGUNI4bPjxMxu+Z/erB+QeQcVYo3VuThusH
PITFZe6DZeed9eaP8nCFajb/6zd3IPFWxfVcqTxU0KDzfnx6GyaYvKcfxufi
+tVrq+Xv0KBjtUNaSyH5f5ZjVdhWlQsG/0x2HrO4iVM/X95ZMZAD27glRY/0
3kB1YT5VNc3rkH0r+3PMlmx867be33cqE1y/cnp337yGgod66Cn/poMsyrOU
O7KQr1le1LEtFW6KQGa5RCYuMotcrhJ4EZx35HhNeWWgnPse/TbbeFDSmqtJ
jkgj/Z3Q9fodDaZC71N16KnYG+vdtulSBMTaX5PKiE3Gbr591nq2QSBstUO2
h5mIZv75I2Gn/eCNTH34MfU4zH8wIzTr7gev96X+3SIbh9ahbLc4Uz9I5Vhn
v1gwDu96hJi/FPWD4Ws20bd+xKKBgNOETdBJKEnmEO9nxqKnxO0B5rIT4Bdv
7ZukH4u5oer8N8yOwhfNMFqGxXmc6i0oDFTwAeH8nWdYR6JReOBLGc8iHzhu
fj//uVs0/jv84zizzxtqDJp7uqyj8VyB0iufK95wJKLkwHfNaCx49lNXiNsb
tseo8mv8jsLXjRt1ro4egCav8YbBpCjc6VM/btCyH4Sj7h+TfngOT88orZ1r
dIX0gN1HrUYj0Oc9vfPnRVdYf8BINuplBJ79mxq53t4VVHN3u5UxIzBk26sM
uf694BYqeEQlKgJDfW7YJ/9xgdW8BdKaqyPQLlihVxicQdmvHqsMwrH9q6F4
z4gD9EutiGzJCkUtradtFmUOcJA/d8ApIhQDS5z6J2IcQGvdGv4Br1B8Vy44
1SHlAGEb1jzhUA1Ftzgtn8UO9nBRpnpqX8MZPKD+d/OfZltoObRmxd3vIRht
WCLiWm4FOnpdrT7WwaitqZbr4mQFivd9mcKawThv8De7dcoSsrJfaDSKBKPn
rhmGrJYlcLWXftfqC8IGXisxd8YuyJrJ6dc7FoQ2uq018m07YaZyRduvC6eR
b9vTrZSHEQz9fJu389kpfNch4xO03AhmV4SZH390Cs/8NFyP5YYgYZ3UnZl+
CnuyDWSKhQ3B69z96mnXU9hS75+tdBvA8euJ9oHRAHz+pH5zxmM9uM9X5BzO
H4BmJZ0GzUwNmFbJodfs8cMEPtvgIm0NeNOlI6m73Q9DFHj1PcvUIb5+uWq5
nB+qF0tPaASpQbKpR1H04Ek8P3IhoCtLBUK+5M8tiJ7Epaurb07Ly8Hfzgvn
PaOPo47SQQHhR8ugw1nkQ4fbEVRXdpabCuQGnuuaXTXKR1CM66fCrAEX/L23
9dbDX77oefyZ0NvO2e2KPXX0uxm+yCHrUDK9rXi7t4b3gV/PD6Pfne+uLCEe
PDEZrS8Kh/DRREO4pJ8MNpaHO/soHUQd1FmqJyOLl9bO2d2YPIADAb1Hgltk
0URE4P7bqgPYJFggbC+/Dr9l90WEWx/AR79PpmdVy+Mxl0deuoFeuOye+hLa
ZWVcOq7wvqDeE8//8JH/tE4FzWjdsklJnrjLsvHqbroKwsxx0UBHT+x4NN+V
3roBF4tLeD1v34chSyxtv46rotk/L45nrfPAk5djwgSOaaAqNZBv2LwXzXVf
MgLuaOCKUsZtF4+9uCS8aM/wew2s3vK2LP6HC2qKUlGiNpo48aDJVEHaBUvi
X+mFy2vh9swMnROBe3B8WDEy2VkL7aizy3V496CxP18C44IWVulz7xLLdcJ5
rWW3do1qYeD6C5slnzuixHGdO8m3N+EPueEZTXkHfNuTOOLStgmPTW1wKa6y
x+oZX4ftvzeh1BGHCFM7e/wc42hmY70ZQx0mdRln7dCw2SEiZ3gzNod9YuT3
2qBtemalGp82Zr1i7+sNsMFHmd7hvRraKD3yfJ0irw1qpCjrnwvSxsi6FZZ8
AdbYJ9effiZLG5dfFJjSzLPC17o06eQybZT4xlgf12aJ7jdtllV1amPv6LM/
PByWWL7u2VmuaW0MTpFPLFezwP8BlEFBVA==
             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJwt13c8le//B3AqUSEroYEQUilKQ7yTrRLZIiWrzBQieydZySwZ94nIKOuc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             "]]}}}}, {
        ImageSize -> {400, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[1, 2], 0.5], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, 
         Axes -> {True, True}, AxesLabel -> {None, None}, 
         AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
         PlotRange -> {{-0.0012994253264371185`, 0.15}, {-0.04121803964282234,
           0.00047804304125073757`}}, PlotRangeClipping -> True, 
         PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 3\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJwV13k4lN8XAHCJEiHZRdasWcuSZQ7JvjNDpJDIFiqEyL5kCaWU7KYoomSd
iUPWiqJNhRYkkgr5KoXf+5s/Zp7Pc9/nnfe995xzzxU/GmTvxcjAwJBJfP3/
N//a/z8tcJanxuRTZC44fBZVDipsgclN5j7hHrlwQFxlRr+0BXq95tg4THPB
LyGB+XVlC4j9C3m5hzcXHvxcet/T1ALS6Sl+vrWXQPnhy/8evmwB9xS1mOiJ
iyA7fV5Qgo0GGyz4Nrua58AO7TMqbhw0cJ8ymKer5ECthUF4HhcNvr7p0Bbi
J8ZTWa794aeBZ67dytBENrwrMuVOlKJBaOvby0rR2bBNzOf6PV0aFF9mP6rn
lgVTN0hxAb40UOSjc45KZ0As8694kwAaxO8yHPvyPR069r4ZEg6iwZcLH2/8
bEyHmfXtTo0hNLh/UUfrj3E6CAXX/keNocHwVX+2L95pILoQYBScSwPv09F0
7ZupIOfWsPLjCg341PumBQJTwe9j4W/fazQYrTob9Es9FdCMe8CyiAYXPx8r
Le9OgZX3354NVNBAtWufwcRkMjRWxK8+aKFBu6955zeJJJha7NjxiU6DYIXz
HuVfEyFG9Nu59VYa/LoxS3OqS4Scb1u4FR7SYLkmqanFIBE+Gd7y13tMA7fT
i/Ge7gngyONdaf2WBpFvP7Y4FMbB9wLX33wjNDBN6pqaPhYHuZ4e59+O0mAy
67RK1O44oMUXnbD6SAO2qkK1QnosbP0upfVzigbsTRzal+7HQEKVGV18kXgf
geZXZQpRsNezjSvsFw0Oxsmc5nl4FiKcmzy7l2jwnflccMLBs/Df6o0/5N80
OMzbW+ecFAk6W5NnNFdp8EJe4MT0+3DYWrRb4NgaDRrtOMWNQ8Phg7emQfo6
Da78piWWsoVDx7WZuMcb6KAczpdgp3UGVn0HW7ZuooOHsOLpvJxQcLtW2bRt
Mx2KxfgfTMiEgurvrhpOFjo0siQwKbWFwBF97dS1LXRw0+ilP/h6Gg6fODlZ
zE4Hm3D2kU7DU3CcXfrWWQ463N7+SWPDu5MAetHe9px0oN8d/aQbfBK4xqce
/9xGhyffTlnVFgSDxcHgffPcdKjefVB24+wJeH6B8SGVhw7bGEqZvPhPwNXY
9/sdeOkgWfNKtMswAIoVTBRL+egwkmDrGVngB/Ta1iv6/HQ4WNJ6f6jPF4YS
7X6/I8wXd+yS9JIPlDRRyxkE6cAfccf2kdVx0PpoNZdOWC4pzJE/0hvifnxR
2i5EB2Ho1fG86QWfnR5e49xBB8+bVku/1jxh5Oy3h8mEU01vz2sreAJJeGTi
N2GN+FGRGKejsH787danwnTovMHpyHjXHXTeP+dRFaHDOEsQT0KzGxR4H+PJ
Ilzaxxy9tu0IZE/Fs00Tjoth5Tjj6wpJhpIrOjvpYC9B/fGtwwVmj2p/TCP8
6cYfM3chZ1CSb219SfjnmqrR0CknYDV+e8RZlA6czF/aqiXJcM7LVSKXMF6/
l8kfZQ9pD3eOPSKsOLJSGPvSFgr282atEA4LfqE86GwNEk/2akmL0eGijblJ
AasFpBucemNJWFGv8rkX3QQOpD8MCiTcJaEjoRhwAB5kCq2lEeb/apu8IGwA
R5WCEsoID/8JLAq4rgOXQ4xr6wl/vtw0oLRTHZzsBZgeEi43zlV5b6AIQnbv
4h4Tbmf7J+9qIgYOK3GyTwmH8N5+3O29QvqiLL7eT5ihhZmPcogbz4p9X+4h
rAJeV+UqpfHZxA/BB/8fj1V/YzekihMR0l7VhKM403wzrLWwaTznbR5hDmuV
2K4nJLTcqXbmHOFRER6OaOp+LNm9meROWPdbcxHfhBE2sHMp6RGWu7hpoUbc
DH/FUEx4CX9Ptb9g5G6Ja0+nz08T8zV3urH7TZENnu3oX2ok/PGj2b76QDv0
d9qQHkvYaF+o+Qq7Aw5kJ5sZEeY2PHyFdIeMZSdcVZkJa61tEImzdMSvc/H7
24n16/XzfN8x64Q3uFaiwghjatw7hnRnHBZ/9VGGcEavzS09+UP4ja4R+JKI
j2X7rdlnHrniRFkWsyjh1aUtVvMb3bH7RzJnKxFvj6Jq359/4Y4G4cyGjoQX
OgNWxMo98JfpVelIIj5HLssMmu/3xJKuzvEUIt41WE+OpcV6Y138De11ATr8
e7mizWd7HEujLjw4SbjTk5pTLOqDX+JvkEyJ/Mlb9X1Z1eaL9OA9enQiH2VD
jBwr/wXg0Rv5U2yEe+86SIr3n8CkF8dpTkT+fueq1Mu7HogcZz0/feSiA8u+
HfF6IsH48oKCUgtRD9pXm4DzwUncKMOxe4KoF3zD+TUoeQqtwhrILITnFvYE
BqafwrWrcdIH2OhglXaxvsflNMYmHxqII+pRq/sBVY8/IRhi1GLKS9Sz/QyC
cpoa4Xi2/SfvW6L+7Rhoj8y6GY7M/q7qef9o4DzpJveZLwKVLxr5M67QoEjX
70TqcgRObshtzCXqa13RX7jTfBZ7lfomK6dpIBZ18ryXdgxyZjJMcH2hwcqd
tM0XbseguNx+9dDPNHCVF8pxZo9Fiu/8a/lxGvxsrT8XER2L2wPVhOyJ+u/M
pLdefjgO3y+cfpTdT+yv2xMci0QScJo9X7qY2D8M/qVV51IS0EzDZKSijwbh
FPb51MwEDDjy1aKyiwZn/BIU/VcTEIf1bLwe0MC4xrCfdywRb7d83DJ4mwYB
Saqea9eT8eGuDGO/BBowiZ3RX+RPQ8W0hDPzsTRoElxl/myRhn/Pp3WcPkcD
BS+pgy9j0nDf9YxS3whif/eZuVD1JQ3txHqvCBH78bUn5DadpnT8e5YnI8eZ
BobWL769p2TicaHRylfyNPBbsA9MMc3GO1tmIttlaPChdWMQ+Wg2ch1pC7xJ
9APq5vPTolHZ6O4/98BzJw2ET02Q6mqz0Ssj/W850U8I5D1S7uLLQa80HUOd
5Ra4vvyI9fpkDs7qfNvc29YCrI84nm2MuYSfnXJcemkt0G5fSMP8S9idmMPw
sJHob9b7YyMaL2Hg+dumN2taoOH1hpypuUv4I+X0sHwRcb2Ye8BN11xcubHR
QyqqBVxEJv1p+y5jXp/SvdE9LcBZci9058IVTNB96Ser3AI9aRXvs9jzkD9h
W2qgfAtcsX7WsSabh4EMlB8zYi1gEn7z60u3PDzCvD+mkL0F8he5Th0dyMOC
RGu+35+b4VPy8/r1iqvY9vJkx7mLzXBl/R+P0qF8bMyTUVfNbIZWSmfQ49B8
PLbD3O59SjPU3BFmOJadj6RWxSTZ6GYw7T/YeKE7H+NevZ2NOt4M/TduyT9U
vo5t1QJa0jrN0PHqQHvRxgKE/CdT5943QXey4NYdtwrxdXJXgR9vE4yUXNfb
H1qC61SuNT3OJjCQOLrJOq4EXVxKRrduaYLlDwEWBzNLkHd7H3fhv0Y4UPzJ
yOdGCc74ykSmTDTCCK/5WOirEpx0PXQz8W4jMMpIFxmrl2JRVkaYlEkj8Hts
uNW4WIr8x5TzffQbwdb+4aus9VLczHjZqnJfIwSKZx86zlaGLBNm3kK7GyH2
5qZALskypGp0nny0rRHeHLfKtrMvQw523USHtw2QcbPubezdMhx7kKQqfLwB
zrF7/r3kX44gc55Hw60BXB3KD6uGl+NrVYc35k4NcECV42Z/YjnKFVxm9jJp
AM7smYl/heW49MuSw1WmAaJeuc0ZDpbjtew1DivRBigbLnQZHC3Hsw0Ky1r8
DZAos73cZaYcz3A6xG3Y3AAu6ZLtPoxU/LrHJpcyVQ8GbheZ/PdSkc3McVrk
fT0ceKKwa0qfikGDmfKfXtVDk/ZmPjcrKqqOLUYd7K6HjVU7Pc29qRiasjNr
a2s98Huytz44RcU8cYtL9Pp6CK7cPb47hoqlgafSvKrrQXz7lqH8dCpeV80M
ZaXWA0lTOXXTVSpyl/M8u329Hqy1OhfbS6n46JdEmNmlesiyEl4wL6Fi96pO
83RaPXyRrK9+XkRFFonZqtT4ejj5pHPcqZCKH8W5QC6yHuwV4OO761S0Wb1z
8vHJejhvKH3jUD4VfxhbNnB41MO/As0kxzwqijVY9dw7WA+a7z1KBi9TcXqt
O4xiWw99w8vxprlU1N61o7EI6uHnoneRag4VZx841WjtJJ5v0E5pJo2Kg8Dx
Nn3kPrR4GC/ORVORvSLMpsHxPmSlOprbHKViPKv4wxXr+5BtlWNf6k5Fc0bf
V/om9+GhXXbQ/BEqvqgZGnuqeR9o/CNf0g9RscWAnL4gcB/qegeGb5GpqCEq
Y+A8UgcUOcXv542pODRWtnLLvQ6+TSgbjMpS8ZdaLxezcx3IOykYzEtT8fxP
pkl3uzowCmBwZdpFReqETKvQ/jo4PPZrXEqcmF/3NOc8yTrYmLhXx0aQipxe
Tf/VT92DRvkoktkWKm7I3Pgg+cQ9WDPmmHnxpRwrCsNvi3nfA27WsJimz+VY
H6h+lH7kHmhVZ5pdmyjHo7qyKos292Djl+QIpw/lWP7d7WCA2j1oqGixantd
jjmL8SeSlu9CyvuJH+rd5agl8N7YKf4uKOi99XlaUo7BVvXFeuq1MI2/Xe7a
l+PeySbWyl214Bqh2PPVphxbRazu8/DVwuzjDZKSVuX4SiTi4a//amDu5ur9
TJNyHOYv3zTYXAOF/CK65rrlqJztc+2Xbg2cDdGW8dhVjjMRm+I3mNwBg/HZ
SJb/ynCEyX0s6WgVbO6R7LPOKcNVLu2vGeQq0K57TNa/UIZnPD4cuGJcBSYF
2nIq6WVYzD80XStfBVU3E2+zJpXhFy6NbesLt6FGbzdfVXgZRt7MZOBIvA30
hMan19zK0NC5Zt9yxS2w7J/7orK7DPsueB3WW66ARJGr+53aS/Hj9kc9705S
QUPVq1auvQT/e9x3vFqtFJzflkrl2RZjs+Fya2F7AZjwkNxk+Atx9MWxs1U7
86BWtLyyMjofHzMW3wh3uQisA+aCHl/ykIUWc3fK+CIkdXTMvBnJwyLz+2pH
9lwEelWFkPVgHg6bD1N9t16EzZ2s5Soteei29WTYQlsOjFZqnH6dlofx9LG4
gV05UFzrt++mYh7SOVzKTixlgXt+YLHbySv4LsZFODkhHQr99SYS5nPx2AtP
nlGPdEgNjh678jkXLXbU6Rjpp0OW0Eppxdtc1JsalLZbTYPuHVUXHnbkosrK
2iub8DRw3fhb8H1OLoZUOD+bPXkexmeLtt1RzUVS3NyXptMpsNlU0eB+0CU0
TjhP961LALEbjBEVn3OwTn14y+W8BJA+fOXu1nc5GFz2o3soKgG+zxsYBj/N
wacTntkxJgkguVP7nFpTDjrlZldXj8VD6Bkx3/LUHHwtWrtozR4Pop/Im7QU
clAjgmreGRELjArvVvYEZePEJucSMY9YkP6v5a63ZzYq8S3czjKNhacM0ZN5
Ttl4YaH+Sxk/cQ412PR4CbLRz8PnrO6JGMjwzKsq3paNt/3z81/+iIZtfSnh
zp5ZGP5bkOsZ51n4+S7Z/fjnTPyW9EhL50MkxIiltfs/yUTO1aXKoZpImLoy
OBVwLxMTFU5ERFtHwl4VvRyv6Ey8KuwbMZQVAQceKVep8GZixXedr0FC4dCo
beuuciADI1+gYo1NKPScYdacKU7Dy87O1oFSofCXwtuenpSGKnzZHs5/QiC1
x9VXwT8NWa+NB90tDwEdKUXZoxppaJ0dUXB05TQw7OOsvNN/HkULDze/qz0F
/9bva+PvVAz/GbxdQycYGjudVz5ap2BB6c0HY/zB8NSJdH9BPQW/r/ZlOs4E
QfjZczqMIim4u3c7V/DhIHh5KKFTaDYZx++/0VQ1CwSDmQeLqinJ6GcW1jqv
FABWke8+r7QlITLoeF7b4wNd2YJXNysmon/ekMeJ/46DXn7hs2HuRLw6Ej+f
2XIcOJO3StxcSUCmJsf39frHgfuHsLheXwIud1VT8+29QTlo12OyZwLmZbtc
f5J4DAT929/svhaP3Wxun2clPMCFjTs9e2Mcko42M7n/dAenyS2hlV9jUSL+
6pGdbe6QICD+um0oFpl+wVCEiztY8Pdu+lIcix1z77UPKrpBJWeWxy7dWOR3
/+C4UdsVKDPLi03T59DS/FW0xvtDcH2n1kBz4zkcPh2UuxZ/CGRUTow1Jp7D
TBWNWqunLjAwP15/W+wczq3mnpz2d4ZAVS08eTAabzq+GuPrdASDek+duN6z
OGgUcaUg2BFkn2jdcLp8Fp+KHWxp2ukI2pONFxQ8z+JbowDXmigKFEiPLDxZ
i0Tqn9DvhUCGUKX1cz/UI9EkzPK/jE92UOeaVdJdHo58alu+Bly1gwv3daTD
TobjvuS8h+M2dhCpZhQiBeG4UvZUP7vdFqCu4GzkuzPY1OSaPWVnAxf+Xm3c
ynUG27nWT256ZA1dr3zXqt6H4U/TkTx7A2v493Vezaw6DO/dyJgLUrcCtUFy
SLRJGB4N26xrcM8SvkkZp/HwhmFZ5OatoGQJe9t2FN8aD0XG1A8BvtUW4P3e
vUn3bihOnR4/0a5gAc97S4YHokNxu74+t5kZA77gYhkRDA7A9Bzri5Kd+xHm
l+y9tnsik8SdR4YbDDGkL8oz4sdRXD8iqLZAMsSGwr/NLf1Hce2R/n9/mw2x
abu6V1vKUVzeNFTxouIABo9zaT9f98CkLffztpw0xoAL14v/Lrvj3Bv5rXsa
zNA3L7VOieMIqjf738gRs8HEI+UN1YpOaLL/Z0iBkQ2+/rp6S+SfI94qv/jD
yc8GLTwTpZ89dkRjo6mw8Tob7EluL13wccS3+9w8ZMVscf+1G0x7KynIsxr4
N+SmLdr+LrvmqUZGtikybTzPDm+rDGpfOm2H1RPkluc37PBxPflTlpkd2pbT
uEvv2+F7n39VXaJ2eCp0f8bbp3ZYkF1R/6rfFr1w2/G2jfY4Ir+164KcLU7T
t+efO26P18a42i3fWWH5I7W9WwUc8Fu7y7VwDTOMfK5bFiTugA2/NsjY/jLF
kphgR5q8A87sGb4cVWeKl761sG3Sc8AhwU+058qmGCt4jTHS3QGbvE0K/ZRM
cI7x1pfvZQ6Ys4M5/5+2Eba0ymx7ddsB14TTT/xZPYBT94/5UOsc8Jde7j2j
jgOoEX5OYr3DAeUkmZWfmB5ALt8l3soPDvjfYY3I2EOGyK3M1T7OR8Zj1dGy
plkG6MZuresnQsbPtD2a3E4GaPZ9eGhUkow8woNGsqIGGNpVVZWgQkaGLAMD
5bv62Cbn/uidKRn3tob22lUBjkRsbO0KJaOL/ydWPlddJHf4x245S8Y3o+r6
lb900Nvf5rt2LBkDKMfcuzN1cOnMMaVjaWSMEnshWNShjT+8eza8KCSjSMLF
qBblfchDOsms1UFGiUL/IwK7NND8jc++qm4yXg3SuMHTpo4/XsRnbnlMRse+
5YRbTur4TAj5Up+T8aiApnh+xl5k4utQzR4no1p8Xlz8qhp2f90z6zZFRp1h
ZmXl62qYdYatZ8dXMh55JEwN3KeGKZPn3Q/Ok9EuW2S17IwqKursvjO9Rsam
n/cl8peU0Wp993/CjBQ8zvbHaHmfMnI+f+lBYqZgQ+aiU2CMEq7NOm4xY6Og
VuyIzw12RXxWFS0dy0fBdbdiPwFNeRS+K7NPTJCCg7TUK1KJchj+bqNmzQ4K
jl0UdjZ4LosMtzUO5YpRcMte5o8VJ2WwP/ghb4YcBdtSpG5sbpXCLeP77IsU
KMi0o1rjzHYpLEyrMilWpKCqiMe7OR9J9E/z6DqhSsHlKZ4rswISuPyZP0Zn
DwV/+P2yDD4ljtFx1c6/91Iw9fVDh+V+MRSMI78CLQpy0EdEOFlFMX7m7a3H
+yh42c+xS7hbBFPzxZmNdCgY8E41eVe8MHJ9GGlkIVGwdi5zeCejEH4Oa9e3
Bwq+3DJIZe0WwBU3i+Z0fQpKvVlimT7PjxlKWsNP91OwLiqIK1CQF10Etta9
MaRg9ZPERa5JbmR39fv0/AAFDdsYpgvvbseBv2wxrUbE/bZ1ZXLGcGH3n1vU
q8YUbI2pTThmsw13HFz1P2ZCwfoLJkN7DTnwrwB+FzOl4HbTjU2HZ9kwnVRp
/JSwJdXhP1LeFqJ/O5kZYEZBEeGV/hfGm/FY+8vRv4RBtjmcf4UJ18TSrKPM
KehvYKPJfI8R576b/5sjfPhjrPFVfwZ02T24bmtBwfy/wn15Dv/aTow8P3WD
8JzU6esaw8ttdmtsQbOEdymlxG88utimmLeXQ9KSgie4mudnvsy1yVcy+1kS
/mg9s8go9LlNjrdK25tw745J3stjb9vYEhYbThNe3LB1bwJ0tgmdHUsJJXxw
S/4ZlR00UmH/KYMAwses+kXl8l6TmA6O9VII5yiE+J83niC9vvXkshphH3bF
2Ja9s6ShX6+9Nv7//2xVjwWmz5MOc85Z9xHP51+hBPFhS6SDDSLucYRZLw2s
FB76Q/odc6RaiXDfYVJzn/YqaRf/Zp1B4v3dDxneZExjgIrg2p3ehBfeuhy9
c5oRFmyY/H4S88dx/gOPjwsThIXXKQcR3mVisV+DtAlu3vGOHyfm/84Cf9AO
URZYrBsIMScs4IeiO1a3wJBFrmAFsX7D6fQ3Wm/Y4K7O8YTfxPq6aSTvDL/L
DhuNF7tIhCVNr4WOJnGCrtLnnxFEPDy20by3t3obDDTNCN4m4iWXvX0vVy4X
yNy8Y/+MiKfK/vKUpMjtsAGlSX8MiHG2YKquIQ8cC1bnWyPi8aPv84X4Xbzg
ktto+puI10PJCYI+m/igw6Bz84AeBR81dv/m7eKHj60hjn+IfHDgtvshobwD
7NvtqLc1KUg7mLg5dZMwrK7ydNlpUJCl9bN33qgwkKP86XFEfslvKt9PT9wJ
9m27DvoR+XjTfOu90nExeP9iA1M/ka/kqSkHbjNxsOxdY5aSp6BZQ5/Hxxpx
kLoWbt0kTcFva87jWeESsJRhfy9AlILxE6GDzkxScPzym454EWL9W4+W0r2k
YNXKpzCLqBfVtesx53qkwN82fiGTn4IFj9Pt5JN3gaxYbdtOTgomHqLVK61J
w0XlnKFvWykoHb7kccdFBgZ+asrVsVKQmnps8WKjDCRtuTchsYmC/06J1VwO
kIVPgu7KRf/IeGtudD5zSA6qN/hm7V0h45b911eLZOThE2nX74fLZHydxiIn
ES0P7jJRnH0LZORn2LE1TloB9r1Z6wmZJmPe8MXpulO7wXJkra//MxkXe6V+
eXXthhEpbW2RCaI+M87vyOZVhIgA6eKKMTI2pzRaWzYqgv6SyqQnUb/vqPlK
h80rwW0H76HYZ8T9nuv/WSQpQx3tSN6VfjK+E7Nh/p6uDIfZg8ere8j4XF6i
evd2FVjXd+xPopExdZ36+kKFCqQ1Xa9cKCHjw4PLugE9qrDf5DC1jNhfbt27
cV15RhVi/W4pW+aT0ZD851oDmxpMSm0Xz7hERpqY7gVWWzXIi4yktieRUS/6
04aPr9RgZo/NG2ZfMvZEap0Ne70H3t4PWnHwIqPMEefmxKU9UFQ95lrgQcaq
PU+XnXn2wp+O5xzCLmTUd3O74mK3Fw5khrm+MSfjbrehNXrfXtBgH/CzViDj
xu87QvXuqEOv4eZLc9JkzGlmqN/zRB0MQ2TpyRJkvGzC0Tk7rQ4BlxL2VQiS
MVtxOrZMUgM+RjvtKdtMRvZTYT1qVzRgstDCIG3cAUfKl5+JBWsCfKoYfjrm
gLc5gq47pWmCr3ukDMdbB8yVEf9FpmpC+fhn8ehnDmjwPiKKOqwJa7dyekQe
OGBj0+ieYh0t+M/uy66QXAf8/gEzjP9oweDllee+WQ54yXCJgXXbPnh9W3Pe
JY24/1Rc3VXpfWCz9WelcqwDMkhRhwUc9sEGluIdVH8Hos+TDK66tQ8Y6GLt
HQYO6LfQxkq20obnzD6yp3WJfmi5L/aruzZYqY6WiGk64KqopqttiDbwf2f7
GrTbAWO2G1ql52uDgMvTxY98DhjHrnKke1IbBoqKr/HO2mON9uSZxGAdmLR2
uDf72R7HNvD+4I7VAa7PM+NtH+2RZYN7aVSWDiRk5tS4vrbHxjtxwe/u6ECV
Q0p5WIc9Hp4retQ/rQNyoz8/yeXZY2RA/rd6J10YzvV58DLHHi+dvvx47pgu
/HZhFY7OsEeT/qI+xlO6EPC2MKknzh4nwwXfd6Trwl/JjlbdAHt8O+scc61V
F17zjRU/0LdHcrG72LCQHixZpc/v17FHw9jj9V926cHnltt7etXtMaA/2GpY
RQ/8Lz658UjeHqUZjGzJxnow2+8118hjj8zp3iaPg/SAEkr+rDlth+2o2dL3
QA/6eU1YS8btMCQsymysWw8UrL+d3TRmh9uV7ga8eKoHA7LRh54O2WGwRj6r
10c9GPy1dtOcbofZfUF/xRlJcN2j0Wwlk+h337z12aVPgk445PgsxQ7f5j1P
ZDAlwcVNhv1lcXYYZ64+QLMhgXqVyDajUDu8w+97Z+AICbL0mh6dcbVD/SvD
YafOksDOaHlF39EOt7WfWrSMJ0HXf4KvWWzt8CRP0xGW8yTiZMRYnGtoh4kM
DKUSV0jA26nNUShvhx7wS22mhgTHQwLEXaXsUIxfO+FZPQlySsJYhHba4f2S
ug1XaSRYteM8fpHLDpczGOQGu4nnCVX6E/rbFn0lT8Z8ekcCQ2cG0u4FW9Sa
uFM89oEEFudLYj/N2qLo6E3F1kkSTDcY85h9sMVh3YtqMt+J6ws3sbD32KI7
911S1ToJNPVkntLRFo8sKSv0bgSwXGF74Ntiiy15S129mwEC64WlOqttUeYT
X8kZToDuXT2VgcR5gvUrWVWGG2CwQMlPsMQWZ8MKOR/wAeQmajYHXLJFy4/b
Ha6IAFz1pdjwZtpiwU4JllExgHFdRa3WZFvMoDLc3iwF8OEKMw9bpC3Om/90
4JIHOBOinlLsTrzPob9FC3sBGmTWSYYutriiPCUQQKT34fzwU1MOtlj2Qg77
9wGk3gz1UDCxRX2LWJUDJAD7+jCZAX1bZIkLtTikDyDsJ3EuUNsWncxS1Vz2
A5AaQxZqFW1RgfKEaZsxUS7arwrZythi3MoY9JoA8Lgenf5BnJ/Wl55PeZsB
rBls88gSssWs8OviP8wBOnd/Oq/EY4uC92UF3C0BUl5z+wyw22LSa/+FFiuA
oD9TDAGbbfEBt+Obf9YAMdIvvtsu2eDu4klvkh0A22bePV4zNii0PKyoaA/w
sM1JImKMON91bYxkcQA43bWrO2PIBtX3z/kPEp69sEWqpNsGt94SlEoiA6zm
Zprcb7FB5T0cndIUgCgrXa2eOzZ4WsjWt4GwhnLJ2ptSG6y+ekxT1RHgz13D
8tnLNlj7ZdAqn/Bls3tKa+dt0M5AaOAn4ZGg07e2nbPB4x+6X+11AuCNKN8h
ecoGRzrVU7wJn/xakKTubYNeAYnfkgjD7KevJi42yLJDUOAS4fvoZ+dibYPR
9y5LXCD8u0oZA/bbYBRXgdQZwnq/ZLVjNGywTfiphjXhe6PWfTnyNrhSP3CS
m3DCrWtB1J02OEPX/d5DPM9E0QaNpu02aMjd2uVDeIUhRvzxJhtsL/jJ/od4
vzVuVq2xFWsU1I4YP0NYVPh6zM/v1sg88NvlMzE/aYfl1zZOWCNJkyvbgHCg
8N0W/mFrPOtyLD+DmM8/BVLNCk+sMVQg92IPMf+HJGPXAa1x0n5/zg9ifToX
aZfJ960xZnZb7WbC7vYDsb4V1sjQVcrEaQvgkVDbc+66NYq2XbnNbAOw9Nj5
RG6WNV6i57TMEut/oebLr/Yz1njERDw02QJg/jn907C/Ne669sdeh4ifyp37
TH64WaNUqNu/D6YA7brbckVNrfGm/SGeP0ZEvOS5pGjpWmM+v3r9iQMA5vLK
bPYqxPicZPxzIn6R5eBosoA1fnHoYz1BLEfvaIF62VZrzKjo+K9MDyDvj6Vm
G4M1yl9yOv1IB8B056DF72krVG35GDtN5I/k+fPuoS1WmPtTuPikMkCOgC31
yh0rlKmv7VBSJG64/UB7c6kVhoh83zdG5CMv5fLV9fNWKOazlMkhDTCZyXTq
qosVfs4cD+3eASAbarfh319LPFQw+vwaE4D1/WeDPj8t0ZL5W33KBgBd8UdP
Xk9a4gXGjt8+ayRoFKlxaRywxPRHuYybfpPAJ6crIrHYEvuXnldWfyXGpQ1v
eRhaEv3Nrqz2ARJEeyW9mNC0xNJbq4E/HpFgTMAo4fhuS6StrEty95DAbNg8
+TSvJS5XdLnvayPB17CpbUVfLPD2t7LhDUR9zbj8qxUyLLDNY8+vrHQSvPgV
7jESa4Em6z6121NIED4c3xgeaoF1zh92pxP1W/S6enzzEQss+qBVeziCqJdm
UX8tVS2wxcfsSpo3CRyqm2z7X5vjVU017u1Agkszqm46kua4ynRvwXRGDzI2
vqWL85ujfdKpUNkJYj/Te5zDymaOOgeGrNZG9cDp6V7axIIZ4tc5u8xBPVg7
8/Rk/UMzTH/lNKPdpAcPnU+JvzhqhtsGhihT8XqQlhpYI3LDFH/NG/r/49aD
zo1XTmWqmeDgLIdDh5gu0V+Hff4uY4Ij1ZJNFoK6ILRrXcVBxARV48cDh7h0
oded3VaKxQQbVJh+PGXUhe+MD59Njxmjz+R53UuTOhCyV5X133ljfPLhW69Z
hQ6wHbbbRpk0QtP5+Mh6OR1geBHktrPsAO7iTSqukdIGg96Pvu7c+1F441+f
thdEf2X9lFZ8FTBvayfD9wR1WMq1dJXv1MGKh8ImWcf3AKchz+EZVi08eoyx
55mWKhzhNGTSWtqLnNnGX/tKlWAiIGfkipEa0kNdDr3drQBmstnjW3yVse1p
0RxDhwxs2y+nmaOhgNSgs2cX3kvBYOqN6i27FPCTIFmo7bkUDAQMeWRwK6CM
WHZcFnE+OP1VI/zuT3nMX9pKNayRgotPVQZPVcnjUgMP73y0FMQ/KmEalZBH
IaG9KW47pWD75jA9UUE5NH8feDvOUxKSopxDXrPI4b+isuGNByVBOWbCPu+3
LJoc5aSmW0oCI+vXRfU3suh2I5C3Wl2S2DNa9KfyZPE0J2iosEiCyqLYGIeg
LD5kWLc5UCMBFLAgH9kiizI7jr0WLZeA0mx+maY/MniU7cQXhqsSUCZ2uT/x
nQzKSxhRX8RJgDeL8MWsAhl8LrTFi06RgNtZ1h5ymTJY+ipFuNNcAoTeiHn3
R8vg/DM38iBIgFNa+aqimwz2av4Hf+UkYLfni+RvNjL4YF18XkBUAiRGStXq
9WXwHz1ORJdHAu7esv6XqCqDDYL9nce2SMDxZMEPRyRkUKanafzimjj8D0gw
vLA=
             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.560181, 0.691569, 0.194885]], 
            LineBox[CompressedData["
1:eJwV13c81V8YB3AjktFCySZNUSjJejTISmQrIyoze2/XHsnIHvfa61573otj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             "]]}}}}, {
        ImageSize -> {400, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[1, 2], 0.5], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, 
         Axes -> {True, True}, AxesLabel -> {None, None}, 
         AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
         PlotRange -> {{-0.0012999675522775201`, 
          0.10596931923826362`}, {-0.04029658294312864, 0.02}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 3\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJwd13c819/3AHArUTIzojLKJmRlnpSRvUs7ZSuVEZKRLWRkk733ftvHyMxe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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.560181, 0.691569, 0.194885]], 
            LineBox[CompressedData["
1:eJwd13c8le//B/ASGhpGmtLQICVE1kfvzGRlr+y9T2RL9t57b1lRNsd6G4eQ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             "]]}}}}, {
        ImageSize -> {400, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[1, 2], 0.5], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, 
         Axes -> {True, True}, AxesLabel -> {None, None}, 
         AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
         PlotRange -> {{-0.12621338153457368`, 
          0.31859108475686043`}, {-0.09225276928162297, 0.05}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 3\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.560181, 0.691569, 0.194885]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.6624715634335537`*^9, 3.662471583232582*^9}, 
   3.6624717904482346`*^9, 3.6624718407348666`*^9, 3.6624719308337083`*^9, 
   3.662471985095147*^9, 3.6624720584681473`*^9, 3.6624722373380184`*^9, 
   3.6624723073626375`*^9, {3.6624723541707883`*^9, 3.662472377054003*^9}, 
   3.662472410790917*^9, {3.6624724721313868`*^9, 3.6624724964896345`*^9}, 
   3.6624725710444794`*^9, 3.6624732549110365`*^9, 3.6625519680878396`*^9, 
   3.662552234891903*^9, 3.6625523256902304`*^9, {3.662552369118004*^9, 
   3.6625524375334806`*^9}, {3.662552484525793*^9, 3.662552509653598*^9}, 
   3.662552810630478*^9, 3.6625528467390623`*^9, 3.662552886091612*^9, 
   3.662553025588457*^9, {3.662553081716229*^9, 3.662553095162757*^9}, 
   3.662553369712298*^9, 3.662553417503162*^9, 3.662709796921974*^9, 
   3.6627270155563374`*^9, 3.662904871871772*^9, 3.6629049762872925`*^9, 
   3.6629051360176783`*^9, 3.6629135109044547`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Number of required switches to reach ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"0", ",", "0"}], ")"}], TraditionalForm]]],
 " when starting in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Theta]", "0"], ",", 
     SubscriptBox[
      OverscriptBox["\[Theta]", "."], "0"]}], ")"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6618642087610435`*^9, 3.6618642550990405`*^9}, {
   3.661870929566696*^9, 3.6618709302951994`*^9}, 3.6620169429159184`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Join", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Quiet", "@", 
          RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"above\[CapitalGamma]", "[", 
               RowBox[{"x", ",", "y"}], "]"}], "&&", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"k", "-", "1"}], ")"}]}], "+", "1"}], ")"}], 
                 FractionBox["1", "g"]}], ")"}], "\[LessEqual]", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"x", "+", 
                    FractionBox["1", "g"]}], ")"}], "2"], "+", 
                 FractionBox[
                  SuperscriptBox["y", "2"], 
                  RowBox[{"g", "/", 
                   RowBox[{"(", 
                    RowBox[{"m", " ", "l"}], ")"}]}]]}]], "<", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", "k"}], "+", "1"}], ")"}], 
                 FractionBox["1", "g"]}], ")"}]}]}], ")"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"-", 
               FractionBox["5", "g"]}], ",", 
              FractionBox["5", "g"]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y", ",", 
              RowBox[{"-", 
               FractionBox["2.7", "g"]}], ",", 
              FractionBox["2.7", "g"]}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"BoundaryStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thickness", "[", "0", "]"}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ","}], "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"MaxRecursion", "\[Rule]", "6"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"Opacity", "[", ".75", "]"}], ",", 
               RowBox[{
                RowBox[{"ColorData", "[", 
                 RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"k", "+", "1"}], "\[RightDoubleBracket]"}]}], "]"}]}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PlotLegends", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"StringForm", "[", 
               RowBox[{
               "\"\<\!\(\*SubscriptBox[\(\[CapitalSigma]\), \(``\)]\)\>\"", 
                ",", "k"}], "]"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Quiet", "@", 
          RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"!", 
               RowBox[{"above\[CapitalGamma]", "[", 
                RowBox[{"x", ",", "y"}], "]"}]}], "&&", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", 
                    RowBox[{"(", 
                    RowBox[{"k", "-", "1"}], ")"}]}], "+", "1"}], ")"}], 
                 FractionBox["1", "g"]}], ")"}], "\[LessEqual]", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"x", "-", 
                    FractionBox["1", "g"]}], ")"}], "2"], "+", 
                 FractionBox[
                  SuperscriptBox["y", "2"], 
                  RowBox[{"g", "/", 
                   RowBox[{"(", 
                    RowBox[{"m", " ", "l"}], ")"}]}]]}]], "<", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", "k"}], "+", "1"}], ")"}], 
                 FractionBox["1", "g"]}], ")"}]}]}], ")"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"-", 
               FractionBox["5", "g"]}], ",", 
              FractionBox["5", "g"]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y", ",", 
              RowBox[{"-", 
               FractionBox["2.7", "g"]}], ",", 
              FractionBox["2.7", "g"]}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"BoundaryStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thickness", "[", "0", "]"}], "]"}]}], ",", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ","}], "*)"}], 
            RowBox[{"MaxRecursion", "\[Rule]", "6"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"Opacity", "[", ".75", "]"}], ",", 
               RowBox[{
                RowBox[{"ColorData", "[", 
                 RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"k", "+", "1"}], "\[RightDoubleBracket]"}]}], "]"}]}],
             ",", 
            RowBox[{"PlotLegends", "\[Rule]", "None"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"-", 
            SqrtBox[
             RowBox[{
              RowBox[{"(", 
               FractionBox["g", 
                RowBox[{"m", " ", "l"}]], ")"}], 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  FractionBox["1", "g"], ")"}], "2"], "-", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "-", 
                   FractionBox["1", "g"]}], ")"}], "2"]}], ")"}]}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", 
             FractionBox["2", "g"]}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Thickness", "[", "0.015", "]"}]}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"(", 
              FractionBox["g", 
               RowBox[{"m", " ", "l"}]], ")"}], 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 FractionBox["1", "g"], ")"}], "2"], "-", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"x", "+", 
                  FractionBox["1", "g"]}], ")"}], "2"]}], ")"}]}]], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", 
             RowBox[{"-", 
              FractionBox["2", "g"]}], ",", "0"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Thickness", "[", "0.015", "]"}]}]}], "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
   "\"\<s12\>\"", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.6593374882732215`*^9, 3.6593376645802116`*^9}, {
   3.659337696180521*^9, 3.659337874907769*^9}, {3.6593379223492765`*^9, 
   3.6593380318356123`*^9}, {3.6593380653192635`*^9, 3.659338160107218*^9}, {
   3.6593382216426835`*^9, 3.6593382569886503`*^9}, {3.659338296411496*^9, 
   3.659338396794402*^9}, {3.6593384375381823`*^9, 3.6593384737707753`*^9}, {
   3.6593385310350485`*^9, 3.659338687937755*^9}, {3.659338742306159*^9, 
   3.659338750650052*^9}, {3.6593387978583984`*^9, 3.6593388007304273`*^9}, {
   3.659338837321273*^9, 3.6593388870403924`*^9}, {3.659342282828064*^9, 
   3.6593422987983437`*^9}, {3.6593423338581085`*^9, 3.659342334612653*^9}, {
   3.6593423728016167`*^9, 3.6593424096336327`*^9}, {3.6593424648406286`*^9, 
   3.6593424659874387`*^9}, {3.6593425044275913`*^9, 
   3.6593425168933964`*^9}, {3.659342584489143*^9, 3.6593426139319515`*^9}, {
   3.659342716271228*^9, 3.6593427225396557`*^9}, {3.6593427604264174`*^9, 
   3.659342761670295*^9}, {3.659342839471251*^9, 3.65934294544912*^9}, {
   3.659343037562173*^9, 3.6593431163568306`*^9}, {3.659343163274972*^9, 
   3.659343166965578*^9}, {3.659343208611995*^9, 3.659343211590099*^9}, {
   3.659343265961504*^9, 3.659343281550516*^9}, {3.659343442367109*^9, 
   3.6593434663390417`*^9}, {3.6593434981375027`*^9, 3.659343522585772*^9}, {
   3.6593436020659127`*^9, 3.6593436396614695`*^9}, {3.659343680043993*^9, 
   3.659343684214939*^9}, 3.659343719030531*^9, 3.6593437601445723`*^9, {
   3.660282803617957*^9, 3.660282924664663*^9}, 3.660282966383209*^9, {
   3.6602835624738684`*^9, 3.6602835668789763`*^9}, {3.660283599623166*^9, 
   3.660283610026531*^9}, {3.660285770018841*^9, 3.6602857724505625`*^9}, {
   3.6615020669215465`*^9, 3.661502077506013*^9}, {3.6618641840263386`*^9, 
   3.6618641952645617`*^9}, {3.6619644045403905`*^9, 3.661964409654591*^9}, {
   3.662015729841241*^9, 3.662015730280552*^9}, {3.6620157871126204`*^9, 
   3.662015792376336*^9}, {3.6620200340031576`*^9, 3.662020058049971*^9}, {
   3.6629060643744974`*^9, 3.6629060649168825`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, 
     GraphicsComplexBox[CompressedData["
1:eJxkXWVYVU3XRgzARFRU7MYCO1BZKAaiGIiNhdjYiI2diFIinQdFRLrjjHSI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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.880722, 0.611041, 0.142051]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNnXXcVsXTxs99+mARih2oWNjdimAXIoKNAnYrNirYYovdYncr6k9BsbsL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            "]], 
           PolygonBox[CompressedData["
1:eJwtmnncTlX3xs9zzn2ffQ5FkwYNFCnk7U2DBmlQkUYaEDKmRGkiyVBkiJCM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            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl2HncltMWxvGneUJJGSMhmoRDZkKGpAyhKKFMZciQKVJRNJKiUEppUiJS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          "]]}}}], 
     GraphicsComplexBox[CompressedData["
1:eJxsnXVcVcv3921svXZ3d/d12d3d3dfubr12d6GAgo2UgMDQcFCRTkWvfe3u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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.560181, 0.691569, 0.194885]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNnQfcltMbx595P89zP6MhSUZDpKxssiKKzGwqipCRvWdmssneZc/MKEol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            "]], 
           PolygonBox[CompressedData["
1:eJwtm3n8FfP3x+/ncz93PvfO3JmQIiVLJFpUWigVJZU2CmkRspNWSps2pSQk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            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl2Qf8V9Mfx/GvUTRVVkQqGZnJzKoUWRkhM00SDdEgERJpk9K2FS2UiKJB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          "]]}}}], 
     GraphicsComplexBox[CompressedData["
1:eJxkXXVcVUsXxUJFxS7EbkTsVrYidiN2YTcqKor6bBHsxAQVsBDpEtAhb1H3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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.922526, 0.385626, 0.209179]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNnQWUVlUbhb/usbELuwMLu7s7sbG7RUURTGxFERQLxO7Gwu7uVkzsrl/9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            "]], 
           PolygonBox[CompressedData["
1:eJwtmnfA1tP7x+/nuZ/PfX/W3SCjvURStJeIQktDEpmRjEJDyiorhW+DfENW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            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl2Xf8z+Uax/GvkV1KJKKQhLQ0aWmQlRVRnZaDhi2jJZIGLYSSVEraSon2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          "]]}}}], 
     GraphicsComplexBox[CompressedData["
1:eJxlXHk8VV3blopI6pGikhRJSoOiEHdJJYVIgwgJKUOFpIFGJUWTpKKBSvUg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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.528488, 0.470624, 0.701351]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNm3f81+P6x9/v+35LWYnMQ0gI2ZStZRTaKtWxUuRIkYRKQ0OkLdvJONK0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            "]], 
           PolygonBox[CompressedData["
1:eJwtl3nYj1Uexp+ziDaytZhRSbS8IWmizYiylFK0UQiVpgVXo7qadu37XqIU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            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl1VdsV2UYgPFDQRApCBYKaAIULhgiptWAKLIVBGQa0BuJFaHICpiICTEB
DJuoKAVZZVzIHspQ9l7KKmVTpoywCpLICAr+3nDx9HnHd9Z33vNvRvagrgOL
JUmS508EEeemJEkLwWSuJ58mrlU8SfajKRaWSJJF+BkLMB9bsQ079Xeghfhb
bs5v41kUl9fgZ1ASreQNeIPrXOdXUALl8Tzy1XtzH3yG0RiFZo7brPeu+B10
Q1ccU+uj9yef4M/RD0fkH3A3HMcfcV4+yr14J5+N++ZPuYB7cHecxD55Dg/B
JdcZzHtQHo9RAXtRTW8eP7D+Ml/BKBxSX622QryKD8ozxC/Fc4i3xB5gEzbi
hjVX9UZjnnwMH0Y+1ur9qDYZP2AKcvGhXiZ/xFmcEvuNgfJGPIin8QCeyv35
J/6Oy3FZpOJ1vIa3cFrvfe6A9ugbexv7h7Hy3e6lLbdBHbX+/AlnIzX2P87L
NflNjBSXwUXckQ/nOTyCZ/Fs5GEuvsYa52/FLVHTmgk8EePRTn5Gf1M8R7wn
tSvyu+LL3DfmTJwTM8Uz45rqN/kWJsZcxNyqzRdv4e3yIXhZPpjrc4e433j+
eMfW3BC/itKxPzHX6hlcCq3Fp2K24xtBKfyDe1gQ86W3K76R2Dv57873i/hX
rIh3qfZ33CfO603lyurpuCp/kcepNeFrfB25WBbzwMt5H4/jPda34/dQT61n
zHXMmHprvsTduQqq4iaKcAsn9GrH3jhmW8ws/sXD2CP+ixvyGjzCNflmruiY
QnFhvBt8gSfYgI1orP8GtltzQH4QxeQJsuI7QVV0Qhe1zsgUf8WT8H3sVVyP
V3Je3IN4Fv/Gt+P9iMdjsXwCL+EmfAzr9Q/LP459FhfxbUxCR/VOOKReELMR
37h8b7wrLI255yXxfSMNhfJlnKBlPAv+Qwp2oZL+UC5yznP8JVarzYg95el8
FKf10+TfxDGxv0hHW1yI74vPWTNG3Av3xdl8L36vuLH+2fjG+Lk4BqWxCE3j
9xJ1kR+zEN9qzHbMOZ44R3V+zFs9ym6/9dXF9cXVOEs+W7wOFVCAYchRb8CN
8AJGyptxGu6iIiohHZVRBako+XS7krHWZyZP/+f8DwSg3Yo=
          "]], 
         LineBox[CompressedData["
1:eJwt011ojXEcwPEHK0U2pIiNyUbS5hQbtRQXFEUsy8s2RrmSbWVedjbzeqFk
ZFdeCp3NjSStNdtSktywqdUcVjhexkmT2CRv5fMvF5++v+f3/M+z9ZzO3N01
pdVjoihKERsbReM1oWd0Ei1kUsI6skhSQLNzxTrMVybTQZwhD23XQs3Vh5rB
G58pGhdFy8nPiKJl2qSd9h3mOCPmlI5qg+5yv4oV5lM6lSl8dz8nXNvP02v6
Ua/rBW6ZW3SzljHofJ++0Cfay2NuO/OLn0zjit0RvaSNelmLKCaPxXYTdCLr
zTM4YC7U/VqgdXqIg3T7ez12N8nkB1msIeX+an3qzPnwHLbYbWUbF123a9r9
bJ3FDnby2a5S53OUY2ynnAo2+ew7LdXZvCcnvEM6ucthhpyp13LOhWfoIJ88
/4TrkxynxO6B3YD5rLmK5+akXa25jLfmpF2/LnX9SjfqTBrtl2i9NhCnzvU9
Z6rNNexjoV2tTte1zCGXXuc2aJ/GdA/PnHvkusn8IbwHXcDe8F70i8ZoDv8z
35y9b5/gt3kkfPear3nc4aVz2dqjV8N7Ct8hXQw7m7ZrNbeR4LTrNtLmVu2m
ixv8cX5U/+oqfe3MSq2kIrwXv4lF/397/wDXVnZV
          "]]}}}], {}, 
     GraphicsComplexBox[CompressedData["
1:eJxkXXdcz9/3T6KBJGTvlZ3s1c1OsrKVlU1CkqxkU6Glnda7JNp7Hu0ppW1m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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.880722, 0.611041, 0.142051]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNnXXcVkUThs9z+oCtKLaiKHZioIKAgCIqYmAndotdmNgiBnZ3d34Gitjd
rajYmIit31zc9/PDP/bdObt79uyzMTtzz+y+C+6wz5C90yRJOnZMkiziLq0k
eTvi5yMMzpPk+ng+K8Kf8fxHhK4RHoznkyMcBB1lNgx6cIQz4vn0CEdHOC1R
fVFtclKEEyMMipAXkR6hf9Ad4p0mQhnh5wg/Rjgg0ouI8wi/Bv0DZSKeNcL3
QX8X4XNCPG/l+r+JsG2E6SKsF3VvH/H0EW6NcgdHPEOEUyP9lAgjgn4mfvDT
Ee4I+tko80xL9b8baQOCTiPsFmV3jbBUpN8Uz0mEDhEtF2WaCMfE89Xx25eI
cHc8f+d28O1z4r2vIn9efnfQR0U4PuiNouzYSL+Q/orneSIsGOHMeB4VoXfQ
i0enfRN0n6DLoIsIKwfdK+pYK9L7Rtg66K0i3BXpR0R8cIR9Co0Pfd94HBgD
2pz495HeuF/pK/p4kPvqogibRVgt0Xh09PhtGH9+iHgnj+Fi7s9d47e8EuVe
jnBzS33EeAyM8l8lGh/Gk/GbJegDE43tzMyrKLNBpm8xXozRHBF+TvSt9SO8
Hu+9Rr1BT4nwS4TxicaE8afvvvPY0c/PtTSWywQ9IuKjIgwL+umIn2KutjQm
C7rfL4x6Lig0VttG+gmJxmjRaNciEXajjyK+O/LuYj5EODXSjolwXtBjIvQL
enJLa4K+HRJ1PRfxKMY06FER9o+wX4R9I5wQZWeLOmeNcHWU+SfC3xFeS9Qf
62fq35EtlT2WuRTxSRFWZ2yjjkMinBX0MlH2GX4f/RX560W4JtH3V/bYHRdl
j41wMv0Xc3RyhHWDXiDKvhrxkxEeD/qxCDtFaLn/mCtHxfhuH+XfpC1R2bCg
14vwW6S/HeHmoGeIMBvjD7+I+MgIhwR9TcSHR3wY/CLe/TqeVwi6U7y3ZDyP
C7p3tOtO3uE3RtqDUdeFEf5KxGu6R7g08i9xv9/W0npmHj4Y5asIoxmPqKdn
hDry/hfvXxDx76z3yN8nnodGeCHC8xEWirzdo+yARP25cTwvH2G5COtG/g0R
70Pb4t1DE/2WTSNtRdofYaFI/yPKDQz6igiXR9gvynwUaWsGvUXQn8VvfKOl
+XhdhKPdL09F+pPwCtZAxDNFuDPok6LOveL9IRH6Bb1Wpj5bOsJSEYYn6if4
QZcIVyZqI7/hb/rLPGvTiO+lTaz9eG//eN48wqP0ifv104iPJi3ok6MfTjLv
WCDSuse7i7e0zqgbvpdFPb1b+m3M0/5e/0vEO2WEKxLxydW9ri+Keq5i3CLc
l2g+wlMmxfvfRvisJV4zyDxkvuiD9yJ+N1H/MjfXiPBl0BMjbMIcbmn/WM91
bRBhxghnx3c/ScTPzwp6dKG8UxLN98Gef8Ss+QHxrWPZDyIcF79rj2jrOhG2
ifcWhHfQn1GmzsR3F2Y8WuK5L7VU74YROkf5BxO1deWg/4x3LmX8I+4V4U14
Qbx/bktrF163mdt8b6J1z++6wL8vqkj2KjRnf4vwaqS/H/HmEfaNeveM8FnQ
79NXEe4PekKU+djtmhT5X0T4lvGN509aqgP+DT+G/38RYWs/9+dbUf6WKLNO
tG3tTHvnLebjlJsz0r6MMl8nGi/2NPaL9ePdHfw8R5SZPcKPjEmk75gorxt7
TYTvg/5fIt5AHs/fucyi7AkRvky0PsiH/9fx+6oIE4O+vaU1v3PQx0baHS2l
wSN38vz5gL5i3bM2o73DIl6JcvC6RPvJOxEeizA2Qsrvpu8Zj6jn/JZ4+XpR
/+iW9uGRQW8S5e4J+viW5t+ezMlIv89pA7wGmfdnRD0nRfkdIjwReePgCS3t
I/CG3qyXTPv6/kEvH/UsF2GOln7Dwe7jkYn4PXvkT5H3RUv0Gi3lsX+yF8EP
4AUrRH3LR7g+0f5woNfgyXw32rIRczITDzvY4RD384qRV0U4Jd7r2dI3kOXY
yyd4Xo2LNvaJ98dE+qkt7Z+sp1GOWVOntZQHr784yp8d4Vr2xpgP50Y4MsIa
mXj8EYn2W2j42FGJ6IUinO9n6D6F9gaeT4v4X4/dWZbdkA0GRJ39I6yYad89
2vO8bzx3j/BQIln0GMY8wgPRpvsjbN6SnEk/14me6dsqwokt7bvHBd0zU7uR
B0bEd19KRPfKlIessHhUvH2U3859P9Jj1y3St2QvaInPnei5ijx2ZiKZ7N3I
e8d87VvHlD0+vrVdITkHvgUfQ1YhDf4zdyJZ5hTnLxLpXSMc2tJvPdW/l++M
SqbJf8Qd3U+nO+1M06njM0zTr2e47NOuJ3Ud0JnjM52+ZHy/KCTXfxLjPyGX
/rAoe1pLusEmEXp5rk3VJ3iPNnm/4pn+eM39NWu8+0dL8i1z4y7PjzMZk8g7
LsKN8Z3pc/HB8RE/EWHOlvgEc7ZzhKHsmy3tYae3NF/PS9Twdt1XOWbu9S00
/+APL0Z9e0fYLN5ZIcrnqebIVi3tbcjLtzlGjv04lRxwcdDLRvxnS3LoixFe
iHCJ58+l/tYeQaN4zRV5F0fc8t5ZFZJJ2Ft3aIn3s+cjoxHDe96Ksh1S/aZL
/Ruo86No74cR5mEfiPxtI6zS0n7KvsMeSntujXi5RPsSezT75sOR/pDzXor3
RkY4IcLbkfZWS3tn93ieLhWvXMK8B7luofhmlwgzRvqjER5pic/eFGXn8976
h/fWG4N+P+IdW9pf+7e0pyHnP+aYvW8b5OFU+wT7A/sIe8eWhcaJ+leK/BlT
8fElIt6F/aKl+Xibx2WrSN+6pecJqcbp9qDXQG4pxOdWjHiFQvxrr/juvlF+
3ghX0ect7cesdWQ31j5z6sOI54rwdpTvlWp+X9aSzHpPIj2P/Z49/teWxuRe
z5f73Pe/+Ts8v+5+QIb8Peht/Dx7KnnjgQjzRRtfjjYuw5oqpHeSt1YquQMa
3ZR9lz4bFGX7e8xWDHqVaOsjkb57S/oMfPJYdNkIq8bzk6wl9piWZEbKtpjn
yDMRZoE35JIVkSFXiTJzpPrd6NdjPXZjPZbQr6InRtgzyvRoaX8mb65UWMML
Qc8Z+Z0jzB/Pc+eSfZ+I9F3Q5QvpKceZLyKXPpUoDX44xfTSEW5IpduQD294
ymXQIZ42v9qokJ7G88aFntGjpmPPineWzZTOnF2EdVoIC2nrdcTwQNr9vMs8
Zxq964Wo45lc/T2ffx9lpqTSwV5MpB+wp8wX4fCW9E+el45vvRPvHUE/xEfm
inB/Kv6BfoVOslbkz2b+Aq+EZyKTT2AORSgjnJtKt+T5sig/JlUa84N5guz6
ZNS9XITOLbX9bbd/7Sj3b0vPx0f+Aal0o9U8fshT4x0zzltHmQPjeYYIeztG
pn/fMTo4uAtriL37g0Q0a+dqrzHSPnQe6cu2pKvxm1aLb8+TqmzXXHLPR9QZ
8cGp9J5OmfTqjxPJaBPcD+jE6AgbeI686nmStSRXkHcdum2Eb1PxV/gtst1i
8a1uEbrCg1PJ0GAayMzEHf1MOnJ1K5M8+4UDNLJ0Gukzt/Q8MVVd4CNfOEb2
/jxVHvL2tVF+BzAUni3Xt3El4ukcf+t3v4kyk/z8XSp9YJLH/jX3Q6dCdbXl
7+9c3+yF8pDN0eO/d/73qeR6sJgu0ZYFI4xPpWORNqPzKIMs/kPk/eTnn1K9
j+wN7/zZ4z4S/CPCgRFuiPp2RXegXKp3kNcvjLS7gr4jlR46xeMFH4Ae70De
Uu4LsCzk58OjzEGF8DHwQ3QpdCuwBHRf+BhpvzsdzAa8rHH8p8scGplLtFQO
TOQXtwFZ8w+XoW//cf8S0I1Zg/+mwhJ4Xqql74JjgBX96W8yJ/fzvPzX67RH
In0UeQhZqI3Z0bZ1M+EyPPNbweym99xlDo9wWcqA2wzKhF/yjC6S+Vu/Rf2/
pnpeL8qs01I5dHLqLFx3YZqxKvxNxgzcMJbDVH0RfJC+B5usWuKHp0eZ4YVw
YNJKp68eL63GvhrPZxTCfMmnLcO9Dqm7g+uvTJcOjb91frx7XqE6Wm77Ml7T
07U0RnNE3mJBz+71h+zAGrwGHTfTOrsRbC/TvGvAjQrhUtejV2ZaQ9TD2kCP
nSniGQthFZ3ReVvSSW/2mmG9LB15TS79Fd0L3Q497fl4fi7XHtmR315of2Oc
kfsujzILUnfk72M5AHkAmQxMCHkWWXaDVHr1bJYhkCWQ54an4tfso3uzb2XT
9j9ieN7mkTb3f+QwYvYjeDO8GuxlW+994CC3RdnzUu0Zs0T6zIX4Ljx2kZZ0
4YdSYW2sE/j2wubh8LlFzevuQy5wu4+Odw8Les0IS7b0Xjf3XzfzHeTBJZ2+
dEvrh7UzNhWGxfPc0ZaFmVTwe8anEP4+P5ieZZiLI+/hVG1ENlza9bAPd/Fe
Bza2rPcJAnvN617HrN/+jpc3fUnU+Viqtmwb39s00560XHz3p3g+w3I2GBb4
1VyRPmch3PCYKHu4f/s7EVZnDkb6Dcy5XLjn1RF2SyVXPZZIRkIOXjXyP4v3
P42wXSosku8gB/JbH44y/aPM55E/MdOe3MN1/NPSd3h+ItUzezj4EHge++wC
mfjC6i3ZdMAB0GWJ0dXQi5FBeI+6J/h38htHuhxlHsuk423A+GXCmdf0d3r7
W9TXy+U3cP1gDpek4hmLwn/i3XX9DqGP3927EEYGbz+g0DO43JoRD2qJJr2f
5w84UH/3IXxigHnFe6wXP/+TCj/l+YNUth944u+OZ0uEK/c1X/owVTmw30uj
nc+msiM9ZKxwkNct/B154xbkkwh/ptKDyV+FuRdpW2b6bZen2gt4B51jfdcx
JvKvjLwrIqwB70iln22Zqu/oN/J4n3eYa+CSzL9jzIP5Vodc+D46EXr4EKd/
FfWPzfR8SKY2oSv/L8pv5LInR93bpMLIWXPErIlXIu2q/8zFTT3vJ0SZtzwP
GMOhHkNwkM097swZ6GPZN1NhJ8i+D7gc2AvxlqYXS6VvozNlqfLa82cTz6FD
M+lRlKM+9DR0NORp6j7e8XZO/yAXlop+hU64tesf7N9N/1wedb4R33s9ws1R
9kivTdblMM+rN6LM8EzPF7eEwaBTMQd39Dyk35Eh2JuQI6DR3zvmGhv01QVi
vF7LpdfNkuodyoNlUd8xyAYt6Wzoa6em+h7P83reMGfQOfZwmV3hl6mev7V8
zv57VtCnpapjs6CvS9Vf2AXQz+An4CvgDsjCL0SZrqm+sUy088f4xnZgLrmw
BvYscALkfvYT7FPsaf0sm7C/j414Ec/fW73n0B72HbB4cMUFEv1W+hAMa/mo
59eof1QqrJEy4F2HtPQO5ae09Ay9WpTvEeGfTPY+yoDV94w61ojwb6QvWggv
O6wl+xV6F3OkToXToKekkd6y/gVWit0GvBR8GXsimAn5zF3eXzuXXYF2fOgy
vAOmjX0YHfwYP6+ZTMujTsqOcPp1fhcaXQJbKjLgX66H9LPjN4yO754Z4b2W
MESwaexbYNLsy+CXYFSLJ7Ixkg/mQ3nKoAu8kcuej30RTHSk12OR6l3WHc/k
g5F2K2Trb9sgicGZwY5JXyLoa1NhUWBrpJEHjypT0ZQBIwYrPsx1UO5Az4Fj
PV6M86ke0/vZV50Hbne60/n9YFLkYUMjr133aS7DbxzpfsCeBma9YCK9E50E
fQSsHxxr+aCXit/4Jvh1SzYx5HVkdex7lOudyIZLv4FbbpjLN4Lyd0T9R0VY
NcLiyJ+FbD/E9B02IGR/6mzrAueZvtc062Xm+F0XBb1qorTzXQY9BFsRMjn5
F7rMavG9mVKVw255jsdnnkxleAcbMdjHSonWBnxj4US8A5o1t3Euv4SL/A7v
glmN8m+nf1iT1BOfm2rbHeV0sK7LXP9+7i/6ClkQvZ7+7pyqDJjY5rlsLZTb
ItczdlTsNYzLrh6fq0zPmSp/P9d3tdPnTUXzHewN17g96O03uB9Iu9Zzo18q
enmvu+u8Tkf53cP8+y71bznaZVh34Ouk0wcdMtn2+AZyFfIVe8I3uWyJbV+Z
6z1PuqC3Rt5KmfQ41jVyBXoE9jN0Zmzq2N7QU7DXYOMGu340l00YPBu73C1+
F32bMjM4vs3lB6eyj6GbEN/hdGx0lOE97C3YkrtEvGMhvwaesXVBr5iIT4Ch
wCtIw+bUJ5E9CXr3RPjuPS5/p9+lDN+53d+dPpP/BOXgM+zx8JZ1Ctml+cbm
zoPfzJTJJte2Yd/rdUG/8Pu3Mn+73/VMjv75ORdmyZjCo+HhD5mGVz8e+Y/l
wqSRVZFx4Uu3uhxlsCFCX5sIW37Ev4v3sAU+4vyHXebEVPWBP7NWxnq9YCuY
6tuTaJ/EFohsh60C7P6cRPHjpslDP/8kkVxAHrLBFu4r+mZnlyf/ZLcfnsm+
CgY3NlEfgBHy/H3Q3/nbxGA2fOMmzyHmzxT3GXVgd8LucqL5MHsnPBgcAb8a
/HbAHMEe2Q+fchl4NbY9ysznss+axl8E3wfk7Y9a2hef9/OzrhvfKzDNQ13m
BY8F8Yum8f3Bjg2GjF3yJX8X2xc0uO6wXPZK8rG/8u4l/s5zbs9bzudd8HRw
duS3m/wN6sduDr2F9wi+i96xU65v4Od0in//hn7vdZenv0hHPpmYy/+DPsA/
im9fl2gfftf9jb/Gm+4P9ra3XCfx2y7/mseldPyu6TNchvdYp+zr7brfcxnm
/vteC/TTx+4r0j7wHH7IdFuu+dB9jr3nfZeh/95wHz7vMvDMtQr5/pDXYlOK
kOcKjMWWHsePWtPe+8j106+fuG/XNE0fEn9q+jXTlMUHBHyqjU1BYydlvU10
+iSXQ87BZo5vGPIJdlNofMMOcB7p+BB+4bnNe1/6XfAUaOrmHXzFqAPfJegu
TuN5wUQ+el87vY+fu7g8NHYx/NO+97fatt71HE8yPdH0Z277d27zM6Zncdu/
dz7lvnU//NKS/xk+dsiS2ATWTOQ/8KPf/cU0shwxee3++MllSP/ZZeDFP7sM
PoWTnf6DvwUmSfzLf+r8xW3AJolcvkAi+yl2L/CqjTJhXDyjp6GvgXXdE+l7
Wn9DX8fuxRrFvxH7L3bYT3PZlbFJDM/lf4lcPJtjfi94y99BD0yEVYB1sD9v
EnW/bexjFv8G+A/61pKpbGroSOhKyERXJbLDYg9eJpW/CG3Avof+2fYTwBaM
bLl1KrmZ/ahvKnkXWReZF/8K9hqwQ3QM1uMTmWzDPCPXY6tDRxga6bukej7d
/Ugfsueg+7MekVWx4yHDIGdO728h/4FzISsegH0k1/O4VDIlsiLyFxgkss34
TLZSdE0EOmzt2ML/dJ/Sn+hKnVLJbPTT7O6rA6PuWY1nDs31LnXslErOo/zX
mfAF7P9goshwyG+n5MIrsfv1cAwmBx45t2lkOnA1ZDwwReQ8ZLxnMtmB5vUc
Yi6BgYLhzZ8KvwNfxI8NHzZwxAVT4Yzgf11S4Ydgb/gJIbN9GXW+9x/shhgc
CV0XnRdc5YhMuivywvL+rcwNMBJ+H3gB8wKfD/ZtsAQwC/AE8AN8RMAd6Gv6
nP18tlx2U/prOueh77Nulk6lS64d/b9z0NtE+v5Rvm8+bd4Qs9aZ+8t5HjFn
l3fbmI/4KzBPmY/4+jAfN8hlv2ceoTdgO2fuMEdWTiX/H5RrjNvtI2buMIar
ppLF5/b4MV4Hgxnn08aGmDG80X1NP9+H7TfXM3O2r+ftiIh7Rpg/ES7Yy+vr
z+jz3qnw0iMcL+4118frjvmIzRt7JuMDRsZawdbdz2sE+Rf5Gfz8kPj+sdk0
W3h/l9khF26MPR1sGCwdu+ey0f/fRt7AVLI8sj12mY6ZdADsofjlEaNz3JTL
H2VQKp8FZHrk1gGF/O14HpnJj7bt07C+y+BDC74PFr5hKjkeGf64XH5vPM/u
PNJnziQrY/fcOJVcjkyObA6N3eHwXH5g5B/kcpSZIZNcjn/bJbl8tuivp1LJ
qcil8F14H3zvq1x+b2AMp2Xyqd0slR2AGMxhi1Ty/F6JZfpUmPqhqfJIhxeC
XcIPwfbgm/BMMEUwRnD2I3Jh3Ns6QIMv3pULc+T581wyFn7JO6aS+ZD3kPt2
8Dp91Xmks44YA3yX4WfwKXjUZ4nGj7GD58J78ZkA4wOHx7eB+bV7Kns547+H
58BT0QdbZXp+OpONnLrw5WFMLk807/by3AM7PMpz+NlMdmvKfp2rf/FRPjuV
ryftYgz38zguHvmvZ3qmX/d3375GWqZn+Ch8lfn7faY5is2esT7Q436g58Hu
nj/YzfdIFB9imnV2mNv5p20WrM19M61D0umfI00z/kM9Byg7wuVH5fIRwc8Y
vxJicEXsFceYfhNMJtMzdrC902k6Hzog+Ad9OZP1wXexH2XCJk9JJaeyJyKr
QoM9Eo80/SHtz/TMvDjJcwM7Cbg28+5N10U9B2byeeL59FT4aBsjgQYzIT7N
9FIuR5kfculd2IB+yaWXgluelQqrasvs0Mj2xKNNz5fJ5x1fG/zT8dFo25ah
ezgeY5r4PNP4k5+fyv8LOzN1xGem8tRzPBakUT9+POdn8sfCBoifNj5nyDsP
5zrDgx3mD8fYYh7JlYdvMzY6bHnYQ9kXsTtgswALht47UXyF6ZdNU5b4Sqdj
K8B2gF2MvRq7F3OK33GNfwt4NLg0vlasxeu9Hi/I5d+DbRM75Y3+LfgKgB8h
M9ySSjfplUg/gQbj/T3XuQXyb00VU+bKXPbOMf7+RW4DMtebnhtgm/jbIZfd
mep7fAsb4J2mScNvAR+Ge1L5ZSGLsj9BIztdk+u8EPn3poopg9x6r2n2gfvc
3w+k0usfT6TbQ2ODm5LJN+gBj+2DHt95M2F/bbssMdjhI6lsoaRRBhqZkPhh
08hHj6eSkebPNC/bNldi5hf5Y/9TBrpvovgx09Q3znWC4zEu+H9MzmSDRDaH
j8PPmQtgE2AU+CT8msnX5Ml4HpFpT2I/eieT3yfP+OuBHYAboGNCw+eJnzH9
nGnOdhE/63RkxOe9vm7L5RfF8+25njkj8mKqeCHLlS+a/iMTT2nzCGL4DXLi
y57nt3tuMAf45qv+7t257EhtmwHxto5JRz4kfsM0v58++TQRJsS+fGUiHQZd
BtkK/oDvCPZqbJrYLnsmsltCp47Jw9b5vumeLs/z2i7zgdM52wJNHcQfOv2A
TDR2z8Uy2Xfxc+UsAjE6++OZ/CrxfV3MNDZi4gmmPzGN7+UvmZ6hSYNmr8cH
Ch+NTol8DbFLsfbxrfrM6fhMQX/ueKLTObMATf52merBn4r9h3rYd/CRwu8K
vyl8j/BbmjORrxXnHbZz/peuZ2rserbPRFMGnyv8qfAzwZcK+pt2nOo735qe
3eV5xi9rx0z07P7WJNdJ3iS/S/yd03fO7NeVqL3fu82sK+gf2nEq/6vdM/m2
THZ5fic48y6Z6Dld/ifTlPvJ63Rq7HR++xduA3PweM/DKzL5MTAPsfPj07h2
orMv0PgWEk9x+sqZ8O+27xExtkF8yn5z2sqmZ0qEc2ODn4p1FzpvxTN2dGh0
ot9NM1f/cB7z86BMNGWY92Bt4GycZYNeK1H8t2nWwN9eI8T/OJ35ht8efiz4
mrDW2HPxw+C5h9cfNDZx5iHv4PfHe9DMyTtdDzT9MtlrAT8HzlbRP+Dj4ORg
6KSRh938ftNT+zCRrxWf5zwh9KJOK01XpimLD35l+p9c55p4Xjfe/V827YxT
7Xd7ZLJftW0bxNiT0G86OK2HdZ+hieKOppE1O1onutu/BTmT3zLZc2A66x2k
o3tA87uJZ8imyagzWDdZPZN9a0bXQV3ghbvlwlWRnSiDfIjsyt7xWyY/FmRa
ZFzkxy0y8RF4CDwAGjs3WB/2UfA38FPoPZ02m2n86KEp+1wm/6ePE6V1chnW
G/YVbCvYPqB3dtocpll70D867uz0l03/5LUG/4LnTDQNz2E/Z89mP/05ky/O
TC3Fc5tGDoBGPmDP5522HW+ebNpeTz3kU473kSXuzbTX903Ey7u5n0mbP5u2
v0MjB7BG8RlinbJHsYZZv7+Zpv+Ju5hmL4Me7/XKHtPeX6BZs0zqhb2Ohhby
Y+IZHJVzkAsmOo8LDabKmadFTPcz3dtlFjXNGTJozvBy7moJl5/s38gaJF4s
m7ZPQdMHYLeLuzznL6H7JPr99AsyNb6gnJM5OtFZGehjEn2H862cixju9/u4
DdD7O21p05wDg6YsfufYa8HosEVC46NOTB4+6suZpgx+hcuZnr6Q//py7o/l
/duvd3+1+20Fp3NWYwW3k/NS/B6GAv/WFf27OCvQ3enEPONbAv+Gn2M/+iIT
zXwgXtk08wGaso+4Luo5MhOfgW8s6XGhHxqnYzfnW33dn/AZ+A75j2TiCaz3
GU2DXxGv7vSZTJPPuXvOcHHuDLsn9EKOe5rGHwj6eMe9nM45XWjysbFil+X8
HOeCobFvEvOMXayPadLH+Lmzy0Mjr3K+YUn/Xuzufd2f2KDX8rxljq/lOU/c
7z9zu5/XwKruE/pwgMfoGM/BAabRp8EZ4IH40OKzi786cg/0dI7XcfpA0+R/
5Wdo0qCRtbAhYsNmIPExhmaPJuYZn9z1TJO+jp+hSYNGLsVPmjOc2K+HZLpf
gGfuhOAM/GJOh8bPnHiwaXQIMH1kYeSeDZ2+vuvZyeWHZNPShrgM/rD4x+Iv
DMaM/obuxjkc6uesEHgqWDyYEDYJbBP4WKE340cLVn299xX2FHz48OXDBxY8
CFwI396rM51fAudDDsX3GBngxUyyKbz94Uwy5XaJ5ModnI7/MjIi8iFyImcT
kP2QAXdy+ZcyyYWk351JtkNmQ77Dr549BTluN6e/mkkuRNbDLw9/P9p+U6bz
TvxGdGt8iOknZLd9Mu3dYFdgQGA+4E3gTuDuYNv4kG1vuQt/R2Sv7p6H8JHb
M2Er6Ezg2ZRDNqMcvpHw/1sz+fBhF0LGBOfB/wzsBgwH3zLwG7B4MBzmP/42
8IrpcumK6IlgxvgZt3HjY0yD9YL9gnOC63L2GzwPzA7sDrkFLBZsFpyWcQOr
JQ3M9cRMGCwYKpgq+BzYwGj/LnAwcFGwMPBOzt6D1YFBcjYY/AmcC7wLXQQ9
Fn0WmRoMCZ88sCX8CPEnxA4GdoS/F1gRc4EzKt9afuEcFjIMeid+ouArYCrn
ZcJVwEXAesBGwDouyIR3gFVwvgIdFbzhokwYBPgAPtPICOj4+Dqz56NH4+eK
Do0efFkm3fjeXP6R6Kzoo+gD6ALM/Ss9/5kjV3meMN/xv2cdMN8538J8/yCT
bskcYC7jf88cZy5zPoS5zJzFX5+5zFq8yXOVfrrZffVTpvsjwEKwoSMfYu9n
L0AO3MP7Dn5azJ27MsnlrMfUNH7r2zqPdNbN3V47zE3slFNtlplkpr6JZIF7
/d0HMsnrrJfcND6wrKEHnP5vLlmcuyuQu5HDOQv5USYfYmxQrO+HvcYfzbTn
0f7VTGO3Aa991OmcIQVTht+Py6SHX2x5Bhr9eoZC8gHnvZj74NfwKvBm8GvW
wfOZZNyPE/kEj3V7OjkdvB8fb3x88buFV8HL4FfwJ/gRvOiVTHIt/KezaWwX
8KRXnA5OBj+CF7FWwLKn8pVUWDdnJ7DR4V/LmuB8Ingxa4hv42OMvYg1BC4M
z8B2hy0P31v4ygeeV+A04DbwEn7TR/5d2CI+zuRHjKyJzAkmTJ994n77MZO+
h643T6GzBzzPW+gZv/xJfnfllvgo/rLYD/FL5I4P/CHhK7PkskEwztgdaS/2
Q+yk9Dc22W8y2QjxjcVnF/9YMPvvMvGe03Lh+219CxoZgPgH02DDP7rNzM2f
PD/Pz6U/tHUHaLA44smmwWDAZbC9XJiLph/QLab43d8z6VptuR4aOR//WvwL
wcbh9+Bl9P1fmWwJYNHYCKDXdEwePPtv05QBb6ce/IDp1889Ljjg/+v6V4m+
nyHX+U7OS+KPC64Gzga9bKI4NY2NOstl18I/BT8VfGIK+6zgr1LmeobGp6Ww
LY/zf+gSyMzoE9DYsolr08SNafy58etu+21BszcRdzR9pGnKEk/n9IUK+Qsi
U9M+fh9+OzPm+r3nJkqDBgPnvDLzDP/G0zznmG/4QtNX+Dkjp3B2l32Ds0jY
7jnvuX4uP8x9o/zsuc4/jQt6jlzP0JyNguZM97658sZZbu9smvNM0Ptbvp3T
6T1Mc56XeC6no+vM7fLz5KKfCHreXM/QnJOax++ukiuPdOw6nMEaFvH8uWjW
yAK5nqFXznUWnTbvlyuPdOzS2KmR+zjvhf4z9ex6JprzpF38LjTxwqY5/0X9
naLORXKdhSIdnYYzvsjwi+bKI50zU1PLwRNy5X3kOcN8mpjoTFU3zyvixZyO
fIHND16I3YCzTdgOlsxFTx91LpXrGZozUNDYr+mzZdxv8N1lc/Fe+Cl65nD3
/3LuT+LlTeMvgt8IvhLwD84dweu65/qN6HCcVepu+gXTrySKVzJ9aK4xoP/p
267+jchKyILIS8yfTu5/5in++Yd5jeOvTxo2V/DENpYI/aLT1jTd2zRlsdP2
Ns1a75NrveMrge9E27elXy6/Cfg256bgMfiZ48M/JJHvBfTBjtd2+kDTU30z
Il7H6fhrDHQ6/hfr5slUHxF8w/ER3zSRrzNr7UzHrL3RXoMbmMZ/eLDL44sO
jR/xENeDn/lmudYV44ufKT7b+Jpis90xlz2NtI2dvqlp/DqIN3E6vh6bOp35
spnrxLcDf+x2e6HhD8RbmN7KNGWJt3Q6viFbOR2esbXnAH4i2+SyUW+fy17Y
thVC4wPLuRLy9m9pLu/g+cw+yNlRzq3gf4kfZvt+Gmh4NfFOpncxTVninZ1+
UbuvWvIJQt5dwnLibi4/QxXrvJJfAbI7Psr4LXDHwqaFbHPgL9wVACazZ6F7
AYZYttrQ+As6ztr2N6Ac+dwZMNhl3kp0j9+aPr+GLALNmaNhhXyyufuGc66c
PWM6ce8JaWAY3PnH/SRHuQ20h7Oc3H3CfRbcZdHL71In9jLSsYWRRl5ff7PX
f75Lnfg887sH+rdznozfjw2T+524+4lzK+uZ3j4RJsIz55HR37kDBj26v5+n
6vqFyvDuqoX2b3xloPGbYV9DLh5UCKcGo4beKJF/BO3BB2VMrn6kD7mzizsa
GBP45CYeo42cTp8wHpTnXCtt4DfskMjfbgO3Bxl8XX+r/W1kc/qjr/uEsRxg
H56d7U+CDosPJP6RXRPZKXZ2OudmuOsP30jWMOdG2mnQnAs4rNAZxm5u856e
S9zluO9/ynAWnXOPhzvm/DrzZm+PI77p+Kzji36X58dRliW2sDyxh+unT/hN
W/p3gcfu5Dbze4d57vH9fdx+ZF4wWWTkIa6rfdfFHq6Tc/mcz+es8S3+Br5D
+EHjK9y2w0Njc8d/p18xLb+f0xlj5h8+RPQlbevv/l7b7WQMSMNGhN37eu9H
zHvmOjgbPJ02I5Nz9yH3ReLHO8BjxPvcKUKbxyc6O8kaZ77jX0t5/IS51467
AjlLQtpuTt/dNPcPDPAz9Obu8wNa0q2vy6Vf35LrDOE6iXz/8LHDr46Ar91U
v8xUvpvsw/iI4vPH3oXPHL5z6EMjIj46F486K+Ldc9lB4GF7mI+hZxyTa85+
kesMCT5k2L9G+F1486HmzyOct1YinJJ+pA+RfZBdkFu4Qwb/OXAU5OLDcsnG
+GTi/4dsdXwufzVwEuxr1ImPOzrERbl0in1ynZFgD0K/QT5717yRtX2u1/h5
ufw72s/QV5lm7eNfdKb7E2zmeH8Xn6NRTh9tGrwFvJy64BXd41vn5LrnBzxm
tMvwPv3E2RXaSFu59wm5FdkX2XWs8/Bn/sK/d5dEdwdRJ3c5Ipvjp4J8Ptrj
xBhx9ohvts8i4XdHGnZU/CMZZ+QNZBF8+y/P5Z/wRiIfBehzHZM3xrIh/iTT
u/yVTr80l29fP5e/zfVc4XehVypU5rJE2NilLs98pU54KlgP7z7vvmUO46tD
2u2u507TL3ie35rLPwxfl2vdNt67xenUfY3TrzPNN2kPY0O/4HOE79HGifyS
HjaNfyC+gPiP3JNL30O/o88eyOVnxfnlB10evOpOt42yvANm1fK7+F884D5H
liP/XpdJvEehh+EPRZ2cD2Y9jc3l38fdj7SN/IdyfZvvEvOMj/CDTsdPmPnF
+/iljjXN/KH/7nB/cq6Ic0fwdc4eQd+QqA/P8NzmXOzm5jPgEJsV4tOcNeTM
Ib612G55bp+z7Ob09rnEcxwv7nT8cqHJ515P7vc8O9FdROjY6Nebdwg+GWGH
eB7H3t1oLW8Qcc9Scv/GQe9aSk4dEPTajfSK3SPttkayHOcskXGnyreRtmYp
PW+N2HAGNsLyBkd8diMdavGIN2ykU60T8T21eP9u8d5Q10mbuYcO+YMzvviv
4+c52N9Cfm75t3C2l/sTuDMCn0TWLDIJcgh3eTKujCl76MLuZ+Ymc5T1wrpZ
yXMVnILzgZwNvNQ032UfWMjvdnWbSO9hmvfwR6Wd6D6F20+fc66aO0E4W829
WZwP52w4Pu+k4/cORsDejs2Nb23uvZ7xGeox2jT65sdCd68Qb9aI/i367/da
+MjOkbZLIx3p7OjPvNKZh/2DPqiRH/DskXZiI9/Z7SPesZHedXeUmb2Rb/gd
Qc/WyGd8h4jvbKSj7cZ8aHRn1R4R79lIB1s44oUa6edXRFteqIUzPh/xM5Xw
xkMi/+BG+8+pUf/7pc6AnBLxXo3oG+N3vR/0yVFmeMQHNNLBzokyBzb6La2I
T2mE0Zwe8RmNdJLbo8wJjXzJl4x4iUa6+vLM2UY6+UoRd2+kc68S8cqN7npZ
Mtq5TCPc//dowx2N9PelKdvIp/cNZJtGdwH8FvSyLvOw5xh+lb0irXcjPXw1
2tsInzky4tsL6YNHBH1UIz3w+IiPa3T2Yolo/1qNzjqMiPiKUvrirEGv3gjr
uS7Sjm7kY35btLlHI4x11YhnK4UNDDUPQV660Wtheserel1gk+JOHPw/uRdn
6v04ieYld7Cgry1hGryCtQoOgv6PbLWJ5Sv0OzCLdtnZ/C73R5CPvk9b5nF7
iOc1jW0DWY2y1Ak90PLbXKbxv+rktuFXSTrvgbdMbU9LuAb8Er+DqeuqkG8Y
eC7fI582DDVfbf9m7qghUD8+X/jroK+taP0MmrOw3KWDfoK8AQbBWaa2bA6N
bEzZYX63i9cv5zKRw7dyGe78RE4dn0hmRR7G7wk5m3SwQWyd6FnoXPhAIgPf
YT6zmnnL1P5wn5ziek+2DkVb27LWtm4zdW/n+jf2b8GWBL+cz+MFZjWz+xNs
DIwMPI69ibsbnrS8A0aJzDOTaWSkyS6Dj/Rr5m+7tuRDzX06+FGDAdF+sGDO
Z8zv7/7kMpxvBTMAOwBH4KwGtj3seuiUzFvmMu/3ML+F7/Zwn2ALQW/HXwLZ
rbt5OzTyHG2/2OnQ2E2on/Mg/I4V/VvQ6ZFf0TXB38AuwTTBRaHBVbjPk/0J
nZg4N01ceOy4hwQa/r+ky0ODSYJXzug9jrquSHReonI9nVwGPO1H9wlYCmmN
3223Cdy1q8duN7effkCupi/4HcjLYDi8S93kz+AyjDHn2YYlihl3cNHOrp/f
yxmlGZ3elmPw9ToxF408g439hFznLvLgQ69XsintEvFatWyZ3SO9eyX788WR
tkMpzPz0oGcohW2WEb9RyQY1Hj5T6nzJBhH/XckW9FUpPggPnD743vONdKRn
WGelzqYcG2W3q8STubeY/w3A/wXgvjvuHea+iJkj/7lGOhj3+nMPGXeV3Rjt
GVnLrnd11DdTLfv0M0Ff00g32yT25FtL7flnu07uCNoz6vytkY7EvT3coYac
id6P/g8+gN7PM77cSziPdO5v538B9Et07x13tEU1U+8r5v9NcG4XnOAAl8c2
Bg1+MMZl8I0h5p3jTR/pd9u4Q19jF2AT4AJLxm8ZX8pnnHvazvB3D3J5MIqD
XX5Jt4Hfspfbe7TbzPlWvsVZ108S9Qt9gl/HaPf5Bqbx3+gTffVNo/OIy0Qb
Xivlg3BZpD3h9rwX8Yu1/i/AB0E/5HW0X9BbN5L9bo74xkY6Xo68UevM3qWR
9ngpjPCioB8rhamuGN/6rhTG+UC04dFSvuGvxXsv1ZLFtm0kMyEvXRv0s6V0
9guD/hUgJZescVspeePjiCcUmg93Bn1yIywVeWoOy1RPRvoVjXDMBaMNG5Y6
67ZCxMtXsqdxHpl52iXRvD3H/Um/nmuatAtchnlHP3NnIPfpMY/5vwnEZ5oe
bnp/h1Ge59zDxxzjPkCwyAs8f8g/3+uB+TPGc4jn8zw3lok2n17pnMAFXl9H
uM1jTPd0edpwodtP+vzx3nvRDyflyj/fZW6hXyv5aDBHD/K3OKN1iOfekMjf
qNJ5mOOQK0vJMg8HvXCpu+oWiHjZSnb1byI+tZJP5ZyR3i3C3Oj98a2PKtnb
i4ivL2WL/zfiRxthIksFfVqlMxCPRzxvqTOs2wb9cyNc44RIG1lKNrkn4lMb
4TErB93Z31osyv9daq/pz3wvZZe5LtK3rOVXsUTMh3Geq8iAi5eSA3tG+iaV
7MAvF/oN1Pkpsnwl39geUWbpSv62X0R8YyV/n76N5FFk0WPjva0a2WamBP1r
qbOXH/GtSjboT6L+OSph3nNFvF8l36gHSq031toaEa/fyD60ZdDP1rKvP8m4
lzrTOTjiNSr5+LwZ6VeW0kcvj/jgUrobMvUCleTqmYKuG9nXp0R8Sa39fPso
+1wtOY5xXtRj/WS891ehs7ZXBz20lp/KJo10JHQi7qfl/mLugiDm3vmxifzU
T/N6Oc1loPEhPNE8k3kL717FPHCkeTFr4UTPYe6UOMX1Mzfh3fBI7gI6yfzw
JfNueO8+zu/q8gd7Pp/g+uGxlyfipcz3Ea4fnjnc+whrhPdOcj0n+bt8C/kP
bBRcFGwTGgzzdP8W3p0n+m9iJR8W5ibziblUBf1mJV+VrkH3bGRrnItxbGRT
OgldpBQG0or4lUr+NVtH379Y6c7gk4I+sRYGz286yL9rxij/XiUfnC0b6WPo
Ysik3I9P24mPK6b9juPc/jvjvTlKnSnk7tITXOdxfnd8orE5wXxsFnTASj4p
0wf9biVflSrWSNZBsuSp0cYZa/kQ/RXx37VkUu4Q40zZy4mwTvBs7szgrgLu
LGAP4v5ObDP4hL6U604EcEX8sXgXXJx727Cntm2p0Cu67t9d/xTL1sjVyM3Q
YAvgFZzZw4/or1zP0H+YBsdAD8T2D86MbYO8RS2Hc17x8UQ4At/ApxddhPqn
WE6f7O8iT4OLgf3u7d8CFvp6LjkeGR6/Wc4lcobuadOc4+P38DuxlT9rmt9L
PuU4/4e/7ZN+92XXiS4JBvKq68eWRX+i4xCPN803ePeERL5xvINOh27xit9F
33zZddJ2xuNXl33Z5ZGB8atGB3/O/QZNe2k3d0XQj+Thd01/tNwnYOPQ7btQ
yAM//Mb6CboJfvDcy/NpIj0GnQddhv7lHp/2HT4/uAzvTcq1F6D7IN8j25/h
Z+j2XT/jHH/vd/EtSgv5PXE+GIyE8+3I4eylnLNAHj/R9HauH5vs0cZ88XHF
R/LUXDwfn+LTc+0j9P84z21wSu5aQraf5N+7qdv/jenBpjlPz1kU7G2cQcHW
h/0PGxy2IGxCrCXOKfzs+UkZbHO8g5xNeepgjjPvL3XZyS5P/r+u81+vybet
H/3kPmcvwb6I3ybfxS7Vtk99bpp8zmljD6UcNiru3cGOQjnWPXYA7AFtfBca
XBe75Vd+FxrbFu9zrgSM7+NEWB7PVye6k5K7KfHfWyp4z4ulzheuGfTOlc7Q
3sQ+W8v3cXLQZ1Xyxfop4lsrnc1YJMpfXOoM66hI69hBuPyJkXZAKZx8dNRx
Vi3+3D/SxlQ6s9hE2i2VzkGdH+lPF7pD4tygnyh01wW4Glgh2Fp3MKVKPnrn
RdpThe6f+Cbob0v5GqyNTldpzt4T8TWVzh8uHu0aa1m6Gzy+kd1p3ojna2R7
2Tny+1Y6d71ClJ9Y6g6Lz5DzC+nCnaPsJMvn30f8dSHe8jv6V6lz/fdG2v9K
+R50jnruL/R/IR6Jd/+yrPV40GUlH95RyDCN/Dz+F/HkUr5qDzbCBMEDwZ7B
tcGft4j3etXyzV026n+z1BnxV8DzKum5twf9Xi3b142Rf2wjn4wb2O8K3cMx
KNI+qOWfggw+3HsxOs0N1mv43SNK/fY541sdK92h8FYubJ37MbgnjTsQsTuT
9obT33CZs5zOO8hX4Pzv5pLZ2Nd4BvO/2fscsgn38nDmk/Oe7fOfFzvtfdPg
08xt5jXnpD70POeuVcpQx7uun30NHs/+gU7HmTXWKb9x6vrwu6xb8jjLxpqf
4DLU8bbrGW5dpX0mbn/rLIdHfx7ayNfmtUhbsxKPWi/idSrtpQcio1ay130Y
9Eel/Hrmib59t5Cc/0Up2RS59G3Wcan7v8FWrzW28FKhecm4dI13zyp1LwtY
9anGro8Bjy1118tKUWa+Sr5Lg6130f4/YpyHNfJhOqqUHosOe0Yl/QHdYUrQ
I2r/n5BGmD54freo875Sd7Sg16bWbZ+NMk83sveuEO+uWMpHHlnsBctj/8T3
H2hkm+MisW1q+UW/HPkvVfKLfxX7QCmf7g6R37GWvz7y9bBaMvb7+NKU8t1+
K+i6lH/3a0FnpXzAwfh3rIXzd4q0HUvJSrNHvGctukPQu9XCkY6P8jOX8mFf
O37jmZXOggwM+spKdtRnwWcq+aFfE+25r9J5j0kRf1fJJ/38iKfvIHtbh4jr
DrJNbhjfGVLLZnhylLmlkC3v7KC/r3W28LygB5Tyix8UaevVsvNPivirWj6y
J0YZLm7F9vkr2E4lX/V3Ip6ulG/7legitc5WD4Nv1ZJPlosyXUrdm8I8/brR
XF0t6utZ6d6Kfuhqhfb3BSJ9UKn7COeM9E8L3fs7cyPdDL1sCdJr+Qe/Hunz
VLpT4d2g3260988aabNUOq/QlTGpZVefHpyt1hmM1dDtCtlJl4+0FWrZz1eO
eJXa/n1RZjPbni6KcEEjf927I/3iQneAwcvvMj9frhbGB773IONW625g5Pe9
asnw7C2ren/5Muq4v9R6Xy3iFWvZ7/rHN0dUusdhpYi/bOQf8HHQEyqdG3gq
4qcrndVZJ8pfUensAjbGLRrh2OdEPKYRrnxuxHuXkq/OR9fsIFszeM8rxnzO
i/RXa513uxg9tJEf3pURP1XKH43xHNdoTK9nPBv5czwW8dhG9/Rczdos5c/x
fdA/NsKhP0H3r+T3jQ59n/XoP0rpIeggP0Tah4WwaGxuXxSyu41qtH5YO+yN
YFjsj/NW4jvwnF9K7W3sa/dEfHej+9XAxm41PvZwlHm4kU8eNi7sWBMT4RPs
neybt0S8cSm95qtCezD772eRPrGRvPhxxBMayZEfssc1ug/s1Yhfa4QFz11p
jjI/2TPnq7VvovcvbN3/8aj/jUb3hrwV8aKVZC36Dj+Y64K+KcrcUUv22wud
rpQtlbSbC6XvGWmb1kqfKfpjhg6y//M7Nqr1W16O+p9p5BvzYqPv8a0XIn6p
kdzHHBlQaZ6ATY40PjmpUf/St9jxulWSgX+Our9r5O+OfPGVZYwbCq0x1hfr
/h2v/afgx5V8xqeD5zXypXky4vGNfCLui3cPa+SHWVWSY5BhFo9vLWWc5/NS
8hOy0+eNMC/wrq6V3p/q5xlpB9baq7cI+tVSdFmrL+gH+NYVhXjXNpH/UKmz
Wueixxc6I7IH86rSua3ZasleyF3gcLPUwuKQZzvVkmkfifKXVLJvwydmrcUr
kNGyWnIa+vdVpXTwJ4N+qtb5jc+jzNeVZP7rgm46yEfi6qA71zqnc1HE7xc6
Y/EvMkCtswyslc8rrZdHwUVq2TrBKY+uhVUOYq+ppUO9EGVWr2UnOi7iY2ud
B7ow4mcL+W2dEvRthc55XBD0+bXO5YBz3GysY45abaWdLTDMWmeM+vPNQj78
+0Qb1q51D84AsMdCOi7Y5Le18Elk6v6Wq3tHWlPKVjln0M+XOhc3by05GBl4
aeZDrXu8/om0soP0VvafnUrtQR/W2gPg/90iXrTW/6cdiu5Q6347+mCzSv3Q
s5bfBj4b31fiifDDf9EhKv1vgX1qYUngSGCuj1bCXcFH962FkSKLrWt57K+I
B5Y6R/I7ukOpexqGBd2n1j1E6zDvap2xwm6zfSUd8M+I+5U6VzYXsnYhv5qb
mIe1sJFba9nCsYOzl/5caT89It67tJQPzl6RdlUhXGJw0IeVuqOL/XbDSnvu
BhEfVOqs3iz4XVQqv2XEvSvhEHNF+q6VzueBH39YCUOevYN+D78F29HttfTa
XpG+VaV7iG4tJIsgh3wa8SeVzhitFWUOrnQmtW/QB1U688c+MGOjvWD3SHu1
0N1FvTtoPjGXVg56wUpnvwZWWj+snZHwCdczptb7vPtmI2wXXPfISnsw++/8
UWaBWr5j60Q8sNY5wz5R//6VzpIeEfEPhc4gMs7zlRpr5LtOlveGsy4qnQHd
jvlf6SzttkFfX+kcLeM8rtJYIzMuWEpuRN78u5DMuXnQ3xQ624vc+lAl2RUZ
ubCczFy+zPMZWWD7WvLApRF/UOm+tqvgSbXOw10e8c+F/ByRJbeoJU8yvzar
Ncc2Ia3WeUhk1Y7ec5GbDrXshF7+QyXdnDW0Wal1BK/dwjwWnbuqpXcjUx9c
S64+qBafhceyL23kfZa9ay/va9fGu/dWuqMH3fqPSvr1IbV4MXyYffKeQvtX
l0rzgDmAvLa5ZTZ8T35phHf9HvGfjXydJrP/VzpD9kcjPsjafyviGRr5nD7O
2NX6v45g843x+V8j3qPSebIF2Xcanec5PsqOr3VOsqmkk8PnHyyk06LPvhP5
79Y6F/dSKRsY9q9H4ce1zvv9jWxVybcx7yA+Dg9Pg2510P/YYV6zTpjbO1XC
U6beR1ZpbbAuhleau8zbyyvJiMiHh1Rab6y1uVkLjc5BrRrtWbeRXwqYxHSN
9taNo+xppfT3fyJtm0q+q9gl3q9lmzi6ksyKvNoROa3x/9SspNug1zxSiHfA
N96M996oda/qW7Vs4djB/wfPqPX/J4+I+O5aZ1nhc8dU4nXYWybWsrk8HHHv
Uvdp3VVLx2ONnBtlH6p1Lhlbype17CnoNN/U0mt+iXhyrbN62DOn8D7YWK09
lf30skKyMnIy+8+PtfagH9gfKp0d5PLgf2udt7uzli0fO/5ZkT660f9WuqsQ
f4Q3PlGL17P2OyFPFvKhXr2S/gMfxhaHro6ejs0BbAtcqwt6QCP/lMvjvT9r
nQ26n/2z1jnS6yJ/lVJnTZHxZ7Scv0+kDaqEsbMPwN/h7ZOCPrzyOQ5+Y6Xz
j+xRda19CrtBYdsBPlZ9GvlZ3VtKP0c3n6WRnxbY/OhSeAFYweulbNvYtS8q
heWB42FzBi8DK3uhFD4INvhTtGeRRmfbrqqkD6MLY8fGRoh9cONKdkFsgh9H
GyfUOlOKzRxbPnbzN0rhVmBWW1fah9iDxhaSS5BJwKWY38ztKr5ZNjqb+HKk
D+kgX0lsI6tU0k16VdJd0VuxdeMDgb0b/0R0RXgO8in2SGTU9SJev4Mw6/8D
fzX3XA==
            "]], 
           PolygonBox[CompressedData["
1:eJwtmnnAT9UTxr/rPfe+lixpUUhkj0SLspQSlVQksqSIFqGQXSIVUiFSyFZE
slMpRBJpsyaSFO2bVFq0/D7P7+mPed+ZM3POPXc5M8/MfMt37tWyZyaVSvXm
T47/P0Wp1HnQKelUqiFj58apVGPkvdlUahz0Qj6VGsXYq/CtsC8fUqkfGduM
fBf2O5GfRf8ecmeoPPwP6DfB3w9VSlKpM6BTsS3PBcvBl2b9WvCnQkPhZzN2
K/w29tAY/hLobOQTkfez/i+st4W1ukOb4D9jTh3Wy0Mfob+Xa65Adzt0A3Nb
Qxcyvz70OfoH0K9C1wtqytxrkKfDv838X1nvXcbOgH+Xsc3IB5HrIkdQbfj5
UHH4DdA45o6GPsF2HfRZ+G8N+B5Qf2yHcf2WXPtx9n8E2ysZ24/uT6gv/NXM
mcBaj6J/F/07UCX4t9HvQjcH+X34W6CNyIOQF8O3gz7iWt/qnWW8pxS6pxlb
iW4gNIJrb0Cegqo1e3gF/c/YN8L2Q/TD0T8fWXcdtAL9cqg411+GviP6G6EM
uiGMPYPtYPRL0Q2Fluh+ClKpf7U28lrk16F98E2w3wz/MrQb+VPdL/sfAC3g
+k/qe0K3AHo+5W/qfN0b+iXw46H50sVeezw213L9w1AD5leCZsP/Dl0CXwT6
k3tdhP1O7Kuxp1rwJdHvQH4EuoB7qZf4W5LNSHSdkGtpLmMvIQ+ELkA+BfqK
+Vdzf0VZ903sH0f+APoGvjL6otguRL4W/gTmP4F8FGqs8wT9Bj8DqpbyWDn4
AzoTzO+H/AD3Og95O/Jy5C7spTP0HvYXsf+96J9Dvw39bdAG+GOM9YX/GPqK
9b6GijL3Bea8DV+D+ZWZ2wMqif1axsqib4V9M/hrGZsB/x5jlbGtAlXEtgJ0
DnxdqAb8mVCWa9WHHsJ2Ies/xtxHtSbzX4NeZr2qPJ+92G5Fv5Pn9GLkZ3cD
+rGstR8ag740Y9fCXyMfwLOqxNj98C9gXxJdG+TvuFYdaAjyXbpn9AdY83jk
S9EXQjcF+7OZfyNjpdGfDJ0g/wAtRHcd8gXwbaE34N+EhsB3wv4T9r4eebC+
d+SVrH0i+1+HfCv7zzK/GzZzufbN0FzkFdhcnfEzLsX132X+/diPhHZi+xr0
kd4F9C/8P1AeXQQd0/nG/jz4gdAE5D7aP2ulobflL6HZzO0AvQM/lfkb4Uug
fxXbicy/mbk92d837KUc+90i/4j8G/I1zHkc20PIFbA9HSqH/jRoFroZ0CzW
+xCbmPVuY/15yN20Z3Qzkd+CL4P+J/hJjG2CH8ZYTs83Nl+Y9dbFPuM627rn
baz3FPIG+GlcvyH2y2KfhbOwv0++DqrJekcZu0vfP1QKeRDyRfKN0Pl6V8xf
Af8p+tro+zBWB/kP7vFzdFWR28ufsL+z5Iu45mJsp6O/VOcPmov+jMjX3op+
L7pvkM9FV0wxAv5WbJ5D10X+HfkZrnE79ndoD9hvZawKtlloAPyXkX3LJK7Z
gbkdRcwtirwR/g35QPiXGduj9eTD4Q+w57NYuzYU53wPrdEXsP+OrNeeOVVj
+yz5qtGKoej+wP5p5OnQ8fCloOPhT2JOQ/Sv5P3tj4aeYr2YsfbwAfpB/iL4
2dwN/R3sM+Qr+kMXJ37metaKqZr7JvoDWa+RYb2uyHOQb4J26ywnPlt36ZvD
fqhiBLpO+qbQV0z8rd0NfY2+Jvqx6Nqy3kH2ugubM+Fv0xlX7MCmUNrf/AT4
w4z9Af8m+oG6d50Z1moBzUd/MDiWLsjaV+5DviNrn3mrfDVjE+Tfmb8dfgf0
JXKxlH2nvgl9C/KhiqW7g799xVTdy5DYsU73JOyyPfjehWE6KbbGjkUfsP42
7md45G+5AHm1zhr6EegHsN+/ImMeYZ0r0DdBX10+GfsuaWOl09GPzBozFaAf
ADVnbmHsK6KrAD2A7kHtMXhM/I2KGcExVLHzeWEQ5gbkdnp20MvIR/LGVv2h
Nch/cv2m6DojX8paZwvPsJfJrFEc/krGpsAvk3+W72XstbR9/lWKreifQL9V
/kjfX/C33xO6Df7W4LWeQV8B++bYT0V+UTEAXUPkichHoMPs7XLkp+AXZYzV
9miNrDFbE+TAno9jr5NSjsWPCIPkHJOvQH8v9gszXmOs3newr14jfxUcsxSr
MoohzH2MNS5nfjP5L3Qjg+/1euz3sZ89rPFt1j53DrYf5h1LX4W6yjckjj3H
9A7Rl8H/bkQ+Gfl21uoDzdd+GCsh36QYKf+imCvfzZxDyPXQN4wccxVrFRPq
Yl9b94Tt0Iyx8QSoU84YOY2+CvpRzG8pDBqMaYRl9M7lSyZHxr7yKb2Y+wjy
F+gvY42V2GbY73zhs4yx36TIvk0Y8Ez0NaCHsz6zwlJPRsa6wlTC2tXRj8ka
cz/I+ksi+9oa8uHwpwdjf8WgiyPnDMoV9kB14c/R+UBXj+e1TViJ/VTI+4zW
xf5UxoZnHfNfUm4RG5s2StsXfAGdk7FP+EX+CP198mXyV/DXM9ZBvjRjX3s+
VDNnnzsMXSuuV53rzeJ9dkbehH6o4j1zPmbvJ0R+lz2Yf4FiM2s+pvMODUJ/
H7RYWFN4Bf3NibHZxVAGXTXs70HfWhgefcJYB/jFXK8j8k7hP+Rd0D5sr2E/
ZfL+JtYljgHy/cIkg4RNEvu+u5jfj7kXon886xzha3Tzmdsy5W96lOItNu3h
2wnzwOdiP4uO3NNA+AGxz+pg1hgt7BW8tuasiv3M9ayF0esFPwPdu95ZjC4R
poFvlnYuWIA8KOucULlMkdhrK6f5AXm53gdr12POcq7XTTkccm8988RnSmdJ
Yw243mjshzB3lPIX5P2s91D2P0wNn0qMpdrDHkW+CbmhklVok3yLMHraMaw/
fD+oc9p7rMnaLZCnwa9lvYS563h+k5lenPkfBPsQ+Y6u0FJ0D8fObdpgMw/9
1mDf+2zW2PP9/74lYdB79S1B1ys3Yb3b9D0LM+WMQb9DXgBdn3OO1g/dxMi+
STlHg8SYVVhVOfD1wgbCgOjmZJzLHUC+M+ucbkLsHES5RythrGBMLiw+IGNs
ng/GOsLojybG4MLe8qHK3Z7levdmncOtZ/0nFCMzfibC0ivRd8wZU4+N7FPk
S75XTI2NiYSFtMYtiXMo5U6NsakCfyRy7UA1hJMUC/WNYXsJ65+WOOdXrl8G
OkuxHv3T6F9nTl90vRM5b74t9Oej/00+Fv0uaAy6FTqvepfoL1EsFmbiWpcp
ZqFfGhkrdRXehx8HXZEzBl0dGTMLK///G+Ha7Zg/KeucWti8T+JrC6M3Qt9e
zz9tm4uQf0H/JPpijL2Gbi1UAr4y9GreOa9y3fXQP6oHQL31fnRm5Nug6hnH
HOU23VmvSc45zi50qxj7Ouscs2xkjC5sXpH1e8MfgnpmHXPKR8ZcwlqqGXwD
/y20Cvl17vGY8GXsd5NVfhecYym3UswpG+zT5MvuQP4C+UvoaMY5qHLn74Ox
pHJo+do+rLcoa597J3u/A/or7XvorbMYGWsuhE5kbgvkfvDdFH9UvwnGegd1
BrH/FfobfTnkxXnnVMqlVkM/YXsEOg2+vvC3csXg2LodOgdfehxyI+Z+wfXX
M3dX3lhLNQjlbmPQv5RxDhdj/xjyIuWK0CnIO7CZz/zXlbMhB2gBfHPsX1Ru
hr4h+v3IX7L+nTqf6H9l/YAcQZem7CN/51kUDs41ZfNgZEwkLPQ3ezoF/sFg
7FY+7dxTMV6xXTmozkItbNZnfCaEzUpErg0Io22I7NPky8oLD3G9yxPHdmGs
Uaz1L/Ic1nouZ993JvZrMvaBq+XrYsdm5XjLuLeZwblha8aOCS9CM1LOQaZF
xsDCvoWg62LHNMWymdg/EfxO9C62KL/ifnIFxm56hjtYa5vqeegeQE7QFRT4
2V+uegXX355Y14b1/tRZDo41+5hzWuycSLmQMPa6yDUM1S7K6XqJMZiwV1Ho
58TPWM92MnIr4ROu975iI2O/oj+auJZzEvIa1caYv02xCpv3ImNeYV3VALej
n45+d8Y+UrXCyyLfq2qGE9H9wNhvWecwTyEX5npLWGsZdBx8MWilfF3KuXeI
HGuUgxdFN405L+ZsU0j4Ezlm/VLKLxPvUXtTDaM784+LXNt8HroDuUjk2tD8
rK/9JPOX5ryH2fCD0b8Ev0c+R3Us7ZG1t6ecS68KfpbKqdux3g2xdddl7bs2
Kb/M2ocpd1sGlU47h5MvmpO3rXzSLNUeg9+dzsyPwhaRz+7v6Iuwv9I6oynv
sWXsZ6ZnpZqUcvMocq1TObqw9sesuTRlzF2owJhZWFln+DD8j8G5nnzE2OAa
rWqz+ubvU7zLO/boTCn3eTT4LCoH2hg5Bin2nJ5x7puOnNsqB1at5RXk7mnX
XMoi91D+he1m5MqRawqqJVRNu3aUi1z7Vg2pJPYPRa7trsL+77xrPKrt6B0c
j35U5Fi+Gn0auT7yvJwxeynkRXq+7H9tzrX0LcG1ItXUU+j/YawI8+cq/0yM
WYVVZyqHgP+AsXlc7/aMa3trIueCqvE9hTwlMZaqqPoR692i70nfB2P1kZsE
++rDyIuEVxKfpV7Ir8H/E9lXDsr5W5vH2J05f3P9E+fIyo2V4wr7b+UZVcw7
B1Bt9Xv+7065xrqF+c8ljvUVWLMF+uYFrq1nhFXQTRJGSLsmVg376Yl9oXLs
p+Gnqh6B3CXnWHpVgecqplbFflpi3SBsVsl3Jq516hn+nHcOrdxZNbEFqk8m
vlfV0LfkjWmFZd9QfII/LAyObqIwRoFrYqqFfYxcu8A1IdWCDgjPKPdRPUO1
PGEM5I8i17YPCjMjVw2uHXyPvFj5FvQd1+qhmlvsmotqLRqrjP3MyL2F3TnX
YldFrtWrJqta5L+R341qkg8nrkmqFimM97nqtYz1y7nGJP4QY/fkPDYfeW7i
d6F3WjZxTUi1oNI519b2YN835xqbfOHjwWddPnFO4p6Oejndc661vRWZV83t
beSiyt91VpHfR34vcS1WNdbN8MWDdcOgd1QLQ74F++HIHyXOwZR7jUJuyv2P
ULxA/ksxAX2RxLYloCbohwbXqv/QO0a3JfHaiuGKFVPR/5Z2zPhQeDV47Yfk
Q5H3JuaFGSpi3zg4F96Zc+x9KPgsKgZfFTsmKxarJnJEuX1wbHoCqhS7pqxa
snKeOsjnIY/POQf9SrW32LFynOyFHXjeo+H7ZJzb3qv3n3KO2xK5F3LftM9Y
New/Uw6AfV/sZyXOqZRLdZMPwHZGYt9XM+3ctB5j56Wdo85UrIxs2zXn2tUB
xh7OuYb1KfwnidfW2D74nlCzjPdYLBijCZvpHbcQ/lSNA3m88BT8ucH39hhU
C/6LxLlM/4xrD4dU08i5BlE1cY9DvQ31LNR7WpB3L1I9qM/RH0w8V3PGBWMc
YZs3tGZwj0K9CfWg7g7uqamXJh+pXuKbefdu1FMcodoE9GLWOYx6gW/lXWtV
T7Ct4k/isy/MNBfd+Mi1/WkZx/IpsX2FYrpym5GJex3Kcc6DTyfOZVSzuCly
zUi1op+Y8y7zj+k8pl1zvjk4JigW6BvvrOfF+j9nnZMI6y7HfkbGmLcda7VP
XDtXz6UUtsfH7iXMRt8Y/mKoZNpz2ioXDMa66jHpbDdlfp2cz3gz5YKJvxWN
/aJrQ39ljeFnyfckzoXV81Tuqx6jeovKgfdF9nnydf+mXStQDUO1C9UMvuN6
fyPPyhkjXAnfPHHuqW+yOXu7Sjlvxt/46rxrLqq16AwIy63NuxYpTKfaZdfg
e1UNs0TsnEO5xkTGhqG7Tucx4xqPenXyqfKl6tkpl20ZbKucVlhQNWDVfoUJ
1UseGbv2r55yYfZaKHEtVzUr9SqnRsbO6lleha4B8rmsf07OtYwRyA1yrml0
CP6G9O2oBtBW+Day71cPe2/kmKJY0ouxi4NjtmK1ctSnlatG1qnn94bygeDc
sw1jxSJjyP9jx6xzM+VsytWUoxWOjCmFJVWTFfaaHNwbFwZT7ro7du1MOeyT
8JOh17PuAeWFH1njxrRz8iLMzeqZ5Fxz2x45Rio2yuYF9OnYvWrllFn4NpFr
V6qhqRezMe9eiXoyPfTtxu79C4MKm50c3FsQRvs0uGegXoFqJrq2eljqXWkP
Dbj2FcG58a+KWZF/86B3Owy6SLlD4tqEelIdEves1KvSO7ox2IfLdz+T89nU
bwz02wKd0d91beiFrGsWd8euUag2obHz0V0YuRaqmvxs9LNi9/rVM1LttlFw
b0c1XNW2JsWuJajG1UWxIdiX/aIcAL5X7N8yKGfXbxHGxM6d9ZsEYUl9c/rW
hCmrw1dL3HtVj1i5R+vYuZxyENVKVDNXrVw1E/UOnwnOHdRDVK+lGzZjM+65
HIxdM1Ot7LDy1eBnrGerM6pe/l/QPVn39Jcrd84ba2oN1XKFyYTFVNPtGjmm
KpYKg34Qucej3o56SJ+pdhJ8rR+hQ8q9hGGxX5KyL9Qz0rORT1SseTZxb08x
p2ZwD169d9VsF8GfEFwrUk+yLPPLxK79K2fdpXwyGDs/qxw52EfLN8tnNFWu
Cj2aMSa9LBgzCytr7FvW+iZ2reio8m/0a4JrRfqNxXp9i8G1nf0p15I6xa41
qqakXqhyZOXG6onuQH4HuW3WNeXvsP0+9tqq+dys+mjstZSzjU/c81CvQz2F
DcE+Qb5APcuE9e4Pzl0UA9S7uCZyLVY9jB/kexPX2uXjP4/9zPWsP8u6dl8H
+8EZ1/DPDj5TOksaU2+2THBtST3aKyL/Bka/fdE3IawjDKDYL8wzMDiHUe6i
GDAD2+mxa/PqgdRS7BEez7hnoV7Z7ryxnXpmwm4rgn/rIAynXpEwn7CeekYv
MffrvHvn8sGqHQ0J7kWphjROe0mce6uHrlpumcRYVzVdPfuewnMZv4MocQ1C
tQf1rIR9xkSObcJA0yPXmFRbUk9tU2RMJSyl3zipdrYyca9bNbR5eeeMyhVV
41dt/P3Iv3VRjXww1/4nse9RzrQw7xxSuaNyxDbBNWTVjpWjrldum/e3q5xI
v7WYmXctUL+5qBickygX0TOtz9oXJq6NlMwZaxdPXLsT5v409m8o9NsJ/Ybl
D/gZedc29BuhGsFnVGdTmLNKcE6jXEY1cuU+tYN7lcqBPk6MaYVl9RuR4cEY
XthdvwnqHlxzU61NZ/xE7S1xb0E14GbomkIrUn4nn+Sdoys315hymRKJ70U5
jbCcepLqRQrTHYeuWOJegHI49VruiYxN1XNRbGsf+VtXjPsflxMHRQ==
            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl2Hf8zuUXx/Fb9kpFkqKQ1aBCskMRUki0d2hroRSViiJFSxtRpDQoRUUk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          "]], 
         LineBox[{1968, 2648, 2649, 2646, 2647, 1968}]}}}], 
     GraphicsComplexBox[CompressedData["
1:eJxsnXV4Vsfz9rHi7u5QHIr74gSKuwSnuLsGh+DuTkJwiBFCbBLiIYS4ocWL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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.560181, 0.691569, 0.194885]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxMnQWUXUWzha/7vQPBCRbcJbi7u3twd4cfDwGCa4Dg7u4Ed3d3d3eHt7/Z
exZvrenputVy+vRpqS7rIZvvssbOpUKhcMPYhUJZ8bfFQmF1heUVPtPvTxVO
UvhB4XuFUxQubRQKxys8Jfg7hYpCT+FpBVVTmEzhC4XPFUYpPK66HlO4WOFd
/b5b4XSFZr1QuEYPv1phpOo7RulHK/yjtLbChAoXCX+NcB3BBcX/KnpP4VeV
OVtxl7qoW3GfwpOCn1C4TOFUhfPTtnpV7VY8lsJBwh+osIfgxYRfX/GMCl8r
fKTwgcIK6owFlWcchZX1ezyFqRUe08s+qbRP9PwZFc+gMEjhBrXzF6WPo/CS
0roK16nscqp/eqVPIPz+Kru/cP9TmEX4n4V7XuE5hSkUZqD/lPdepd+j8L7y
v6cwUvgXVf8LCs8qbKqwicJqwk+j/FMrTCP4R4VBCpMrDGu4vbNRt541ucJu
gpdSvIjCfYJ/V5hJYWi+7XfpzxcVZlWYW+EC1XN+w/W8pba8zPspbCHcMgrX
0Seqb0GlTa5wjtp9k3BzKmyiPvhE8euUEf4ZhQ0ZJ0XXvbDCP8rzt8I8gldU
PZsqXkhh3LLTF1O4UePkMNU9XOEqlb1SYRHh/9XvSZXvAMFnCvda3uVIwUco
7C/4GdU9gcIY/f6t5HHDmJhZ5WZSmELhCtUzh/CzK/ypZ22vsJ3wDwr/gMLy
yn+4fq+m9HkVHtN7363wJN9P9T6ncGfGdy/z4RWlv9zw/Hks45HxydgclXH4
eeYBc+YTPXNfFdxE6Y8oflhhJeFPVh1/Z84wNxj74xc8JybMPFlWZZdReLDk
+cH8Ybxd3PD8YZ6Mynxgnjxd8ZxhPizX8Nxg7jKGP8hYXEa4paueD79kTDG2
bhTuOfXFjRn3U2durFrwPJmq4PE4W+bLj1kPeEfmyvQZq6uqnlWqnh+M6Rny
3B3UtpPUthOLHu/MA+bmT3q3HxXOLXnsM74Zo9OWPQfWFTyd6mor3E8/K/3x
hufSSaX/5tkxBc975vxiwi+qcGPGNON+roLH+9yZA4yPoZknzIVrCx6rjGXG
MWP1rKLHH+N+Y+XfnfGtcKjyH0I7MsYXzpyaW7i5CMpzm/C3KhyX8c+4X7Tg
Mb5Y5siTSr++6LH/b8lzZuOC1y7m8BwKu6jfdla4lXdR/IfyvKewh+DdFWZW
2aloi8bJW4KPE1xWvITyr6f0SwVforCx4CsUX65wuspvpLio8KDKPaAwK3OL
75TvvbfyfKn4fYWzVee8Sr9X8OKCx1WYX+mT6J3GUVhO+N2E27XhMl8o7XOF
dRSWULmJFD4W/g+910NqR40xwLdTWFH4S/T8ixUOFHyVcH8xThUGF42jTX+q
7KMqW2eNVRgj3Kl894bby5icTm0ZorCK4IMydhm3jbwbv49S2LngNfabxIyH
E1XPDXr2fco7adHlydfSc69l7+R7KD5X8TkKb6gtryscIvgItX1SwZMobKA6
nmUcKewv/Gwqv3DRbVuL9UnhAT3rBOF+Ykwq/3kKBwu+WfFNCnsJHlrTuq36
5lS+i1TPfArjE6u+eRUmU3iw6DWY9fFa9lyFKRlPqn8e1XOm8A8LXlJ5F1d4
Q7ibGc+Ze8wV5uekyjOJwrGC31WeO5S+heCm2txQeFPwuMxnxpfCIXrOOGrb
IIUm+7xweyvPD2rz9wrLC3dy8m7KeFLZlRT2Yx4q3kLpWyjtLcW3Kb5VYXw9
ZzyFzZVnFeGnUJhc4Xc96zeFo5W2r+ouqvw6yv+Awv1F9+N5avuirNEKbyr9
MIW91La79fuuosf6mfo9OvNhDO9Y8hiap+K+Ym4M03M2Vphf8F/sGSWPx9tU
37t6/v0KKyssqfSJQz/skHVyR5V7seRx/YTqvIv1R2E15V9KeSdRWE3tXEi4
BUve63fO+JxK+cdWaCu8pXrmUvqcCvczHksecwupfLvosbWl8h1bNF01ifIP
VphC8Gzqn2+Vtqzg4Xwn5ne+8x751lfXvbbuLnhPtWEPhYfYB4SbrOzvz56+
V9bMq5W+RNX7PWsU35k9uqB6bhF+Pj3vB+G/VzhU4dGC1zy+NXs1MeveF8r3
ucJ00BIKS2Tt47vvnzx3CH5d+IcFv6W6t1HYR3nLiksKTxS8VxyVeXuF2nA5
4z7f4cB8i50z/+nb/VVnL3Tb1KH7SLuMsVDxmLlUdUyleJDC9sJtpzBu0fQV
85s9aGz1w2N10w5VhUrF6+H4wo/T8N4+bcbFwFpzRNbSButWxevgqg2PkyML
Xm+gAVmv/oHOKfq7Xq/ntPQtP1CZ6TN2eOfTVXaEwrIqN0O+Lfse8/uYfOfj
VPZYhR+hC1T+FIWZBK+pcmtANxQ9H/lGzE1o0RMKXpteU72vlvxtoGOgZ/rp
fpWbsejvMqHyv6g+fQFaQbgbFLZWeJE1HRqHdU1hW4VteCeVfVXhpYbPGqzZ
nEem0r8pFfoUJlYYq+z16hnle1rhLoWbOIuojkcVdqv43HKywqUln0NOU7hF
7/q70s4T3BF8kdIuVNhAZdeHxqr7HaDHoHMOEq6mZ1XLbhM0FGeQ5YreA2nD
Auqf+RWmUphdeS5RfRcr/Fbx2k+ZawVfo7Cx8Jc0PEcnUthMz9uUoLq20jf8
gzVS8OTKc6vwKxadHxqOun5R+Z8VLiiZxjy/YFr9eHD5/XvJNC6/L1Wd9wg+
QeEwxknF6acVTQteojwl/X5f8GiFM4KDPiwK/07ReS/U85cO3fNMxbTjZQV/
d+hHaNpT9aym+uAKwc9WnO9ywWvouavXvR6toPTl2eMU9ld9/1PYQfjnlPeW
kve0ORumCa9mnSS9YVyj6mfyvJ9VZmeFHRWuVN0rKx5SdDtoO32zS9F7EW1e
VuWvL/icskroMn5/pDZ/qPCLflf17B8U38I6BG1Q8n61a9F1UXZz1bNZw+vi
zmrP5kr/QGknKv+OgrdXOFDpe+p97ij4/AM9CO34pMqcXTSdeJfS71S4HfpK
8WkKswkuq/yHRecbqXYdJPxRgg9Q/RPmDHOMcEcrnFtksdD3Vdr7zMWKn8vY
v1Vt+7zstOGq51CFj4ueT2MypxaAzle5yxT2VP7vlf510b+ZM3dmHtydubCh
2r+Bwp/0ucqe1fC55FSFUzgfFo1jnYMeO1h1TsM+xfrFOa7k/WzRqumk+5Rn
WuXfB3oggbEA/nS1t6M8DwheW89cq+51+RuFrxW2VfhUeT5hzqjMTKrnX+ib
os/V0FOcN1YQfvmG98G9FB9W9FoIDcP6xL51e8n09yOCRwt/RsN0z+FFr4WP
Zt1k/WRf3LtiOvuxgumRR7N/Fao+iz4u8CS160SFT4umwdmLOJ+eWvL6x5lx
VMm/4Z8cl3Mk57gTBI9XNJ73eDrvMjO0rvCHFr1GPZ35x/txfiPvAazVnDOg
p9TnGwnekH1W8MeKxxb+WuiOgs9CvyXmXPdKwWcj9v1Zq+ZNkO/PgulGzhcv
F30+4vwyjr7Jp6rrutChnJ2gAc5RW74t+Pe5Df+GX3ByyWcwngPf5ZU8a2Kl
T6jwtvquT3WeUnLeDxXeLphepT7o7xfTnj+Cv1x53kj7nm/4nDok7/Vr3of5
zzrAee0w9cOqKjMr9EfFNOtbtIMxKXgW4R8qmlbm2b/qG14Jvcf5BV6Nymwp
+BfFPyl8xDpb9NiHp8Xa/G7mzRzsBwpjwftRGFthVeZs0eeklsIsZZ/lOaeP
UftvVPhQ8LCiY/hIm5bMQ3kj7/hczudrlMyrIh8TmjMT7/+32vUndJBwy1Z9
hift6fAh2L/ua3jv5fdFFdP4nwTPvlkqeD+HN8FYY98Gf1K+A99jlvT7Jxkb
E5S9L1FmwrJ/s++uWXJbv6JcyTxFzn3FstvNO3Ce/yZ1vphnzJox9G1wU6a+
UekrytEP9OWX6c9S0efU7/L94VlMEfz3flx//ENgaA1+s4dCj4A/JXPi58wL
eBc/ZQ4Oyu+xk/5T8nBG4/eaCmfCK1A4reTn/5o8zwWeIvFvwQ/MQ9L/SpsH
pU28B3sZfAfO+DNm7AMPTfxH+v+1wEMT/xn8L6mXscRa/nfq/zv4QYn5zboN
76hSNP/ovfyeILhy8MD/ps+JGdPAjHfg99J2vkUlMd+APt8g32jgW5TyvaiX
+lkDoQ/4DW8L3ls59RNXAr+ed+S96WvW06rSLuLMVTZPGd4t53no69nKprn5
PVHVtBC01iSa47OXTetsqfVni7p531sKv4XCAoIvEO61iumaFzm/q+5xFXZQ
+vY179nsNdA4k+pZV8CLUrheeSaDPi757MB6SMw4n1D1TKCwCHRKxTyCPsHb
qb5tFbaCRlEdhyh8pvKjFc9R9vr4CDyiis/VVdW5u+p5U2mX1c0f4WxCx48S
bqTy15S/WvWax7mE/WUJZTlf6QuUzVdolXyWJY0zKHwNzkanqdzxCqsr/SfO
CgrXq33HwqMoeX4/K7gCD45yyvuXnrOA8IcInlZwp+TzDecdzl6sS5xv4Oes
UvZ5Cv4N55ZJ8tx7lOdHpf2QM/TglF297LMZ7dtGbdla4fPsw+zXnFXqat87
8E71e3KlT6awtOCr6j4HQisupX6bSGER9jDhFiuaH9IW7ijyVPxM2sZZ8Sg9
d/GS+YVrCV7+/7WDmHMi/UEfjFvwOGO88d6L8p3rPuevrXIrZSzCp5k+7835
GtoEWuOwhvfgyVh3s+eTBp+DsxW8lxNUx1Yl70fn6X1/Co3FGGDMwjfmPDRL
6L6HhP9S8F4KXyjMkzTOU5xlOB9BE0MbQ+tCz0CTbi7wAuVZqOzz0tjQXeqb
t5W2nupct27a9KuizzHwvZYQbvG6zx4zMU5zxuD8RTpnmRcEP1/3uWHDsml4
eKEHsX6WTH9fKXj9ss8GOyedc8EYte23sumaXVV+l5rPkLuUTG/Cf5wBPkfd
tOQ1yjesbFrv66Tfo3p2E7xyxv0s6RPoY879C2bdYD7MH3rsEdWxdNlp0Fbw
WaAtD9RzDlDYXbip4KvVPa/2yPyH37Sdvum2DdNME4YHBV20mvpnsbLpjOXg
dcDDLXlNYEzCe2nqHd6tmHbZs+T5BK+UfZ7448ytJTNHHld9a4SXdFXG/m6Z
W0tlfv0r/D8KaxbNF4IPdIjwFxZN0yyjMJPwMyqsJ/gxaKfMRWQgnIE5/85T
9rjqPxPD6y17LOzeMJ+X/Z5vyFxcp2DeI2cwxtoI4ecumYd1mvKOUtha4U+9
7+4Ks1TMJ2dswLfZSvCWClMonASPT+X2UZhZ42Fqhe2U73bhlyh7DR+kZ+1d
89ma9vTLNAsey7z3GYIPUNr+Ct/o96iK+SBrsc9wpiq6P+ZRPU8ozwHCHVQz
j2ndzPlxMk7WU/3rKnxVN7+QfY497oySeej8vltpo0vGfST4w7r5OLfBVy+Z
h3e2Cs1Vdr4zFTYu/sd/J2Y/PUfp2yicpfTpSuZdkm8WxpfqOke4/ynjfgrb
C392yfz1YZmfzFN4EPBk4LvAJ9mu7u+9uX6/C+9Y9f9PZa5VvH3Z7TtG8XIl
85QeLppWhjd7svCHCTecPHWnbanwZcmyFfIsxphvOB3ZGecg6MkP1cbJKuaz
TMuZUeFTeGaKP+NMWzRvlbZDw9DebdPmQ1Vm+vTBzfAdy+YLIt/kLHmV8qxZ
MZ+A3wc0zHfgN89kvIwumF6gn7YX/Kq+71pK2yn5d86aM4Fw41eyRnC2Kjvt
4ZLPDfAIkPnsmvVzF73no+zVCeQjbe7kI8/RetYUCpPXLEulDs4rd5bNkyDf
varnjIr5BNCb0J/QjRXlL3NuqplGYO1BdnBcxe/MeRpZGPF9yv8F31Dhd/0+
vuJ8nL1PVnySwsFFr5f7FS07m151T9fw7wfLPmf3pxV9xoYeHlGyDIPfB6qO
AwiCj1CbDq/5PH54yfmQeXN+5uzHuY9nnlixHP6Eitu0b9E4+GTkgyd9UMod
QhsVfitaloQcFBnoP4JPVTiy5D2SvZKz+s7CDS6Zt32U+mG4fs9U8hl6ePKQ
/meew746omi+wC5l77vwC44qmb6AHwDPhhhaAz40PGt40ccoz9Ely5xHFh2T
Dg55BflOU53Hlpx3kpLP6CPTjkOK//EWRqbsGPXfMQpH1cyXoi3w3vdp+EzJ
+w/w7CYR/kXl20bl3+Q7Kc++DfOHj1I8X8n8//FVbjxkIhXzDJEFD1bZOYUb
WrXcZtOCZTHINBlvJ+RbP9iwPJbfDwlepuTfM0K3NCyvfUNt2FF1f1I0DrkL
eUZU/EzkPE/oGTPAq4ZHCI2geN2K5Z+k8/zDKy5zin4fWzHP67yi34n3513g
U8LDhN/3btF8SnD0x+npk1HB847wDcH38yqLThuc/KNT9vT0J3W+Fzz1wItA
tjt/wfw8YM5Z8OHg54EjPjt5SD8rcAu+tN7zo6L1Is5N/ovTDs53R4afR/rI
vCu/P1Bf7apwVMV8BfgMnOFerZsHxm/4duxR7NcXBNYj+/nZ/KYc3xZePnoX
yHfRUWAf2Uh5NuTcwvxRfETDsi3qvyD10L6L02/oN1ySssiG0WfgyLchMouS
5WXkAw9vivrQxSHvSfC5la9RskwI2TZy7cdTJ/Wge3F5YHCXBkbGSP7FC943
4EewdyBfQp5IfU+VLCPnN+Gq4JENoCfBuRLZLPo4yGeJ+T1R8NcERoZ2XWDq
uD7P5Z2eyHvBC6ENJye+MTB7FzBt/F7verHCVKqvq/4du+S6rkzbqPOahmVm
8F/uaPg3vMczOSdWzIt+WHXOzNmwYv7kLVkHWFfgP8J7/Cq85Nuy1twafJ/K
fq20GUvWoUAPAl4CejB3pA2UoSxrGnLEMcGTDrxFwXLROwfGTNG/gZ8PvDXj
rWIdgjuDuzv45/PsIfnm1LtYwfQKeagPvsY9advCqmPqrJtP6n0vb1jO/kTi
VbImsQ+xLhGzzuxa8FoDTDq8Qfh48wl/PeO6YVkq+lf3Jz88PvK8lvih5Gfs
PZ55ggwaPHm/D90DPfNKeGjwi5APIXcqMQ6Fv7/h38i5iE/N+Hks45n6Hs6z
Lg6eefNYnkueazI+4YHc2rDsi/G3fMXnFs7r1P1U6r+nYRnUU5lvT2Z+vlI0
3xY9FfRVkNfCp30lv4FZ65/OfASH7H7D7APApG9Q8TdGz+n9sr/91hkbz2d8
zKj0D8pOp29eSP+8kL6gnc/mudT5Q9JOTb+Rh3J/VS1/Yl2H78JaPEnayLvM
nXa+kvdizYNWZ716OXjeaze148CSaewXkwb+Pc4KVeuTsVeS3ix4L3s9Y6Mp
eGTdehlTV9zf6Mw8oHK1iuW6DwpuViyzfUL5CsnzPvRn1fsY+w+8JfYa9CZe
St+O4ZxQt57COHlX9qDn4bVU3d8Lly2f4/23CC8HWmAa1TO1wrSRKcF/Yq9Z
V3U9pbJzqezT6ICUvO8gT+RMBu3/qPCP1C1f+lB5d6t6j/0J+qFm3YKPhNuj
arps99BN0EN7CN6y/B89RAzPBdqEdOivPcs+v8Jj4EzI2RD+AjxRZFD665eX
ks6Ze5+yzxq0b4ie/2LFsiv23vfTJx+Vfa5DL3VKvcuQhs91yKvY/9j7OC+S
znmzU/P5jbS79K531n1u+xhdj6rPeayj9CVr6TvomVR9ZuIcgzyc88vHeuZt
ZcuoPy2b7kf2yBmBmHME5xTSOZdAr0O3Q+evFdr+16LP2l+nndMLng5+kOr6
BD2Xqun7h+umzZG7QXtDb0Ofv6v0raumr6FtoV+hGXcKzctv6EfoWGhl6Edo
S2hQaEJ0BaADvyx7PvD7wKrHEzLPg+kbxqF+z6vnztMwHTdlzeN5eGghxiHf
hHHK3GRcz6k23V223HIa5Z/w//U7MfOSvYvn0N9TK32qmstDF1GO8TtUeboV
P+NXziAK9ynfS4pvVv0Tw/NA3qjf8zK2S97vkc+eVbG+DvTHeMHtnf0dPQ72
evg98IWQTaL/xlzu54EWzUuBF/my4r6Sy9zW8JrLGjq92vGKcNMqlCvWESHf
5RXrhfTzdtWfXYXzKy7fy3NfEO4ghY2g7yrWZYEOOC+/BzGv4MtW/R4z6lmT
1v7jlxEz/u8qWybN+zFfmdc3F8wDHi/vy16NfJj9eq2GdTjQibpX5XYqmUf3
LO9acr6Syn6rtOcE31e2jJm0deqWudLnD5U9LjgnoV/DuYXxxfkJHOMOHhj8
cHjf8LTgd/XSlgnTnvnh41SctoDib1Tn1/Bg6tYPgJdOm+Fvwtvk+8L/G8Y+
pf5YAT0xhTOV9yHFbyrt7ZJ1wqAVrlNd7wT3udo5ouo+vlDhgor5ibvVres1
Tcn8DL7nLgWfuTm/IyOcoWReArQJMbwF9ri7K5bZQ0fNAq9I8AqC3yi7DPnP
Rp+tbN2vo6uen8hs705d1MMayVrKPB6edGD4JF8pbFLwOoCeJXzahVTPglXL
J4dVrJcJjbxJxb/RVx4dHDTDl/p3qsKVwm1Vse4XZ7+JFL8UvuqLSl+z6jrQ
i4bm27JgXR7gxUMHzhU88dyBb2n4nIAO3Nu0Mfk2r1gnep4EYHiDfMOh+Y4v
IZtm3VHeoxvWg6JtXwh3YtXzaU714dLCjWCv5pzK2lexHhS025TCn9Sw/iW/
1y9ZzjCh+uqyhtPQMRiv4XrQOx1ZNo9/cuVZXfgVS86zftX8WdJer1t3A17V
7RXrpgGj3wG/H93gMcLfUbEMgJh8pEHTL5F++5FzrMJSJbebb0AbxtGzBinc
wreqW3dqyZLbDM9+J+a40n8tW5byivK8rHCh+mNlxSvVzXM7XPkPKRk+LGdw
ZI6r1J0P3tzaJctkkLe+Wvb7Hlnw+oSuJevP5jXrZJC2Ud26HSsxrurWa4Qn
zriD34x8nO+5Wr4pcxedS9aWZwRvVnYaOrzIeT9UnkXLnh+3FPwdVs+3KJUt
9+2XB6v+0QrXVfx+6HzzPjW1bbOqZSmbVi1n4p1+UJ7vFa5S+uLB8Y7wBdfJ
c3lvyiF/oS/Xz9igH9EzXpd+r1gnYoBvRYzuBDF4+PnEGwV+XvVsWvbvZ5Cn
830526nOxWqWNcGrgmeFTgPvuGbacBXztOQ03vPa/L6+Yrn7gFyfGHnmDRWn
IfNHJrBZ0qHzNs84/Jq9ouq8jZrlUqTNI9zcVeslsJawpqA7+wZ9W/L4pr5N
U+fWJcuO3hE8S91l+D0z9LB+b1eyjGXr5EHPB54DcpPfy9bF2S7zZPu07U2V
27Xk581ad73IqNZR2bUV3kP+U/cc2CbldkzZd6BDSl5TkPshy2HfnjV1sjZC
M0JbwoM9T++6eM5CFwler2rZyPlV7zfMbfZ50pHfIO8Dxx41afKy/4/F3Cpb
rvpdyToK6LOjs0H8vp67t8puAy9Uv+esOx9yh2+V5+Kq14b165aHsdfOVXc+
5BPw1SmH7sdrZcst+L153fp/8Ng/UPw+3zjykINLXm85fzDfkQPOkf45Xvgp
K+bFkwb9Bx3Innye8jQUdlTaWJwZFep169zCm4emJT4scJ/Gz75V/4Y/OyJz
YsWK5wm/v1P6JVXvgStVnAZP9znhVg6OMcCaybn4iJLTqQ+69YjAH9ct8+A8
Bt3NWYZzA7IVeKycJ5av+/wP33SFun/DL0WniRiadsW60+ClrlrxmeSopFHu
iNC/xwU3bs28V36jV8R3nr5g3hs80PMLjtGRvKBgXYATSz6vXVazDiW/T0we
8OhQnZR6Tkq9wKQfnzyvJA29DnQ/T876MJP6ZEb4RBXb0KEDhu4XdNiz+e7o
laPPgMxxubL1G9BtIC94zlDEpwX+DH5g2XIfbICQLyFveqxkGRLyJ2DwSxYc
jw58j/JvHXnT6ckPT2buyJfIc1bwwMT8huapZj0+O8+jPHIq7JjAsTbX6s5H
29Cjgi8zX/gtwKx76FZj14BeBDH6CGsLXrFsGHsHbH/OCx6dXXSNOHKjK4T+
EDre6MeShlwPPSTynJ78FwW/KvO07N/oP16cenr6161bf3cOfZf/lQ2DQ1eY
fNi+oBuJrBz9fnQl70ybz037Jypb/4l8EyUP9V+ctgFfnr5gHUbnGv1D9Baw
gcSGAD0cdHKAkXmR98rkR5f86uTBFg/dO+SqLVW8VNl6L9gjkAd5Fvp51/6/
sQr8fMYwaej4jVu3Ph/6KuuUHZP/+uQBhveGDjr8t3597pLpFp5zTZ51bcP4
GxKAR/JdVPfPCrdGt+WKjAH099H5RQ+T+Ja8C32BPGBTxRPDCyk7DXsA8PsW
/N43J/8mZcv2H0m525KH+PbAyPWRyyprYcG67eT4jUwPGw/SFxZ+IfgFJcfk
G5P3uCvvsljd+hx3p920A57SBFXj7so6ge4D68mSdetD3FuyTSj8Zc4dyF+B
4TPfzh5d/k8G/EDyoBvOb/Iuxdmn5HYvV7e930N5hwcz/3pl85qfzHPuTz3w
I5A/ctb5vO615+HM6ccyr9GDRk5J3jOCZz4jn8F27XjhG8wLlS9WzGPnOfCy
v6i7XsoPV55O2TKFL+tOQw7KuZwzO+UGl237MmXOCE8nnfWPMwlr4FPBD8t5
BDxnXOwR4SkP4Tvm/Er+Z1J+gsTgOc/yLOxpKYNcmTWUNZPnv5g2zNewLSO/
X8532iXfBxheAra+lEFniX5+Km17KWU4978SmLLT5jfwy4HhG3BW4KzFeYEz
wWvBPZz5wJgiHTx7/fMV68eThq4Nut6cqXtq81mcn5W2esXyAmy2kAVwLob2
5mwMDC+d+O3gid8JDD8eO57FBB9cdhrlsBt8N8/C3off6DB/n+cgs3g/+cjz
csU2h+CwS3o17Wf9Y51l3UMuhiwNfjsx+rPw1T8ODA8TfbqPA/9asa4tv3dq
2L7ig+T9MHmwlfkk32Wnum2r+P0Da6PCbCWvYejdsNZ9y7lVYZmyzw2cWzg7
rBGYM8X2DevrfBbcF8FDT/fT1XqPXZS+Z915OJeQh/o4S5IHepVz1qM5a6E/
DI1NHaW69drQRYLehpaGtkbfBfpzWZXdp+58pEGHgv8yexn7HHsbNNf3aQ/p
36UssgXwWyb+ITD04A8ph30g9lHsp8Q/BWYf4/dq2dfAg8M2Bv1m9lD0dL5L
u2gHePbZn9M28hRy1hs3fQuMzi6219inTFxw/Htg7CGBWTMvSNr5BY+vPzL2
zk95dGOxk0YvhH0HOwny3FYw7q/grw7MPor+N/a3cyfGfhb5IDaL/yR94aSB
B/dv4K/zPh8VbNfza9qMTSN5sMNF37qQ9+V5tIO9m7NgKWdebC2xXaqlPsp8
XLDOYCVlK8ED/1OxPje4jVX285r5ZnciJ2xYZwZ7E+RPJeYv9H7ZePhdwNih
fFSxnk0978o7b5x3bwZ+M7/ph1bw4Ij5DR+AZ96U58EzayXPoZEhI2PGLhM7
PfQi+OalvAt7BXsT/BJi1tBhWed72bP6+afB00996Sv4wewp7EPYgpEGDYY8
jDzohCMnZJ2fsuC1HhiZIjbH2Khj64c9/TiB8dsAjA7J1AXnmSZjAPvrAf8D
4+Vdvq65/zvBkcaaOWl+A2N7zbtvXrCuOjrwA3QocD3r4UShD6ETJwp+4PcX
efeJ847sOYOzfyFHAQ8fBv0D7NLnzHMmTD289+D0A/400JVZLu3EZpN5RDxp
2swaP1lg5hprPThso6kfmSw29EMC02eTpN8oN3nqHC918u74VSA/9suzlm3n
gM0/OvxT5b3GCtyXd54yeL4BvgP4JthMY3+KTSV2zNPkG2GLRp7ZC8ZNGxg/
GdhOQ6Oi54gOJPq52D/z/GnznWdIPbMG5l2IZwxM26dL+/vS7lF59xkznvr7
Jv1PPHPyDwlM+nsFv/tA/bOmH04vWx8dHeFZgifPAhpfZ5R9BuV8gp4iaynn
PORn0C3IEknnjPmNPvjXCmeVfX5Db3BJ4fcu+/wGDC9i3rL3BWRsyNr69f/K
1t1ERjeb+vO8snU34T1AV0FTcVZG5xz6n3MYOq3sEZerP18vu33T5/tiIzBX
zTJL5EXQF/ABoTHgZcKzYw/dqm49e3Q0OTf0694Jv4nqfKvs3/CEkI/BF+Lc
Ay+Msw96t0un354o+2zMufjysvXC+dY71WyDQdrFZftwQUdz55r13TlTonuN
DjY6s7cExxnzkrJttgd0adF3RQcc/e7lU8+lZeusg7+sbJtt9Gr7/a9kHJK+
Ztm649Ab6PF/lr5cJ/05Xt3nrnUzFtZOuzjnoC/LuYZzNnqenLXRNUTnEB3o
zdVXE1ec7+qy/U2gV8hZBz1nzjsPl30u4kwEf3azfGvk5PCZkJXD04S3iQwH
GR0yQXgz29atW4+s96qy9bN5bld9+G/Z+dC53Urx+sJfjXyy/J+Mihh6HvkG
chB4VOjooZMHn2rRmuXK6NmNI/jvsvONCg6+EGcg5DTQz8gskV0ip+dMsavg
eYW/U2VHVv+rixgZC/wg+ELIp9HJRSbdr/OueK+yZdJ3q+yyFacxb/bOfGEO
IJNmriAThq+CP5Z70AutOg3ZF3IxZK5XCPdX2e0b2rAMCN4BvNbjy+a3Xlu1
HG5AxkbMOYXzAPLEbvqMPuQ8tLiedULVvF1oUfQ70e28oWz9ePIgd0L/FdkS
MiXkSciSZlXZhSr+DS8VHWtkNMhe8F8DLx/aGFs47ODgyx1Rto53v6ygbPnI
EVWfBzgLQMOeGzoWnjcyFeQpyyCvCX/tmqpltbzP9YIXC49yiZp5+gN8fGJo
IniXpCPLeKxmPjs2i8hQ8N+AfATeM3YO8KXhu5MObx7+Mja38I9v0LMGV8xX
hU9LDG8WXih6yfA74UGeUjZfcqma+Z6kwTc9NWMSfuSojD346fQ98p2vlPf2
mvOtoXiRmvPBT+S94UuyJrGmN7I2s4bDL2QNYi1i/WaunJX58ozqWDDrFLw3
dL5HZ46em3nK+o2eN2sA+xhrHOsbvGpsgVibn1Udl1X/W9eIWaefr3k9xRYK
Xhf2G+wn8IfAse6y/rHeTZx1jnWNNY31CfsleD/P1bzWU571j/WUNZDxfWHZ
/LFla16PsNVAjsd6ylrK2oPdBWsSvA30yJnTrGGsKawnjC9kt5w5OXtzBkdW
xTy4IeP8TNW/XM1r6E1l59mRPSW/gVn7sclhnUYXA50NdMTRB0FvBL3/Fyo+
S6Mf/nbZMWduxivjFpk9fCbegzUY/Q70PVh3P9Dzr6v5N2st+tnoekCcfpbf
+LdATs/6V9Q4fKds+2vmOnMfWfgrFZ+TwRdV9s+kIU97qmz59+1V+xBBV5sA
nxEeI7ohDwRmHUU2zzqEPgtrPes852VsYpDXvFI2jM0veyC2K+yf7G/YcrC/
7Vz3mRlfZgs2bBPO89jTsCGBhvpe9d+p8HjF+hroe6BvxPrxdNkyQs4pyC2R
tfF9nst3ZL4yr9lnsE+CbwjP8MmK/Z7wmzUJOSJ71MlV18N56KmK8+E/4sLI
r6eEJmq4re/mOa/mWdAi0CTYdXxc8ZkHmzjoCegK9PvZS5HZs5+i6/12xkBJ
9f1c9jfD9xdyGmQ0Y9VsV0C+QTXb1ZNnQAbM+oDd+Xtl6419WLbuG7L+78r+
DXxTzTpMjEfS0ZFDjw79fXSMGLPwA5B7IfNiPDGu0CVaueaxi20D4wfdKM65
L9es08PeSN98lf7hfIiMFvnskWrvL/mNru/XwcMbQ/djovQne9Zd0Ns16zkx
9tF9+C7th0/xQ9qG3hv6b4cVLLv+Kd+UZ/ySscw3/DXjYXXVOW/NssQf1J4t
q/4+jM3fMlb3rZvfgVwROgB6gLX5j7JxyBnvq1rXH/zjVevkoWsHP7ya9tyP
EkTFa/k3NZ/Z4FVCz6Lvwnvjb7CS/OgDAcNL/6VmfyW8zzSpk3RoHWge6mSP
Z69HhnV83X4A69l72IOQ950o/Al16wXCz8DOFF4BdpDoCaJrtHDD/ntIw4YT
PR50eGZX3FG4sOC4HRi9KPSj0AmC9wavDz3hU+rWC+4lAKNnRTn0+LBv7SJj
Ur6xKvZVA8+C8/6gPJvntvIs8sPPGBT8oSo3XvLRbt4VPhvvx/v3v0/d9qDw
0bFdw04G+Sz9OGHm+MR15yMN+gV9FPRCyNfPfy/YXhAeELwf6FroW2zGRtTt
u4S0w+v+jf+sIVX7GsSOZ4qK4c2K/g2MbQ98En5j47NC8pGHvp0q71yt2S8R
3wDbT2Sr0CZ/1KxryzhjjWatRraLHtk0GRvojk2bvkHugHwCG4adqrZvgA4n
ni4wfo34fUrWCvRlWQ/AzRA8+nLob0KPD65Zx5RnPFS1LSVjgO88c771XzXb
y81acYCHyFlvtvwGZr7OMTBny9a3Y0yhj4VeFjpsk9X8XOrlvDhbysJXpE70
Ks+uWNcHP1jQbtB46JzQd/Qhe98Gqme9mmXw69dcBp09ZO/geCZyWuS88KWh
U6FXOSt8WbN+GOvUafrOi1ScjwAMLTpxzTq4fANk++gAoK+CXsASGXtzw3et
+je6Gsiy1yi4jkVTD/YIvAf2Dsi5ybNBYspAZy4dmLLEywTPmYGzA89kPVsh
4wr6Evk49TFuGD+t1Lli6sG2bO2K7cuQna8cPOkrBYZWXaXi+n6v2UaUc/AZ
dc95+P2j6/4N/x8bL2y+sHE7M+msEzwL/HQFP3OtwKvkWdS/ZvDosq5WdT7y
PFu1PSrviH0O9jsLCv9z1b+B763Y9mNA758Y3Xn2tvWDIw/wUgXPDepBr3z8
1HN88m6QPNtWDVPHZhXbjCxdsA7lhsmzRnQqge9LngHdOGL038lLHvRC0ZMb
lnTiTVLneqkTOxPqGRb8MdGPo9zz2bNpz8Z5FmPmy4r1udDpXDt6bdsWPD+A
OWdtkfkC/v6K7bPQycNGCn2no4NHT2y7gvXhSMe+CdzWwR8fPTh0qLZNPeDX
rfo3MDhg7L+2TB70frH7Z91nzSfGZ9mhBftm5Bk8Ex992wW/VdV58GmGPzVs
0h4r2OcNMLZpO+UdaD8xv7H5wo8RPNDNhd+gajx54InunLI7pCz2Yhsqz64V
+6skfZfkId41z8VvJT6NsK/B7gZYTe73d0Ta7cmzR2BswXdPfvz67Rn8xlX/
BkbPjHZgL7Jb8lAnMXngme+a9tC2YVX3Be3BLu3wjH94/Mgh0HMgxt4WXgEx
v+FrbZ/fwPiuxQcDvHRsJbFFwdaA9P+lLLYp4P+XuD9f0faUByT//tXYWxZt
E4n847bUeWDyIw8Bj+8hdOoPTp59qn4W7Too+KNSzyGBWROwD2Ud4Jvz7uj9
4kdieMbG9lXbTyyeOT0ifUL6YcnzefDMe+zXh+fdsXHD5m0Bxk/V/cneB440
bN+OCrxA8vN7wC4Ouzts6PCpBYwu9C5V5yE/uGOCJz42MLKMQzMXqOuYPGv3
qvOAQ+eed9878fHpB3xNAZOOXh92qusVHJ8UGP17fqMPiK8s8OCwkUDPA70G
cCcnPza9Z2SMUfcJeRZ6C+TnTEd8amDmyGnJv3fVdgzYqs+Wuce8wzcD9YJb
EXl91c9gjUNXGBIZnxnUOVPKnZ46wY3Ks/CHTP5tCpbJIJtBd3R41brqrKvo
3Z+VPAO/eQ5rHvs+6x7rJLru/yu4POslMiD0+cnDHowf0HNTP/F5yU9aP71R
Mr2ILjeyIfTtgacM7sLAL+WsOJD3/OTnPc5MO9G1RPfyk4Lt84A3EHxJxb+B
LwqMjJuYNOz4+v0/VqznQ4z+P7wO5KSXBoaWAk9e9D3R+3y1YJ3sK9KGk6Lv
TN7RwbM3EZOPfeeUquFtMsYYc+iREl9dsR7p1cEzlkhDzwwdM+Jr81zacnna
hn+ta4Kn/LWp89iq35F3PzM6uaTDu0QflT47Ozqn4NAdQYcEGSAydmD4sTdX
/Hve9OH1qZP4hsDov5Fn1pSlDDJ69lX2e+xDz6kaTz3oU9+S8YAeNb/hDRLf
VrGuNfGtyXNB1b+B0X1ET3ufgscd9aBrwbkd/IC+9x3Jgwyesy46ruDGBP8v
Z0++R8E2ldgCYDNJjF7k2kXbht8V+NLoS2IvMKhhf6D4MobWgB5aqmDaB92a
AfoHPPQI/QAtAh0yLDB0B3s1tAJ7O76T8YvUyr4PHhoA/0jglyj4efgfxd/F
yg3b0/C8B4InD76OHkqewVXrWg3omhCjX4XMFH+lyBDxh4RfZXzLTNCwP1N+
P5o84M+pm1fE2Rh52cMpO2HVOlLwfepJ79epKRuHjhW8Hng+4MgPfGLBdtn4
nMQG8LKC4UsLTn8qecA9kzzEzwbGVzRtQOb7XfJQx99V57m84LbQZvhg8AWf
Tx/cVLffefYu+C/wYUiHB8Oeyn5KXvCMDfZQ8PgowLcuPp0OKVgv5uXkZ19+
KTB8QPDozBC/Evzn4fWQDi0DrQOdsoT6u1SzTeSewUPP8B6v5X2RhSI3xW/M
+3kWcl3aAX7dxG8kD3wy+DGcXxgDz+dd8MeHfiFyKGJ+46/mncDg0X0jDT9t
nNXfCb5Ss/8a/FnBH6T/2PcHN+zvj3zo0iGvRVaLrBV4reDeD4zPpA+SFxww
/mc/SB7wU1bNC0C/AV9YvA96Drzfm3lHfpOOXgT5P8r73hteFHxCbDHZO9k3
76vb7wa/8Z2JH5Jiwf5JgLH1Q48MfTJsvTnfQ+ucHJqHcz70zIjggWnPt+kT
6vg0dU6f/NTB+sR+ydqFjRG228hP0d1Crwtb7a+CZ/3BxuKb5Fk2Y47vjF+l
7zLOz02d56Qc+VmXgL9KWebEd5kL8OXgI3+c9RlZEWv17DXDrNXYYKEHNlXW
YWQ2rMnYIOAjER0nYmwR4O+dX3Me1uotkwae9F8C4x8RvxbY4YL7Nfh+faGK
/ejiuxe4X3eo4t/4kqKtlEEvjP2atrF3/5E85Mfn2x+BwQHjBxhdG/wooYeD
3zJg+JbEfwdG/wZ4IC/5sB2AzwnvuxK6krMWtCX+p/EFil4E5f5JPeAgwKDT
8E0OjL9Q/A8VAz+R8pQlfyl48pKH8QmuHDxjCRtUxiT6F5ShfvyPkof68BFD
HnzpYC/1V9qzXdoMrQ5tDn3Pe+BblPsgxkqM713W22ZgfNwR85sxRh211AO+
njz4/W0GxpYdv6/Ys7NPso8yDrmrATz2ksT8vq9gn6+d4Pv1gqqmD0kHf3/B
NoHgB+hA6ELydlIPZUnvJc/XeS5zh7HC+EP/EF8qjL33CvZPzH0U6DMwH9HR
hGZAHxOYcY5vT8br+wXjxgn+n+yhrJ/4WcGfCrwO5gh5qI+z0njB43cFGBqA
ePzA7IfslegSL1wzfGJoBvKsk/QJg2csM77h32Jfz3M3zP44YfbcVvIw/vFZ
jb8sZJGsQ/itYB1j7R8cGgBdRXQWt8x4wWaGMc/cBc8cx4YGPGOK9x6cd8fP
OnfNoG+Dfgj6N9MUfB8BePYg4ikC9/ukr9pHGes06/lkiVmvWasnz29g1u8p
s+bj7wC/B9iS027agfyO9wMP7xde8NSBee5kaRu+OqbJ3KH/58w3Y+xMV/3P
R/F0GW/MNfYA+ozvP33GAH7duLsB/VJsO7DXhDbGlxl5sP2BRp4xeOw6gVlX
iWcKTBtnzndZqWaYtrMOk4c68DOKb941E88aGF08nss++0LS0POfLXnA4Zts
/tTPe0+bd2cjmj3vwnsxvpkP3FsyNGNy9uDJQx8NzRgj3+yZO9if4S+DOTU0
/UlZ/F303+WQeO6MH+bf3MnPuGL/AMf3mTdjhvR5kh/9mnn/3/iZL9+S9+M9
sZOaN3jy8P3nz9ggXiDvPnVg0qFPFvx/32KhfD/8j+KHlHVgweDJw71J4FnH
8GfOb/yMLRoYPPFSwVPXgvku4BfNuGoFJj93JnDnBv5a8enKnS74RHmk4Ts5
BtLx3d9/P0PD8J4F83yXSp3kWSz1fJJ650h9i6fsRwXr0A8pWIeR+2bQdfy4
YF/BpCPPwEfnx8kLfsWkLxuYdXKFvCP9sXz6ivm+XObXqsFflXdfIX2HT0HG
GXs9z+e+j00L9lkDvGjilYOHbwI8kL5i8qATuXTawzNXyXPxK79Knku8auDl
A5MX/xbwu+G3wOvFJnrpgvV70PNBT+7wqnnNSxXMf8UemXMWPDZs2+CzvVa1
LTF2xBdWzZMlD34d4G/CV4E3uVHVtPp1VfMigd+u2sYVvRjsVrF7RfaNjgb6
G8iu0UdAvwKZGLQq8gbWQNZebB6RQcHPQ1cJ/iF+TeDhshfDR1897YeHhw0/
fDz4c9slz3g18+CgUX+rWnaFrGpYzT7u8W//U9X8NXhrE9TMo4cfDt8OPyfw
/eC94asKHhq8NPwUwHN7tWo/sLRz/Jp5beSBz4TuArymm6rmS8KTxBYRm0R8
cPRq5nPB44KHtV/6Ex8n+LBARgbPbI98x0+r9oGO/R+8f3wvwJe6PefzRwv2
4wjMOR1eLz4B4PfST4enr5ARof+EnAheFP4EoMmRTSFTR9aNPuPp+XZPV23z
jwwLHTR00tDJmqNmWQL8nF+r5rPAA0EugD4WMgL0jND1QqcAPg06NPBqsJmG
7w/Pf4aaeUbwi+AJnZo6f6zatx3PGlU1zwh+Ef4kRgXGZwW6Wei54OcBXTR0
UuapmdcDnwc9Nfg78HbQrYP/Au8Fns1ZaTPz49zMEfhD2G7DR6JvLkj/IO/C
Lhe5HHPlwswF+CjYycJLgS+CPSn9j74S+kvolaJjhK4Rehxn1cxDgT5ExwEd
O2Tv6LxcVbXuHbyvM9J+ZGhXVi07QwcHfUT06ZiX2AMje2T+XZd5h1wPW25k
ev06RVXrraDngb4HZ3x0QNAtQ7aPbBP9HuSbyOGRxSKHxaci+jro5aAXgn4I
Z3b0UO6oWhcFPRz81XKugseALs2TyXt31Wf9St3+jtGxQAcGXwDPRg8CvQd0
HpB3IvdEL4HnoSN0f3QT0HtAPwE5MfJi5PKsMdxvxBhHpo1OXr8+XsWyUWTx
zHX88XEGRd77ZNUyY+Tk3OcHzYVM+KnMNXQB8D2NPgDyT2SEyAeR3z6d8Y9s
Edtg5IusE/gzYh1iHcUfCvMSeRn+IJgHjHF8PbC+MlfwT8F6zDr6StUyLdaz
16uWS6HPgE80ZOCsf69mbWGtfaNquQ3yGu4EYs1jjr6decoag68f1kvWPPw0
sYaxtuFrjzUMuQb+oVgjWavwkcR6Bh8dfz2sQ6xJ+BJiDXu2bj+GyEWRy+Cv
h/0BPjm+XeCPM3fxc8H8Zm59UzV/k/mHHwTmE+MdW2vmB+vHj5nXv1RdN2vs
ZjX/Bmau4++D9QA+Bro17A/MY3wEDMzdXzN/4YXAl8GnMDxJ7lcbzl5fM8w9
a6wTv1etDwd/j3vURhS8ZqCvhh4E9DXnHHTlLqzbNzq8tFVq5pNC/5dr5lO1
it4n569ZB5Oxg74F+gLogaIXyr4HXwg/CuiUtmuG4SfB06Ie9MnRa2Z/Ym9i
X8L3AXqaN9fNp8NH8nw1x9B08Ii4Fwl+Efeb4BMKv0T3183fwY81azb6x+gc
oQ+KXij7D3sIduPoeNI3+EKir9DbYv9j70Nfg72TfRNfR/g+Qreae0/QUWC+
su+hw8G8ZMyiY4F+xdR6/iY1+33Fxw8+f/CrNE3dafiNgo+IPyx4ieyr7J3s
m/j9Ip19ee2a87CGsB+in42+Ev6V8LOErQDvjW8m2sh+OF3NeyL2iPg2QgcZ
vZIZ0xb0wmaqWTcMP2z4bCpmHE5b81iEjpi5Zn9A8JPwicNajT7gfOl/9iV0
kdHvgG8E/widQfhM3FcHr4nxhc8Xxlj/nlbzvsY3nyvfnTWevYp1Hv4W95bB
Q0M3AT0P1jP0yNAxQ1+Y+cb+x96Hb39sKtDJvVfxqJrvJ+LszLkae110edHp
RX8cPYuFarY3uKNmPXXw79eshwcPGHoNnWbGL+N0sYxbxuGSNctD0QtGLxof
BYwj9KTBrVozzwJeRL8/lpp9sqDbio4ret7gVgh+w5rPgZwBGe/ohUMv0Gcr
1uxbhTMiedAvxu87PHr48PDkgbkD8as8m+eyF6GTR5+hK4dOM33AnrNazXp7
6EatWbMOGe/N3GZeo7+Dbg86Q+xda2fsIcdD1wd5H/stOkDk5T7YDdN+fB1v
nHFLPCww42KjjA3mA/PiiNCVrHesdS+kHbQBWmPTmmU8F9RsY4neOnNrnZr3
K957y7w7PDN87ME3w7/d1jXzSfANDrxG0fFWwfPO2wTGt/xuNd+bid06dzOM
VfS9MNsG/jl47muAD4n9Kjq36MgCY6N6Zc13RYAj3jF5tg8eGD7/LnkW8a6B
8ZnNs7CX3zZp6DZcmzzgDlF8cM0+yeEF8S7wNvdUvAfjqWg92b3SV/vU7D+P
d989edBN3Sp4yoLbPWX3q7kPuUsR/3uU/07w/2pOA48/Q2DuBXi65jTw+N6D
vznA5zwgeL7L/oEvCR4f7PAsD0p+9M5oA7pnpB+Y/LzrQXlf/PsdnLLn1NwX
4PE1CO8e9gZ3YB1WM/8TumlEzfrDpA8Pvt9Xdc36FcT4sEa/Ap2KwwOz1h5f
85oML+jQlH0v+amD+MjkZ50+OuMcP874XDwq4x88452xdmzGJe9xXN6FPecE
BRRT0NOgLLxc6sEvNHdL4cvxqMD4dDwxebj74AzGjPCn1HwfFXmIT07/nBg8
MDxa7mGAlwvvlDsT4HdxRwNrJveKEpOH9RP4tOB5DvkfKNieAbsGbNXYW0bX
vL/8VbceP+scewX0PfvFuzX7TeNbPFhzXdTDGDgxbaO95wTG/gQ7FPSOkScg
Vzg64/qCjO2Lavb3hK8naAn8NLFO31jzOKNv8a9FvvWUZ4G6/VLg5wVdVHRZ
xwSP/5eLCrblIB2/DuAuDx47jytqTkcvnnnef39byX5RsAfHb9XVaQ8x+BUK
hq8JHrsC7As2Sn2XpU7sGJjnzPEbatGzLdrWnHfEno47WUjDZwVzFl3zbzNn
b8l8pO28Iz4pbgtM+/HLwW98UxyXPqJ/mN831zzHsXvB/mXn7JPsi+yJ0BHQ
uNAS7JPYYnH2vb9mWXOtZF+O/H6i5PiBwMihyYM978M1y5OQJRHzG/9++Pa5
q2Y7LuQ5pKHT+EjykH/y7DHsL+hmPl6zzcE6HfVj03kYm/i1ZzwPqRtmXuBv
aZ34pIKXCM8a/jPxFYE5l3KXBzaP3GvJvXH4J+Q+Ge6V4R5VeNeTBcbHCb4+
6Gfu9qEs9/vwTJ6N//xJ675vg/zE/EZ2xx0dk+W5+KKfLM+aJM/FLwQx+IcL
vkMEWSq0B3dFcicG90Uy1gdHxkogD/JaZPXQ9CNSlrtv8IUF32qi1EM8YWDK
ACPz5V6PyVM/vld5FnsEfmjxZfpr2kAefMxydyjthj/M8wenTnzfTpJ3odz0
KUs/TZW+wu6TNGw/wU+Q/iceP/BFwXeLPseiWz4wd/vhon0YkJ+7dej/GfLd
WWOAGRfcvwEvEj4kd/HMX/d9PMwP5v9Fee6EedZlwTOf8MeCf5itCl4vgPHF
Mm/dPq24K4S9dEj6CltPbD47RfvaGTfw4IyHQwreL6D/2RfwHztNzgKcc/AB
xz5C30yb/kFmMjhlGTuDM37wSzFO6seOCxgfGOj/4O8M27GxA8PDwQaV9pAX
HGnYmbEnQSdtlX6dOH27d/BrZDxAE7BWcF8EvmvRkcN/LTBjHh0TdGDQO+H+
KWDOU5yJOM9jm4AvE3yaoLt8RmB0mzl/DYr+DD4juU8cnVVo3/EynsEBwyvD
Ryy6ZeiOYfdA/fAK0AXC/wW+L8g/TsrSlkFpz3ipH/wjed5yoaWZP+Dwn0E9
2BXiaw0/a9SNr0DuYsSX4DIN3znKHR/YqvN74B5SYGyEOTejz8EZt/9u1MZ/
dQAjM+Vex+UDb5Y6Kcvzx0ob8FnN/ZfQHtDhvDv69vjww7cIOk3IY5dLPc+k
XmS8+BYhD/Y1jP35Ms6Rr6FLgV4EvCPsIrgPC112/Odid8MY5Cz6QegcYOYy
d/QMGRgPda8R5OXOecqOl/2FMcM4YswgY2N9Rs4GjO7lfhlP4NEV5j4J9HV5
zjR5FjjeH5rtgfwG7pfZZRzOlDzUgT1QrWE/DvOk38DzncfPd0dWjl0WNlnY
ZgHfmrgS+J2aYfJy9xp9hY7JF6l/o4LjemBskYB5PndB4Pv47LQHn0rYKOHr
D5/jbxR9LmatZtzhb4k8+J3A/o6y+PTmjjK+C7YqB6Ts/hlTSzbMexk/35Q1
kHvb8GnFWoVOCDqX+B8m/iEwvJl/a+Z3cqcYNlHY8fyYPJxJl08ZZPG8E+/G
O8J3/K5mu6ffaj4jcT7CPuXvms8R8Bf/qZnHSPxXYPJSBhuHbVMWH2HwO7+t
2X4F25Bi3Tz4ct2+cSYo2p4L32fYtIKHlwoflbuQ8Ds3QIsBQ3cR1wIz/qnn
68TllMV/InMbfjXzDJi5xnN43mHCt/NcYGzIwONv5s+8F+9LOvmwux3wJYcf
uPPr9kM34FeOGL8+9MHv6Qf6hboGzkB/ps5FGrYfG7CJIsbOjHu8uVsJPz/4
/wHmzIgc5djgsecaXjcfF58qjC3GFbJTxg7yU9LJd2jB4wo8tufY4WGjR59x
lxN1cuYFt2++BfVRLzReMWMXGFoPPPTe7VmLD02bj0s98KyxKUM3kGeOTHuO
UHxk3TZf3G3I/XbwN6Cz8K02tGjbsSUCH1333Hgj+CPST0cGJg82ZNiSXViw
viLPPZy1uu59nT2dOqhrSOYmv5lrtGNE6uRbjEg9R6XNPJfxUs/44Vvz3c8q
eB4z5+nzuev2zYHNIL6U8Be6bMF6JvhHxXfWb3XD6JbgB3W2un2hzpmy5N83
v/dJuTlSlnho3T5D8e3GXde7FX0v1YeBoX248wv9BNrYSzvREYZWwGfl0NS5
TWgD8NAMrIGsf5x/Z049+BDA3yt+X9Ebgb+Grzz0WOj7xdP/0MfAFxScjk+9
6YpenxZO/3Ov/SLBEy8amLr4PbJgOgt6C38PX+W5+N2ib+hf7NhoF+3jXjP6
j36kjcifZ8y7IxOkLnyQzpI81ANNt1Dagy0u/YZ/POx9OfOz575Us5/9N1PP
kzXTfk8FRs4F3wKeCLwL/JNg/89ZmXKU/yf1vBz4tZptcbHDfbNmf/zY12D/
ij8CzmTYbHEPAXZb+DbBFwDyNMqCx76M+LXUg80N9bDfwQvErzq8Rux9sW/n
DIr/f56HTTP2+i/U7IMDWg77B/ZT7JI/rrk/Ps64AmY/ZEywP/bzV2o+17MP
si+y5xKzjmPfN/AbuJPf+JBiT6llntCWt9Ie9JzpL2ya0GVj7LFHf1bzXeC0
ERsK2rlv2vtp4N2zR7KOIbNgf4T+Qi6IX2DOQPgufiPfHd/mb2UeEfMbHxrv
BAaPfzvS8E1IOcrjl+L11INvil1TL3XiHxFfiPNmXv+eOcWZkXM4Z/Dt67Y/
x/b8j+SBv4H/RMriXxEdoM9Tz5d53qJpw+t5FrJpfO7A38AOCX+s2ChxNyAw
egL4jP008CeB2SuJScNfK/6JuQsQH8XoQwDjO4g+oC/wL8L5GVpT3dj/zFfy
XPgrwPApWJd+y/tyrxT3S3F31UHp0/7+TD3Qq8Svpk7e/7esgfAQ4CkM7CfA
T2R/xwcf/Bb87XxXN6+JmN/4+kOuje8Y+hKfSehCrZ81B9oI/gl8FPgpnCPB
/RT8wG9oJ2Rj3EuBvwjuSQDmrgT0i6gTPzO8M33xVfg88IBoI3wb2rlu4h8C
4xf546yf+Aj5Om3jHMr4YL3E9yMdgk43d4lwpwjyZe7wxDcffqJ437/y7siv
GUvble2PgrKzJz9luYsEf32U5Y6wDRpOA79X+u2z9BV+puYs+47LrwMzHr/M
OISHxBimvQNtOiN79M8Z24xdxi22I/jU+SxjD98LxbRt9572pZ59R+2geLam
z+zbC96x57P7VopPa5qveb3i/Xr2tbmv4n165jMeIPyuPeugXCh4l57vzJhM
8eQ9ywaGt/WOXduZz6I833WtZ7OC4I96Xvv2VZ5vuj6f/sI6huNB4RcV/vOu
18L3FY/T9nl0F8UTd61zcaDqOKBn/uZRij9pevzPI3iprteGWQWP1fT6PbPg
btP7Q1Px3R3Tz0OEn7JnGcOyKrdgz3LN2RTf2xKtpHoOEzy8Z5r9EMWH9swn
PabnfOQ5VvHfTfNARwr+uOl98GjB3zW9Rl6o+u7u2b/LTcId1LNviMMVP9K0
/ja+armvdLWiy+3cdtkX1LZ5mpZ/se89kb3vL/qsZ9nQn4L/7lpWBG6XjvHz
94mu7zN9j48n+DL99zHVDTMvDsw8IR3eHT7TeS98FzF3SCfvR8l/pdr1dMey
KvK/l/UE31fvB4b/937qeS15OAu/pzZ+0LWM7SfFP3ctW7pFdZZ71nd4RrhF
u/ZVdp/67dmufRI9r/jFrmWBbyveqmVZ+cuCX+ra/9DUit/pWo7+uuLXuvaj
c5jqf6DjMVlSB7zSswzrd6X/0bXs7V7107pN84d+Fe6Xru99ulm4Ss8y14kV
/9GwbOx91dnsWaa2qOLFeuaXw+tj74MHuGm+Kf6CuaMZXh58PM7I0ATsv5wz
OHcM+IoAhu4lXiQwtPAiOZtAa8yT8zVnEeRYnEc4c8+TOvGzjU/Xu3Iu48zG
voM/OniO8BsnD4w/LnzUzRY8dwJzNzB+hEgHj+8uxis+TaA9eCZnFc4XnCsX
Dbxzw/5k8XezQ8M832kL9gFTylpUyLqEPg++d7iXhTtZ0LmhHH4cqWfBtB8/
OvM37H8Wf8L9cMF1UCf6QeRdKPk/zfuy576bNOoeKD/gD2m+1AMtxLegX/GB
S79dnJh+5Hw5NDD1c/8Pd+rAQ2Zcc/8CYxsfQ+DxA4O8hDtRjlSe1RqG8f3F
nZCUx58n/No1Us8awQOTxm94vOjGYGu6R9H8LXhe8Km4t4V6uasF/3jgZyvY
tob86NKgi7FSwzjk/kuEd8EdOPQ5/o7Qr8GGDbkB8SoNyxf41kPzvnMpnrPh
u3p3bPj3NcHPPQAX/Zs86IWSn+9On1EP6x5nUsYMYxZeIHby8BvR8+G5tIVv
w7tNWTAtsnLawzutlH7gvVdN32K7Rz3zp79XC553fCjjCnkXMrwBWd6jgRnn
V9bdfuQSwNxfP3CfPTB4YHi/2Fphs4Y9B3mvSFnuuL+mbnuozRuGuYOb+NrA
6AZdlzzc0Q1+yqLzXB38DXWfzTiLHZZnLZ4zGnj0bojJxz5F2etSD7Zp1MPY
oNxNKYt/sNuzp7BuokuBHg92OqxH2PiwJgHDS0f+cGtg1i3K4lsMGTV2XMj6
kS0je0aehVwVOTEyY555c55LXuTWyMi4N4H7ufF9juwMPPUdlHqQRxPflTqx
DbsjZZupl76/J/VsWPTdVi/Wfb8V/E9438ML9vX6QMY2Pl2B8X2KL7h7UnaA
V75EwXMEvSXGFePrvsDoMAHTFgJzCFtuZMKMH2TGIzOukAtTH+2AB4sPRMbe
wPMfTHuof8XMx4eCJw/vRNtGZy48V/eYZ048Gxi7e2zyufuWGF4nfM4n8lze
HTqMuwnRDX46eYCJnwyMzPuJ5KccMDxn8lAG/ieyaOzcLitYHo2sGhz6ReCR
TXMvGf0Pfx29JeYuNjS0eeXMZfK+kPxTa2+cqmc9JvipnBnh5+AfA54Yeo/4
0Oeu7usyDrfMfkQM7xu+N3x6+PXMKe6NwQ5k1ayNlEUWMCT5p8hcZE4yNzj7
bZP8+BjHDzm+y4nxBckZds7sW6xd6AyBh1Y/reGy8IKwO+G5+OjGjuPQrOfD
A8OL49w9PDA2BWc0fB/iHYGxLyAeHfyZgfE9hb+pMwOfrPishv1o4SPs7IZt
qMEB4ysJOuO8huWJ38J3a9iOnvjcwPAht807vpw0bEtJpyw29ewf5wuetWDc
ualz2/QVZekvfmPzwnfYPN+CNf9/Wf+xTzkkfcKesGP2D2iBHbJf4DMNv9vw
KCi3f8rin4V7qLEbw/6CNOwLuJ+a+0ShXfEbyP3x8Gcod0DKHsveojDs/6VR
B3wNylM3NC71HJvn7Js6586746Mbfgltg2dCnZsoTMVzFTZt2H87aRvmHTmT
ccb7O++3Y96RMUcfsSZzZzR5Bu6SXj8wZYA5J3L+4xzIWZdnbprn8rxN8l0I
vB/fijZulHZCO9AeaA/8slLPnGnjRsGfnbHE+GGsMcbwc8UdYac37C8UHgH3
UcFD+Lvg8cfYg486KuOfsT8q4x9f0/hex2/2KQ2Xpf4rG/4NTF3AdyfPyYFX
Lvh78Y7wf7mDDb70dQ3fN4fvuxEN42kbeY9N/k0CD0sgbeqC726jDH5ouJuY
++y4XwX7/eMavqv6Xq1Dl7fsC3NJ0fyvN+wn+AbR+9t2rbe7g/Crtuy/c2fB
67TsK3QHVbBd2zz4VxS/0LYsdV2lf9yyvgE+rNZN/5+g+PiG95rjAnMnEfFx
wQOTjzuJePdr0272khOSB9qRPoHeO6hhf/TYXB+e96XfsNXi/bFZw4b60tRJ
/ZfmuRcovrDhdZJ7kC9q+J4UbICBdUTqf85l6X98v1+RPuTbXdn4b026cuD7
Nlwvc2fp1D9b6rs49eM7nbq4JxsdI+rnnXgf6ofeI748MO90WN4LGoV6aCP3
tVzSMI67Do9qWI6MHxPuT8R/1O0N3zM6cOc6MX6rWJuHZ75QjvLQn+MEpp6R
qfOY1EOdtTz/krwLbTs9Y+zCvPts2Y/YJ7ZOHSNTJz7dgVnTRiUP8+gczu4t
6yY9nr0Emz7uHeAbcxcAz78lbeB73xz8jYpvaPgehF8KhqcoeNxcn3Fyb8P5
sc1kL+EOdGy3Kc9dA9xxTR7ut+b3cwrPpp5PFV7OeCAf926ryn4/Ufc1nM4z
accHBd/zcWPa82jDz9oz7WE8D9xZdG3G1U15LjamxPcOtDMw6dgQ3hP83Q3f
N9/OuL0rbXum4TTurH8y+chza8YA/cYzr8tzr0p/Ml5mKPh9Z8zYuz7jnHe9
L+/LPbXUxX0IJ6Ue3ok7059Mfp75TNr3dGDa86DiBxqej9iWAv+UmDTuUn8o
MHkYTw8Fxr4Q+8TFEz+S/rw6MOnMJe4P4O4A+pt+vzr98dhAn6St5H0keagH
X/qUxUfE48kDjK0yZelL7ITx88i4WzLt2DPfnz7iPvEXM26GFDwOnsv44b7x
pzLGGCtPpz0DfcS3+0jh+cZ/5V7M+GOev9TwXSSMwZeS//L0+b35Rk+lDfQf
/YYOA+VfyDelzufTthdSPzB3V7wQmPF2Z8bYERkzfHPmHfMfHHTaHnl3+gH4
GMG7Kd69YR8v/enB4+d6r4bpOsbaVRmHj+bb8Y3W17xvtn3WXK5r/iNnOuYn
6Z8o/+kiTBbo2LaAuqmTe8AXUt7JutZlmFp5Nm1Zz2gZwYe17It3AsHjte3H
d3/BU3ds67BX2knb0P3lHbj7ZsDHd79v3qppI+gi1iHWI+z42HMOCoyPlAMz
R+DZwPOBd0Jd+NDBfw7+cHZN/7A2Uj/rHrjdgp89ZeEz4Eu6vz+Lxu0cPDpX
0OsDtDowNPmCycPz0RE5OG07WX1zfNe2EHvpJU5v26ZkjPbxIS3fFXC00o/o
2uZhDnjDLdvBLKa42ra+f0PxQi3ray2r+Oye9UoZc680/lsjgU8R/FrDv4Fv
y/ipZW7ekfEzRs+6q207yDOCZ23mHpwxjf/W0TGZF9yRcWvqOUbljmxbTv6u
6tm6YxuOM+F/96w3zFx5NXOH+LW05+XApK+lfhi/bZ9A8Fm/bJrX+n3KkH9D
5Zm9bbucZ5W+Scd2JH3CXdSxrd1yit9q2wb3Kz1/tZ51vidXX03ZtL7f/5Tn
nbb9343qWU6AjOBS4Zdo285vLrXh9aZlW5wF+8+E7LnKu2fL9yhsq/Ys37Jv
de793D7nOeId6pbFwBfs5+nV7f+ImDtesAncKbhd65bTI6NHfk1dnAeRP4NH
loLe0R5162gR85u7rbFn5e4fxthuwTPu0AFkjDI+9wqMfiD18TzkYjwfn+Dw
G2nnToH3rrsM+fHLyr2cmxXs+x4Yf67IytGd4C46YnQpBu6rg7fC/XTkXSFl
oee5sxj/kMSrBMafLL+hpbm3lbswoQ+5o557irlzgXfaLe9LfSumzmPzm3ZB
+/CMAV+PK6X+HfJd0AfYPn0LzH2aPIv7RM7Rd166YzuipuJWx/ajyJEuaJqH
caq+8zEt6wZwFoKWRvZ3hvL+1bKt7VaCP27bVhW51uCWZVvfK16ubbucTTSu
NmUiCH+K6r6obV+98GuRTyCbuLVj2RJypd1V9tKmeRuXKV6+YxvcmVXHLF3b
ZMGrWSZ8JO5Z4b4V1i38fQFj64ccF74/tCo8NGD4b9z7wf0f2Fwj70UGPJB3
s+ThjuhN0lf43uX3wLcaFjx5N09+7uHA5+BMibdJ/bRlq7SHu0bAkxddzy2C
H2g36zD+CbdOWd5v2bwj+lPoU3HHAbjlgj+wYP9f+P66tG79IXDE/B5U9Bp6
WWDua7m0/l858qFrhP+wiwOjK4TO0GPRWT27/t8dfPjm7UXvFPiGgvWH0VdG
Fw/fvJQh76i685EHn2/4I+YccErwfcGhz4ou63ypB/1Mnn9u3fbE2EIflHnB
/ADmLm94VwfWzb8Cd3Dw+Pxh7RoUfSt8eaP7hN4ecCPxicGjKwFPHn0J9Jq4
VwNdOOwlgdGVIw96FfDt+Q7oPKFHdG76inqwEaUOfJV1k4fvVkLG2rOeB3qr
vC8+AOkD+gjZK++GP018aXKPArLwLQqWv69Tt80Icnh+I5fHngXfQ9iqbJB1
4+CifW9uEJi7mrmzeUDWs27ghzKGWLcot1HyU98aqXO1jDfekXLrpSz+wYFp
Yztl0LnlnU7Ke72Yekinrfg5wk/RWRkf2D6cnXECjN0D+Dey1rL+4g/79MCs
e+hLj85YAkcavq7RoT6j/t/YPCN5aDvvwN0ga6Xf6EPatWbeETugtYJn7WcP
QI8CPUl0/tD3Yw8hDTrnMuTdLc/jc4hbuXtE8V09237s0vK6yZo5XPHSTfO8
R0C/NK0XcK3yntSyvclm0Axt39UwhP25ZTvHbQVv0bROx9Ja8ybt2G77IKUP
aUaXTHC9abqoT+mD27bFn0H1z9izDd42Krt40zLhTwXf0bVd6FJKX7JnPeV9
taef1vK9QRsq74cty2uOU7xU0+vMjsqzesv3Zqwk+M+W7YF6Sn+x5bVlF+E3
bvleqG0EL9nyvRw7CV6z5TtMthO8Qst3dGwveKWW75LaWfHQpu9U+VPturJn
nYvDhZ+paZ26w5X/kZZ9hy8v3Hst72vrCb9i0zKW1fV+a3Q9Z69RHUe2TJOU
FT/dth+FouB9OvbRMEp5l2v6TrCflf5Q274TplWeaVq+o2ak6n+h5ftgvtF4
u6TleVFVuSdbXq/eEn5o2zq3TyievmXdvBVU9oeGfdJfBp3bsv3HUsK/2fB9
TecLP0fLOk1bC79Ey3fRDFb7J+lZt3Ze4U7v2S7rBMWzt3z32JHK/0TLdlqT
qD0vtywvW7JrPQx0MJ7rWmaP3GlP5T80Y2x3wfu0fCfPhkrfqGsb9hVUbsWe
dfpWFW7VnvWYtlL+eVq+C+hk4eZsee+dVO97VMv9/7PasGfHvjCQMwxqW9Yw
s/AndS2D2FXpv7btI+FraN6O/W7MTZu7vldqPsXzd23v/IHybNexrf9qasPY
bd8lM4fqH9qz/epywv/csj3ZfU2PD8bGKcp7Qts6rtcKd0Pb9lR883/z3VcF
3/R9IH+pvvnbtoOeRfGELdONMwj+qWXdv8PRU+haNjVUz92/a1vAvxkXHfvF
OFbwBC2vtVfTnrbtzq9T3sO6thFcu2ndBfQWVlI8ddu07vsqNzLjdjfl7XXs
76FG3wg+Dbku56qu/R3cqHpWa/q+LHSFrmtaX2iU4i17ti+8RnVf1fb+sw76
FF37VpxK8ZRd711nKB6N7orw4yrvq037aLlT8B1tr7ffK/6hbV8pfyj+s20/
KOvzbTuWk/+otr/VtY33qpzhWl5Xb2pb34j97kfFr7XtD/cU5b1Lz5pbz9pS
8HZN+xl4R/Ut0rG/ge9Ux1wtz4UJ1ee7tb2f7668k3VsS32g0q/o2SZwXOXZ
tW29+sHKc2fL9mjvsd527NuFs9FqLZ+P5lS5uXpezxdjzexap+VLpR/d8noy
rfK/1rLt2mGq/+6W/cpMjh5Ly/LfXYXfuuX75DZQ/FnLcubNWl7rWeeHqe56
y7T8PcLd2LKOzxFq70Ft665PJdzULd/bxloyQ9aTX9X2WTr293CicCe1rbsx
UvVs1LON47/CH960Dt0pgtfv2Z72a+iQtv0AzaQ6PmjbTzf7zMkt7zXTq20z
dG1bPEzlfuhaD+d/0OQ920xO2fbexr62iHAL92yHjc8hdKLQMX5C9T/ZsT1E
RX1yZsd+ZP5R3gXb9jcwv+ALO7bXP0Xx3z37ppmv7XnIHDxf+GLbusH/Clfs
sz7uBcLX2ranY138PWvjasK1+nxPz+qCr+kYZn8ep8979ERq+/Zt61Wuo7jT
57tPCopHdXwmnUjwxH229xiPc3qf7TQ6yt9r+yx7DutWx3bQZzNHm9bFLSnv
Im3rDlcF1/usp9tgT2xbn5fz9Ns5U0+EzlrP90jt0fJ5G/y56Lv1bDe7f8v0
B7THzYzxnm1HoUfeDU3ykepet2M/19Amc2Y8/w4fos/+TcZG16/rO686ir9B
d7BkHkC5z3yAV1THn03reNf6/G68V0/5uwrfVi1veSkylxf1nL+S/2XB2zRt
A36h4HFb1i+9QPBFPeuf3gFDq2tfUeuqjus77v+rFb/c9P1Kf6jcOD37OoKu
mbdn2uZg5fm+Zz9KRwu+u206bU7Fv/Z8B9XvKvtFz/6MphX+pI7vxzpW8aCm
7fs4v47f8xl2QsUjO/YBM5nyf9ezf6OdmB9tny8mVz/s0fa9OoyRtZoeJ0XF
P/Xsy+wE4b9qWU9+JvTglP/BsvUlB0dnchLFR3bsh4az7Nwdn2enUd4fe27n
Z6rz2o7vhvpUuBFd62D8IviUnu97WwQ6rWf7ROJFm4avUrkrO/a19BtzqGv/
mT21f6w+2zJ9C93Rtu3nVSrX7rPPrz7F7zds63SF6ri1aV+4H+md9uj5Hrt3
Fc/QtN+GtwV3mvbtAL35TmhO1uDPsg6j3/pGyzqubwn3Zs939/3Q837JXvkG
/d3zXXzs5+9lT0c38Mau9QOhNR4LvcE+MDh00YZqZ6lr/2LL6J1O7LM/rYXZ
9/us+39Xy+s1a/WHyv9G2z7toLWhh6CFPhD+n7b9fO7dMm0EXTRI+E879ls3
q9KP77NtxDDBo/rsv2p9waf2+d6s51umF6EVJxD+2D777J+Jtbpn/b1tWt4n
2CMeb5mGg357uGUaF/r2SsZb1z5uJhF8R8f2a38p/rBtP3AbtUxzQ2+PapmO
h4Z/VemDO77n5mfFPyl8BP1Af/fZH8rdqvv2Ptu7rw7902d/KPMq73199g90
j+JHu9bTZx9AL5O9gH1jho73jila5ufCyx2seNI+29FVlP5Zx3ekvKn8S3V8
V8qX9H3HfgmvVNmD+nxf1g2CD+7zXXlbqj039dm/zBbKf1qffYBBLyzUMc3w
ieJyx74Er1Z6uemz+ZWKb+2zrxlohEtCJ9ymvr+15ztR72AO9Xzf6Uqq45Ge
feE9r/ilnnV7OSfdmbPSOIq3b/lexPEFj9e1r6CrGT893/F4BP3Ws1+2BxQ/
3Ivdv+KJWz7nHtWx/g308BmMhdBFi3DG6fkuTcbI2Bkn0Phnd03nD22Z5mb8
/8tYVfgcGkC4vp5l3C296+ie7w0uqtzDTfvcW1plZ+n5/sxvBJ/Z8x2W6H3v
E3pshHCP9+xv4gj6oGf7Bs5hV+csdpXi8VvWdYc+5XwFjXqd4ut79qFwI2u8
whjB72kt2bLjuxt24EzWtR+oMUof3bS/InSxt+1ZL/Ex9v+W7SGGsEc17J8J
QeKMXa+l03Wtpw4j/gXlf7BlO6RphZ+ma/9c9wh/VtP+Np7gXbrmaT/LGtOz
D4Vn+A4938t6Wcu6COghQPt82TP9c5XG0TV95vusqHjvtn3jncr5pWX7I/a3
XbPH0TdHpH/GYzy3bB/2FnRc03cQf9AzzQS9xLo4e/T/2evGzX53nuqfq2Nf
a5znJm36TAeNOVnTdCZ06DRN06Ibd712sG5U2Mfbvi+zrnjDlnUeH1V8fdf8
Rs4lx+dscj5ntJbvK92Ad2z63raXhBur5fufX2cvbvkeZvbMCbJvcvadLOff
1dmLevZB81vXuunopQ9RnWM6toP/vO0zD+ed8xWf17Le4E4qt3PPvlQuFv7Z
ju1NzhP8TMd50Em/tW299Lna3u/Z6zmLn53z+L9d69+je89Z/O2Gz+PwXZ5t
mffShn5vWQebfX7ytvf6zfWcLTr2pcdYmynjbbue13TWc/gcfU3zOg5V+vCu
fYQ9J3ynZd3tT/XMibr2McfadkXL6xu06oIt06vLtr2XsI/s3fP+yt4K32Wj
pnkvj8MT6NrP3EqKr2v5nmP2n9lS9ibhHmz6ruLbBG/SNB/vY84uXd/nORF9
1fRdsnM3TTfTBuip+UJTPQjN3PSZ+gClH9ixz8oN2z6fcDZBtjlW2/LNSRTv
17IeYAV6rW25ybtd2xVgU7CO6l63Zz9BnL0mbvr8tUjXtgTYEdyveOGm+ed8
q2Va/l6ns1937O/yDMEfNMwDRK/nqK51ezhjfZpz1heKP2/Zz+UnitdrWacY
+eGpPfO/OYdtl7MYa/ZeWbfvVzxJy3fxftvy+sjayL49Ydt7N/Lhd5qWEbfb
XmdZY2/jfNmzb69llf+rhvkD83ZNc0BvLCD4npbveIa+gx6FxmOvu77l/e5O
vet+bet8llhL27YBRwZybdtykIWUv9lne0LomoXapm2QQx7VtiwSmu6Pnuk6
5Ipzty1b5Nz/T9dnf2j8xdum87HvWaxtG5+v2Ddb5u/+Bj3QsU3c85zhmpFZ
wctp2obgReFfaFo2wnmLsxbnrEeEf7Rj/1Frt03L9t9xqviBluvkvAXdD83/
jvrsp7b9EUNDbdA2HXWw2nZI1376qG+/1Al9t3TbNN4I4Q7v2F/qNPRtz2fn
kznztexzdw3qbtu2G3ptk7Zptq0Vb6WAfzj4r5vnbL6Z4E3btkOF7tiybdqD
dYg1i7Xouo77i75aV3lGtH036vTQmG3zmsA91DH+MWS2bd/pehw0Ydv+R6dT
/mn6bBO/v3B3dSy/wGYLOxlsZMZu+tzCmeVeaIyOfZtW2Svb9km6puJxmz4H
sXZe0vT6eazqOaZr/3PnKs/RTd+/it1Vo2nbq7OFn73P/gtuZ43qM/0PvXl2
0zTnpcI917bvwKfos5bvg7xE+Gfa9mPE+Y9zI2fAYwVv3LP/ign6LPND3ncx
465hWcn5wl/G2lRxey9uuc2XqY7LO/a9d47yjG7bdyN983zT/bNf03OG+bIJ
Z+WefZZNB03XsQ/OQX0+83DeeZGzYcNygbE7pumh5y+Cvm3bz+uD7OlN25qv
oD5bvmvfWvcLv0DTvjoZ72NaHvPwXS7pmPcyDF5u03zjGQSv3LRPkRkFn9i2
r0HG9U0dj23mFvOBuYAO49h91mP8CLqmY5+vNyOPbdvv6Y3Qe03bfy0GD6Pt
O0Gf61iPAR2Gi4V/rG2fkfTT7S331SLC39f2PabM47Nansu/q+wxTftOeFD9
dlXLfqfYc2bPvnO9yl7bZzuHVYRbuWt/1fAju+FJsjaPaXt9rnZM90Pz/6K6
r+rafnaDjs9pnNHgf1/QNg98DuGGduwLGx4hNDH0MOVWTFnOJd93fTa5QvGj
Tdvofau8PzTti5Mz4oI5J3aE7/bsPxEe2+iW+Wzshxs0vSfC+7w2/M8vO5Z/
I/u+vO1xyZhkvNzY9pi5WHkv6dr/5heq49Ku7aAbKlfv2C8v82naPs+pz9gX
Or63ifH+Sdtjfm1kE03fuQ3/YOa2eQhfNnxW55y+ZtP0JbTl1cp/Tde+ZZnf
8DuY45voOW83PT4/Eu7jjn0Hc+55o+uzz5iuaVDoz47S2x37S/6q7TMY569V
hFu1Y1+83wn3bds+jG9r+vzP2R9ewuld8xOOVHxe175J0dkZ2bXezmmKd+r4
bu9bBd/WtY/Rj5rm6cPPv7NpPi883i8Vf9W1L06+J7aXfFN4z+t1zH9+o2l+
NDD2hYuFH3sCdFnXvlX5DgvnW4D7qWE8Z8HHuj4PPtK1bSp2qdBQp3ZNR2Ev
+F7btOgDPKdpexP4+vd3zdtHznZdn2Vt8ICRLcEHbqlsu2c/nt83bV+KfSi6
Tid2re90qvDnt2wzch9n5659yHHmvqfrc/d6TT+b506u996jaZ/N8FeW7ZjH
Ak9x2vDfkOMt3bMsjzP6PB2f0/9o2g4WPYr5hZuvY1+5Gwu/Vs++CpZTvGzP
PisXZXw1zadaQvDiHfvxXVLxwU3zWuH9V7vm/z/VtT0ttrQLKs8ZTct5p2z5
/MnZcxnhz23aXx7yotW6lhmtInjlnn1W7guvpmU/0NBET3dNF8HjX7hjPv9a
im9v2k/24j3zueBrrd0x37Dfv7zwG/bsU/KBpnk38G3WVLxGxz6PV4fH0LGP
3o0VP9G03/Fhgp9p2rf0fH3mf8H7ukbx/h3r27yn+P2OfXNfBI3Tsc7RRoof
b9rXNXT3+h3T3pyz9+r4rP2ZxuBsHetN0cfwBOln6j4o9cNjY69lny0yfxv2
4763+uOWPtsdIUs5vml5CmfBE5u5E1V5DujaXz778wod79F8k6vb/i77Kn2/
rn0ZI2f7pW1Z22+ciTq+33sJPWenrv2w8c3hs/Pd/4b+ats3+UFNywM4C99M
27r2fYlu/s5N6+dv3/F6wVrxbdM8ZfjJWyneumuf0bz3im2/+w4t81PgpXCm
PLTjc+X2wm3XtT/jPYTbXeGiqvlAr3TNC0L2tWnH8q9t/6+l82eNIgjjsBDI
7cw7s2sTRFGJiSFB4mEgIYWFCBaCaBGSD2AnIqIiWFmKoGinhUHxY9iJjWDl
H5IPYBlBEBQxqZyH54rlltvjbmH3dn7v7/nNO1yjZH9x6p4zxdonM25X+4/j
be+H5/OuWuNR35FFehnmka7zf+rtQzqq5vnI8uEZrE58Azzju1kNBot+EvLo
352+AJ7AqH1H19v3dCs7V4F5CuP2m4+T/dRhpLBqOOlilgHDf9eybBWuCv9Z
mOjYI+iFzjV5/3Vyd5j7+aTuRFv+7GSfcE/4JHUINQj34KPwPnyBhhpcr/tE
dq4F8yw+hhoI/bPAMyPZD36c5dYwa1jTcpE3XcuT+RhT6iPGIcagi1luDbM+
VhzDGL8+hxoRfTjfXufa9qd9/lenv4m3+SCZcSTf+CnUMWgYtOrsoF5db/vf
e3tDfQ31KFoU/fI21DCXs9lEcolkJW4l8xKznHtyHYCT7fi9sNfXattfG+wF
djWbRSCHcCmbXSC3sM71aduhkbkAdB4a737IA2ABV7KZBvIMcGZqAPT/6fb6
MOydfBj9nuyrzfW8U72m6LJvRW12m+fH4NoSqX3ns94+GU/b+xcG1zbAY3je
6zPMU58l+/rP9PqPeI+b2bwFWQv48JsqI35d9YPwgvAjd0NPkvF8Ojmmk/vb
DrN/H0Ktic5Eb+4U99+HmpJzfhVqdPT5IvVrdQ44NeJ2tU78kuTNaC203sFE
78Gcx1XuvJHNl5AtmWvHTxX738OxVwZZ9kroT+FN7bXjP4prIZxt7y237WBa
D4N8AD4G9dZ4sOZaKnqR+JDH2/7N5LoNMNK/RU5KNvZoMR97I8mxYFhLyZwu
dfQM9VlyrYZzjC3J9Rb+A+R3jH8=
            "]], 
           PolygonBox[CompressedData["
1:eJwtm3m8VWMXx8+955597x5vITKXCsUrISSpUFIJUaSSEqJR8yAJZSpDhmgy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            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl2Xf8l9Mbx/FPpbQzSpLRHmSUMkvaZaVpNaiItCSjkGiTFlJRaBkJCQnZ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          "]]}}}], 
     GraphicsComplexBox[CompressedData["
1:eJxkXXdcT9//t0eyN5FCkoRs0iERycome2WFULI3mRklO5Ud7STp1X6P1vut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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.922526, 0.385626, 0.209179]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNnQWUHUW3ha/19cHdCe4J7hqc4MGCa5Dg7hAguASCQxKCw4+7u+vDXYK7
u7z9Ze9ZYa2pqdPVp6uqq0uO35m33WP93SulUmmqCUulqvLX6qXSceVS6Vil
o5S416M0QckwOBMmrylNlLxQOrlRKp2kpL/SGfo3VM8frfSAkKdV+kjwxMFV
M6X9y657eqXTVclmut5U6VNdf6I0QuljpY7StEo36t4NSv9T2k31364O3aa0
peCHdP9BpWd1by2lpZRWUvnj6fvlur5MaYTSZ3rmKZVNonSOcM5WGqLyq5Wu
UrpQ6RSlk5V2VrpefV9V+SrUUfI7zKw0Ou8/k9JbSndSn9KxepeLMk4bqu7h
em4awVtSf97lPfXhHaV9BZ+v/AvdO1DpEb6F0txKjyk9qjRQaTLV87YGbQ7h
ttWfRZVPn/HlO3WFc4Ha/Z/y2ZRe1P3ZlfdV+kbpa6XP6J/Kz1baVPBI1XlO
2W1to3wr5bMqXa37VykdKPg8lZ+rtKvSqcI/QmlhlW+v6+1S/wtK/ZQWV9pL
94/UvSOUDldaSGVLKb2svveozrNUdrFwLlR6V+XPq+wepY1VfoDK9ld6X+XP
qOw0la0h+CiVfaj8VaX+SsspLa+0j+7vrbSC4I/07jtpXDZXepnvq3QT36js
9sEZI/gSpUOVPtH9jyuubxs9u7XSmYIXUj8XVJpfOKur3X+Vn8F8EO7iyhdT
2ke4eyvtybfX9T/K31T6QDjvK60q+CrVsZ1w5q153UyQdUTb9H+JktfKxFkL
rJ0HMyfPynxeT+lIPXyE0l6CL1E+WmmjrKGJM/9GqGwXpe2YE3r/z9XG25mr
MwWHdcN6m67kNTF9+tO/4XXCfD2+5rk7OuuPtce8ZU2yFqcuee1NmzX5VNbB
uPWgl7hM7R9X8bo5J/OQNbFByXPxC/XtD937vex5zVyfq+R1yRqZp+T1x5pj
HrIuWYuzlLxu587aYP2yXvsIPlrtHqX0sa4XVN9f072TWO8Vz+n/ZV2wHhYQ
fLDq3KrstTiw4fXJmuzdyybMOumbPvfud3y/YexpSu8J/ks3/lQ6hXdoeD2w
DnZSOzsqbV/yWmHusQbGCL6k4TXHemLdsY5618mSJc/l/pnbzFPm7vKZ9ytk
HQ1mXikdXPE8An8l5rDKBintr/Lz1cZ5Da9X1vquWYdT63rfstfNQYJ3UppW
9w+uee7uXPKaW1P56krPVrwOdxH8kPIHlW7lHYW/qtIWZc93cFcpeU3dWPL8
H6H7ZylNUPY6WyX9vF7X1ymtI3hD3d+g5nNiWqV/Vfaw0qWCLyp7/p+r+8cI
/kLwKOVnKw1gfEqep8zvtfUeA9jr6/6Go/PN3tEieZ+1re80SvlBnBtK0wt3
OqUlBb8rnLV0fwzzRflqSqso9av4/tuqZ4jg3ZSeE3y46jlM6SveWXVMKpyR
7D+6P1bpbb6LymdSmkfwsUoHCGcQ80Dw0oKfELyy2jhX1ycKXl/1Tar0t+6d
X/bezPeaTPCYvOsHur+/nllD6VU990rF+/X3uq4J3la4cymfXKmjtANzUGko
6099mUSpqevlle8h3N2Vtub76v7TSouxNpkr1KF7V7CGlHYW/hS6vkbwfRrf
e5Wm1PVLwvu/is+An/TsxLTJeST8M5Vvq/JTlR+mtE3J4/V59oJFhf+L8AdX
/C6cM6zx6wT/T+k1wR8qf6PkOXmo3v0Q9ibBv6i+p1knrA/V85zwzlP5nsr3
UHpZ8I36pjco9XCm6rkDlI5Q+VDdP1rpdsEVvUdZaXbVsbjuL6Z0qsrf0P3X
lR5QWltlA5SurPr6dM5B5rCe66vyBZSuFfx/Knux5Hm6Z/bGxVW+GOOlsnv0
/F7cU7pUZdMp/044M+j58yo+kyuCy0r3qPxa4W9d9j61nuBLdX941gXnwGRK
72ZuQT/Mozr31bNnsB5U9lPJ328G4f9c8je+T+V3V/zt28JtKd2n8gG6/qHk
OXyI4IPLnqPTKN2tsruU5lAfFtOzBecqZzJ7l9JUqmNKpT6cpxrvt5T2Fu48
Nc+PQ/Xs3yr7S+ll4dyhe5NWvAedxNyveF7Np/tL6JkVVT6j0q8lj+nFun8R
9I7ShMJ5VjgFeIKXUlpUaWZdT5JxnLFhuupoPXuHxuR2pd/Z0/i2Ne9z89e8
rx3JfqJ8ZMV0yckqP6nmtfQu+6vSEuzlDZ/3w4S/rPIheoc7WMeCl6p5z9pc
OLNyHqjvm6tslZrP6mNVxzFKi0I7cVZUPab9hN+3YbrhR+G+rvKzWEMNnx8n
q3xdla9T87raSvfuyrgsrLKFlNpln/nsH+wXizY8TtBee0Gb5F3/0Bj9rvSS
ymdQPT8o/0BprOAZoBeUZhPeURXTGtD+zCPm8e2Zd8y55fUeyyk9o/urKl9F
6UXB8ymfV6mf4GPYy5W2Vzpe18OUdiqbboB+gJb4R+3up7LBSmfWTOufrbRt
zXTYWex9ZefQY1uyPyvNWTU9AV3Bubxyw7TLxcx53ftMz3yq1FUdj+n6lqy5
C3R/ctpXHWcpzaGypXSvqTRM7zeB8HsYZ85h1XeY0rZ8c93fWGl9pR11f4ea
67pb7zpM8Kj0gXUzg9IjKn9Y6UfBXyq/h/FSncfV3MdefoAcWmIu1buy2p9F
6YSaaS/2+ff13Ht1rzfW8aU5414v+zzgGnoL2m6i7NHA0GFX5hr4xJrr5fzY
WXX1qZiWvSw41LlRw+tv3pJpuqvyjdYV7tW5Bgc6ies7NX7H6956Fe8rV6at
y7PfUOcbZZ8f3LtI73ih0vLQH6rjfMFP69krKqbPrgNHfbyhZPjK3Lu+5D2E
cmi2T1X2ZGiLC2vG7eVzyKEV5yz7XOKZZdROj9IJemZNjeULFe87X6j/nyv9
H/RPzWfDLew1zGWl31S+LrRJ2bwDOWcQ7UIzc25DN7+lut5Ueljp+IbLuX+X
ru9UGqD0m+q+V+nSqufsnZm3J5S9p96ZBMyZOJJ5UvOa2EzPXKs6phburcpv
gRZhz2Et6H7fsmltzgr2/5mF/2XZPORzwrle6Wqlayrm5e4VzgN67hrhvZP2
7067V7CuhHOzyvcXzn4109HQStDo0Oen6B23CH9ynPJjA49o+PohwVs1TLs9
lAQM/TYn9FvFZ+9xhdf5/Sr/NjhNcHSvVTF9com+w0cltz2m7mv44HLZ+cCs
H8Yb/uWKsvkIeAOeg17jukdt3a62qkonqm8nKD2p8q9V3+ZK+1XMaz2V9fR5
xXTQU0lPZ25/ofKNyr7eXc8NUdpGZQtXTM9R59wN8wAv5rln8izX8ATwxRsK
9/mSach+nBW6HqiE8GVI7vULPrzHBhXjPqs0WnWPUrogPATli5TMs76Y+hdU
nX/pmUHQKcI5TWk/pcE107OcjxuFPnpJaX29x3pKG6tsY+V7VUxD/SL4f0oN
vfM8Db8bZ/GRDfMh8CDk0GjwJNdXTLe9nnXCeoH+P7RinpjrOVXfDbo+TGmz
4PL8pqH1qA8ahLGcIc/wLLQf5wmyFdbQPHqPvnpmAfqs8o2U3lTZYxWPF/KE
ixqmQYGPUV4rm197JHMD/vFm4d6kNL/S4xU//17m3EfBPbDi/n1YMl1JvjTz
Vu+yvdJBeR78KcFvmEd4nzWZsQY+sew1zzt8WTIf83Fyrtsl89qfBubMBOa8
hF7+rDRejvNZ5sg3uTdH6vgkz44IzB6+QXBmzzVtTpv7X+YaedZX/8H9KnXS
ztdpq7ev0LSLhQ+jLc4hzquZgvtNnr0/vBzr+4GyZVS99OUP+b6PavweVPna
ZZ9TnJkzlnyG/JQ6T+CsKSzLeyLfqQq9oXxs2XjwBdB30PazC/cr3etk3kIr
LaZ0rto6R+lG3VsCXknp8IrXKGcY6/TrsmWTXL+ues6s+iy6U8/dRJtKX6ut
o1V+lNLCSt9WzGMtLvifrONTCq+HvzN//8kcZp+DTmQ/PKkwrf9XyTz1n8qH
KN0anoZnmtChNfM30JTsfex7/avmHbg+W/DgqvnIi6DBlC/CnFS+tPKleEeV
P610G+dF3fspfMcRyqsV8wePKa2Qs/NyBFFVn6Uzqp/zqQ+zCL5O5XOVvSf0
UXk/lc8s+EN4q6r553rNMpGC9VY2T8Dae15lq1fNly6AXK1u/uGJfKtFWdeq
8yHBsyqdB1+stITgJamvatp0Q+EsqDSr0k2sv7r5Huh32tlW9Syj66Whw0In
QS8xRz/UM+fkPDwotB4yjUVUtjw8F2ed7j0SOukRXS9bNm//kO43cr6+VTct
OKHgh5lHSoeFnkXOAR27rJ7/5z80EDn00aNl00Hw0rtqfu7SMC31ra5vCW23
mspWbZjG/DxrirUITcP3ge5ZSO1NpLRF6IJpcp4/C52Vc/SJsr957zokfzjr
j/XIPrtcxbQAz0NvLxyam7k1Xc7alYQzUcXfknMB3oyzYMWK5yuyT/Z1cuZ7
LfPiyJLPSeYX62yFitcY1/dqzAfl/KtlnrD3dmrmSxcoW246Z2i5laqeo1zX
NDbVhumIW1T/kjXz7svUzI/NK5wLde+CwjJQ5vxsZe/Py+q5R1R+csVzlXkN
f7pw6Cl44cOEf2jdPFJZ+CMEj1L7nwhn96p5v0VVtojSk4x73Xwm+wPyLug1
ZAsbNzyejOuiKl+kZtr3eHiHuuUXyCHYT9lLz6tZzsX1+TVfLx6YdbB2yetj
Eeal4Amq5sO5flzv9IKuT614vjJvx/EkDcu50INAn8LTQ7vupfb3VNpS+Ovr
/npKz9d9NiLv4nycDX5WaXPOQOWbNNzW82XzNKOEs7KeOaJmvcjowt9iJcGr
65mK0o/gwtNWPeaPKp9F6WfmWd3fbOWy5Sjw/che7q9bxsR+tGDDfHL/rBnW
DrzKH8K/SfXcoNRCptVwX8rQ9Sp7seqxXyPzmT4is+Osg/8m57x7QM9MWDP/
x1hxziBXn7Tqcwu5yGN183WcU+gU4AegcYZXTN9wfWbF1/AN65edwzucVfG9
9cr+/uunfGDV/AfX+6rd7ZRmF95JZdMKGyiNqfp6Q6UV9ewKNZfdHVq0j+o5
vWL5HddnVHyNDuUQaLaKZUdr6rk1apYlXa7xuUzpV8Enq64pq+4jMlXk+/Do
K9XMr3Pdv+ZrdHJnKN+8bPh3wVfr2auUvlZ9+yq/lzGI3AO8r6uWmQF/U/U1
suLFhb+acO5jntTMZyKHH5sc+oT+co/+r8i5UfX7rVxznwaxv9Qs70S+jx5g
94wJ15QjFz1KONvl+oeq5aRcr6jvebTu3VG2vBK5PXQCdDdw3+TcQ7a5Y2Bw
fq1a1kkZ8pgdU44sg3FrlTx2wNBiyCMGp/z4wJwRu5St40COt0LJcv/lS+Zl
eQf42bUa1kGCewm0gNLZNcuFkeejO7hM1+fUrE9BT4dsG34N/oxxgb/ZPWOE
fJV6aRe+Gf3e7ikn3yNjuIKefTPXDXhbjdergvdEbtxwv8iRrSBX+bZqXRPX
6Kl2yXuhpzo7+wm617Mzx5Dvon/gvcmRBa4seBrV+X6uGaf9MlZb1izL4Rp+
Dx0Wuk5k6vtnTyPnGt3WgYEpR5Z5YOADAiOHh86Hv4WmYswOyrgt0bAutlcG
enCeXbLhe8hHx9SsG+/VSZBDG6OLOTTfEf0Pcm90fOgcgdHvXFC2fB99zzXJ
4aeQkx/xHxzgBUvepw9JX/ZW+42K5XsjlS4uj9f7HpWxQbdydMpGBtbfuHxo
4OGqZ5qKr+nXoekn8pW98y2QCfKOnDvwDsPz7ShDPohssN2wHPG4zPdhvXO+
ZPjs5McHHhwYXHgheCLkH8g1gKdI2YmBkcOdGNw7sz9ukPsnBYe5fHLmMzLH
kzMnyU8JzDvtk/fiWx2b/vPup2bM0TGj90KPhYwfeK2UcY0+7IzAlKMrOCMw
ZcC7Zl3TLv1CB8K4zZvx4xr95lmBKUf+fVZgyoChY1krI7J24PlH5Fl06/R5
m5LnyJGZJ1eWLQdBp8jZiFyWc5l9Al3jwsE5N/Oc/LzA7CvnBRf98fmp8/DM
VfYb8gtSfkRg7qOjQz87acn6KGD2GPTXF6X86uBNlnnKvBXquHzkf+bnyMxn
+nZl3oX6rkqd15a9Znp1ouQrZM1dkrJrA/NNyccEPiwwuNiLoEeBF8PmhPMP
fSJjfFnGeXhg5jz55YHPDgwuMoIrMobnZPznTtmVKQd/VJ5lDC7NOOyc9wKG
1+Qsmj84V+e9e/eIJfOuwOwV5Nf+5x2vzZigU0U3z16EDhKY/RA7hetSfmPw
2B+wz2G/QA9L2fUp57kb8uz+gSknvzHwdYHBhf/jPD+u5He6Ou8FPwNfg/wZ
/gB+Ad72h4ppQK7hS+BT4I2fRXaue9/r+nv1+bSqdSbQMLerbL6S9Snw4/D8
/QWvpPQztGbVZ/ydZfP9nM2cy4dWrXfi+reqz++7y7bxgOeDD1wKPkLplbJp
DOSgnNdzNszPf1O2HI1vjMwNuhD6EF5q8cgxkF/Au0KjQ59vrucmrPoaXQT8
KPwhegF4S+h05NPwhNC2Bwr+rjKezyGH34OffbxsvmLqqscH3g4ZyxMZv4nU
1h018093hS9Bpn2w8A8KnwANTw5dDD/9mvL12dur1iuM0ymonrtqponhJ9Dz
wIPAa2JTBR8Bb/Fc2fzFXiqfrOpr6GR4g1El0/AvlC3Dh4aH10FvC70L3Qt9
/LnauLxq2rEunKJhuozvxPfaMXPnlcwf+vtq+nxv1fpUrv+EBxG8B++EXKBm
nQ22Zugh4L8x7Pi3av3QimrnrbLpm/sr1okCT1e1/Qj3kBOQb6lHm4Lv1/Pf
VU3fQOegA4JnhndGhn5V4bre1XVb8FU1z0d09chB4HGnbXgeQd/cWbUeFLij
8g/L489RcnRvd1etq+PeVPA54Ukur1m+wLsdorb+RpZetdzqo7zvjMzzyvj3
+Tjvu5rG6trCegvk/Z9mnjM26OS4XqPiNk8r+V0/z/tCN6FbgHa6QDhf5Zr0
ZcpfUV8eUbpQ9x+sul+9PD85fURmNzbzjXkzIHOJOYgchD3jubrlVt9nPH7I
mHyost3g3zg8NG4v6Pon5mXD9Bn85p5Vly1Dn9SXh+C5q9btorvGLmgoOOFR
B+m5zRq2SXqKtVP391xXZesoTaD0V9n09Zwl444Kvc3+xT4Gf3q4nvmH9w+P
+0vKf1H55CqfUm09WbWtQVnwl1XbQlH3V1VfY/sxifCfEv5kNcuNkCMhE11D
7XJoor9D1/1X+kP/kQ8ODH3CfeiQI6u2eeEevDlt7lbyWPHe+5fMF6Hrhlc6
RXVOkzH6tGp9Ie2t2fCzwPCga1VMd20ieFqlesVyuOkq1o8v1rAeGjp18Yav
0elMqnyqimHKkVEdXDL9gs4aumKfhvXfPDsZvLzqn05p+4btWcA7oWqd/QQV
y7q6qQe6CR0+tNMrdd/n+lV4/OBjS0A9Q0t+rpNnn67avoF3QVYB/iEqXw95
TsX2XR3153Fd/1J1Obr5SSrmVdArQlv+zn5Y8TV1T562fq4at9c+hhy+cq26
dZM8M3XNthTI2s5s2OYAGn1gzTZSwGsWvsZea3DDYw68TtVji80Ae8wUFe8t
L1dtD8S7rlu1/ny60NrQ3MgM30CmV/F6P0L1T1d4v5ytajsS5t5EamvChveO
qZRPqbR/3c++XrcNwT4Vy5MWyhxFhso8fId3rNhm9Yaa9fTsPchRkXmcCw1W
tb6U6zOqvgZ/05plsujH3xT+AUqzVnw+Uwd7F+89Z+YVOh30Qu8wB6q2oUEO
8mrV19hizay+z1sxPEfDsvh58xy6HOSEhzZsRzJ3xm6ufE/GA90De9gz6tvw
jC/P9k27e1csM8N27KbkyNWqaudt4b+l1D/P0NZHJbcLDjJv+C54rmOrrmvB
iscYm2zuVdSviwW/X7UcFxtgZLnbVi3/55o1vFj2ukmRDdY8v96r+juht1w0
Oc9up/Jl8gznCucLew9rfams99MK66G5Pr3wNTqGD+q2V1gm95YM/oC65/fi
FetemRfIINGfIHfm/JxM9z+rer9BF4GMmLPi5ZppRGTM6G3IoR85S5FHIy+e
vrAukLF8qebzhudvEfxc1XsDct/+GedW9gvWew3ZcNVtr1O3XctqFZ8pyC45
R1gTa2RdHF63XJhzZ7Oa5yV2G2cXntvoAmYprHdhzD6ous/flS3fY27Dt95c
2D5gbaWPVN/YusuQeyEHw9YCuwpgaF1yrrG7WD8w5V9WfA18V2GbDK6xqUYH
ir4YXTMwuhVyrtEZDwxMObqygYE3DIwOeu+6ZcRb8T2i6x4nZ6xYV4z+eDqV
b5LrDerWJXP9Yck6U/S5H9et6900CRhd76DAK5Zs70296KMp4x664dlVflRh
HUe/rClk08ilKYMWZU6x5yAbGY2cXmkoOn/mqtIxStNGv00bX6d+2kVmyjuh
q/+3Yt0d7z6j8Let+J33qFvfzzV2lPDGnFPwwsDYXF2Ue5SPCLx1yfkOgf8O
zFmwfcmyIeQt8KTA26Rsp8CDA4P7fcXXwDsFZp9n/+WMvq1kHfjeGaet03d0
Lthx7pI+/F7xNfAugbEbY06gs4av2bJu22Gud6n7utcuYUjmD3QA7Y6jM+rG
2z1zAh05+vEN67ZN5npg3dfYFayXHNyN6r6HzcEPhb/13hnjXTK2P0PfoSvR
vfPzbdm/Nq37u6Jj36zua2w5vmHOck7kHXiX99kb67aNphy76QMzTwelDnBm
rdt+HXuwT+qeu+Ah48dmYZwtQt2214dULPfnHnYKhwVvtZL1yocF3jG4jMWn
ddd7UMbl4PRhrrptI3huar3fG+iZapajYosHv3NpYGzwphLO67q/W81lRwXn
s7r9E9ApYQN9RMp5Bhh+HNsi7qNvqlbdJv38Qvif122jg4wUm1J4f+z4gaHt
GZfjAmOXhC0Pei6eo+2hwQUHeyT0pcOCzznDd2O9nli3TRZ6z78En6TUrVof
Sjm88NIN+4r02oaSIx9bpuF72I1iU3ZS7lOOfgmaDR0Y47BHye8KjE6NnHvw
s6cFBmeSqq+BnyisS+ManxT0KewT66W/7MP71L0ncm+KqvUSG2cuDM94kp8Z
GFszYHhe8rNSzhwfkfXIveGZU/tVjYPOaPvgsCb2rbtt2kMHgE0/9D/5OYGx
92dtsQbPTTnraMaa7YzPzTXPINM7sTS+7BlsawufTdcUtiHDfgz5N/Jw+D/4
Ong/eAf4pwsDXxD4q/SZPXFo9saLA5+fZ+EXN6laD49NWjv47J/oC7CZRRZ3
mt715Pp4Wp8ceh6bffCQiyJbGx187mEHsG3JtBrtUjd1YC/PvTGpHx3fBlXb
dyCjmL1m+9dLM38vyxzuU7ftJ9fom7BXREZHfkXg4VmfrLMtarb9pZ3rgoc+
BxuWMWkXO3f0LrOUbIcPvGXKrg6MXTYwuLRzZdrC7v6K1M2+g308dlbgXpNn
8aO6N3MSXw90LYNLzq8LzPkKzFmMrxT2Kq9nH0OXz173Wp5ZgT2qZhu+a1PH
9akHWg/7A/gIaFjoXehY7LGAoYfJbw68QGBwj6naHue3kvMbAiPnoh32Fuxs
qB8BMecAtBO0FDLU2zLm5LcHHtKwXTbXuwseWfU1z6A/gAbDXptnkP1Cr0LT
LplnwOV73pJy2mU80bkeULI+DLhPyWN8T8rvDsxeQTv0E73tSbkG5v14T+hY
dLD35ll4b+TmyLeRRd2fcnQK+Bugd8DnBhh+CnvTBwOTYz+E7RD+TzyLnIe9
6fnMgTeCDw50IHZu0HvjbFxSz1uBJyk7fzQwfB5wn9RB2/j+YCf7UOBHUk49
+EZRP3Z3+FvgN4ReZfuqbX2w3UIXg56pf8n+ecDwztgEPxWYnGt05dh8PZE+
42fANbYiTwYfXTxtPh4c2sS2H73Mc4Gx88G++7nAlAEfWbJ+55ngv5B26QPj
yPfYI3Pg+XxfvvV9+Ub4vuBThr6YnGtslbfLvb7JX0o5/X05fZ49z6C3Wrhh
22jax58MfOrgm7+eOcAcwU+GfeO1wMwd/BVeC0wZMPsG+oNXgs+58nLGE9nE
C3lH6n4jcwM/VPwmNitZPvjWf+bDW/nGyPrRK0wbfGDoBPye3smz2EK9mWd5
5s3Mk3eDM13m7RuZ0/i70C77LXsZvmSrlKyHez/zh/yDwNAY76aedwLzLPs0
ct97si+CT334Qm5UtRwTG4OP0s93Ar+duYh/2kolt/1xnsXm/JPcx2dwbJ6F
dsZP6sTgfhJ85ge2wn1K1rfjo4j+nRzbYmyKvwgMDjnX8CDU8WnmxpOB+wfn
s+AP1L7Rt2r+DxkeZzDnb6Vq3mbFku3Yv6nYphCeAxvFrUvWJ6BfwK5mmsJy
Snhs7O++ytrZqLBdMtfwr9xHxonuhTbhN/FTQd+CvgpeBB8u+JGhdfthIndG
FvJbxXv+qzXLhekr+gr0F7dlHo3NXOpUzZ/QT2TYyO6RY+9WN4+BbSX2YvBp
8CJXqGw+XWOnCF1drvrdsWeBroW+wt4QvgvaA54Pu2jOOHArwV+6aj/q6SPD
hmaFXp2zsH8I17PVzRs0I39vBR+6Gz0KNPbcddPx2JXCQ/+ZfjL2vBvvtV/d
NBy2LMtWbb+FPRX6oQkDw9eia4G3hZ5FFglNeyk2ilXTqrsU1uvw/K3oqqrW
I31X933oWOhoyqCl0bFAp3IWQFdOmfHBxmmqvBPyePRAvTJ5dDrI5VeoGg+Y
9cS6wpa1v/pwX83fiW+AfR46K/QG6CyQ2aNPQQ8xTgch3Bv/I/sjR9eAnL9P
1TZ7b9Ys258h3xmbWvhKaEp8G6AbkV0iw0TmiVwcGSXySeTTyNXhTd+tWZ6F
PBcZNTnysLdrlonjo4XMHhl9r3yeMuT/yBjxyUHeyHrCnp658x42NtXx8jVy
eJor4SsLz0XkPsh/oClYK6xTZDLIn5BTQftsLdytIrdCbrZA1T5cyB/nrlom
eVth+07mAvMXO2PWMWt3karXLzIB/CdZf6zVfpl3/6dnT8waRmfF3ocOh7WF
byf71gOFv81bmctLZz6/Ung+4TcDX0bOPJow85X5yfxiHsIfsTZYI/B48KPY
6bImHits88f87VOzbx6+B/jgYruMbelMNfMk2C0PqDpnL121atx9Sp6z2H7B
7zAfV8g8ZH1jww3vunPVz4APjb5+9n9ofWh+9G7Q5NgmH6fytdMebbF/rx0Y
Xz/k48yvv+GjkVlXLb9nH2EPYZ9Dzs5eN0vN74af8IZV8xLwEW8Uth3nGv3n
hinfrLDNH/rPXar254TOnKNm3mO9rF/48LrgTavmkeCP8NH7qGoZ+9w10+L4
Bu1adQ69/Gf2R/acLaqm6dnr2PO2CIx+eNPUuaz682DN+kloefCxV59B5cOq
Xj/ojbbO92KMt8m3Yb/cNutgjuAiN561Zl07forYCG9ZtR7+45rLgHeomhaE
DpxSbX2qe8vV3P5O6QNzY3C+KfnOgbG93SXjtpCeHVvzGDCndqzaXhk59w6p
H535rhkf6Efa5azDfnf31HNC3fa4e+Q77p1vCW2OXpo9E55gSPDZm9ij0EcO
hxev2z6BubZ/5hv6YGxMsS+dQv28uebvhu4dXTw2qZ/hI1Abv4+Tc59xYgzR
gU8unOtqniPsr9gHcIYzjw6pWo/+VNU8EnzKGurL6nXbo6N7RCeO3v179A7F
+L3vyHxbdKLQatBp/8O+Im2zVg7IeoEPon5k9SdWrXuDFz+vbp8KeLg3qs7h
3Y6rWm+BzuLHwnK9YzNHmFfoCI5EJlt4DX1Wsy4WWua5mp9fMG0enXZPr1sW
QNvI5k8KPnISbFg50/gOxGdh3B+u2S6f90NWf3zekbFB/8074wPHd+NboSP6
X9X2sbNH1jhO/1T3Nfqol6rO0Umh7xmevQG+HNsdeHNis/AcOix4CGy9obd/
rduvF7x3q/ZtwJ6bM4QzBX8NrtH9oPcZXnjNc31m4evz8jz1QHeNCPxLyfsZ
fiDsoVurDxdU3fYlVfuO4BeP3TTyMmRlyGDOD93Yt257eO59WLWvJricgRdX
rePYtbD9OvW+U3V+M3tsYV9oeOxRha+xk78tbdPu7oX9WLjGBxL75V6+GBg9
EXwY/TyyZJtw6jte8Jl1rzFsgC7L8zy7V2G/SsqwP8bGePeS7YyBsU/GZ597
2AmTXx14ucJ2RXx/1vflWePoYS5L/dh0XJO5cWPVNuYnlDxHrss8oez6lJ8S
GJvy64OP3R26Q+YWNsz1up/nGltu3mUg7dTcBvWgr8UmBH0ytBt0HbZBt1Zt
+3p+yfavwNgR3VnzPcqx2bktY76C3vGe2nj7+JvSn70L+0XzzPKFbehp+66q
7VHG2d2qfKKar9Eh35Xyr2q2R4G+4z56bvrKfsG+gb3O2MI+NpxbE9dsE4yN
zn1V2+tgq4OtCnGgoPEPhY4txuvtyLERadW9hrHb6Ai+rvB65t79eRa/v7ey
V3xSNS5ztajbxgJ6kHF6LGP1eODZy865fjjlTwSG14En+jl7I22yV2DT8WjK
0TM/U7Uu8bWq9crQbMiSsZdCtvxD3f4HLyQBY0dF/n+BiQ2CPpo58kPN/lHs
J+gn0V2icya4z8uB/63Zt6cVOvG1tMse8Hr2BMYDuVuvzA0YfVAP8vW6+0rO
XKTt/Qt/J77N8xlPnsVGHju6g0rWjbJnsT+tJ/yfar7G1wxdMjTwBXXrZrie
qG7dLfrPeYX/c817Brrgd7JvXFj3M+iv0fuig0WHBY3zcdV0DnvPJ/mmxOcA
r1fv9Gnw2R/ZJ9GJT1z381zzHm9nblD358HHfos5uTcygZrtbTYpOf8q8GM1
w9jhEN8Gn4VeXwZ8GNhn1s+z2N+QsOH5PXvP18Ghfmx+uHdlzW3TLu0DQ5Nj
a/N9xhmfBGDsce5JP7E1u63mdvGbwA6fe8QPIZYD34jn2D+RbbH28UvA1gT7
kl8CH6byq2u+BqYMGHsUYnJgD4mtHYnnsU/Bhw//qENT56959u+q72EPwx7w
R9W2K8SoQG61XcmyK2Ce/TP4wOwXPIP8ifp+S51/pPxwzuKa26B+7Pjw24ae
x24PGzV4xq1qhtn3yLFVAX66Zhhc5EnIlY4u+Rls2wbnWXwJuKZecJAd0Ufa
xW+xknbxzeRcwp+Ns4mYI8B/lJxzjZ8buJXa+PoqaZdx/inv2Kh5PKmf7/Zj
vjt+9sj6kdchwweGPidvB14rML5p7F3s4exjnKmcrb19bKZv4HbyLOPKfs3Y
MkcmyDxZPjC2r/Pja1gb7wc1YXC4xzPIS29Nu7dkXvA++M7dmfr5tthkIJ9F
NoufOTZq6KSwYyOu0VEllwGzbsi593fWEOsFHnyX4EySvYk9inn/ZPCPyjqi
nDWF3Jd2q2l/qsDYUQHTL/KpU047U9RsjzdF1ukm2fdYk9jDYdcGzDfC/mza
wORcYyf2YmDKqWP62vj9ZPqs/Z1r9r3v1b2Ro5ODVpsxZeAAw+OQz1Qbz/sA
g7trzePSy0uTM8bwn31SBk6fjA/5LIH5TvNlLSP3Jh4Msm54TnhPdFdDaoZP
LzmfI/AXgcHdo2a9dK8eiBydLzzoXCmjHvTS6NIog+95gDEJDC6x8OZJf9gr
gJGN08d5Uz5PYHw/r647jt586St1o/feI21QPzGYeC/WKXbk6HjQ7xADh3un
Bqdv4JkKw01oubpjOfX6M/dLPcjRF8zaJNYOMPZUxGVZKDCxMhbK2iRfODD+
ycDIduYq7Ps3Vdl0OTB8AfmiKYemBuY+NunLZ232S//pD/4m+Lliw7lEYN4F
v8klAt9at08s1/NqXc9fjPePXTLPEjOT8YHGJrbhYimnbOmU4y8OzFj2Leyn
iYyOsmWCM1XdvHsvD0AOr0xOOTwz8YcWy3zDHwf/HGI4YE9MLB18c5CbYVcK
PUy+YmBoZGD4BGh6/BB7/eqAsf0j7x94QGBwiQmFHT80P2UrB4d4dfgnwtui
BwZGd4w/4qopXyUw5z459zh/8W9YLTjYZeGfiDycvQqagD2NtQ/MngafgB/j
VsnXDP4ShWHu43O8VuYM+zbwAqElBuRd6P+AvAt10e6W4Wvgc8DlnOUM5tyc
OOcxZzH5uinnvAfm/uqFbVh7y9YLDnWvkX4+WLd/LHMRPzFi9JVLjnVGzJEd
S7ZJ3TD3iSWIbWpvGfC6JdOh2CdBi2LfA7xg8o0DQ7MBg8sei9y2qIyX4bLf
Qgtid4ds9tHA8PXkmwUeFBhceIJBgSkDhq5nPjHP4D15pw3TT+QeyArR06PD
3yLfGloBmqGX9wKG3iDfqjaeDgEGl3hVjM/imUubpx7Ktsm44ZMMfGbybVNO
vDpg7rP/4QPPHkhMBuB62etm+6yd3r6Os5moeT4wT4jBBR62tfiN4h+KjyOx
r4hdcEHWwk618fTtTpnnnCWcWZxBnFfAnDXkO9fGn1PA3Gf+czZx1swceJLk
u9bGn0fA3H+t5jOC82W2wMiNyYfUxp9BwNwnZhu6ZHR/6GmBoUnY+zkDOIfY
+9lrev3ygNkPyfeqjd//9+rFLdknCn8o/JiA8YGiLs447KCIpbdPcPE92Dcw
ZcDDQqdBw7F+Fwx8YOi6/WvjzwXgBVM3fX4g7e+TdnmnA/Neo0uOv0qcMGLQ
EqsCXx7uHxQcdDEHZ0yIiQiMXoZ4cocEJt4d8BHBOTQwseiAjy051gtxLOdI
jo/8xiXLMoC5j+wA//nesiOCg281NjG99jDA+C2PKTnm2CUlx947MO2Cj881
PAv86tF5lrlMfB/OBWKuDc28JT8m8A6BwSWWGuNDrBjapF74pmNzj9hqwwKD
Q8418deIzTYs5eAfH5i+Ao9OfkLKj0799BOaGhn6venPjunbuFizNdMDtcC9
evmTU35KYO5DV54S+OTARb7nqfmmBwRm3MhP+893PC3fG398fBc5v/AvBN40
Ofc4O4YHHpC9aHjgMwKz9rFBIDYudgjkxFbDZgm5CbFb8dslLhkwNjnkIwIT
ZwUYXPYY7NJ6bdKA8Sf9PffmzLNnps5La/aj7o15QY4vNTKU81IGDjByUfLz
AxODEBhc+ku/x8WIK7n+dubgifmOF+W9wCHWGX4I6CFvyD3KsRW8OO9FHRen
HvKR/3n3kXkH/MXxA8LvBh98YPZY3nt03h2f2tEpJ78k8DmBwcUXeUze69yM
yTEpu/Q/735p71jV/V6sM96J/mMPVi/sG4b9Pn6CV9Ssa4fXxB8NPgVfFnhs
znr0Ncj9keFB46NrYO9FF4FuAl0F/bwsfUZniw4X/ho7C/hzeF7oenQc7GnI
qLC/R46F/hB9IrLMKwrLMrYIv0xMNvjrUan/98hDps1awAcF+SZnK/JL5Jn4
M6Nvvi/viBwFHSeylFbh2HbIbtHDoNvCVwAaAFki5z70JLH4oC3R8RFLF73N
BIXj+6D/R96GX8dckZ/g7wONhIziiZplHegu4EU51+BH8dWC3kNG+GjNemVs
IfGDQ3e9SmG5EjjIDIhfCp/BHEQvPlO+z4u18fwmfk/QPMjRkKdhi4H9BHYU
F+asROfKuQlfi94L3habC2R5yPHQq2B7wXPIw9CvQGv9VlgXji4IWek7NevO
8YFCdw7NhX4PnTc6CuS+6ObRfXF+YZ/M+bgyes7C8VvQE6LfRVeIvAufSb4P
OkD0f+j+0PURQwe+AP7g08Doc9ADodNBpwevCJ+I3pJ47ugG0eONTfl3hX1H
kd8ji0QmiX4E/dR3NeuJkN8j50fHg64GGSvyVfQmxFpFbore6puadVfo0Yjt
hd7pg8IxraAHkVkiw4Q/Y1zx4YFWRW6O/Bz5OjLyP2uWhSDr/qtmuQWyauTd
yKuRGSPDRX6LngH9BfMRmf2vNctykD0ja0bOjC7ml5r1MVPW7a+CLJN5VBSW
UbIOWPNvRE7YKCwrRDZcKSzvRZaMHBkZMvq3b2vWwSEPxJ+NOQ6vRBxdfKqY
1/gfTpb5iA8e8xE5APrIOfJ90Guy7qHlsEdnPiJDwn8Y+RE2Hf0K84zT1K3r
5ZvDc8N7w7My19A3oxu8pm4+n3hjAwrnyC1mLowPn448g7XHumNNYMOEzB6Z
H/sFe8V2hZ8Bf/3CMYVpC14cnhx+C5uL2Qrz5tgszFHYjoc9ALufRnh0+Hb0
9eDOGvx1C8c+Y/3OXRgH/v3GuuUI3FugMN89d9k8NzAxkXbIPcoZm74Zn9vq
5tvp6811+40TC439lfiV7Jfw3H2z1ti/u4XllYsV/n7Q/PC4i+Y7Xp17g8Kz
EnOHvXfJwvwnvOdDdfN4xD9jfS9cWLe9UmF8+F32VHRmrCd4U2KPwp8uUxhm
PC8ufA3MnoptAXswurIl0xb8Lu1iR8ZYLhh81hD6KvZ47HqI8YttD3sq+yZ7
Juty1cL6YPbF1QrvjWsU5mPZn9mn1wg8bpwyVuiasFXi3IDHBZ8zkLFZMWO3
aeYc8437aweHebdO5s8mhb89350+rpl+wuMCwz9uXHjOrZg5s2HmDesB/Rwy
VerbODicA5ukTubRZplv2NoMKmwXwDxgPmAjhn3KFoXHCfsh7Iiws8MPDrui
ebKOsEeqZ05um7VAvl1g5tv2mYfkOwTG5mjHwvZn9GWnwrYGyFnRFSFrJT8g
8MOFbdHo55DCeuJeOdauWRfkuwVmHx0SnD0L64Z7ZdjAyK6x3Rhc2FaDfXHP
4OxTWH/ZK4cGRga+X2GdZa8cGhhZN/vxfik/sHC/2ZPZ13cubN9Am3ukXfbs
A4NDvIdTC/vRopNER8lejo8hOkvK2HsOK7xno3fAb5Z96B9sIIvxvkzkmyen
HJsu/GDwY8JvrU/DPmpcH1sY3rxkXzZg/O+QBxDrDvnAsMIwsXOJg8c1MRmJ
W4aPAf4F/xa2G+BM5FsdlO91R+F4muBiH4adGHZD6CvwgUVncXJhGNqMnGts
07ARYlyw+WdsgLHV4XcTaPf7kn1B8QnttakHRmBEfnpg8jMC0z9sG9Djob8D
7padnxn4+PSZ+ontiX0q9m7E9kOWgRyDnLje+GDiA0HsBvwgfsdGpfD1eYXh
icq+Bn4r8hDqIh44dZydeohPiSwGOcy4+Adpix9pwdYBOwf2MPY+9jFkodg/
LFh2zEBgZKLjbCJS/lDhuIS99V2YdskvCsx5ga8+8lhiEeB/Q6w2YhLgM4DN
OfHWgDcpO788MHs2dDb7PH4AVwWf+i4prBMfE5jziDP/ysLnBWWjU97FZ6QY
HyeCHPvtiVI+c8W6cfTy2BrhK0Q/iX1BftV/4OvTf+bwDZm38M1nZZzZO28q
vH/eUtgXFv8j/CeAscfAT5Z761S8Jm7NumA93ZY1xdq5Pevnq7p9zHp9Ysnx
37qnsK8sZeAAX1tyfndgbDbvCQ5z/77Mf+b8/YX3BN7jxrwL8+iBzCVszB/K
9320sF3NPGXb1gDjq0bOvXGxEAvbSgJjT4nfGXYE7P3sreyrP9ZtT8C9pwr7
p4GLzeaDhW3xKHtSafWybTOfCg56JuR28N34dmHXdEfJPpXPZJyp/4k8i+0S
OPjK9KvbNgj6k2/+fL47Z8sLhe1dF2hYd4iMmHiNxHzB1pH4pcS9J74N8Wvw
WboushfiKI6KfObhwMiXqQPdI/QIdMmaZcfTAWdcTOCK66H+e9MeMLawwLSD
zoKYIdBUzwbGzhwe+NnA6C+eDs5teQYdB/0iHjExHrHb5F2o+9H0mb48mGtg
3v3B9BP66cHIyWmTtohbAg38XGB8xImDwJznNyWwN8XWlDMdmN+YwO4BP3/s
GUj4+yMbIMYJsTmJZ0IsEnxvWI/43wBj5/9S3Xb/xK5H3oiOqp01yD7CmsRG
k3LkUdRNW+NivNQdi4G+0ce3A/Muz2WssAfDNprYC8RgAEYOj488MSDo+1t5
Fvs31jjXyMdo543/tEUb2NGxp9E39gf6xzX71WWBKR/d0jnTcUyXp5W3u6bP
lmxq3+t4D/tEZS+0bCf2u8oe79jO80/lf3VMTxCw6vaG5RsnCve3ju1Zd25r
X+xa9vGDyn8X3GS/EVzv2s5ykR7N5bbthK5W+dxNz4XnVcfFTdN8Lwju6Xr/
PEy4l3Uct+g55ec0bTvzrOAzmqYjRwhnhbZtIA5S+cEd09td1b9XyzrA01X2
Ysf8w6vU17H/x/qJe0OMgkJt1rqmw/ZRfdWuZTH4++IDTCy6GVXf5E3bU3cE
n9tyfKi1E9cRexJss4DxZSB/PDDxnB7LumAdPJY1O6fqOKzp+bCf8lnatm2q
qP2HG5YFDRZOo2sd9SPCmbfpuFd9VD5/0/a5n+ud3mnYLuJXwYd1jP+Byr7u
OKbCSsI/oG3b+kF6bkzL/fpO90d1fC7cqbJdW7bZnlT52x2v40WEv0/Lsat+
ylpiHe2ZNUVcxRezdlhH8KDQ0NDP7HXXhCdFd4Peizj7XIOHPvqq8K3g916j
t4EPhB/sl+eIpU/MZHKuoeW2Cz7PXhccynkO2h1aHfk5sYWR/xPvjGvkwPCL
0PHQ7fzuCrGwiYMNnc+ztI/c/fY82xunmBjFd6ZO6rsp18CU3Rmcg1Jni/dq
WJeMXhk9+Q3pG7z89YHx0Zmi4VgArHFsYWcP7UDcGParyRvG2aFkH/3JA+8S
mFgDEybeEvjrJuYM5w5nE3WybxDvhVhC2OH3Sx/Q7RA3aJLEDuLMmijxatjz
3s9+SNzo6zLOjDcw8cyRiYDDHol8AN8Myqhv0sQvmiSxiWiXOAzA25R8f5KU
09+J0ucPNAeP7zr+Cfp4xg89PON5a74d8Sqg9bcKbQMML/BYyb958WjJcThG
BYcy4rcTzwR7d35HClz0g/hE4YvDfcqJ8U6cmJF129p9lDqnzNzjmTlTx5jU
w7l9d9Y4MZTwwcf/iDifr2UPZ61w3uBjBg7xlbAJJ2bSq8EnfyUwsaLvSZ34
8VMnsZpeDg5+29ADtIuOBjkI48OY8U6XZ40Qy+WyvBf2g9gRwisho8QeEVtE
3hcYm+pZGsYDpxIYG8UrM1b18L+sI9pk/t+V9cJ98KBzeAb7Rvg2xumyjCHj
enHaQoaIPfyNoZGuTP0XBYc6+K58R/g+cLGhJz4M8W3ODdwb7wYYW2hij8NH
kJ9dN99xY3DwI+Yd4SHpHzpx/HU5l6fXmfVRx/KCBTQHxwY+SvvhDW3LHvYS
zvcd8/z/KP+3Y954ZuGc3nYcxVtVdlLbvmE3C967YxnOLeA3LAt6jL28aV+3
mziTm5Yh9VF+VtuxFv/HXt603fEcTZ95nHenC36mY7nIHcqvb9h+ciuVH9U1
PcN5vk/O9D1V3u3Ydmt9wXd2LOtZlH2+633+bpVd0DFdtg7nTsfjObTjc4Uz
5e2Gzx7OnROFs1Db33FX5QM61nMMVP5DIzGEBK/UcWy/M4Wzasc6hqWUT9N0
nMIldc5s33Qco8VVfnXTMYX6Cn/BttfgPSq7vuk4OYsJZ9GOZbtz8r5t60Wm
Vz2juo7FsC7ttq2j2EDw+h3/Bhq0w3ahH+bUdzyrZf+Zl9Tfd5v2l1xFuFu1
rQd5XvWd3bJN2VoqX7NpPU5/3b+rbXu+tVU+adP6kZWhm5q2oVsP+qttXcZ9
gq9r2+9uCd0/oW2dylEqP7Jj2ev7Kv9NaSf0Tbrf6rHsezu1P22P/XV6lHd7
bC/8tXAfVb8/EP7K6mf/rvmtSXS/0jTv/Kny35WWEc7Zuv9x03sd85q5zty+
hnhpPfaT+7bhcWFMzoFm67Hv0E967jH8ePX43cpn6rG/6oOsox7rChi/XzOG
zzFfeuI7ylzosc8G7/dD3vEX5V82fZY9q3y6HvvH0t9LG+7z94Jvazr2y2S6
v5TGZQrOcr3Lbl3z8CfqXU7oWK78onD/r2l9znEqO7Zj+cdSenadlv0AWX9D
216DV6iOszqWK1+tfOqmZbKnCv6lYVvs4dCfHcugNxb+JkrnCx6o+t5r2C/2
UT13Y9Pxjo5U+feZ/+fquTXa9ik6X/DdLcfG2kp1/NywDGqkypdrmdfZV/08
qWte/cqO9wv6CV18Vcu08cG6v0jLfNIVlHcsUz4bo4ymfbyWFrx227EhVxS8
advraxnB2zbtA3qo6rmvZVnEIN3fvG192v0qf0DpVdWzlvIBXcuV1lZ+btd+
dhspH9i1fGgi1bdoy7Tu7Sq7Q+ll6G3l63Xt//uJ3vW9tmVTXzGuXes7Z1TZ
PF3rWyZVPnnXMkp4gik75gs+Uv0jupYjzMf+1LZ+b2KVTdS1X8sOKpuka7+Q
qZTP0rU8czLlPzYs85xC8O8ty0SnFDx113LPuRjvtuWZP+n+tR3rqbZX2Ypt
6zCHqHz3pn07RtFW2z4Q0MvnhWaeXTjvdKxDflP5Wx3LJN5Vfk/HtA3763vZ
Yz9R/nHHv9H3PvtT03zx64Jfalq+PkHT9yhfSP1csGs/sC1UPqDp3w1cQO0e
2bXMaFHNnx2bpilObZr3g+9jzPp2PW4Xquy4tvVOi6tssa7lQM9qnFboWr75
JDRg1/LDZZUv17U8cUnlS3Tt09kib1vmj0HQVG3rQqdQfn/HusELBG/Utm5z
iPr2acfy959ZXx3LyndVvkvHuq5DlL/asGwefuiFdmx+1NY6XcsaNxHOxh3H
7r1Q73hv2/qN3VR2Ucs+iV+p/Nam41ZtpfI98u2GCH62Zd3pTsq/adjn8l/2
jbZ1tMepnaO7llWtIPzl29aTjxXOzU3H3TpB+fxt64c3FM5ZTctxOYePaPss
/oLzren4WhuxjsO77Ul/Oo5ZtY5w1246fusW8HBN+5RvJnjxpnX3kymfoWX/
d+b1Q23P7ZkFz9R1LNtRut/TNr8/ocrm7lpGP6fyObqOsTqb8tm7lr+/T9yM
lvmUbeALW+ZpRqit/i3T8purD8s2HT94Bj03Y9cy/R9VdnvT8bl2hq9sW4+0
tfAPbFq2cbzKBnVsf7ANfHrTMSC3Z700HcdwO/aijuMsPqX8lKb1Seyp3za9
r66sem5p2958V86Ftu0JoKmhrYn7y2+Y8Fsmq5X9WyZcY2dFzCfiBmxRMo8H
b4btGXKYA+vmwbm/X3AOqVvG1ApvyG/ZsL7IDwvMffCQO/2Qe9i44V9DXLk+
kfMA4ztDOwcExn8B/xPoQ/I/Av8ZmN8YJZYz97D1wrcKO6EJkhPPGp9c4ohS
J/TqwXkv+ozPH75/+MQdlHdBVsa84T3xByf+1j55X97p8LzXh3lH3gk6Gz6f
2IDw+sDw/kfW/dtXlbJjuRHTDXoAn+9T65YhEGuKuFH4kVMOfEzJ908JTH17
pU783/Cl2TE83V6h84kduEfagkcmngV0AvH5+G0kYvSR7x4c+ONdgwP9AUwM
BBJ8MjH4eH/enRg/26YN6uOdhqQe2t87ffu1sM0H9h743dBPaHLiHvyacvQs
6HKwJ/2tbj/2X6Lfea+wLcR7wWEvxYcYn2LsPvCZ5jd/8Zv+prB9BrYZ6Cm+
CUx9b6ZOcN8Ifq9PGv5otIuvLP7z6HmIZYCe6o+6dTn4Fn5V+Pc78X0m/7Jw
nLT300/69m3aRSdCG9SHny66gpcK6znR83O2E7+AGADQCPjRomd4sbBMCR0C
semIgYCNTK2e2M11/270qhWPH+MIP4JNDb7WR2aM/844Y4fyc2H55L91+0Vv
yBldGMY/Gv8R6sH/BRz0iL2+0+ToEvGz/KfwXKulD/SHscOnD9/SRt3yS3xN
sYtBF4ierbff+NARc7Wc/lNHNTA6IPwn0RP9k/7TFn547fp4Wyp8Mh9OW7S7
X8l5I+0Sy49xQ59yctYLdlbAp2XtIP/Zuu5zjRiMxGaE/v8mMHEbkQdtFXjr
wOPWTt3xHMHfoe7fYWT9DskzxH2kbLuUE2cR+MOS4zHuVPeeT9ng4PDbl8Sm
fKXkPZjfNWYf5rcFiEmPvSoxYleom6eDvl8p5Zxt4K+afOXAxLQH56XU0z8w
9rPgsLfDBxI3lfik7IvL1n22Ei+Tvh6cd+E94R34zdJBefct6r4GJhYmMTDh
NfbPmL5fctlmKf86OMS75HdK+U1Pfh8BmSbXvb99NFfKB6V+8HdKf3bKWG1S
H/9bofR1j/SNPkEnIM/je22Z78A7HJh33SDjPO53R+uugzigG6V+2tkwMPnA
wHsFD/xN8iz1IKP/KnvCON/auu1Cyflm+K6yN7LvwzsQj4ZYab3x/4HRVxK7
aGhg7KOxk0Yuyu8LECOCWAqU8dtt/Jb3sJQvmvJjg099R6eep4N3bMl8JuW0
zz5Nn4h1zL7AmYetGrZrrBHOH/SW7EHEnSS+ATicieBx3et3fkbK6csJ6Q/r
78SsQeo7PeuOvhyT/mA/u1zGh74fVzftxBk0eWS569btA8ycXz4w+OvkHvZ3
+PauXbetHP7SxFhAbzxuTWQdrZBvwffBppo1BW3AHFg/35E1wDXxK4/LePIu
1E0byFHXCowf8SINXwOzblg/0Bqs7cFZO9hrEl8dn1PwibPGNbEgiJfxSXl8
veDCQ3KP9+hpGAYHGL0478bZ8nUxXv8OTLyQz3M2cR5hH0lc1KHJietCXCbi
v36btYxeF/0rulfWBvFmiZFMLAJ03pxB0DLQNMSdRh/OPXTi2BCODQ51f5f6
sd8CH/rn+5TD56I/pj380ZkXX9XH676BmWus36+z3tHT8DslvbJbYPS5mwZn
v+xL32Zd0wb94L3Zn9nH2dtpn34QN2irlLM/cc7yjrwTsWM/T//RzxCDG90W
tmTY6UKPoevnTOTcRBY6zsaiOj5WEWcOthaUIyNFrl+NXAJ7GeAdS85rKf8h
dWKbs1nGf8WSy/5NW8QboT/ojviW9LU3puxn6TPPfZJnofU/zfel7NOUfxsc
xgqbHfpAv9C9Mwf4PsQH+CHzAbqAPtBH5NbIr5EfoqNAN9EOjc0Zw5nC7zQS
F5u4Yawt7rG+kAdPFZkwdkjgEUObOmeJ3Bj5MTBycn4rctbU03sPuTW6iT7B
gSegXniE2dMudcPH8FsmxP5inXSjf+Hso5/0C90ifuzoHPHpBX415ybnLuci
dVAXugZ0c+iDkANTH+uQ9ci67Ml6JCZFJ/jofbrBgf8oMj4zNRz3n5gJ/A4L
v+uDLQdl3Du65DiyxJbFhorfoQOP2BeUTZ9ycGcMPj7mwMQDnDU4jC32VTNk
DCmb4T91Eo8VGyrm3OwZN2KsUs7vk9HmNMHB/mqOtEU/gbFFwfZqzuAw9tSD
DcwceUfwZ8x7EV9izrzLuHiteZ+pwj8yN/ieU6ddYo+8J/705YZjsF2cufde
aDrWGvQwPgj8XtK9ZcvygMeUnC+Vcn4XaYm6deXki6ccHyb8miYOfwpPC+9J
rB1i7mCjgu0JNijYzyyWZ7G7IMYesfaINcTvr1LPLYH5Tdb5y+YniHkBXYo9
y+ypkxh+xPK7MP1cLH1GN7pI6qG+RVIP8ELp58KBKSfnGh09fhiLpW/Icyev
m5YmDiB9JUYZifjexNYlRspHhe3QsDn6tPA+DO3C+UEcaPidscH5uDBMTBUS
PBA2bvA6H4QvOzNnD+cOdgDElsKHA78c+G14bdqfK+MGrd7N+DD+89XNdyMD
mLc+3teN74Kc4Yb0n2exX+qb73JT8HkWOyHKsXXCPgr7uZ6yY10BY0dHvkDK
J8w3gv+DP2Cfh0dg/LB3/yz7OXZ1+BPz3vCAvbZ7wIwP+R+B0Y9xNmD3S35W
YGyngfFZPj2yg62TE+sf3pl8prr5acabOmmTcvCQMyD7hhaEpoPWAkZGh9yN
30VGjwyvCQ9LrCbmHjGLsadC1wwONgDYXmGD1XsfGFssnoMHhkfGP+HXwNjC
/RQc+GZwaGfquscH/Qi/xTB93fzETHkv+owfwIQZ50nqtrPstbEEJl4K32GC
zAdwJq07lgo8Irwi8VZoh/aw4Z8s85xvRNk0Kae+SfIsfaFP8B2Tpx7WBbQF
vAq/xUDcQOLtE28b3GmDT8ztmbNOkbmzbntxZ005OLPUHe9v2rS1cXC4RyzA
WQKDT+wu9gHsCP7Q/vZRw3EExyCT79iWE7lvvceyX3xI8Y3n95Tuw74mtiX9
OaMa/v166CJs3dBb83vdqzSsv145ML9p1XuPcsqAoaM2UTuDWo6TuLrqX6Nr
+QNt8jtP/LYCvyHJ76zi5zugYRh7nkeUf9g0zXwq8tGW4xLuq/d4vm2fjHtU
vn3LcftWU9kNLftz0Q/eAR/JNdMWtqbo5W5sWDdHGfeQFSALWDM4q+TdqeMB
5dO1vK9+Lvjdltf1u4I/bXstPA7d1La+fnN0ay3H6cOHET9VeBB0cd81zYNT
1i/lg4Q/rGX/oWe6ttnCXutM5celnNid4PN7gv/kefxeh+r+I13Lm9Arft40
j/ym4CValo9he8DvCGCfgK3TgIwt77563hd/JH4rC1qU77Zavh26xN8b1iei
+zqlZXryZOTxLduwYw+IjSB2jS+qL981HMfwN+WTtbx/Yg9KH7CJ4Pd2iQWP
3fLBfKuWYzV+ofH7vG279VG6P4Z5BX3Tdl3Us4T6s0TbsZMY+x1bHn9+K5bf
08IehpzrbVT/E8K5rmsb79cEj2xbr/QGera25ViXpC1+R4bf/LgkMG0D81sh
N7etj0f2NVT52W3/NhI6qBca1kOh034yeu3nlN/azb6t+1+2PYYfoK9rm+69
UOWjG/69U/Rs70fXRj5hj2F0cQRzYG/gt/xWyLg9jYy9a7t09OHPtK3/ZYyX
ybe+S/mNLe8JbzBHuj6Dlw0O3+QGraP9W44HiS3eXR2f9fsrP6Bjnwhoq+VC
X/Ecz2PHuwB2al3bdT6SeqlzVezgurZ9R163XGhRYv7z3fntZd6D90EuwTr+
q+m1jG3xinnHBdELtR0Pd7DGY462fRaP1/2Vsi8tnzEhbjll/VP+knDvaFkO
8HLba5j1y14A3gQlf/NR+dZ/ot9vmZbZSe+9ats+o2sx9k3/DuQAwQ83zSei
N262fIZiY3hJ07QVsnt+qwxaYjZ0yE3HU/wNvVvXcsNZVP9MTfsM/axnZ2ua
Vtyp4WfxteH30LgmvsQN2Ca0bBM1OOXUv0HDvzfHnN+h4d+N47fonlK767Yc
M3firAvWwi6sy4Z/14PftmYfgDeBT8E+kr3hRvVxzZblxthuvBn7jSda1jOh
Y1pF8F8N04fPYxPasrznJz37Tcs+x/j68w74+9PHHdK3yfXuU3TsH/OecLvd
+MygW+vYD/BD9f+fhuOi8Vvx+MljW/umyt9qWz79mZ79sWt5Lu/EuxH/edGM
A7+F8Wv2DvaN+TR/xrZc5/Ts2T32352P79Z07MGNMj7XqK0/VPevLcclZLx3
zJjvofI9u/Yl+EP3i6b9GvHfp5/8djO/x0Ef+O2twxt+B36LARvB7fIu22dM
wNlYfdm4Zf88ZDPIbpDb/NixnQQ2ErOqz8u2bJuMfSJ2ddjUHa2y5VuOk4du
GBt19M73quyQru0N9mp7LbGOZlF+dcP0Enrv2VrWfQ8T7slN24B9JPw3W/Yf
xY6P9np9++ZNu+irl2pZZ32e8pe6pvU5A+gDfmDQjvweKmfXOJ+/hutDLzpr
dKPvtK17Ru+MjHaeRn53vmQYGhI7hYmbtlVYrGU9OvqvS9q20cE+55Ku9eLo
xPltTM4yYn5yZi6Yc3aHrBfGfJuG44fyOwTohz+Ijpi1xBzidxrRA38WXTB6
6W+im76ta1sK7CiQsfG9bk6dCwfm+wHz2wPoXX+O7pWxWSDfiL4snv6s13C/
sdE9SHUf2DV/z/P0kRir2BQ/1LS8Ct9ansVWczONyZ8N27IS63SJvPu6mlfz
tBz/eonUTzltcM1v3ZzTtt0bNm/zC3e+luNoH9K0Dhj97wFN64nREQ8RfHnb
Pov8buAhDcsE0EMcmLNyt7btq7Ctuqpp+zBkqvs3jPN+yTC/hcbvoC2i+6Ob
PtP5zWF+e5jf74aX4PfkWDcHpy1iAq3atN4dnfvY3CNGEPcPTn+Wb9qeBlsa
4hQf0/Bv5Zyr/Bzmg9KnrOmOfWLpz37p/3JN69Ffy558UPbh8/Re57btO4sv
5EHZq9dq2m4Mm7HTdP/Utn1J+U2Ksxv+TXDee//Uf3pg3v0m5b92zY/Qx6Hp
Z0X1VTv22T465fzOCDl4xJ3rp3ZGdy2n+hD6o+HfQmIc+Dac10c2XM7v0y2o
+hbqmE+aS892eswLUefRaZffZAeeR/CDJY8Tv+kwvG1bQOwA4WcOyHc8WWWn
tO2fvbjqG9m0P/eM6QPfgn3xsOyN8wj32Kb90edt22YRe8V7G7ZHxBZxIvrV
Y/4KW4a5W/4W/E7o8Jwp/HY3v+fN76hjNzdFj3nDQ9q2F8FW5FjB/ZqOrcA7
DssY8vspwzKG0ALQE48LfkjpuIbf+0mlExqmJU4IzgyZP8flm2KPs1AzNjnY
YMT2A1yeeYL9XzjTNu2zPrGuT8p4NgLXk5+c8iOUn5rveErKwcWHAHsU9GXU
fWLq5/4p6fO43xtruO9bpJxnmdenZU3t37btC3Yv2Fi9FnqY+6dnTp4ffOAz
MubEvMLmZUDbdi+ch2fmW2AHir1aNWv89KwlbCpvb9uukjrOCP7qHduFYBNy
me7v1rQvPu/OfOU330/LONDnIVlHs5Rso4etKnZ6IwSflW+xBvZWHfuKN3ts
r4at2vD0k/X7pfIfOvbP5XfneZa4eaPVh22ajjdAGfX2zoURveu3bTvacTa0
Zc9nzvSftf7uaTi+BWWHpxy6b8KOaT9szRZr2t4M+8q3mraxfEXz+tWW+fUJ
OrYhRof+tsom6dj2krV4UdbjdCq7omnZwoUpZz5P3LFdLza9PR3bNGOjMr3g
L1uW5x+bfY+xxKb4xZZ5GWzB9m7aHuw3wb+2Hbfia+XftK33oS1+axM6+XY9
O2fHPscLq44zm7armV9lmzQdi501N0fH664P/VH6XfBsHdNb0Fr8NtPF6T97
/sjsjfBDF6Yt5sD5mQcX6bkt2/491PNSzvzEruqWhm2r7m97P2UvfZA9uG0/
Zuq7IGN4rcoOatqPGdp/dNriPtdzl2wX9mjXawTbtJGxT0NXd17apU/nZZ1+
hW1h0zLJi9J/2qK+kalzRNltAN/HPtd2/Ey+ybmZY+c3bWuFndW51Nf2b9Ne
pft3tx3vBjusTdqxxYIe6DhewCct25BhP9ZW2aUtxxn5Q7i/tx1DZFjbNl7Y
d2HbPmPT9u1Pcz40/RsRVzbcP/p2Ycv2ebz7lJq3k/dYBoYt4XNN2xPuprJV
wivdoWd3aTueTlf5Ry3rp47LOzIHz8485H2hhffNetmibTvsiUIjs444N7Zl
bbYdw2Ph7I/8lt/lysd0rbdizzgi32LHtu1KsSk9KvsJ5VfCH7cdTwLbxoGx
b7xZ9x9pO27tEmp/yY5jjlyqum9oOK7QWm3bvmP3/pfgu1qOET4dZ1fL8Sfw
5cIHDH+uP5E5tBxHpKHyy5rWaX7cMJ8Jj4nM49u25R7HIyvq+PcQkCE90bAc
CX+v65rWe36n8kNa9gc6VvnPbceaKYQzPGtwGHV3/LsC67c9b5gz1zXsb4B9
47LMr47jp6zbtm0xdsXwoz+2zJNiM4v9JbaXZeWHNm13dyh1Nx2H4W89u17T
/p4PUkfbsStmEvxteMBpBE/bcWyDW9WHv1u2JdmjYf4T3nOKpvca9pm3BZ/V
tR/yfm3b62Orf5XKru7aF3dDzbcVwu8s3La/AbrCXXR/565jNV2u+7sK3kfw
/9qW1yCrwWcCHzn8JpYWvHXX+snzlV/QtY/xYOU9Tf8G0baCt+vap73atI0+
NMaOKtuha//yfbv2FWEd9VO7l3ftP4zN9T9N64oXVx8m7rGseV1scrv2vb9W
9y/u2Ib874b5anjqpVv2p0JXP0o4/9dx7KGTsZvu2nceX6vTmsb5hjHv2L+n
pWc371pH/EnT/gP4DiBD2i9ypEOxPW46vvtNbdtrYqsJ/3dO1zzgMl2PEeOD
b8qWTesl4bP57VJ4bextj4nN7cfKH27Zzmts1+uTtfkhfGHXOt4nlD/ZtS3d
iJb9NPDR+FT5Z13bja2q8mu6tktjbEZmfK5p2xYfO3zs39tt2y+8L9zbWraD
e07wqS3bx73Ld2nZVmaulvkQeJCvqL9pXfeVypdsO2b6avo+tZZ/I+hpPfuU
0juF/RWGdO2zAD99cHjqA5Tv33U8gA1Vz2FdxwgYoHqmbfk3fBZW2WUN+44N
RWbQtR/9GL3Hfl3HiDlN+ctNx6tYA7q35d8gwsf3r5btZa5Q/nrm82vKX1X6
RPhLC//epn+76TLhvNK1feKDTcutkFktypzv2qbgZeXnt6xnY++8It/o0bb3
WfbYL+FjOvatRP4xe8cykJ/Yu7qOcfZLy/IRyt9oWkaPfL6CHK/rGFrskX93
vU8iy0H+guwFfxH2AvaBB5Bp9Th2FzIM1jbregvkwT327y/jF9Njmzxk4cjK
kYef0bKcHRn7Y4K37nHMJ+QW2/ZYdrGa4IE9jnPAnoR8in1pAvWz6HH8qW+7
pr2gu94Szgtd/77Ikx37peCT8r3KPtY9iPXPOMe6lv9/wft1bQf8Zde0F3TX
14JfatlG+Bvk4V3bF06kdms9jp22kspW7DruQgmfoa5/C+Id1nvDv4VF31dv
uf+vqPyphn/b6jXBZ3StU201LZdEJrlJy7Ik5Eibt6x3QefyR8MyAuQD07Q8
R5mfUwteq8e/eXae6itajrGwact+I+xdPS3PS+Yk+8oW2VsaLesY0C/cp/yA
lmNCPKb7q3Qd++RRldU7jsO1U9N+DsiLqi2vN9baMi3LF5AtbKbnBnUdH2Tr
tmk+6L2tm/ZLxyd90bb5THjM+5peA8z/1xr2VcBP4R/VuX2PbUiZR1u2PJdO
5gzscZyhetM+gfgD7ql8jx7Ho3qgaX8efHnOVF+GK90reHK1u2OPY8jN2bY8
Gln0TU37KeGjNAXyxa7jU0wDvdHjWGjINtBbIN9gvKdqecyRMUM/QTvN27K8
BlkNPhyPt23f+7+W93TGfKOmaXro+fsblmsj095S8FbhWaA1Fm+Z3uD3YYl/
fbzKy+ztHce9wqd8kpb9yuETeR7+san7rY7jyu3VNM0BvUGsbOrhd2S3Cr5u
lx5pmeaA3mD9Pd7yGsSGZZ2Gz4tLm6aB6A+2FJwd2Pg9XHJdzfR/i8BV+OWu
Y/lsrLJN4AFVzyDlmzf8W07I1ZC1IRfbEH6w4d/Lpo+8M79te5fquLPr33m7
qmS8aZTPp7IZ1AZx4i5u29cLXXc/5X2VyoXrRTZIfPIdWtYvolusC3+6rmMM
rQ6v1rXtTUvlzbbjbxEnAJoJegk7fOR6yNvYk96ITPUm5e90bc+ND0e7ZVtE
5PFrhy5CVsez6OOeUT62bf04fnuvt+y7t2bXexb71TPQHk3HBcSujLgJtI/+
586GdUBbZ9yQT+LbB58Jj0nsh1tbti2Ft5sr/N2BHceGoPyplnUq6FN2zzgz
r9CFsieyH8ILQo9Ci/Ld+H7LlvxbepsEflj3H+k4rtmybctrkNVQH/USU525
gz/8ON+rqvtNnwe3HcOC+BXo9F5sWK83YfCZd8PL/tbMB/aAf1veBzhn7m/5
rIGu37Bt2h4d2isN69E2bZqP/SWyWfQryFfRFUzXtr5goHAubDveJbJpZNbY
FKM3QH9wdcnn/EMNn/X4GzBvsXUnlsZmTdsInaq0F3xL2b50M7XtT0eM0M0a
jrNKPigwe8m0be8nm6uOw7uOGTIw7fK+C3S8V7JPEkcE/yJ8i67vmnaEbmR/
vSF77KTCmaxj2/kBocnRu8/e9v5FW/QRXSry8Is5Z1u2U8V2YMq27Qe4Dx46
JnxSn2raL/UmaISu/RDYOydre//Ez+yBjmX++KSiQ0J/RNvwBtgAfC/cH9qO
g8l+sUvv2MIDNf17aHu3HQeEGCDcYyxY67M3rVdDp9ZH92du+zeHoKHgDaCj
0FHf27WemnW8RtNreW71a56OY6Rdoedu6zjmJXRNuW3aZt2m+R94H+wyd89a
uKjj/tG3QvdXaTpG5ub5jswB1vT6Wdf85s0eWe/c43sTG/anjuk5aLlu0zpj
9MXo9JbqWq93ieAGZ1jVv6W3acPrbGOVXdR2bFbW3KbZP6E7Jmyb9iB2CHYe
2Hg8BN+j9FrhuA7MeXQg2Fk82LKtxf8DKUB1DA==
            "]], 
           PolygonBox[CompressedData["
1:eJwtmnfAzuX3x+/nue/Pc3/Wg8hMRraUjIgGsqkUKQ0USZOW0tLS0EBLS7so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            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl2Hcc19MXx/FvO02klAqlJS1lNKiIpCWlraJpNCibZJNRCFm/rPzISoiy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          "]]}}}], 
     GraphicsComplexBox[CompressedData["
1:eJxlfHlcTd33P0mTpCcpkopIRYYIRQ5JKiklQiljKlRUJA1miQxRQpEy9oQ0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      "], {{{
         EdgeForm[], 
         Directive[
          AbsoluteThickness[1.6], 
          Opacity[0.75], 
          RGBColor[0.528488, 0.470624, 0.701351]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNmncYEMXRxu9uD41dsfeCvfeColgRRUBU7EpRVBQQREGRiL1ix94LEnuN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            "]], 
           PolygonBox[CompressedData["
1:eJwtl3fcT1Ucx++955R4KjOye7yoNIyyEw1Ke9DylEpF02hoF8poaSeJkpRU
JDzisSWyIzTMBmVlJJLo/enz++Pz+30+53vuueee8R35Hbte2SVLkqRKmiSR
/yf5+RxUp7EsbR/Azw9Jchh8O+gML6KtJvbjwRb0ZjAZWxGYAB8PKsCPBXPh
80Ab+NOMvw2+HZRDt0dPgn8BKqIrgVrwmqAtttvAVviPvKc8tingIDyP938N
f1/zxn4AzEafAMrC/wGz4C1Bf/q+DkrwXF/6341tb/D3VgbnYTuAbTC2IlAc
WyuQYfsEfIttNX1a898F+53Y/gJTU39jE2zL0J/C14Ddejd9S8Ong/fQZcBE
no3oXvTvGb22k8BGbJvAyfDa9BkCLwY+g+8DC+C/ao2wj9KYjP2TxoMfCd6E
38t4++HNwc3qi65Bv2t4vjb6RNAp8RyOwPYbtv7weXoe3RV7dfjRtH8DbtKc
0UPAbZoffa7OfVPD4Dno3X8yxtLoM6C9b6x29FHg49TfcBj8cPAeurf602dq
9NnpjD6bZwfqGfQxoBm8KVhL/3VgA/b6YKfmjs6Hn4F9PXwzWAYfQdtZ8Plg
l/pqTRKfqcuwVwze2ybopcFnSmdJc6yq8YLXuhV6rfaCZ1bBS4D96FKgEPtM
fTN8DzgG/gBtKXwxOA79EboXPPL8XHRdvucqzR+9Gv0HOETbIt0R+o4AF2Br
AzZi2wTK6Vt0hrHVRJeE18P+I/x3kIdeDkbCx9KnltYS3JV6TpsYvwp6qe6H
7i99N6Avynymq8G/pK09/Buwlfaq0XwEGImtPPqt1Hc2oFeBMfDfdMfgj2A/
CC/Ns2tARfQi9DDNAXsl9GLtv+YY3SYunzJWvgGMTf2Ov+EXRn/7SL6nBvxY
2j5Hr9D+8kxl2pbAh6pN/gCMg4+Wj8FWqDHgC8E++leI5lqjJ7C9GLz3X4GL
5OSC36V3nAL/imeuQF8PeqPXZT6rL4Al8gXBe6s9+xvbv2AYfCDIj/YZ8hXL
wQ3wHWCa7pP2PNiHyHfIZxxCH6XvQ8+Rf+D5RsF3ST52I32byMegh8uHwedn
fpfORBv0KJ1p2nqgH0Y/FDzWKWB2Zh8k36M7fB99hwf7wn9AD/hB8GVqnzNG
4+v75AsY70L4GjBB/pix5sC38f88tsG0vYL+Pdh37QUXyz/xjsvp04E+1XRf
0AuwtQZt5RvRVTL7pElgFbo5/7Xov5P/6vKhOqvgJfovDPZ18vE6KzoTOgs6
MyWC11xrLZ9bJ/jO6q7uYLw62E4F36G/1x1VbEDX5j0ngZfR63XnMq/xtei3
o89yNfCd1kJ7lvrMP4WtN8iwBdACvj3z2ThdawrfR/8ZqX3oEt2laF8on9QV
/gL2xqnXeF60j5BvOBUsRA9EN4I3APPRz6BPg9cHi9Gvopul7nOv4ku0L6oB
xtE2A32Czgj6Sexzo896PbAgOuYp1mnM5Vob/o/QOct8FnTHdbd1JtrJDlpg
24q+At5MPo/v3aL9RN8ffZZayr8pNkT3HUWf8vS9NHrvv5DPhE+PnqvmOBG0
Rv+KXpl67fZr7VOv4aeKX+j8xG1z5K+icwftYb/gPdVeNkwdm28P9sWK0dpb
5QjKDbTH+hbNWXPVNw3QfkSvjdagHs8ORZeBF9cZQQ9B5+nuJs51OtFWK3PO
8wN6hr4B2zmZfWslxZPEPnYLelhwLC7QWc+tudb63dRn/0rsxVPfAcXWW4Pv
gmLsRvRlutPotpnv1iXBZ1t3bAr6McWozHPaqlyI/3bY7+B/M/o17K3Q16Ff
Qw8GpTLnQH+AVtF3YwB9ble+R//t8D2p787PyjFS3yGtTT9QLPMa3QjvEJ27
qc8K2hpFxxrF3M/gY6J9qe7MOsaeqXXDXgj6YusD6sIj7U/AH49e60TrqXuD
3oC9D03dFUtou0W+N3Xsbx+diyoHUOyUT5IvUgxVbHoUHEodo1oH5xTKJQL4
UOcp87vKZ85dF2aei3LYHtgfBH+mjun3BOd4yu2UMxbAt4Hu9P8F3Q0+KHhu
+8A10XuivVDMvk6+EF6g3FcxAn4nbX/B3wFvwLfkxsrjvw9j3R2dmzUAneCd
o3Md+eCW8KeC90prdJfeFd1XY2qtO6J3p17zW6JzbOXWaiuAb6bPjtRnXHM7
LTp2a443R+fwyt13gcnKB6O5cqKG8BHRuZpyZuU214OdqXOcebTXjY7VOpO3
RudAyn20pjdE56jKTfXM0fAOwbGyBRgk/xedq5fMPFetUV5uzo3hK+H3Yz8e
fW5wDaDc/0DiWqBysE01gfbqh1ys1J4Nlr8HdbQ3tL0VvIfaO+XQ/YN9cP3c
O1RLKCdTLqaaQrE9KgaljvHKDe8Lzu2VI57Os4tysfBD2tKY/F9YyRfqzOvu
Ph0dS3SHX9X5jY4lyhl7BscIxYY6irvw57T+PF8sde4/LXOsVw3waLBPki/S
N6lW0BnT2VLNoLt7aXDurDusWuCS6FxSNUEX+LOKP6ljVAl0ccWcxG2vB/sU
+RLFoIfgD4MDWtvEsXJlcC6mmLlXc5ZPTzyGcqVzgvdmWGLf9E7wXstHvatv
R+9OXOM1DY45ijXllH9onYJrwf9zNPhU+YjEa6Jcamjw3VZOdXmwD5Xv1Jhn
6l3g5cTPzFXcDd571ZhvBMdgxd6G8tHBPrwg5+NX8/9SdGyQT14R7dPly5tm
9k2Lop+Vj/oE/nH02ihHU+7TjjGrZs6B5ItHggqZffJj0TmXci35rBPRtaN9
pWoexcL3o9dCMXF6cAxV7FRNtTrYp8mXjUd/FH1mdFb0jtHRNZdqLc1BtVX1
4LulGku1l2pA1X6qwcaD4eiymfd4Anx8dG2aT1u34JxJuZLuQDn1Bb2wD0J3
xDY5ei6q8QvhE6OfVcxTLq8aU7WlcnrlAoWZn1VOoFg0Lji2KyapVp0VXOuo
ZlWuuCvz3VLOuCdzDaPa5RXszYNzSuWSOoNr4dOCY53mqNpksnxA6hpFtZJy
buXaqplUy0wMznVV0yi2l4yuLRXji+j7dfTdPANdBl46upZ7M3VtMiEzV42i
tVSOptxMa6rcWDWnak3lyKpdpuTGUg0zOjgnVy6uM6tabXZwLFTN9q38X/TZ
U81XhO284Niib/oPGxJUvQ==
            "]]}]}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Thickness[0]], 
         LineBox[CompressedData["
1:eJwl1XmQz3Ucx/Hv2rU2krRmM65JjkqWTE3MiFxNOkhbYRLKUaNNIeSekOsv
ojblLGGyXTO1G7lVjrWsIyXnFpuso2TGFerxnv547vP1/nw+38/v+/18P9/P
1u/3Ws6rKUmSzPWnAkeuikxkoQwdUIyauGZAEy7gxqlJchiPYlxakozFGNyh
ns89eQjS8Bd6ow9uwiK8g3Lj3uU52Cm/x8Wcxzt4p5sayu/HXPwBD+O5/CFO
yYv5R2ww9kDchzwm7gHz0B3Z2KL/EW6IRihR380/8GO8mZtyD3xhni8xCZPx
FsZpX8Mv8mp+idfyLtd9zk+rP+OneCW/EM/Mz6EFnlEP4IF4AyPRJJ5Rewpu
kyvEfeFheQf/a+7q8i3IVxeoD/I+/IRPsB8/IxXXMTKeJX6DT+B3rFN/jQJ8
hW9QiCf15cT18ipzD4hr4h65LzZpO8/f8fO8m2vr38Nr1M3lrXJP3sanuQfu
QTX9XfhOvgvV493Hs/BH+AWv42ZcwdD4Pf3DeD1vxIa4X/Muifvn0TwKDYzJ
50+xAp3VB/SfkXuhA06p87ice+l/FgtizXk8T8D3+pbzIW3fcj9exf35LM7E
nlX3RXscMz6bm6ET/lS34bexztgj6ky5RtybulD9UKw3r489inR1RRzVNkn9
gNwRZ9VteTbmIBVpmGjMVn6Tt/Fq447HXuRCrqntVlxS71VXwQh1U2yS/9Ce
EXtYfoWn8CDOxcvYq79M2/b49jAr5tB+XXtpPJu6TD4st4r9JNeRT/BG9f3y
Pvmc/Ddy4xvTtjLWEv1jXeN9GnNUXRr7IfZFfBfyr7gdXTFN28LYP7H+PBOz
4v249on4bbkb3xdniHwvL+aDsffkXbFHUVXbjagU7xwn9R9Rt5brxp6T6/Fv
vDx+m7M44RSMl6fwVBS7tjzOmphfvRslWKrewx9zNa4Vz8LLOAOdcAPqa6sc
Y9FKHswXzHkx3kesu7YZXMTT+Vh82/pbqofLtXEVddARx2N/8zVjLsd5oC7i
B+NauR3XwD/IxJL4zmKuOJuwP84q5KB7nEtIN+bx2Je8wjKcdr63jfNRbsMN
1HlyBhYhF320ZXM+KqEELZCOUlT8fzmTWNb43/IfwlnX9g==
          "]], 
         LineBox[CompressedData["
1:eJwt01toznEcx/G/UTJzo4apmYdwQVZstDknc5ocrmxc4IJZbc+V4mZIMbNR
T4SREDI5DtE0LmaOuXEmxydqQmz2OIvXr1y8e38+3//3f+j/PP/YsviCyi5R
FCUxNS2KevBelCNDr+dsCzF+zyl+Yz62axQVYn63KCrgQ3zR/IRciZ/yd/7F
cd7l+E5MkQ9zPvLw2/EizjKfy1v5HW/jKlyX13JdOIbH9u/xI37AD3Efx+wM
5SFYKafQiSf2yvhZ2JM/ySX4inIMNj/H57FUXoIme8P5hdlIDJNzeQ7eysV8
x85o+ZrcIefI7Txe/8y1/C28T/N0bNEruCa8H67jON/kWziFk8g0++K8ifIE
NMuLeRRqwnVQiwYcxR5sxw5UYzN2I8d+ARdimpyBfeiFv1iNNeH9OH7ZPZLy
Fc7nA2Zj+CAP5Hqezke4FOMQ0+fxCixHGj46v9X8ArL053pzeHb5tlzCRfol
NKG/nslnuDH8zliH9WgL/wMkMEOfiVn4oUeYLT/lfhgk9w3XwWn0Ce+Gb4T/
D1659x++at6KFqzSN6FN3shn0YgyfQNP4sl47dzunOSWcA0M0LPxwSyFl3In
JzzaCCz0nfTmaq4K3xHuoicSZnl83H46L9Jzeb9e8f8b/AcyLnoV
          "]]}}}], {{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Thickness[0.015]], 
        LineBox[CompressedData["
1:eJw12Gk4VV0bB3AklcyUCBkapEEIhdwVSiizyBwJIaGQITzmmcxj2MeTKMp0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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6], 
         Thickness[0.015]], 
        LineBox[CompressedData["
1:eJw12Hk8VO37B3CyJbIVIiWUCtWDUMRtz1b2KEu2FNnJWrKT7FmT/YyUoqwz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         "]]}}}}, {ImageSize -> {300, 200}, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], DisplayFunction -> Identity, 
     AspectRatio -> 1, Axes -> {True, True}, AxesLabel -> {
       FormBox["\"x\"", TraditionalForm], 
       FormBox["\"y\"", TraditionalForm]}, 
     AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, 
     PlotRange -> {{-0.509683995922528, 
      0.509683995922528}, {-0.27522935779816515`, 0.27522935779816515`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    TagBox[
     GridBox[{{
        FormBox[
         TemplateBox[{
           InterpretationBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalSigma]\\), \
\\(\\!\\(\\*RowBox[{\\\"0\\\"}]\\)\\)]\\)\"", 
            StringForm[
            "\!\(\*SubscriptBox[\(\[CapitalSigma]\), \(``\)]\)", 0], Editable -> 
            False]}, "SwatchLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1], 
                    Thickness[0]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.75], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "0", "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.75`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
           InterpretationBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalSigma]\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\)\"", 
            StringForm[
            "\!\(\*SubscriptBox[\(\[CapitalSigma]\), \(``\)]\)", 1], Editable -> 
            False]}, "SwatchLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1], 
                    Thickness[0]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.75], 
                    RGBColor[0.880722, 0.611041, 0.142051]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "0", "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.75`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
           InterpretationBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalSigma]\\), \
\\(\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\)]\\)\"", 
            StringForm[
            "\!\(\*SubscriptBox[\(\[CapitalSigma]\), \(``\)]\)", 2], Editable -> 
            False]}, "SwatchLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1], 
                    Thickness[0]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.75], 
                    RGBColor[0.560181, 0.691569, 0.194885]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "0", "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.75`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
           InterpretationBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalSigma]\\), \
\\(\\!\\(\\*RowBox[{\\\"3\\\"}]\\)\\)]\\)\"", 
            StringForm[
            "\!\(\*SubscriptBox[\(\[CapitalSigma]\), \(``\)]\)", 3], Editable -> 
            False]}, "SwatchLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1], 
                    Thickness[0]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.75], 
                    RGBColor[0.922526, 0.385626, 0.209179]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "0", "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.75`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}, {
        FormBox[
         TemplateBox[{
           InterpretationBox[
           "\"\\!\\(\\*SubscriptBox[\\(\[CapitalSigma]\\), \
\\(\\!\\(\\*RowBox[{\\\"4\\\"}]\\)\\)]\\)\"", 
            StringForm[
            "\!\(\*SubscriptBox[\(\[CapitalSigma]\), \(``\)]\)", 4], Editable -> 
            False]}, "SwatchLegend", DisplayFunction -> (StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1], 
                    Thickness[0]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.75], 
                    RGBColor[0.528488, 0.470624, 0.701351]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
            False]& ), InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "0", "]"}]}], "]"}], "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.75`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.528488, 0.470624, 0.701351]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm]}}, 
      GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
      GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6593378525499735`*^9, 3.659337892647298*^9, 3.6593379624956512`*^9, {
   3.65933800426814*^9, 3.6593380409140387`*^9}, 3.659338085118251*^9, {
   3.6593381418043003`*^9, 3.659338170792765*^9}, 3.6593382672589054`*^9, 
   3.6593384132800612`*^9, {3.6593384694127073`*^9, 3.659338487619558*^9}, {
   3.6593385413473325`*^9, 3.6593385654363585`*^9}, {3.659338601444784*^9, 
   3.659338616935613*^9}, 3.6593387026301336`*^9, 3.6593387656016245`*^9, 
   3.659338816722734*^9, {3.6593388547155704`*^9, 3.659338903930329*^9}, 
   3.659342360639033*^9, {3.6593423975801177`*^9, 3.6593424012046905`*^9}, 
   3.6593424354808903`*^9, 3.6593424948578424`*^9, 3.6593425430678835`*^9, 
   3.6593426412912655`*^9, 3.659342749323585*^9, 3.6593427882470818`*^9, 
   3.6593428682675905`*^9, 3.6593429739942837`*^9, 3.6593431444796977`*^9, 
   3.6593431946151195`*^9, 3.6593432376264887`*^9, 3.6593433124693565`*^9, 
   3.659343492498519*^9, {3.659343526396463*^9, 3.6593435556411204`*^9}, 
   3.6593436661491895`*^9, 3.659343711802425*^9, 3.6593437496551743`*^9, 
   3.660282855513707*^9, 3.660282891645281*^9, {3.6602829288076096`*^9, 
   3.6602829569525394`*^9}, 3.6602830004813643`*^9, 3.6602835863177643`*^9, 
   3.660283627329791*^9, 3.6602857826527867`*^9, {3.66150207849673*^9, 
   3.661502097141877*^9}, 3.661864208877943*^9, {3.66196440452538*^9, 
   3.6619644137044377`*^9}, 3.6620157378288975`*^9, 3.6620158001538568`*^9, {
   3.6620200545609164`*^9, 3.6620200657784595`*^9}, 3.6629060812774754`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Direction of trajectories in (\[Theta],",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "."], TraditionalForm]]],
 ")-plane with input"
}], "Subsubsection",
 CellChangeTimes->{{3.661864152347782*^9, 3.661864177114909*^9}, {
  3.661870923399332*^9, 3.66187092448711*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xMax", "=", 
        FractionBox["5", "g"]}], ",", 
       RowBox[{"yMax", "=", 
        FractionBox["2.7", "g"]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Quiet", "@", 
        RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"above\[CapitalGamma]", "[", 
             RowBox[{"x", ",", "y"}], "]"}], ",", 
            RowBox[{"Not", "@", 
             RowBox[{"above\[CapitalGamma]", "[", 
              RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", "xMax"}], ",", "xMax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "yMax"}], ",", "yMax"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"MaxRecursion", "\[Rule]", "5"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<u = -1\>\"", ",", "\"\<u = 1\>\""}], "}"}]}]}], 
         "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"k", " ", 
                RowBox[{"Cos", "[", "t", "]"}]}], "-", 
               RowBox[{"1", "/", "g"}]}], ",", 
              RowBox[{
               SqrtBox[
                FractionBox["g", 
                 RowBox[{"m", " ", "l"}]]], "k", " ", 
               RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", 
              FractionBox["3", 
               RowBox[{"2", "g"}]], ",", "1", ",", 
              FractionBox["1", 
               RowBox[{"2", "g"}]]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"RegionFunction", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "t"}], "}"}], ",", 
             RowBox[{
              RowBox[{"above\[CapitalGamma]", "[", 
               RowBox[{"x", ",", "y"}], "]"}], "&&", 
              RowBox[{
               RowBox[{"-", "xMax"}], "\[LessEqual]", "x", "\[LessEqual]", 
               "xMax"}], "&&", 
              RowBox[{
               RowBox[{"-", "yMax"}], "\[LessEqual]", "y", "\[LessEqual]", 
               "yMax"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "/.", 
        RowBox[{
         RowBox[{"Line", "[", "content___", "]"}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Arrowheads", "[", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"Automatic", ",", ".8"}], "}"}], "}"}], "]"}], ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"Reverse", "@", "content"}], "]"}]}], "}"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"k", " ", 
                RowBox[{"Cos", "[", "t", "]"}]}], "+", 
               RowBox[{"1", "/", "g"}]}], ",", 
              RowBox[{
               SqrtBox[
                FractionBox["g", 
                 RowBox[{"m", " ", "l"}]]], "k", " ", 
               RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"k", ",", 
              FractionBox["3", 
               RowBox[{"2", "g"}]], ",", "1", ",", 
              FractionBox["1", 
               RowBox[{"2", "g"}]]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"RegionFunction", "\[Rule]", 
           RowBox[{"Function", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "t"}], "}"}], ",", 
             RowBox[{
              RowBox[{"Not", "@", 
               RowBox[{"above\[CapitalGamma]", "[", 
                RowBox[{"x", ",", "y"}], "]"}]}], "&&", 
              RowBox[{
               RowBox[{"-", "xMax"}], "\[LessEqual]", "x", "\[LessEqual]", 
               "xMax"}], "&&", 
              RowBox[{
               RowBox[{"-", "yMax"}], "\[LessEqual]", "y", "\[LessEqual]", 
               "yMax"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "/.", 
        RowBox[{
         RowBox[{"Line", "[", "content___", "]"}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Arrowheads", "[", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"Automatic", ",", ".8"}], "}"}], "}"}], "]"}], ",", 
           RowBox[{"Arrow", "[", 
            RowBox[{"Reverse", "@", "content"}], "]"}]}], "}"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", "k"}], "+", "1"}], ")"}], 
              FractionBox["1", "g"]}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"PointSize", "[", "Large", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"AspectRatio", "\[Rule]", 
        RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}], 
   ",", "\"\<s10\>\"", ",", "False"}], "]"}]], "Input",
 CellChangeTimes->{{3.659092660503997*^9, 3.659092730994789*^9}, {
   3.6590927620727415`*^9, 3.659092766757049*^9}, {3.6590928216718388`*^9, 
   3.6590930359802175`*^9}, {3.659093133188882*^9, 3.6590933792526903`*^9}, {
   3.6590934302837343`*^9, 3.6590934463070517`*^9}, {3.6590935175703897`*^9, 
   3.659093858481265*^9}, {3.6591663204973946`*^9, 3.6591663941063886`*^9}, {
   3.6591664719213533`*^9, 3.659166555838629*^9}, 3.6591666093244085`*^9, 
   3.659166707620841*^9, {3.659166753489255*^9, 3.659166770157028*^9}, {
   3.65916685457866*^9, 3.6591668835801454`*^9}, {3.6591669447463503`*^9, 
   3.6591670305969915`*^9}, 3.659167084929369*^9, {3.659167115832197*^9, 
   3.65916714948697*^9}, {3.6593444153664026`*^9, 3.6593444277091208`*^9}, 
   3.659344463093103*^9, {3.6602830748760457`*^9, 3.660283187873063*^9}, {
   3.660283432189598*^9, 3.660283447226246*^9}, {3.660283506395157*^9, 
   3.660283540959632*^9}, {3.660284873497243*^9, 3.660284874183729*^9}, {
   3.660284921609313*^9, 3.6602850162314873`*^9}, {3.6602850546217628`*^9, 
   3.660285126226468*^9}, {3.6602857184483223`*^9, 3.6602857342405047`*^9}, {
   3.661502106966797*^9, 3.661502113064109*^9}, {3.661864105150813*^9, 
   3.6618641266600256`*^9}, {3.662015672237578*^9, 3.6620156806295023`*^9}, {
   3.662019975998054*^9, 3.6620199867991734`*^9}, {3.662020114665166*^9, 
   3.66202036014327*^9}, {3.6620255109990206`*^9, 3.662025512221225*^9}, {
   3.662913456262205*^9, 3.6629134766686654`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJxknXecTsf3x3UiIr5670EESRBRMyJ69OhWCSJ6j+gE0cvqddnyrN57H9ay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      "], {{{
         EdgeForm[], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          Opacity[0.3]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxMnQXYlsXWhd/uz0BsLOzEQMVWMBBBTCxExQBFRUHB7ha7u7u7u7v1WMc8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            "]], 
           PolygonBox[CompressedData["
1:eJwtnAm4jdX3x8+9nOOec7vnvGd4j5QGmmhSNEiTSinNhgoVKg2aU5IMZUgR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            "]]}]}, {
         EdgeForm[], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6], 
          Opacity[0.3]], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxMnXW8HTX39Yvbg8s9fuacU+wWd4pbcXe3tjgFirZoixUvVty1uLu7e3F3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            "]], 
           PolygonBox[CompressedData["
1:eJwtnAm4ldP3x48GKZUGqXvvOZ1z7j3nfc9UNMkUolBJKEMya1CGTBnK0E+I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            "]]}]}, {}, {}, {}, {}, {}}, {{
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwl2nf8l9P/x/F3S0NDmzIiKyQhoYEkFVGojIyWPSq0kz0zsiIqZJeQKNJW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          "]]}, {
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwl2ncc1tP7x/G7RKVQREN77ySayCiyySahFFIqqZDsQoPs0SKkRIhkltGQ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          "]]}}}], {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt1nk0VP/7AHCRNcqSJUskKlJJQqhHJYkoslYiScTHnqUQQrIrQsoyBjOD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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwVz3s01AkUB/DB8ais53i0SWISsq1HDyedbiJia/MYGnnGoCIhYkKHjEex
jEZ5zNHDjJnfbzaFkI3cxLaUJW96GaVMJVQqtK2d/eOeez7ne873nrs25Lhn
mDyFQvGRzf8752prbba+GKhwzy47IbZ59k5Te7LMlzcrzD1grUVpfdXiAZnD
Xju7dbCssT22gm4gMyeA+lfllm1IX3Otr0NPDA9UGfw7LAecsp6ID5A50btG
3WRkN/qHRNo/1hVD8WxTf/oWN5RcP2IKMh/pvFw2UvQrUv3UtuTpiGF7eZsy
l+WB0pmCo61UMTQ290TXEV5YYm/Z/lxbDOxU1ZGeYW9M8zBznNCS9b/TLp1Q
YqDVuUeTvZpi6Fp5Rvnj5oNolJFUK9IQg7Lv56SvTH/sMEzmh6mL4UOEmuMc
NxCZ7G1NK9TEAPTGZycOBePEGqPFUlUx+FqM86RJh1Bjaf1M9DIx8FdHd7aK
QlES4yCsVxbDpsS0/HXIREH88awJRdm/NpOUjKEwpCW7tC/KiYF237jUXPEw
Djw0NnmxRMKQUz01zuAIzrsmVNV8J6FbqPem1vYocvbbuCxbIOGNj8TFICQK
pTtUGIVfSMA5XTMn1jFU3WBZLDdHwjrXFtVQTjQyKtn8smkSPAvyXXYFxWDU
9cC4tnckrIgMcGh7G4ME2Rs3IJXlH9204WQsShJfnbR4SoKlvP6pr/wTSCQZ
NDkPksB57nCs+nY87nnlb13TK8sNVp1RcE5ARqDZuEI3Ccb7N65y701ADXXe
l+AWEkyGOxg7/k1EolZzgdJAglJhlsM5Kgvt+q/4V9WQoG043S+4zEKVwRSF
XVUkiIPMi29ZnEJ/Izc/URkJTKuu7TU+Kdi+/yA+5JBwQF5p8lRUKu69z2Pe
zpXdp3QHeH5NRauZ24zCLBJU2ni1RmdOI127NYASSwJhq1Wb6pOGKlo1L8kw
Ep4nDPfpjqfhXmbqT0+CSMiwDW3wM01Hgp7VP+dLwuzUyyBeZDp2jElaFixJ
uOkaeG2nXwb627yfrKeSEJQZVMr3ZCMlRvu8sQoJ9CejrK3dbKzznChsliNB
RL3es7AiE6lee6odvxFAl95banDNRKO6gZrBdgJChaWGki3ZGJypcPexiID4
eNg3bZmDXd/dk6dKCMj2njTtE+WgmUGApW8hAR8kN9XtX+WgnSJL7+ZZAiJ6
OsfLjc8ie2PP6TFXAj5pxtn1qeaiZDQuZ5MZAWM9Xin75fIwLVj4bVqXAA8r
rkNYch6yKdZ2VmoEGCe2NoY15qFd+Fh3oCIB/JVoHvQ5D5mrXm7d3CyCi9V3
h0yf5mNJxZ9JLy6IINIrPWy4uwA7fCyfuZ4RAWWGW06hcVDiWNdxKElmxSGL
3bs46BShYBsRLYKzlYYtmcEczHvfyNJrFIJ+Gf3dLeZ5pP0jF6niLYTqvi6d
t0wuquy8oXVurRD4F375LX2CizEzBRf3KQvhw47U1xtoRcgZZWhqLFbCv+Ym
vHnHIhyZWWy4M1UJ4xbcSxhahLSU88pc1Ur4vfBHjx8CLqLRjYHOe0UCuBue
vHToQDE2Z3I5Mz4CKKzM053tL0bpgfnK3K0CYLMeG6hrlaBUL9eyab0A1jXQ
0qjWJShR+hQ8pCeAkaZJPW33EnQve1zvTONDuN5t8rtOGT46tsFkpaAC7Od3
0ARfyjCKvccuKqQC4seW/x0QzkO6xWmRlUMF+KyLT9e+xEOnJ/pCllUF8JRD
Uib+4OHcM8ZozZoKUJvljV4f5GFK6r557+VX4UtswWBTfjkmLbRMxbKuAEOn
qot/+BJ2OL9fffLnK3BS3ibu7cAl/A+rq6+3
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13c4le//AHCUvUmENFAKkUpI3mRm5YNkpSKRrE8iLZKVjJA9ssk+4zmO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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwVzXk41AkYB3BMh8hNM1KuhNi0T6S07b45CjFthKISI0e576xbOZoY4yqy
wpCEEsbM/H4drzOtrWyxGufaoS21ykoqm+zsH+/zfT7P93m+rw4j1NlXSkJC
wk18/2dWZXtzJo0EDZejC562sXfPcu/dTxZ7y9ytK/J0A3zozhX5iz0y1iIn
S9+JK543aO4Vu7VAbrgzzhLJAy0R0mIL7vQOfXG0xZgG4XgblYSrGy6jiTYd
2x5t9zkttoJDoqg+zglprqPLkmKXjqDSdz4uONUzz2WuI2FR30Omy/EIRqVU
pFHELv9XdXqfuQe+apY+HaRGwkrnO72odQJNgo4FdKuSUG0r51e8wgsX8n5N
kRc7009ypWOcNxaL2M22KiQ0sqsOLc4wcNWHl0thyiQsvPN8zmGcwq5dyj5M
JRJcwioM9j33xQcfXEUFiiToTA72TTj4464dx76NlSfhvMErb6kdZ5CW2r58
SI6EEvv6gMwbgTgrZL5ev5YEvrWZ5ArNYJzN7FZJXkNC8FC7YjglDP0CpA6r
S5NgcW6TT+W9MDT0t2isWkXCuLpv6aPYcMxWY7RlUUjYn1s0rPx3BEbI7I+Z
lCRhgK4QtrUmEieuSzuYSIj3RpKkrbyiULna+nDhFwKoGHDy6EA0xiwPZDYu
EiBgJTS4s2LQ7kvMGPmJAJo1oe5iF4sd6UNM+1kC2Dd7OfPbfkK7jMOCpjcE
qCZJvSyqikdpvS2rD04TsPu3J1IeJxLwbtSxhOG/CPhGtSBOjZqIIlj6I3iU
AKGmd0ztUjJePeKYLRwkwF220fi4IAW/UiX1FvoJ8D5tn0NTS8XxzoJXlKcE
aBRpkH3hqRjk0PP45y4CrLSzDGOm0vC22jNfmfvifw23bK6XnUPeqdqkGyQB
GyXMps0Xz+GnZOVHu/gErExTjm1zO493rdr1hLUETNjQiq8/TMftl3mG9pUE
JM790hmZmoFemwpXnCkjgHJlqKxvLAPtQt5tjC8hYG/ecLLe7kz01E71TYon
YGZt/wuJvgt45sgFY6dAAvqbBnSGaRcxLYU+95ZBQHecLr383kWsoZrM1XkS
YPogHz8qZOMU9cExDw8CQicorvaMbLSixK1WMifAxFQ36ff3LOxizSiiLgEf
Ocmm8xvZ6GWmM9lLI6Bx0ib0z1A22r3vp9xXIcDhTazMs2I2OlvkVVTLE2DD
zLh0v52NGctabOqUABy9KzdnS+djyIacS9ceC6CQKXJm1uejUNtjUqdDABej
+cZvv+Tj8ISsN/2uAAJ/HNxcsrkAnfuMwoJ4AqAqGYXDwQIMKUuTrUkXgI+2
cW5XfiH+wFHPVg8SgK1IoiTXrAiPr/fUW3NSAK7ToQZu6UXYIScfFHJU7KYI
VtNNcb+5+ESPkwBaRw1rVw8WIXOLkmiPkA9aZzVyD2QU4+yYpXD7JT4Udd7p
EY2U4HZZr7LxSD4IN5BKUhlX8ImRwwcvBh8sbziZvhi+gqxwfdscdz4s7Twf
57CyFP1S8lvrD/HB2KLLsG5bqXjP8Y3FHR6wqE/W+T8tw+K6TR3ugTz4mlXt
slWrHN2mOPt1rXjQNqqoube7HHu72ctmW3kg5bRHRWZtBWqWzlHqdHnQ+STY
VaBdgbQXOxOUaDxgP3unwNhRgQzbZ9ym6FawJvXDv/pUImOgeel77VZIuDbQ
0fG5EnVZGt7R81ygv27K+sGGg4rOUE8f54JFCN2NcZqDtyNqlg37ueDvYVk7
E89Bfa2nOp97uLCmQjkvisVBI7MocyUFLnxykLFI5Fah4SiaxN1qAbZPZFbH
vmo8To5X6ye2wMGGmMp/cqrxP+J7qe8=
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13c8Vf//AHBklllKqcyiEBklqV4yIiGjsouMKBkhZKQIkT2SWfYe93LH
Md7XvVayuSgSJS3JR0hDfc/v8fidf+7j+bjvx3nf+z6vdSSvepm7sLGwsHix
srD83ydHanXXeCkTiXvWjp6qKwSJhBtRnLeZaDJhZxFFqRg0rs1+pdkyUWPj
9cD4r8VgHLqcqm/CRGMM+sD6uRKIYrew8ddnorVVjh38wSXQvuXka05dJiqb
6YpLSimB4/zoRZoWE3EUWEbxVZTAclprl/kmJrIY7bgZpFEGbtznshTejaJb
7KOB1X/LQNjsw2Hq8Cja3JH/66lDOaycCY2+1jOKguzWbLyTyyFkfyn1WOco
ehgmbdtXXg6Zmd//46CPIrXPWirS9HJ4RDx4nxYyitryPfRzdSqBbF+aWGI1
ikYuLKAo1irwjvg6feLMKJrv9eikXakC7pDgP0snRpGG5EunmoQq+Htd11jv
2CjyyZTT3lVSBaJ7XrxIVx1Fl8sUpEJaqoClXaNU+v0I+m74Vl7saA0QvrI+
8W8eQYO8HwMVv9UAx7eqJ/TSEaSd/zlhxrAWFu+T9MxzR1BhS6ptRGAt/Nr1
7YZw5gg67HNot35iLXhvLX4+nDKCzA7JU1hLaoEzXpGz6cQIeptzTuZyVB1U
3FsyMhIcQS+jFMZ0p+vA8CE9v+XnMOJfpjkzeOqh0yqpwGFxGEV9tZR0Ea+H
MB0BWtXHYbSZspGsKFcPTmeG9FffDiNSYOPm72r1YDB9nrj4aBjlTNu+KBmq
By2roVt9DsNI3mPG1l6MACaspIjbhsNI3aO/yViXALqnZvI0YBh9v8GzJGdJ
gFPPfjEzNPD9EoUYKQ4EiDmSK/ef6jB6uGLAv+ZOgC13HudunRhCxBmGftMG
AY47A9uO8iE0tM+ROK1HhLHy+WcXk4fQhOuX0jB3Iqg++7bd5cEQEp9XXVEO
JkKLrUyr290hlLuuco09kgi3rr6odw8aQmLM6M3Dj4gg7LI+zSI0hEK9Sfkd
Eg1wLtDsSNXkIIp/4HAs360B8oY6/Zpog+ihKxFjfdQArR79NcrEQTS1mUU6
KbcBWHJFgtyqBlHlfo1Mk5IGCAYx55ziQfRtPeoIV20DxN21KrJRH0TYx8A4
T/VGGP+5l8Px7wB6779y0jmoETKsLlIaOwbQPamNh31PGuHrTRV1rfIBFHDk
2KPX5Y0Qe4YjYSNrABESr9tN1TcC7VNwUeOjAcSi95ubSW2Eimrl7QRyP+rf
S1/OVSCBSuqOLenn+lGMVc0WdmcSmFUsxkpt70cu+4q5j94lgcxCZungzz6U
fBDSax6RYKdmdqbkQh+SrHamXk0lQbim3x3P6T40smHgJZRFguSfLTvEWfvQ
g7W3ctvZyDDO2ZGyKbkX7f+XeJpDjQxi1K+92Va9yHtCNzrAiAz5t2a6zE70
omWjCwKJVmSQopENZBV7kVZ+wrWUy2RYn6ne/1O8F10/WCqR5EyG5R/uJ2Pk
XqCWK8vvP3SRwcEnovpCTQ/K8ObaJvaDDFkPc16/8epBg8ovzoryU4Bl/w2F
RNMedNDJM9x7FwUuuJeZzmr1IL0e/lwhcQpoj873KSn3ILOaAb6qfRS4tM7b
q6b2HKkIVi/R7+Cuqpb1buhGKvuX5vQKKXC4reAD+HUjUR5p1jkSBYRNznQL
X+hGqtTbQrE0ClTNm8X80ulG7IVhTPMOCkiliim+Vu1Gu4orkXAPBbqy5uip
8l1o5grTaHQbFVbqrnpblHSi6UKD+2xHqeB6+eYjb6dOdH2tVMLjDBXsNFmX
F093ouNxPl7+JlQIuxsuL6fciVIP1Kh4mVOhx/BYx1WJTkRVya93vEQFntcX
7V886UChH01ivvnh9/9RJKN7qQPxvmo+HR1Bheml/Sq31DrQqTlTtdJYKswJ
PiY8kO5AHhWBSgoJVPCUKZjJ2NqB0MHDzPJkKsxOGLANxLajrv0lMQlVVDDv
dn5JOtOOHDUOHTKlUuGZ0BHI29eOzr+To0QiKox0v5hN2NaOpD43fEylU6HI
lzs8lK0dlda1N2R3UMHPPDq0joOBHGl//ltfpEICh8UWLIqOUvi/iBuwYiC9
2VhDTJ+O6Gd9rMd5MCDqtWUYyNIR1rYysM6HwclK4pytCB2pR03/+yeAwbyL
6Y+bXHQU7qQxzLIVgyXWM1yj0W3oq2vMJilJDET5p84t6Lehocpv4bsOYBBo
HSm3LNuGxrLLFjzlMZDdkpXxXaQN+cVe5BU8hEGRRxPHClcbavSw6apQxIB2
8o3iQhcNeaWLtTDVMHjPZdP0tpSGymzlhtvVMQgJ166eekxD6rGrbSoaGEj4
321jRtOQ7XtJw6zjGBzi5qPU69NQrPEry3XA4Ean2IcsWRryf273MVwbAyNu
M+sEERr6qb+Y3KSDgeNuRb57XDTENDAZ+qaL/3+j2S3mDxCS9h65P3gWg6Ok
gGZvLYSArThX2AiD5bPRcxt7EVq08MqSN8ZgWOlP4cPfrchyzfWopgkG7NhO
40qfVtQ1fmRCyRwDrofO5Q0KrUjs7vDUhgUGb75YZKtvbkXGM/tfvLyAwU11
jlvUDy3InfXupZqLGKw8+hBKsm9BMU9Tn5GsMFDl5rSr3dmC3MrTvPhtMEhg
3xQht9aMFArZtWpxG9urTBWNNCNZ9/FKA1sMdu54f+5xQjOy1Pt9wcUOA87b
Xf4CHs2oP/xP8kfcFQpZ61Fnm5HICM3d2R6DNDW+6Q2ZZhQetn9qArd/w6CS
H3szCprg+aR3GQP3P2k/Ps02obyz55MqcWtHbIYrqAnRjF8O8VzBgPluVmA0
pwn95xtf7YD72KsXvgZ3mlDEZQvpOtzbTgf5NVs2IRGGsOo67ln+7N2HjzSh
nOstU8ccMDht8fZW4dYmZK+sKXEL9wk1lsgdSxja4AzbKMR990ux1cM+DEUu
Bvj1465nRP76XYEh+797HvyHu2m7ia9nDIZsHZyU+Bwx4DlD7J1xwVCLmY6v
JO6JNhdBCx0MHZImmyri9vuzw6BDAkPdx5q6VHGnegSGqv+lop2bTSaUccc/
1MTKJ6lIRMr7/gHcRd1C3HuoVKQsvq9TBLdZVpV3QgYVAdGz8B++f+y1lg0W
PyqKLbwkOoObP3GV4mtGRZ3dc3JU3CVXOavmFaloq8A+Zixur33PZqx5qei7
v+Sui7jl2AMc+j5R0HnBhTUR3KF7NI6c7qIgL/Z0zxH8vI54Z7o1FlHQcpxS
eDTujA967HL3Kaj/+6C8Gm5XY5Ns4ZMUNLcebRaAPx8Vr80VsaIUFJg0/IIP
99L2cX3WdTLi2IifycGfr0eIc1ggk4zoX14m7sOdTbhquUQgI/69Ey+L8PgY
y7o35ZZERtecq1r34lb54C3y9iYZ2ZWFnErE4+tGr3g4KJJRAOsWFX88/rw8
PDS9+MkoBTOnTVvj8TQqVZe/SEJlvuJc2rib/hObY6slocnO6dZVSwzUFOIJ
RxJJiDNR4vAZ3PuOkqzcvUhIhfjAJukSfr+saMMRJRIaeuM2KYTnA9ubS8U8
giT0gE9b5SyeL+MMxTWtpUZUOLuifQfPp9s9OpmEuka0qlGT8twMAx/WkvWF
pEYEL3cPfzDFIOCfzc0DPo2I56Jy77/zeP7/6S2QXG5AP4TCNkni+WwQohlS
TGhATOF1dl5DDDIPiVp8SmlATpbsEusGGETLjtxR9G1APzNzfrzWx2BQyOel
6QoRGdf0Uo7i9cO2z4nwuYGIeIldcS1aGOyRJb/TSCciceG3KQF4/VnRsCqI
9Seild29VvKnMMCq2ViMAgkooLwo4qMKBkP9xjbjP+vR+z8eGvUKeH51mD0o
w+rRPFuMjPdBvJ7mFQsLZ9ej0OZf2p2yGLgFvCu/F1yPdnq8ld4hgwHpleeg
0UYdSvZXsxMRx+DAgQZDaK1DzRtjubd2Y1Cj+W6yKa8OuTdEf8rYhYHuj721
x+/WoWgC/0aDCAbmHlkyxqx1SM0nU+obXt/d3d2dnkfWonEpi6X5LXg93F9l
+FGvFkFoZvRLvD/cLmBX5OWqRTFn/T53cGGQxRb8lMlZjZySI/9+WaXCf48f
qWtzVSFpxd9BzgtUiBO4fDQnuhL90LDed+cDFf4ZstgM61eia/T+S7/nqGDP
NVPBz12J9Ayz995+S4WA28FrY5vLkW5kdIhLHxWGLn4lvOItQ7c1XOJ08P42
wPZZiTOhFGVOtZx81Iz3MxuZ+BKTUpRyfTd7Kd4fj4czt5kIlCJFswT3JhIV
fF63BaZuL0ZHeS8ZBeVRYWx8p8XNXUXoootyPcL77c4wZdrD7EJUOGU6diKO
Cr26l/mK7ArRhpLdx/+iqcCW7hHWubcQ9fEPFj+NpMKZGLcrnAeeIcVRCUFV
dypsZcmeXDn0FB36WLA8Z0OFw3+5prWv5iOjz72ymRZUSNMPjIl9n4dG1+5f
+nge36/n7o05tzzEHh91SsWICixFUb937MlAl/Y+munhxtd7i2ab/U1Gt5yF
Tlyfo0A4u66G97tE5PX8S3fiED4PffO7u2kiHoVoXVJY76LAYHSA1ZPhR+iW
BG+PJIMC3dv0nK72xSFtZW073VYKPA075yatEIB+5G15T/SgAI0ZOWgQZId+
RLaKnj+Nz2srCoI9JHnQ/nltfk0Od+n+Bz1OFpAmnhf5DJ/Xwi+u6vla2sLO
Ve/oBXyek3iWE5dT5Ah3X32oOSxMgTrHC0+kVu7DW2mVG6HN+HyYe4ZPaX8s
dEd4iwYnkGGmhLTLjRIP+W+cfi3dJoNBn4JuZXgixMiIjPLcIIP3k6SZ4ypJ
kD7iQuNzIUOan8oyW1ESXGXJ3sR7hQxLogr9VXWPYS9b2bbvv0lw+Lb19jD5
bLjyWlDjfDcJkoR9Dyy+zwF9f6++9WoSLOmdFneh54LjskdR1VMSaN2JXfc6
nAdOci1Wf5+QwPTLCW2bvDwIrN2ebojP0xMX7qfTvhdAW0yeA9deEuzr8TlZ
21oEbSFqV9LfNMLcFP/z0wXF0Lm1SMyQ1ggTs68lkraVgLozt3x4XSM8Gttq
s9OoBDxBcF9KWSMEpkVMxUWWwIjtaZG8p42gNeogm8xSAf/ap02VxfD1WcKD
waRKcHiT+q79VQOEQDnDPrEKKg7tVI2gNMAoJnTK4HcVnOwdaIXSBmBfnCjZ
rVwN8v5bXNPzGkBwdbPnhGs13C+7ZvY+vQFMviX/+HW1DlKFG1mVOBrAxiQo
UPloPQxOXmwqwYhg15ne9yyvHtZnj5e8TCOC58UX7gnD9eDyU1d+6B4RtHYJ
YD4L9TBK0A/WDSTC0mkpSwNOAlhvNzxE8CRCL9CvTOYQ4Xc782TWMAEyPhGO
HndqgGLOeLH79wlA77evONDRACtqC9Gr1gQQ0x5707/aAOLS4R6JegRgY5l9
ysffCOqMLf4XNAlg99K/65RMI3zz4dIUViZAlaCS18EHJHD9Iddz5XE9GIXm
PDt4mAxJTIr1nEE9VJxJG46OJMNuz2gPLUn8fXfJ683NGjLoz9coXOSrh6d9
n5NMGGQQ2MmiY72pHui7FtikJ8iw0eIub/2zDiTuq8KEGBXOlnQoyVrWgdt3
Jk94CxWqnjtZxbLXQZrV3GIBXud+VM9bYo21sCASnHUNr8sOvKI203G1IBY/
Xk3Sw0DYeYwyd7sW2E2+vFvH57J2w9d27xxroedJEad2dhPIa6prya5WQ4xc
lmrr0WYYH7me+1izGjK731rzRTSDudJmUZ7pKpiQyX0yUdYMJzDFOcHaKihg
/ypU2tQMof8uF8Y8rgKpq/7bXPubwSNfxnz9bhVwf+H34F9ugYiMn4OIrRI+
x5ld+BXaCvwExZDTpyuATYTxyofeCtdVpNDAm3KYiS65YzzXCkYBf35/rimH
jO8sytKrrRAOl6k3M8phvXB14CMHgg8EbfgUWg5pXDJSy6sIOPUuxW4TKgP7
FLGTjmo0qHgy6xlkVQr7V+x1bprSoFZbybn4dwnY1R/ddvYyDXLviGuK9pXA
PxTipuBCg3eXFHx6G0ugmSley+1Bg3F56pGgvBL4e+LYQe4xGqROf93mK1MM
vukW49bcbXDe3J0Y4VYE7055jTIl2sBViT6/nacImL7Svh8V2mD5vdYu7ZeF
YKlx6/28ShtoRLXxmrUVwpY7/SLTx9rAgltY17a8EB7a1napZbSBbjKX3nPx
AhBKJcux09ug6txzTQPrZ3CMT7RMdbwNHN1Hd+evPoVbmwLUcmfbwIQ4sLWe
8RS69oa7d863wZvDwx3Eiqdw2JYy/+FLG6RaDpkSkp+CG6az460GHX5qClp+
/5sLf5ZNqr/b02FSRIJnxj0HOmLqH2t54d+nxKCKvGz43i68Rg6gg3ZlZNr8
sWwwnZmc/BBMh8C4l2d/cWTDv7RncwLhdNj5l0WbayQLJLM4/oXR6aB6FbHv
cH0Momv3TU1m6NCeOKW6pTod1E3oKzaLdNgVzMP5bSANKKdU3eVW6ZAnoLJ+
wjENmoOS3CLX6RDM/01u8mAauPa4AfM3HRh/jj/xXU6Fqb6hEaHtDJA42PDK
82gKXJ/aXjEiwYDTRmxBXy2TwXSrjkOoDANcrw60J3xMAtOPcEP3IANQR5bk
RF0SyCl2ApsCA2QLT1L2BCWBa6bdmyItBohX6m877h8PT4VGYncaMuDUmL3i
QmMcGAbsncsyYUBEZfSh7WOxwEm0V+o3ZcDgtYe7xFxjgQATx9bNGXBWOypQ
fO0hiD4TVxt2ZMDwQr7kEBYF4UrazHtuDPB7dYC/YM8D2Fr8V7viBgPiVHvO
3TCOBFPznnyVmwxIXqzx634fAYasV7YTPRnQc3KhQyIsAiocrKdc/Biwbd9i
hsWbezBhfu2FQAAD2gye3BsWuAeCrJVzVoEMwFzGareUhYOMAKtwVhADXsjY
DGpphQNvztay82EM+NLAjHx9OhQix1YW74QzgK+Af+VKQTC8aq+oi7zHgGfE
ud8Zw3fwOFKPirqP/75bBSFdbHfgszNX3qkoBggKH1MwYtyGMZdV0S/RDEgo
LgrxkPYH2tVlv8YYBgSR9476WfjBmDPnbMBD/PyjT2kERviCrjRlcS4W3097
ac37nQ/IcG8kJsYxIMqP1uC6zQeu6pRqqzxiwPgkydBKxxvKziZOXolngEeu
VuqVMzehpiai7TPu4FuNSgolN4A/z5ByMwFf/ztVaJnjOkjED4/bJjLA1rL1
+I0OV7jwxJqlC/cR1hIj8f0u8McANOSS8PN/rajRH+kEl2/fuP8Ad7tchUvg
nCMc/9w1OYG77fx1dTFdB2i31dLbl8yA0sgHsuH69lDnTW+9hptzWoDWzGkD
ai0nDQpx52qJbfrecQkE2wtnx3Dz9No1ST+wgJi1D7FsKQxQ/RlIPK9rCn4N
/3RkcH8b0vb4xmkIx43e8mrjJrps2aPxQAcGf8W8v4i7ut9K5A/ncWj9stjn
iPvlrJj2P045kNEQ6nTBzfL/1/8AOa1+DQ==
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV0HtUzHkYBvC2Wppd1pJybUw2KivKpU5Rr2pFO8IOTXJOjBiJ6aaJpGLU
rKbrjKaLBo3JnuhCupAaveb3bfcklWKnoXbbdtMUutjZckKxP3885zmfv97z
PtbBERy+sZGREZvO517uOvs3/gUCS0NHqpwXJKgnGzNbebSrb+715LAccPuQ
2YufaO/Ssjr8WO4od0tmuNJWTUjb1z3bjHovMw9L2sVH3b/dyPLD94WFopcy
An1RDS5W6zi4Yizg90raTy8v7rZ85o+8l57Ox2knPVndyYgPRJZTVLEt7XsV
b2aMLwnCuORJ26dSAj9Yld9+fYCHxtem7go/27ymR7c2GNsCZAEzaGdelJ5p
+PIQCiJ00wqyCKx44DmtUMfHdo3hVyva3cKWF7E3QpDrwMjJyyQwVuqcwT4d
imV53sLptI+mp0RZ+h3DluHWg2EZBF4rWkyeM8NQuF4mXJROoGq+U4L1gUjs
tXHKPZhG4Itvjl0d843Cpg8jTVdT6T1KHpyl1hxHuxtVwUYSAg93GHb7mQox
ssa1mZVCYPqhoXrGsBBL5v7h7XKeAJfnQaE2Bq+LcsJ9xATm/+cmm1d8Emvf
e7MgmcCP1uYttVmxyLzs3u+QRMD3wpVUTuwpVMcFlwyfJdAz4nUy3Pc0du1y
L204Q+BIpWLeG6d47JFRD8SJBP7KtmWFLkzAZlvWsMcpAnFlDf0TQWeReSSd
wTtBoDXzQIW7jwjvvOqo+1tIYJmXxnNPnQiXB81ODowmcGnow7GwVeeQGc9V
aQUEtlZN+ko+JuHYq+nb94QScGwrcI7WJ6Nj37OW1BAC9URRsW+vGC9lVodU
8QkcjFNd924T424y9tYQRO9jV1KZffk8Nog+xOgC6X8Cuixmi1PQJlrUXxdA
3zcSFTVOpODKxr4YuT+B80t18kiBBPVTO2fmbyOwgMtM7HBLwwpO862eLQSs
ItTV7dbpuL15nWv0ZgJio51i75x0ZD6f+XLKi4BsfUdhuVkGCgabxsGRgMVg
URbPWopPvsq8/d1yAjajNv4po1I8d63JT88isDh9vTSJK8MJ45rWDUwCvfX1
uvcSGbJMqiMkiwj4CJZqw+7L0K3TRNFtSuDjfm04f082CsqHeE0TFNxJ278p
apkch8e2NWYZKFAstnz0PE2OHmXq2pBRCph6i4xpKEfTicoulyEKOlfabVxl
kGP/WkFFYQcFynuM1bdSc/EtP1KYTyhwc1AMCLh5WJsSaXNYTcEo55c79uo8
rFN+4mhqKdjSx474NJKHjePH1XNrKAjKEfo9ts7H3E7J/fxcChIGxytj7l7E
PNfBYeXPFHQt9DxTJSrAUlPz8hOJFJT1sW+X6gvw0WTvO/84CkqDZhmsFigw
la2TOpyg4IX52gsStgJtR1QmLisosOP+s+bP4is4sE90/40RBR57teoweyU6
bqieH/9aA2acuWxNthL/XVWcldGrgYcM802Pm5Rov6Hdi9GtgY8qw/c7+pQY
1fh0S7xWA/VFcYHNU0oc8DhibxGrgbq2TeG9KhW2J96cZe+jAaVWvzs+uggH
jBODD6/UwDtJ85yt3UX4+NYcS84SDXjzv86fMesa/g8eS3Md
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13c41e/7AHAlyogiSlofDZKyIiF3Q6iQiCRFEhnJCmWVkUi2jGyy93Yc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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13k4VO/bAHAiJJE9WSopSYjIEu5KdpKlLBWSpChZspSQkEJZskVlXxr7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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV0n001XccB/CrzERX2Y55TIQSZRinET7hXg0xjzW5VO7Nw+6VuI6HXFce
L6fI1cXV0N3W6oyWIWsaPpuHbpr1+zo2ax5iHbHaNU95OKLttz/e531ef77P
eZvHJIWc3cJgMNzp/N/L6u1U2McE5L6l+sLogg6PgNWwYNpT70YoBVwnlDq3
TvnQNovZbEzgspCjmhM7087uru58rzIQX3e1WOyi7cmTekRxw7DTcOvQZiAB
bZcbM9aiCHwqeXn5d9qR3pEDKlk0FrSmBjfQtp6UNA0Nn8Gus01mabSNn+mU
2HJ5KCpqWHelfYCzaJs9F4tXTDIm1gII9M1wB5VZCVgfcIBqon3avbpFS1OA
VtHj/adonxN2a7Jl51DQ/CWlSbvG9IrG4fLzKOqvmWw4RmBVVygKHE7G3UfH
Nti0/WJu53FMhEhelFiO+BPo0hhr48WkYoXz7apZPwKyPY16Mf+kYe9K/J8C
2nGTlVnHnTLwA6b5h8996b0/MHO9L2RiT7uN1k8fEchxCx1/S0OEK5G/FVrS
vmElThzxz0Y+/6BO7lEC7Nn5HTelYrx3qIlt5UMgatwrp7zsIo4uei0L2ASM
eMzuOIdc7ND/pOUbFgEGI0np8msuvjO9EG7kTcD5VlboL4b5yBQvuPl4EXi2
oUor68jHrznxjnxPAm1GeVW+pwqQyvCub3cn8PREss7KiyLc9oe1473DBELs
9thYvF+MzMCbskZXAk4rqd13BouRE6x6u8aFwK3m048cU0vQzSg/f5szgTfr
srilzUt4/e5zO7kjgbHQlGOfe5Xiw4cs83AHAvyMI6svp0rx9RJrn7Y9gXnW
t4W2kjL0zbmkXW9DwNUknTsjKccHh3a+6dxHoHXYgLO4X4oR67Ny77303ovM
7fMXpOgTO+DXbUmg18E+/q+fpZg1KlfLMCXActP7qmLHVTxvHybcb0zA7m6Q
P7v5KvbuKhxKNyTQE2vaoLdFhiU6dYGoT8AAJuYmQmSYMqDqVGgRCGo06Der
rMJiXvmry1vpPxhfG+9qq0b1xO2rPf9SUGoj5v7NliNrYT5Nc4OCxESFcq1U
jqKF8CXPNQrO8Lg2jGE5CnIq+nOfUNCvinp8Uu8zFGc+0b2mpMAhavdJvlMt
xjf0JUx1USAs+z7vUU8tpujG7M28T0HvaHBFknYd3r8jmdvyHQVryXwJM7QO
rWstc5XlFPh8OuK5XHYdU/V6H1hkU+DlUqRpeFyBQZmrJTuFFIwUHYkNqlNg
iNpS9UoiBeJCY7XpHxW4rmvXNxhPwavH6vnpUwoMmzY6aOlBwYkO9iaf8QX+
B9Bg7QM=
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13k8VO/3AHBLSqkQWSLJUiRSUUgOIoUkJEtUhCyhRVS2kDV7KlkqkiVZ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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV0n0wG3YYB/A06BlTpVrMu9ZLKU699Ohuv9VrDWubpl1qZQuL2jDJvC0M
RZpsikgiKl7SNLGxY3TtdtoVDytmztHLz6JiMlSr3TTbWaaWWrff/njuuc8/
z3P3PF+P9Dwai0qhUF4j9X/3jrAZZ4kxcqIzNtPiBQPyKOspJvHBjd6WXclH
IE5qoTtDvLB408oyOR5W8c7tY8TfSqy0d7mnAKwsvL2Jb92ZnN9Oegvah5zP
U4nlzlcg0D0Vvp9OkGtEGFknlq10c5mgF8vXlcStC2BzNOM9oE/5xV8gNnqn
WIwmXYC2LkrvfuKrz+2exIZ/AJqRUI/7DRiZ0e5MglsucF11Ch5xR7xVZrMp
G1KD9wUcJBZk7jBL4nKgd35rbEyIUV+D6qTx6UfwML0jO4V48/e0OWV6AYzy
IlzX6jGisxU+sXOFEJuxsJhN7PFAM7OUWAwvqDpeah1GPJ/HTGpYCeh9RTmT
tRjJErqzBF+Wgnb2L2YQcX906A5T1zJIOSQpWq7BKHd+ZDfH5CJI24KbAokj
qvdnXBu8CJtOyaP5n2Gkc2S1ThVXgm/+ctIjAUZxQqnWdr0KWnNx5x7i2WRr
dsAX1UAbCLWN4JN5C+XmUe/yIDuSti+Hh5E9ZL3DmL0ELo9brnOryb3rP+k5
V88H/qPstyuqMHKIvu1IPy6AaH+XG3HlGDV8Nak0BNUA3187YSzFyK6cuiZV
XYZMY8wfEyUYRd6bpqak1sKwp85PyMXokJ2Eu9e+Dk6b9/3MKMDoviuzqOsf
IQQ3ag7XczA6Z9nnf/5WAzAN1184szFivp9Q57BXBKfeMC6pPiT5kTp9N8MR
gcOuxtPsLIyi3D/1LVoVQ2S+zM2HRfb19MZ0tktgsMW0pygDIxdK6JNwowTS
um7Thpjkv1W2xcNnG2H4JZt/61IwWopxaO6ckMLzm5aV42cxKtv48W5+ZRPY
lhj1GjpGJi3z7TOLTcB36yr9hYbR6yJtxYHIKyDaYrstR2P09GX8kDIjA3u7
wqrJoxjhr2c9tA6toPKdY8mOYDTG9Uy+OtgKYQU/sIrDMAoZF8Mz6zagF0he
ORGCUd6SyZmE9DYw+TWH7eeBUWCIZ/lPf8phNMinsNIeo2fKihCDiwLE1GNp
AluStwcxect5CtiZ3qKn7MYo8bdiC3WzAizN/n61wAqjmBp+09CIAryyhr8J
2FKjJOY1r1pzJcg2N/sN62rUWLNCq+lWwvTHqbrDa2p0ubDfX7+thBlGePvx
VTXKPqHxknmpwPLe2AHGshrZ2/hx0JsqcOznbBgm1CjD3V84Ku6AyojBG4ED
ahS/QpEJQz+H/wDZDflJ
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13c8Vf//AHAZ7RKSiEpFkdXUkJeUEVF2VojskU0kIysfe2Qrsq+9131f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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV0H1Q0wUcx3EELOg8kcPM8KCm8+BOEeJi45LrGw95sZ1Q0iTGDthW2ECc
jcaFNOVBQKTBeBoC42nanBZD8UoGs28JQyQmoO3L+cB1QCUoAfIwrlzUrz++
973Xff57syTyQ5+4uri4hDP3/0/Mklly7AQtKbvsvJCzlnVuQLSCsXzU/dgV
zlv4fEU8/jHj+qQM+bccHmb1+uXGMd5zIF7gNCZgkUgcGMw42MddqeMIUSXl
/P4C41ddrHxfSRpefPlSp/0Xgs9WhlMmjVJMVAyWNjH2Gl/L1i+k49NQQ9ZH
jO9nfl0u4mSgZeiweBNjnyauYbMqC/2OPJNcv0ewK8Vz6qH4OAoWKhVJjBsW
7yj2bFRgnXu8ZukuQVJNe7HSmI2LG+IshYytrt2NZr4S45wmhyfjVRsvdG0+
B2U3tXBmjCD1ZO1wUPUXaH60t/6fUYISHJsVhZ1A2ahXtm2EQLl3t0mfp8Lt
yea1AMa2rh8F3f6nsFA3VJ57h+CV9I53ptLycanl+dQGG0HT1gehv7oV4psT
akP4MEHbcmmlwF6IBcNHT6T/TOB7Y2zfgKEIG00+H168zfSKnAmriy3G5Bmp
sGeQoJLr7b/sW4Kzad6K/lsED7+viOXNlaC1ootuWAn+JkHmdMUZDDoUw+7o
J9C8vmmKnVaG0uPy0zV9BHmZi7qUN85i94TDeu8Hgig3NndZqUa3k+Wpb1sI
xm1T5z22VyIapvl/9DD75cDojbOVyF4ZOVhsZvr1SrY6RRrMcDwIM14jELZr
b5rWq7A/+xbn9BWC/jn21SMj1fjXa36PfjMRVGiXWnq5NWhs62yM6CDAF1Ov
erbV4GOdrinKQMBnN/zpHlmHHaadkRo9wU8FMUEiby2y9u/AS20ErHzhgCpX
izlPDMKeFoIDd1eKz01q0T28zHleS/DlwR3lloJzWMrtq5BWM/1DoiP0HzSg
mOQvcTQEMbbaqjJzAxaFXDP+qyb4dNruJWM1Yid7NZ+lIvjqmNp10qMZDX1J
Wzw+J9j8nlf6al4L9vkGjr4vJ1gfHOAkhLXioHyb5slRpq9/8XVHVSs+Xcjb
r8ogUIkunKqeb8X42i1On8MEQxHL2wJl7Xh7p2QyjE+QWL9g7mLp8Vlwa6nu
XYLd+UHNEyo9JvS68axRBN/NDPDnvtFjd+g+18dAoE5OlDnu65FTOG9cCyDI
UQsuN8dewP8Ay3Lifg==
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13k4VP/7MHAhO1FKVHaK7LRQua3fJIWslZRCKSFSKnxsISrZQ/Y1W/Zd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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt13k0lN//AHBLRUIq2pQsLWSnIqm3reyFZFdo5SNLRahICUmyRAjZkiVD
lhn7tYwxZh77MpYZZEmUJYqy1Pf5nfObf+a8znPPnXue93LfI+bkbnadg42N
zYSdje3/vvWSuDagRyPIl39ie0dCA7zvGd18zHgExQnk+ivPNkDSq20n0o6N
oAyBq8Jzu8jA3FibqiM5gqwiT58qkCFDGERGbhMfQTtMY3q5VMiQPbrVfFB4
BK3z7ve21SQDj925voTbwyiaVf12cowMjN/TX9U2DaO9WqaNmsqNsBb1U3Cl
YwiZHySWedo0QuzunvxS0hCq2nny8PTtRiAHGAeH5Q4h3aEgz5T7jTD7U+Q/
6+Qh1N2+6mkc2AjTsqXsWSQWqn4gFMd7kAJxNdsPm2mx0Nfo9jChuxQo3adn
yMfFQtfCfn9hT6QA5Qx6ozPFROHv99Sa5lPAYqtspcUAE5327uObJ1IAu8f9
0onORGo+grMhtRT4cUx8sqNvELGxbVSOsWgC6QJlTi37QTRWYn1f7F0TrCuE
rX4TGUS2vAr+1PomEHB6NJP8bwBxujGK73Y3gYXJdeXZuQGUq+KlBKwmOOsS
WKQ6MoCK43XnOb80gYOt/urkr36kENJjqXuNCkzL3+qr/v1obeVOlkoaFQoZ
SmM7tftRhuaFXjFEhcBg86TNh/pRiF/j6cUWKiBtHlgT6kfvf4j9M+uhQvzR
jy7Tm/pRW+GJpo9MKtzXW3/ou6MPRXtR9HZdaIY8j/82SsYzkPd1EerG4GaI
Zr9+dp8NAxWExH+eSm2GTccyeP+qMZCnmPbyCUIzjKdLTd6SZqCVB8Qz3SXN
wNGUUtsmzECSuiKW/1U2g2D+zMsuvl5EaqvWL5KkgaZRhvuxZz3oTuysYJod
Dc4bH6p5rNGD6MRo0pQXDTyl0x35RXqQX9fwYacnNLjRsFuijbcHGeUtXYkJ
pYHbO4GRF6vdaPHONa3qCBpMx6hF6Ux0oZTLNdweMzTY9zJla7lVFzJ95SbE
tpcOffO/Y/dv70KcYVk3X8vTwe2972LFbCc6oJTkq6hGB92W774bWJ0o6Esm
6R7QgWZZEmdA70S3ODxcC3XowCYbcTsmuwN5T+2fbYulw/pQ/PA/oQ60NXBK
0rmSDtTkzE+uWDvSrC+b926hQ6/Aa/OoD+3oZUDcinEvHZy8NukeiG1HPVfC
g/IH6MDZ89Qi90k7UhaRF9g4TIeGbw+oaqw2JHFjXiiNDQPHlw1TuXptSNNi
ypEggIHiuI+z9t9WpCMXXh60G4MzZM9prn7coR0tV/dhsMmm+kJTcSuakf3a
riaKwX8FjQlbn7cgyQbiWttpDP6GOfdrLGLoAPqk2GeIgY5M4vfT2RjydHB6
k2eGwZ7worLSJxiybo3Zs9kCA//kDkEpe3z9qy1+l60xGK34mv1PgYY2qDVn
DAXj6320dAl7mhF35JPnHG8xcCp9O1z9koosNlwddc3EQHXj8fwSXSr6kra4
63c2BhyGBgt5B6nIw4FfWTkPA+bujMBUdiriC3lvfDMfgwX1cM/JrxTkmlnQ
vqUGg/M/3LlN7CioZbPbh9JGDMoURl8sCVGQqk+5i0MzBi5Beb6UhUZU7E/W
kKZj8OjnT7XXbY1Ibtsj/jkMg0svBeSJWo3IITNtitSFAb9B2braGhmdpDvu
XejFwPqiqc9KHxllfDqSHtSHwVLX6S1lpWRk+NBKRGAAg48GXktvJckoILQ3
ZnkYA7YKjsucow2IXSfhX+0oBrMGnuElNQ3ot3CwqPA4BtP3Du6+9rYBiZhs
VnabwICPz+XUHGcDOkIVbqBPY2BSovXmaFk9Gvn6dkR/BgNXjxnm2eh69N3L
r+HhLAZjm2Zjr7jWIwevzNAPcxjs7VxsI3XXofqu7tvsPzHgdPYrHQytQ1xo
b9b6LwyqL71F35zq0GxOTvTcEgYDktLRK+p1yPb8oSv9yxiEiGY+O/q+Fq3F
XTKUX8X3y248p25di2pFq/1y1vD4hnnVaCvXovE9Gx1s1vHzqzZcNOCrRXmL
rhKcfzGIOpXDmfsEoXylz9rq/zDY4NV6pegEQmO1sakY7tQuF6Py6RrUElgx
YM7WAm6GrUM1KTXI5ozUQjfuaEV9mQazGlTGVfPFiL0FtE/IGFA21SBHFcuy
Ktxzl6nG1IpqJObec+MgRwsosLkbNbtVI4kE4YWnuBkkT9tm8Wq0PMlvM4h7
9oZ4JLW3CiX0xqUc5WyBIumuf5SwKuQrmYw8cVfY9iLymSr0eIqvuhD350f+
E3ULlWiXGyNuEreGjkhwTVYlkr44bbRzQwvoB3OTKmwq0TH/k8PquBvVIl8S
+SuR4v4KY1vcfZ7cB4rqKxAx62q8J+6NF8iP870r0ES/PArALcW5i5p9tAJ5
1+ytf4Y7lXKRJ3OoHJVkiqc9xS3X1WL3LrocBR7Ss/PF/ce+rzvxXDkyEY9Y
vIE7O4oSErdShmQa/9wwwm0T+i0smlCGih5HE6VwF5xNXIxwKkP8Ak6jf/Hz
0wsPMV7sLEOr3vem6bhNI0YMntNICLH3tUbiDvbbfy3En4QOnk1+ZYz79Jic
arASCT0QYchw4O5gv8l89oWIwooTswj4+9To2XUjOJGI4u78WzPD3Xv+aEAY
BxFRo4Q0nuLxUUyQOxlBLEVBquyyW3F3ds/LxriUIrM4juVoPL67ntbdSRAp
RRZP1VP4ce9umt+X1lmClg50iz/B8yPxSqtmbnAJ6uueD5rB80khLWepRK0E
YWZVZBPco/8ackoJxYjza9/TvXj+Bf3pPFt2qxj13Kjb5IXnp1sezbdKvBil
XndPo+L5e/SZ5PfmuCJUM1AnYruCQVLnpGGXSRESc6lmT/yD16uwVvAQTxEK
ypNZ7/iN7yft1bLi/wm1vDp8RhavB5lXGatbTn5C57yEgkzwejkhulv3wGIh
ao3SGHPF60km1tfH6GYhiuA9PBu5iIE4f1nADbFCdKXHNDF+AQPpfNSykVSA
LHOTHBJ+YODeef6AcGg+kvJjPLXE6/nwu9bsRo+PyOxRrirfN7w+t6nbSEzk
IfOYjirWFAZ37dt7gq3z0LCmjP2HrxgEvJnRMpXOQVXI72/oGAYPk/e8sRPM
Rkd8JB+3j2Dwr25W/XvoBySx88qsM95/AglfiE/Ws9DLb+cerLEwIPqkfT+V
kY5UQt7aJ3RgIMIoO9ftnYqu6l9eqKfh/XJxhSurLgWtt1Ej5ZowqDqm/asm
LxlVH/fbaYP309RzCoVTsUlIOHd7nX8DBiM75doNIR5VTLpOYJUYxC++cnET
jENTY50jNBK+vrOJff+/12jg44NEVIoBlofdH56KQav2DQ/zi/Hfu1pn7SL9
Conu5M8Sxft7of3S1Km+MGSeFXHqUxYG7ZuzvScIoUhm3kbPHb8frGYmRiqe
BaMxky+Bh9MxeDyjM7Ah5yoKOfn7zdMI3DtuLwYsXYaXAU0HuINwv783pB7k
AVHh1J/v/PHz2hr/N/3lHni6j539/AADDQ4zLWl9X3icshws7IuBh3wHV/Gh
CPDfFps+54jB79rD+U4eMdBmNVdUeAnv56utoh4psXAPSAI3L+D9eVhaVK80
DrjqSSQVIwxqXe2S2LA38GXhiQ27Pp5PSeG9iWdSgfvDZTUzOQy4mTekLjmn
Q674U6YZft/quK136vtnQCA6ZCa1BwPz74mvcrgzgXZMaU+YEP48nXB1OToT
9ATip8a2YTBuGaTZMZoNLRcspcsW6SC6f7R5mTsPEpSKGatjdBD83lQWK/wR
QlqbpH8O0iG8tWiMkvkRSFoNvycYdJBZiOQcl80H01aHofYuOmgERinFHSmG
vGC25bzndKhoTzgi9V8p+M8O82c70qH1bj2l8AUR5JaTlqaN6MDENEfShEnw
fOQyzV6LDv4Pm+4/u0oCw+q7UVtO0+GW3fFVmzwSyJ8oiP+kgs9LDuSoZdEq
8KaGC/1h0WBcIUx8m0UN5PxWcTlNoEGRtazwAXcE8tHvFXJiaUDNElLWWUVg
WeWXp/icBorX+dneidZCq8ba62l8nsuV+pAQo10L4Rnxi28f0iDC8XnMQ+16
OPvz6SuJfTQg6ws+StNogMijo84hU82g469wybemAda8uPLT25rhcHUq+fh6
A9AEitvC6psh6MdbjtB9ZKi+1Rv8C5835e5lq3WeIsNJ42VOm9JmsPhqHbZX
hgKibaryVnrN4OoYvEtQrAmmrK9YhW3F16c6EFFiE9y62USIWqBC7cyd2w6M
JlDN1BH+MUaFg0xl54xfTaCmx0l9g8/LveZ5HqwdVOjko3uo4vM0TWtUgipI
g/RmQZLYRSp8seNtUdxGh1PPg0vDtlLBxUadzS4CjxNh0lxkpgnEk80f5WN0
YHBZyNcONkHw/LUTjd/o8Mcn7whXVxM4obmwDh4Mju9eDdCl4f8X1Il8br9a
4MuWX31tavj6C0YkvS+t8FSryuH9PAV6tbfRouzb4JTSsbIlGgX0xBRtvse3
AStm3PQPiQLcuzZyhRDbYIztroQngQLTiQ6aQt1t8MrVKms0kwKEl+vz1xnt
sHl9R2nxRgpIHh8jRRp2QPyZvJuk4kawyw0oZn/WAZcbNZLFwxph4BlnRmRa
B0gM00eVvBqh9lp9dktBB5gMtVZ8cmkEsUrrIs6aDhD6tOH6UQf8ebC/fVpy
J+gtqNz3LiHDfOGFmUqeLiiduTlra0eGFcLMx3iNLuDlIunVyZOBK/T5Ixvb
LlCvtV422UOG3IwnxwpvdYFEtfVeAX4yOJ8X8/jr1QViNLF7zRxkSPsTE/Dv
RDdYastLE60bwOHXvlu8sd3wfXo81pGzAUJ47jjfbegGUxkqi8Koh1BN02r/
gW4Qph3+xKqrh4g0MbOViW7YVrJHYZRYD9yH3I+6/+gGhaAjO0fz6qFng8L7
A+97IKgdTd7/UweXltLNndZ6gGHPJRefUger+SrfbY/0QsFwzc5ajzpQfUN7
RFDvheMzRwwrrOtghIchZ6zbC1tIWv8UztfBFeFYbNy0F4/jjrsZWnWgoUp4
d5iTAYdWSM3cfrWgSXj7LdeKAfsjmpr/7KgFxY25GhlPGMB/bAsnTx0Cte/E
DNc3DMhOuOF45SWCJN6dCeQ0Bpw2Ki1+eBdBL68Yn+BHBhx9ePRIlDUCsd1b
PR8Z9QHZavj6SWI1qIaxXbuT0Afe9srpjp+r4Fvzi5C9qA+8VMBM0bsKrhOE
yss7+qB739rnWxpV4H7itcDaQB9kbT9f5HOoCu68uRlxfLwP/i07RT/mqQI3
9jaC2q1+MC+S3i3vWwFDpEEfhw/9cMpOWvYAoRw6N1cGqFH6wbaZrZJDrxyW
+l/t8u3ph/yuHr52wXJgEqXqeVn9sNJYWCC7WgYypd458eP9kLqzyPzZ5zKw
qSUXKFoPQM89s7VxbRIwu0dDX0QOwLyGzdnlO0Tw0Ao088sbgLDEnkd/NxPB
T1+Qvb5sAF7ErZx36ikFiyqVCWs0AHdGum14K0vhq3N721TjANip6yt+Si2F
WjnCcqzMIFwrn6U3zBUDz7vkcYrdIGxJjeR3FioGDmRRKXhvEMwGklKoH4qA
n726JzRgEHi2+zsyPYqg0yVf6sSzQfh1K9H6yqUioAiqsg2GDYJYvhFinSwC
ExrpZtrIICiYF6i7BhRCeGiuzXluJmyZVD+trVkAJrIGUhbCTBjuLuisdCTA
kzkTnayDTFB4Lu1B+5EPHD/zbDSlmJBi5B5EKc8HybQyWpcsEwJ3sctXBuZD
0t3FxElvJqgecFXdXZ0DKy8U+IveMKFGhbd8gfEBSk562x3+wASOtNOiFeNZ
MDBoJZVJYILcNhWdJZcsICfd+XWxiAmhUmoFPHJZcL4+hvCnlAmn9Y/U7/7x
Hr5u7zat6sAtS5HIx++14KpvEnlDTNCrKE35tiMDbm0jdU6MM4Gn/FGfc0I6
JDbf+L04yYTg/oYfonbpkKnftLo8zQQf5Vxap0g67LUKHsplZ4FpR0v1R+VU
0MgNDRTgZYGP6s0EkwcpcM74iMGmbSzQ7iUY7nqWDAr1FVOeO1igtDD2dWZz
MszaRdh0CbEgaJSiUhWRBCOCkaFSh1kwOS3fV8SWAPsMnS8GybLAeF4mZ/fJ
N+CBfYtfV2CBUSf5pNSlODhxRkkpX4kFal2HjaXGYkHw+twe82Ms+K09zXvQ
MxbibybVxauxQK+uc2EwOwawGunR4NMscDtRX5dIjgbueLvx+TP4fr3/ad41
i4ZZPm4lMw0WjNjHGeqORMG05Ffzx2dZ8ERi6+bbuyKhm+Oz+JguC7wmmAtt
1yPgxtyv+1z6LIhvJBAg8CUU/RLYKWHAghYDI/XspHDQcfW6qnaeBcOjHuub
eJ6DwW1C+TYTFphMBc5FaoSAgcnQhXncXfoVF1psg4H67IgsxZQFlqvLZzbc
fwZaDJUqy4ssGHxwKscp/ym4nUy+vcOcBbKPU2PCqE/gtZ/VdQpurkPN3/LH
AuFh4MEj2y1YEGuhQJ7c8xhOhI3P5+KeXc+/ue7sD7PLVmynLPH3RRUfkUh9
COcnuuc0rFjgT1GxseP1hdn3SW1E3LOJRDV3rfsQbpzwU8KaBYmLe+489PGC
c0aFl0Nxv6d2uwcR7oKIUjPfOO5KS9uMkHFP4ChoYVexYcESt8TD4L0e0Bmd
oxaI+/YHnS6ONFe41mJQVo97h24a8QevM4S6pfmt4t7iZxQ44HMdeLPeBUrb
ssDsrOr2mnFHIDecbDHDPfulIFItzQ6CVG7Ye+L+WAUbF3wugWTUfqUQ3FZj
go/10ozg9WMbw9e41RtnVw3T1KGiZ09OPG62///8D13Z3zw=
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV0Xkw1GEYB/Dd9mc3R0szJZSm3UaTO5pKlzcqFLIkKzWmlJRz3RI7G5uk
dWTlaIctanK0mUrHWnlKOZLGIP2R3mTkGDmKzEqs3v545jufv77znYcTFOUT
vIxGo9mQ+5/1vcZVxScw6lGePLSSntfQyOXbSYlTXfx15ql9cK7OoD2NOLMy
rERN8UCU5R4bQmxc0+0ewfIHvXl9aydi/dOq3gnqFDgqLqj1iRWDzzduYJ4F
QUVId08ARttdw/kerPNgZbeuUUKs/hDiEL08HExopfW7iDvmTVtbKAEssBlt
+DhGmnBHA55WDDx4FDocTxzcdqqvRysO9G7MrGYQpzv7SLyZCcCseeV3xR+j
v+MDGW3MJIjzmatc4GM0PfzNxoGVDFzbt3oXiGeucUflrBSo2+ud1u6HUfyt
FMMllhDudnZqc4g3NwzmWFAicA6L9VL4YmQp86qIptIgHLTZg0cxkjXNrsmm
0qHbMq5/BXHuZM+rckoMXHGHytmb7MnSSVRRGRAT6NLqwcMo6iNv9CV1FYqt
Hwy7e2GUz6g5pqQyQWiWFGTuiRH9XvZ4CZUFn7EYWB4YaemuThZS18Gwut2u
7zBGLyIevg+gJJC8I5Z/2g2j18wt6X8YOXBkU5HuKleM0AFLTxUjF9aLEz6p
DmLECaztUtLzoNy5emICYeTL/2E7R8sHDXdS0rwHo9pnXexEmhRiljYwOLsx
MredHLAWSWGy8Ik0eidG/aY333xdkkJxt/2oiz35V3NQ1xnNTRizr3IU2JD9
tQYNwsVCsEicLYyzwmjk54EmemoR+HmasCMtMGJNDMlTF4ogo15hOcLB6KSV
KpE7XwIFZtvEQaYYdVkJNM1zt2DsktuQ/lrSL7ov0k2SQWXk5dDHRhi1xSgr
3NQyyCm4qO5kY/Q0kBM9PFMKtx3tq0u1MYpUbLNe+lUGmpwAp99MjFq26l5c
FMhB6PNu2T4KI+XVDtvpKTmMpyzuL5/6gr4b0ct4jXfgH1d6cOM=
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwt1nc4le//AHANMlJGJRUNREYJSdZbkT3KptBHPhpkz0+hHJQZIZuMJCIz
ROe2z+GMx5Z5joyIKCUq5fv8rut3/jnX67qfc57nue/3OurobvrvVhYWlotb
WFj+7/sSu3+tmQkTXezZ5m6RQgLuXyfkXPsYaCPCJ8ZMnAxr3+Xod8wYSPOZ
xnh0EBli/1amtfMxkHqZGv/WIjJ47nxC1FmZQKoa8nb878iw22jU4+/kBKJ1
+BMSSGTY3hemXtYzgcLXcgvZe8kg1afpxdM5jrQFEkZqfTuBQf35WevCOGJ8
I5ZPtHVCm6e7lNbfMaTww9GrdaETEokB8UJjYyiu0G+UY7MTCC2+7SyUMZTH
CGHPY+8CSbOzpeP1Y8h5MXFIjq8L/Dx56fB2FMV/mWv8ktEFs2FRVwhKo8g9
6+x5l4ku8LwjLiGzNoKY9j/zuTe7QD2yKchpcATdpRjMnt1NgY7qE73r7SNI
XJGhpSlAAZ7QJJ1HNSOo67roYd3DFCBuLmKrJcMo5/tLZ8FMCjAutDi5iQ2j
DsorY7b3FLhZGVNMnHyPPisuqlxdpQBmt0+dit6j5dXTjIltVNixZOBFLXuP
qqwn9u7josKdvRq65Kz3aMYpOVabjwppXUcpGv5DqBwiS+9FUoHw2FtY8cMg
Mn47sE+0hQrXA+2jNVMGUYeKrVj9OBW00iMJrz0HEUXzMs1sgQqj4ec+TNgP
ItOYiWN7V6jwq/fTBIfhIEo6+9OPvk6FiZT9mn6HBhBHKXZE6BoNtAZhWoTQ
j9x/Ll58G0+DqUebskKK/WiRU5KuVUSDE//acRF29yOOkubJ91X49YeUrGU3
+tB2SUra03oa9IX9Whie60O1DgqChogGaeJz22tKetFOb+fHFAE63PQNUaFz
9SJ1+ygM06BDzMWY1qiGHrQ/rrPpgTkdKo2H8i0SexDDuyH8uD0divpUTRRD
epBAyu3BBUc6ZJFC+vldelAJB3IrukGHQ/6DVgmd3ahzKiHfNIYO9D/0148C
upFP797QgSw6VF/ZJvrNpBvpB5DUHQvp0HgwWrRApRsddJZ0zSimw68MyhVT
8W4kKPeMSimjw1CQLXs7O4YeXSN58GJ0ELS8PWz1Lx2NaikqXpugAyeblAKB
n46ejKf59c7QwcTq5MOETzT0uNJLP3ieDgGi37ZmNNNQ8h1TOPqZDtm5IrIf
HCnoRVWyRZswBqM1cFlargvd4z3wrVEBg/Pif8UIaZ1onmjushUwoJvosh0y
6kR8oSsOa5oYGPPEfZ863omKlNWdnbUxKFdkWypi6URpxbydNF0MSNqfS2/T
SWh+cjBr1RYDqZRHplxnSIh8Y5F2+ToGF0IOZRrOdaB08665yzcw0G8l5Mw3
d6CvXvK+2rcw8GP2aYZldKDCmhwLeRcMltxbh4e2dKDLVaL70r0w2GMhZP+9
uh11Kqc5HvbDINgv2D0krh3tGrYJHfTHwC1u3JX9ZjtS5n+8Eh6IQbPFacv9
9Dbk1dqL/QjB/69WgrTnQRuKIQ7s20LAgMMyF+Jt29DastDr/8IwGCQYLXMo
tCFnq7akxXD8+bPNtLrjWpHkEadtpGgMThLcDCRUW1EI9kQkJA6D4hvVZT18
rehTSvgi7TEGtWUa/wTOt6Bb3ydH+BMw+Pb2lDS7VgtqxLy39SVj0CL4NV37
azP68tfR/U8KBg7xmu+mSM3osbeMLWsaBpwLFdEh2c3IIINyY3s6BoywZucP
603II1Zg9UUWBm37Zzm5C5uQQOpMuFYOBqcndfue3WtCGfGs91mf4fs5U10g
b9aETgZvzXiHW+2HaIIlSxPaeoQkx5+HASEHi6CVIrTGcup1OW6fZUfbRVuE
QmWrDS7m49djmtUc7AjJ/5Vm78HdnFFZIlZDRGuKXtNmBfj63i9WGo5EJCLm
wKThnrRW67bZTUT343t+qz/HQGNkVMqr8R0yJ75UfIGbdJU7NPLWO3Tbsyue
rRAD1c/8n3L2vUMHP+3ntMMtOXr6bk1rI7KYvZdXjDug8qVhl0cjys9l2izj
7lUg+k4INSLZAVlZqRcYcJlVcq90NaDe2qti9rjrjndKsQY0II6/Fuce4c5c
uPhRQKwBsY3wuL7ELfbTxUqy9y16/Zvwrhn3ZENwomrIW5QVXyTTg3ulrLnS
WPotEtH6r3EId55FAPXacD26BGu3BnCTFWbXvCLq0bzEEcUu3HJUY8Nw+Xrk
JrZ+5A1uxfhVZgqzDu0fCpNMwy0+JUQrjq1Dw3Z0U2/cXbu4JIjKdcjcipGm
hbtHjYWj92Mtmppo29yJ29BX4+FsUi2Kio0Lo+LvqxG36+3v87XoZ6CxBAE3
+6nSOt7lNyhCSXBBFndTm326ROYbdGyUlTaA7+/4vX/9NPTeILuvMnRP3LcK
Av/zzq9BJZL5Jx/j5xOxytETd6kGxTNPxfHgNj68GlzypxrlnPLnjsTPl1F2
N6OzuBrNH8h5tY7HQ2jXuNq8VTWaONbt4oCbR+pKECdrNdK9eMbgXS4G4Xvl
PWUqq5DKn9/6fLj92DnZfASrUBy9cADh8VjZEEcSpFWiffyyRly41Ux4tZvv
V6KnVkjFJBuDm+T+lr1zFejZUkFwUyYGNkt+My0ZFUj5om3f5wwMUl2Hub1M
KtBAfl8OP+6q1sy6wTfliAzTz3Tx/GBsueIQc7scsY3PDVilYqBtm2SuJVyO
1s7HEBzwfFq8Yzvrx/UaiTGy9KzxfBvwpTxY9SpDwT0PHfWSMIjOeWoQOFKK
CjZ3rMolYkD8sbgfBZSgKx9kt8fh+awRL9exXbcY0Wauuu6KwfO//Amt/PVL
pIVl27RGYTDsMCR2XeAlavvU0OIRiUG3ZHq425tCdKJHQmsUryfZuuJdQhHP
0Xm1SJ+p+xjkSoZdYlkqQGL7x/Su4vVHp25Z75MF7obmLFoQBrK//YLKpHPQ
qtOTs/oe+H673uWvcUtHzGSTkv6bGNzXdCs/zpOK+LM4fi86YUD968CzwXyK
Nsp+zn92xEDU2mBsuiIZCc1dsP94Dc+viYWPJj/i0Qeb526h1hgoWXMmb5WL
RXu66CIi5hh8yVif+NYfhfSfuxvMXcbvr3ONwBPwCLlxBGw8N8HfX6gXhewM
RlwNhBOmeH1vWr+a1Z/pg7ATXRF3z2NwrXO5dj/FHe2/LsTBiveHI0ZYto6d
M1KzthZ8qIo/r8jlLSMqd6F40uX0QXF8fV1OxEf+IfzoTmwvOYhB/F7r38yN
aDjBONvevhc/7xcXnsM/cXD30LoCiQ8Dj9S8BxWO8fB2xexL024MJAh1+74s
pUFddh458AcdeMw2bHkrs0E8IHBECO9vMe8OH7wT+Qwu5ZVPnf9Ah6uXV/vD
j+bCPUFzFzLeH0Ulw+xj63MhO8nfQGeUDv3lgueM/Ath5PwNCSkiHV6J3kv0
7S+CTUb/jlm83xYljzSlbC0Gu7xftL0v6CB92L0/Oq0Ynp5j1z+Wj/dTqSp7
V9kSaOW9JiOeQwfVIMuxnOnXcJsSq60WjP/+bsOKk3AFbAtqbeS7Q4c8PU7f
U9UV0FzZcuqSEx2ol2R8t29WQGrctowpBzqUn3kcQderhOzdKsHuV+iwUikq
W65VCyxffLhjOemgoLR561tjPUQGlE3OTNDw89ozX7P2FhZFjUW1yTTYkM/5
3JjUAMn3b9xsbaSB87mFJyemGkDEdtR69Q0NFK/+NxZxuhEOqhwaEK6gQaLO
3JLvwyZY/cqtrW5CAz9vF9fKhma44lpRL3WQBl5ebWOb5i1wSGrqvyssNLgB
z0555rbAfhur3mZ8XtMWLbDJJLUAIeZh3hw+z4VlxfsSP7fgeauntGOGCkec
H/6SPdQORW0DVZ13qbBnWRhsZDvAssesPlGLCrOWnbTc+g6w3lniYC6Bz3u7
r+jw/e0Azt/GFK4DVJhbqPRWO0KCmT/aRuP4vOn133WGwwUS7E43216Ez6MS
P0k7Ohw6QSSzU/9dEgUeJVl0b3fpAq/BUv92Swp4FGtyNC13wSObw/GSZymg
UV9dP3WaArssDz05I06BFd3pX7Om+NzsrHf2ND4v82U7+zO9KSDpet/wOD5P
X4vKE3HNp8EDzmhu1cgu+L5t8yj5DR1qkt9z3YcuyPSNv2CGx/1bPanoFcEu
SAoY5jHB896vJF+eZUcX/C1wcFbG63BYpbbUvT+d0DKlaixIwiClv3ruy7dO
yMyWGRJf7gaqKdc/bladcL/p6eBDrx4ofD49Hs7WCUnRfq6pVT1AVbykdnuc
DKf0N+zW+3og6MrP6UoyGUS9s2WFp3sgPWaEaUgkwwVfmXNq33sgU1bvN6OK
DKYNDwKl13oheMbrphIbGZDtcMesbx845LLsIb8igThHWGJ8dR+0FmknuYSQ
IHXdQ7Surw+YbabpSTdJcK+f+lBjqg8oHJa/hO1I8HHR07B5pQ96DFFm3mUS
nA13Ea6a7YfEw+nlpk87oDwsubfObgDa+y8Qzyh2gOyuDYG7qQMgOvyAI5a1
AzIi/LNLagbA2k4+lO9zO3yxny452zYAu2tfIAqzHZp1hh439A6A6THV0uD+
dojcyrTVfT4IOo/lY3bicVSr2cD3gWsItFl4eyfetYFl5PzGffUhiPjEbmIU
1wZux5SzC6yGYKk0+4yzXxvMewu5SzkNAd8leSGX223Q1V87W+wxBI76Mywu
9m2gyNyrXqHwHoi/6nPIGa2QFFVc+yHxPWxdKd5WqNQKuiRDn7aW9/DPzagt
+WytsE/5xfkdI+9Buf/CrXA8zumzvAeyZt7DTtUDecvMFrARD1OW+voeXv6s
PWvR3wKKDTYmUZXDUGVp/i3oZzOMTNR39+8eAePK4TbxqGaoVKv8mKU2Ak6H
2PxYTZuhYGyJ28B8BKJUTZYHzzRD2MnwxkSHEQimsjrWiTeDEsuQSN/tEfCR
FvibJNgMtqbOqEdwFEJjHYOGFZpg36x4RfudUZhgVyI/eIDgSw7rmZGnoxCi
enXmyU4EfuXiZMmSUbjS8ps020OE8qi1DK2aUaDOqJUQqokQ9l2EbI5GYa8a
YUYghQhlT0ccbE3GIPfwlkL9yUb45TNHUksaA6qw70LbtkY4VHsDm6kZA9ZL
vbzX8Lojna506mHHGDRKxzDDrzaA5cXjpyj0MeA5c2YpTqMBlKSFatmGxuDm
lhLvBNEGMB99pnfOchwEuGqnLf+pB2ZJs1HGk3FIOGUwdDuoDtLHP0xtvB6H
Utb5PR8566DxjXleIHEcRHSqw0J7amFl0HC9uH0cSpTnikjVteD09WhGH3Uc
nDyChXek1kJS2obygOoEhE0OmBJRDWRf6Ku44TkBN79bTUb2VIMz+9RkX9QE
XDD49+iKTTVoPzWNMk2ZgDYP6fIdwtUQYCL5h5A1AVy5jp85Warhx787ZF7l
T0D5VrIMx4cq6PW8S1XfwgDHqEGaPV7H62osDj6UZoDQ6Csls50V4HdLjq53
Hl+PXvByflIOZRVjz70MGBAnPy9mZVEOl3IoiwGXGDAZEerQqVgOS1qH23wt
GOCbyhJ3dn85VE7L6p98zgC1sf2uB/a8Ap96GcY3MgPqGCrqI3hfojYGDmHD
DFjo8FQO/1kEqTz0jd+TDCDyqca/9imC21YFyVtmGZCkFS6vLFcE3Zd3nd6Y
Z0BtMv/Cu+UXQF574nlsOxNsTr93XRh5DsLpj6xluZhgLHGrbR4rgF3matJP
dzGhdLf0opZ+AZzPdaNq8DDB4PNi860dBWD/N3pmhpcJ5NZ944/a8qFmKCRA
R5gJfLQ1z8ZXuaD+uePiNxEmWBsphdo+ewYedk2TL44z4QHLQvXOA8/gXnXV
6E9xJiTeU697V5oDU+xdOtonmEAM3bFmLZ4DR3kkAk7JMWFjDsUlaWeA1Ka7
l5wiE8TYTms9tkiDNxf3PBBQYgK3JxL/eDUVRpnfF7aeY8JkbbZYFDMF1Ms/
ps7jFtOfMxN3SgFegsC4uRoTguxrjZ28kkFm8jDbkjoTDogubLkemATGU2V3
q4AJDO0tfSMbiXDC9PVpHw0mfE/q7TC6nwhVhRFROppMiHWtMlmITYBr13fV
JGkxwS1pYD0nKR5I1ronFC4ygeTSKPtdIB6GP2aO0XFzi/z4/UjxMWSHCwpz
6uL7WfGS3nwpGqQjRs9w6TGBV8bBscYuEuo+7cwJwy01ZkkRc3oEUocNtX/i
1nGv0Iq//RDcEgjG/fpMeFkTccXcPxwkHmi/VjZgQn/0fa+yoDCoLHhllIlb
0W00ZlsYAfyKtmteNmSCj30TMSf+AZQGd6UV4C7X6jP5+PQ+VPuMynzDnZlU
UWahHALRtxO5Q42YkHumItDI7C7wPhewacFdqECSQA6BMOaTO/kHN5GDtUTS
1R+mrx57oWDMhDDnzcD4AF+gs8e+dMZd7WC4+2uYNywZDswl4k41IUwbJniC
zvEvTo24+zwCZ3VV3CHlbZ8QE3ekkejtL2YuYGztz7+Jm0tCVSfB9Qak+PVd
FDRhgkfCmod0+HWwqpmsPol74fehmnAVB1AYz7wGuAv4fZaKXa0gjsGiZ4B7
63r3XJKKCRAGOd1McWcXEWtSVQBWt9dj5rhZ/v/zP53ogFc=
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV0WdME1AQB/AGEGSIUao4UNmRigKWIUp9VJGNSIMMAQtCA4pigFRaHGE6
oZYAgYpQtGWIDTKd1FOIE0JTViEovgYVC0aREZC4nh8ul1/+yV0uZ3HsNIuj
RaFQnEj97/M6jxShwRhRUeeuS9yijpUFbgMhxGIX7bm3fCasMGhT+xJzPnv7
v+aHgI6706I7sTCG+qrG9QgkSVtNbYjfGkVI5Pw4ML7D9DQgzjjcvNJqmAM0
7niq5iBGZdNP+rNdT0DAcomsk/j4G/GN4ZIUiKAXTJcSe1R26RXzU6GwXMaI
J37YoUhpq08H/l2TEhpx3nmjYYWKC7NNfbNTQWT+lInooy4PtsCv6DrinvU5
ejMumRAlr1VEE+tFzvMWEs7BgYSJACPiH4nG++eKL4CMoVK2B2KEQh++T4/L
ggKpMC6SOJKmrvjCy4bwm31VggCMJJtS3jyvy4XuxfJAc2LnjCyBDeRBB1+q
I/Mn9+6coOQO5UP02Q0lzX4YWb+0FNktuwyXg5XJ24iHvNqpaWZXYNV3zkGx
L0a9taaaFvpVyHAcdOb6YKQJwz5mxwogSGbgrvLGCObWbvXiF0JYXb8vndjG
76lRvFAAmheaayNeGLGuC3z2sYWww7carIgNk2OYXZNC+K0r/5u4n+Qz/ibo
TBFcW3qexfDEyF5rXeaCpBjkjxVFeXvJv8aYp5oel8CnQbaDmEFys4052t6l
YNfGGm31wMgyeMfGQ8pSCI+9Z969CyMr1euIvX/KgKEfZNHqipFu0UXmVaoI
4pSOu6tcMDLZ/K1fKhbBoHIiPtcZowa2XdkD2g1osB599M4BowTHHo/msJuQ
5/ihj7Mdo3At3YnMk5VgK3A4Z2FP9lN6Y1gLlcCOcHNX0TBa3lXRYp5TBUlq
3lKaDUb19NUt58OqYY16LqrSEqMxrqpvrboaaucTG+0sMMqlx9+Psr0FcqdJ
06YtGE1/HWdXJN+C/IFnrFQqRq1+R2WeURKgabRjYo0xYuezRRKWFIp5hZf2
GGIUOjrCd+uVgmdztt5tfYzqqI2Kn4Y18A+qtYs7
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV1nk0lO37AHB7hbJ77Xu0KEVSWa4WpJJQJOSNUMqSrbyUQrZChKLkayl7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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwVyn1QkwUAx3FePPDtDqmBIHbKTAckRjTUbPFTplMwmBuJiBN3CiiTQkUF
5DWgwS3wJVMSRYnEUmuinjA43od7YWPPM8ZwDtgGkgpdyksw3sv++N7nn6/n
4URurJ2Njc32d/1vYEVGzvlf6hAqqq6NKtUi2nX3RwOZjYjo21BKE2pxxT7W
yvRrBkdWIa1M0GJ+otvV8qoZAVsNyDykxWpb37xUZgv28RlceaQWpfuvDWw+
2YKhYH1SzF4t/vbNYb+92YI06sydWY4WYWf/2SI48xTnqAXhA25a5HhLqA69
MvR5c9fnTZO4M7cqzXJBjvQNDxwtQyROLFcdcBqUgx28cNlIP4nT5cTSYhcF
Jp2J6FETCcZ3R3wpQQrsz9Jb3hhJ7ErMVVxrb4PkEWNeVEqi9jO6VOGkRtIF
j/URGST8Fs40jD5QQ7Qytb87gcSeJ8SXqn/VkB9l9gljSFRaLHt/o7VjJYXy
dQSfxLzwuVcaux1md6EdlUeiY8Vtuw/kBFyujzdJXUnw56ZWJ2WRyCdCqj7/
k0CmOW+fRU1C9QXB5TUR8PRa6X1mjERdjSqr4Q8CIZeoTtUOWjT+rHeJuU2A
9dM3QWPuWvR6/WVvd51AW+El5yh+B5iFybUnxjVY7D0aO22jwz1xukRwSwPb
iBsvyvboUJn9yFqSpEF98YhHcIoOT0YDGdkHNZgV+hx5r1CH62sz/OO4GjCv
Hhd03tKBF+pVy9ypgeJWR/IiQydKLJtO3r/YjtmRZHXYST3eHA8wsPzbMRjN
TdtUr8dbFOzk2LVjV720cbZfj4Yh6pJ1Q2rEBXWJdON6LL5998ACkxqmVpqg
fGEXqiU+FUatGjdcRaKajc8QX+VHbHNUY7ji6cAPbc8wEnc/YfCmCo2ywnDx
+wZcSOTmzMWr4G7aTXPcbADvIn9RJFuFycd9O9aFGCDlx6RObVPh9J7ybAbP
gJA8+tLLdBVoOTvKulKew/dc9JolUW2gr/csfWRvxOvyyYODg0qUqd3eYJcR
ERnLv//woRKK3HBLqMCIy8Uvi6/8qES2/tcSVtq7/x5zMVOoxKktTCKg0Iiq
jhOrBpOV4FFSnI3fdsOHxgirKVMgzmI9WjTVjXmf+JDn/gpMCA1rbtB7MBYn
+iRqRg7GwBL+MKcHxWfOByab5Sh3c7lbxO+Ba0GcNV0rx1f04EPUxB4ou/hd
6VI5Zq/2JXaG94LOFjsJLDJQHtdkvGjpReSKUXFzggwvp87mXZnqhTzV89kx
fxm6svhKCcWE7eUpFR4uMohv5g8zqCY4sZSvEhxkCMNhV8nHJgyH2jZLrE+x
rrlSzHE2o8OpiHVsshXLtk6UeGWa8XB6rjb3bCuqxC0Blx+b4enpeMghoBXp
9dH9jhozrB75CWsprYg4dcTev9sMuPNO/W7fivmXQRzOazM+XeSh8x2ToimE
VcdlWxBpuLOxZ4EU/wFEOibJ
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwB8QEO/iFib1JlAgAAAB4AAAACAAAAq/mcRXpe4L/pychauT3OP867N2uO
SuC/pxe1KjZUzj9wU8v0kkDgv5QvlbRnX84/fJJR0ZM24L/OkyymkGrOP6Wd
oXPvQt+/VcMPh0MLzz/93q6Yk6vev1niwHbSWM8/9ZgQsllf3r9cmU0/5X7P
P7mOmEAaOd6/Zm1YN8GRzz/Ylmj48SXevzC/WdAjm88/BDFlAcQS3r/Dyf/O
fqTPP05uzHXu3Ny/Xnk40Q4b0D9L528j+z/cvzTM5K0DPtA/FBTcdAPx27+2
ykl4IE/QP2Kx/KBoydu/d8+HV5dX0D9OhJCIk7XbvxQJF+LMW9A/RrKCV7mh
278x0EF9/l/QP6MFikUbStq/0g+Quoil0D8KFhR8OZzZvwMCUg2VxtA/j9HQ
JclE2b/fonQArNbQP+p3WMfxGNm/NxIajZve0D/FCntg/gLZvzEnV1SM4tA/
FDqf3AXt2L9sYBFweObQP8mf1KbZite/8SR5qLsi0T+VaIKN+dfWv9fmdFMX
P9E/+rgMZxx+1r9ghpjN0kzRP6DkJDsTUda/cU4G2ZNT0T9Aus4UiDrWv4PY
Cy/tVtE/5t6Glvgj1r8sjV65QVrRP84cnDP4sdS/HcP7aOGN0T8jseCQRjnU
v7imUDZcndE/qlAEHg==
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwB4QIe/SFib1JlAgAAAC0AAAACAAAADN8+hYD/zj/XYtRT3KrRP9Lgkzcb
q88/uOfKuzSZ0T8DBMXnUwDQP+dcEV9HkNE/iu17464V0D+wXkxQyovRP6BG
ymYEK9A/SkC0AkmH0T/SFQlAZH3RP5YBvk72PNE/7pZhfWsk0j8IpsxqOxbR
P6Bk9oBgd9I/9pcTmnoC0T/hDT3PtqDSP8m1UXuB+NA/scf611i10j/L343C
fvPQP+Q8zMX0ydI/m0PQ73fu0D+VsHERrCfUP5HmdojFldA/knxrkMXT1D+R
XWcHsGfQP5pjxoQcKdU/FQ77ljdQ0D91BbTlmVPVPypLRiBgRNA/OOEn+8xo
1T+TLwybbT7QP3IoEkz4fdU/3wRxkXY40D9dICVIeszWP4AnTvlJrc8/uYpo
R7Jw1z8Rz11VJ0jPP5NIwAIHwtc/f0SkzMQUzz/UdqfwfurXP12yN57f+s4/
BiryN67+1z/BLxEZ4O3OP6vspALVEtg/xHwb+tfgzj9ARA4TgFbZP96ej4LG
B84/iMu78+j02T+4yQAZ+pfNP4olkTM9Q9o/9VJYeUZfzT/YULmoLmraPxh2
58C5Qs0/tCPsJJl92j8+jOu4ZjTNPzqCuhr6kNo/BiDvQwsmzT+egDJh6MHb
P3mnwFznO8w/9v9mgq9W3D/4idMtw8PLP9YrJ1kioNw/bk/iS/CGyz9cgkEB
n8TcP680wCJXaMs/xpAJEs7W3D/TpJGv/ljLP8oz+e7y6Nw/5yqLWJ5Jyz9E
HcTsIvDdPxpzQK8PY8o/vi6WEmNw3j9ZQJWGVu3JP8QFULepr94/KSXLouCx
yT8ixfRAFs/eP2tZBsP/k8k//OoQxr7e3j8XJIDkBYXJPxbkkRte7t4//Jwe
wQV2yT9ccscIZuPfP255qMe6gsg/qaNg8DEt4D+DrpWEzwbIP5oJRgZ/SuA/
egLtwUvIxz9bkZ7GCFngP0mJk8PmqMc/l+1zDw==
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[{{-0.5096847840563123, 
          0.2614906450621375}, {-0.5061711587515565, 
          0.26239086013359836`}, {-0.5011863624865598, 
          0.26363576062378935`}, {-0.4986851532178414, 
          0.264252409278458}, {-0.49743236185179107`, 
          0.26455927923782735`}, {-0.49617811879409834`, 
          0.2648651781155191}, {-0.47591657259962383`, 
          0.2696265877829218}, {-0.46565282603378216`, 
          0.27191256095828975`}, {-0.4604887608575853, 
          0.2730316272486893}, {-0.45789881277544237`, 
          0.2735851514125004}, {-0.4566018764846751, 
          0.2738604076838476}, {-0.4553036383731622, 
          0.27413465873313303`}, {-0.449894408018668, 
          0.27522935824542966`}}]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAzmg4xa831j/+VD98W53RPxnQ5LqQ
ptY/zWOQsqp/0T8zcfAlmAHXP9HbHLKhZtE/LnN2r+ou1z/4HG0iAFrRP3U7
JZOHRdc/V8zZHKhT0T+iurgtHFzXPw/jzUVLTdE/8aB3GOvA2D8yN7JA9OTQ
P3YjWcIVcNk/GRlD6QOv0D88Mi6K1sbZP4ck4Cick9A/YDCLIQHy2T/9PKaY
zIXQP6YRDuWIB9o/u108691+0D94FCKbBx3aP2cghqfqd9A/5HGSm0Z22z+p
Q/eaJQTQPyDxsQI/H9w/fixWxQqRzz9UhJUTzHLcP1g2XnCPVM8/lsMmKlac
3D/UW254GzbPP3KT9gMMsdw/uLdy+NMmzz/+s9K0t8XcP8C7qXuDF88/FH8f
IvoK3j/E1CKWwx3OP7bTrGesqd4/BnGu/ZydzT8MizXEBPjeP4UhrQy8XM0/
8IAvIvAe3z/K0ZmtGDzNPwxMa4lVMt8/vp7fVLorzT8iLa8OsEXfPxeDpZFT
G80/FxMI5DUv4D8Jv0QQZiXMP7rpS3pOT+A/PHWlyXnqyz8oa8s1
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[{{0.4286788080707452, 0.2769747151443577}, {
          0.4343047306032858, 0.27519748679388284`}, {0.4371040635120652, 
          0.2743018587957636}, {0.43850030206512647`, 0.2738522979785158}, {
          0.43989424744808436`, 0.27340157515758434`}, {0.4622834064889436, 
          0.26589392558787334`}, {0.4732411072185231, 0.26202719736385854`}, {
          0.47865937985584306`, 0.2600660805548624}, {0.481353204305241, 
          0.2590786441965176}, {0.4826962677798744, 0.2585832141228593}, {
          0.4840367575339679, 0.25808664569256823`}, {0.5051297871850344, 
          0.24998853333274026`}, {0.5096875669652884, 
          0.24814828031990754`}}]}}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13c8lf8XAHC0jOxRSrLKpqwUOZKKjIhvSUQysilEFEIayip7Xa7r3ot7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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13c4Vu8bAHBEoZJIIglRopRoIXdK9CUSGSkkKtkzGSEjsrJee5O93/2i
26jsFYlkNChNVCpJv/P761yf6zzXOec5zz2eR/KKi+FVDjY2tgZ2Nrb/X3vb
+GVe/xyAOBuPiJZThXgxMDU45uMA6FfczJuPKcTbh3zGDacHIErk3sDH2kJM
+xNxS/H1AJy2dQp51VqI5h4VFusnB0Bb+fnxp88K8czPAjG9sgE4E1I6N/Tz
AbaPK6e/jh0Arg6eXX13izCXoXf7Y9AAlMDZpCc9RbgHhOMmfQbAZ2baRmK+
CAXOjYYa3xwA64uxLY84ipH9gXlLu/sAyOpk2dtsKkaZMU3h2CMDEP3dhOew
fAkeeXzmlavoAFR7fhK6SilBAerQth1rifcVf3W68asEW628ox1XDYBu0Xtv
LdFS5M0/cjHmXz+Eq5c8kJcvxSnhw3Hlf/pheLIokVetFC/Pivsm0vuhOmZF
+tyFMnQsWevtktQP0ZH9X2Sny5AzNSsmNbgf7P77l2AhV47Gjyw4Mn36YbY/
OrLjTDnOWCb5iXj1w5hf8MQ3i3LkuH9VIsm1HyTONlzb7FKO+d28Dc07+6FM
w1pl7e0KXGqUm+tj6welJdKlf2yV+LmxV2LPWB8MOx9jKp2oxPrJGP6nbX0Q
Y7/uV8aVSuSlfuXa9rAP3Opto1rdK3HqOkfJFUoflPOq1L8OrsSl/ugad6k+
ED3w4/snxyp8nhfWNfi8F/yaLN8rTlbh8iHJZLG6XhAq6NPNE65Gmkuwzq6c
XvDt+fa8XKkav3IGHi8i9cJ+TUb7A41q9HyPixLRvTB759HO1LPV+MI9azp+
vgdyc/aQTYRq8D+e11yY3wNBg/vii3VqsCXRcui7bw/4GEV5z9vWYGHy3d6f
13pAT3sgY8WtBvV3dZt9u9QDG8SqlQNv1SB7nMjXD4Y9YO7yte9PQA3GDlXE
eRd2w7GdoNf1sQaLgm+upOl2Q/7q23muErU4MqX+5ZF4N4julBA8p1KLrqwo
eQ3ubhAhyUdJa9eiGuvO6t/LXcBt1sAfrleLLVrhjIr5LhA5+OPRW6NaXEzo
2tug0gULPNGq8vRaVD4wU/h4vBOY6rkPFmdqcU+Fa97nqk5Y4pH+YrtSi+r6
Ql32KZ3Qu8mKZ4WnDue8FGkFUZ3Q4M+/oXVDHXbIK02OBHbCELvx+hChOlRQ
CJUqbOyAnrW41tm1DllOfzR2XuwAVaftg9MZdSh2hCsqfncHWBqpTkvU1uH5
i98l6/g7YPtjCl92fR1aUpMPHePsgJdjKneHmuowP0By+NHPdvAy/5rA9aQO
3T4ESnoqtMOlVdOz+zeT8bFZwJXE9jbo7fxMO6RGRs++a9vNSG2QtW+bM0Wf
jD9Wru8p8WuDXYeOjAyYkpF/IKy8y7kNlOu19phdImP77zK5T9Zt8PxYyvuR
y2SM9smzDM9/Ahr2pYlPcslotlss76vGE+D9fG7yy0My5vaoczptfAJavqP3
Y3vI+LKTeUH892OQTr2h2DxEjF+ZoX/79BjUrO0UjUbIeIS8+t2TqccQ1Es5
OzVGPD9kyeGF2GPQ99BNFBagYMF7B7oU6xFIu/3hN5en4FEX7p1pEY8g4Eme
cehhChpUtGt2uDwCkycnCv2OUTDYrS7V0uYR3F0nMORynILhdCvxBZNH4I4J
3FYnKahrpa4wG9QKgvR/rAJ3ClrcE/+gKNQKfkxSjFgEBVe527/bM9kCCsWy
7/QSKOh7PPOWxKMWUFRIqz+ZQsH4BeXBFFoLdJqf/ExNo+DqY6pJ60tbYJVP
vp5UJgUDx9b2hai1wMJN7XhyFQXZ2G9qb13dAjcLY0Rd6RScXHkXNvGhGXyU
Q7TL6yn4c6uMoPp4M+QsLgo1NVJwE5eiZmZfMywpLXD3IQXNxD4UWF5pBr5X
HoEefRTctzvwe558M/BfetPEGKbgqN+2eDX+ZphouLPpyAsKUR945SI4mkG4
WXf2yxgFq85FFj793gRnlYRf5IxTMHr9fhrpfhP8HZEduDJLwf5funmvLzXB
gcXpV11fKMgHCZqhJ4nx77S1rsxTsLlX59PgoSYQP3/5y4MFChb53ByQkmuC
rQ+N77/9RkGevF2CVV8QUsamH1f8Iu6v29E1Wo+g3d1ftbBEwQPLrplO+QhW
V+lCfMsUtL/hKMJ2D2H9nyMe0n8pmNh7UO3YDoQ5/l13ddmp+DbTzv383EMg
m9T0H19FRbM/m89MDD+Edd0200qcVDSP1Oe43vgQSjMav0hyUbG+tmshwPQh
dE9BdjE3FauvH6WGSj+EO4pGe87wUnHVV1vx1Wsfgm/8sanNa6n4eXg16e58
I9BldoW/JBwol+oaGNUIwW+kspr4qCh6xaD3plkjeOwINd7ET8ValxT9efVG
eMXyy6QRDsowWO8g0wjai1ueGW2kYu+i0jcdbICuNhmZZEEqxl7ZsXwougH0
Y9y/pW6iYpp37NYK9wY4m89qFRCiYimXR5nEhQZw9coMDSdczLNvH/fOBrju
9fC59WYqxm3QUfRb1wDnVDtvtBEOKr9a/3mhHqLmV3/aJUzF6HW7ggawHsQf
0ptGCW85vbHtRFE91MiwC8pvoaLXqrAqcnQ98ErsNPYm3Jdj3hZrVg9BvO0H
VolQ8VVZ4Yifej3QDBNVNAjraobn2knXgwR/xl8fwu1nw2SMeeth5+YBv0rC
Hc2SzhpzLOC8J0sdI0zPmgzaO8yCznFSKacoFZ2/a9iKNLDA8gXfBVnCrNdd
4lz5LAgiRbZqEU69z0afC2dB3032WSvCAXI2Si+dWPD4kFOHB+Hh2ZvpbUYs
aJhotw0m7MWDC3VHWTDfzl8fRfhV+8MT2dtZEJJ7ovs+4bQbv+PucbHA2doi
NZZwzN6FN54fmZBqZr09gnCy8Z4TlweY8GSHgbU/4ebt8nW6dCZk1+6xdPj/
+MduKoezmER//SNkTNjBN+SVVAgTjGybI44SPmz/ppLvBhNeL4XRthD2oW8q
WtJngt/hczkLxPxrfNL7Z5SZIJm152Tb//9X/U+lQVEmVPyTyk8mnOpbPYxs
TOgJOd5wmbBUgSZWzDBgTU5CvAzhcX6V72ndDKgQlpWaJtZHIVrAP7yOAS85
NzrnbPn/fA0svFIZcLvX0us8YVdb72ybAAao7JU+wkn41FtuLUNb4r6cF62K
WH8VSri5hg4D7CWuzxkRrrI3eSuxmQGGC/dSYon4uZVedm3jMh24Nn/ilCZM
K/3uwvGaDo+bzylQiPjjSnBTnKmkQws9lfqIiNfWouLFkUQ6kHqpgqcIb9rw
4lK3Dx2SV+srNBHxvbPgyE7qKTp8eu+VViRAxb/t15LL5OnQ8Ub3w0bCBkqk
5tyNdOjL3f3Lm8gPn8HvV+6P0yD2ZoquMpE/T2N2zoS30qDwyq34yA1UdEy4
oH6nlAaRdA7SGJF/kSZyHi4aNIhq0d7wkchP5eh7yo7rabCivPGkEZHPpCN1
Qo7fqODhqO8XyEPFntHBf46jVMi+THcvIvKfb/d0iJ8bFYplL3evJ+qDh1Bg
4b1jVCi7tPRbkqgnIprSIQk7qFB7rVtRmoPI1/DS7EweKtz0ypWTJOoPrYe5
4YY8Be4e4hfP+UlBTpI/l3cDGQR/8HzVI+qfvbt8L3cYGRIm6aZ3vlKwMRjv
nL9BhifM2+sFiPrpxLq6PV+PDKYvWh9lfqJgHZ/BhU8TddCxYMiMmqFgl+5g
U1ZxHVyX79C2ekPBN9wL+b+j6iAnL1+o6RUF01rDq0xd60ApP+S96BQFBUyb
RWbY60BfetRFZ5SC3GFdQvWdtfA96YTlw2cUDJsVlNxdXQtDKbPWXwcJ3+En
pSXWQhhXjLPoUwrK6r7N9abXwP7TwaaZLRT05N4qVfRfDYjvao7QZxH1emJg
W69ADQT0fGXjpBH9oHW6q/tLNYRyr3/+jExBFPLYvYpRDYOiZphXS0Hepq96
sRxVYKClMS6fQ0HNDoq1vWwlGITJidiQKOhiQmoOrK8ApaI644txFBy3yr29
KawC5OPEsntjKPj45H72Gv0K+GaTukotioLasltPbt9XCi899dpSr1DwhxIl
viWvGFZLJGXfOEPB7ft5m5hjRVD99ZHqGNHPLwkKrJ26VQRqjzTtF1Uo+Hw1
a02AdhF8HV3JWCb2AwyLu/o7NhcBbdRk6q8yBR8K3rC6zVkAQrWFDjc5iP2B
eUdcUUAeFPSf6LB4R0bf0MXM0IZceBz57NulUTIeUnPWLb6YCxkhzYHwlIzq
esK0U/K5sDh29W5pLxkbLu/rH/2RA7r/DJl8XWScStAUoN5NA7VVrkcNI8mo
XHZeWc80Gcxnr1VPXydjycvLnxuak8Dzv4pXe0zIaPCd1hf0MxEerxb7s0+P
jL8e+srcTUiEQTsdx9LTZBwqNT1asDcRLB56e2/TJKMs3wOj4ZF78HCLtWjo
rzp0vb5DJ70sBLySKoDRT9hvcMIhNQjSjxjWGzXU4ZSI/N69kgFQab7tD3td
HdY8Hr+4lOYPaRejjg9U1CE//YODsqAf7JRM080orsMgh0iJSD4jmPDfwbI3
q0M2u8/faStmaBB4NFxhXx029SXqvXS5jiKZHCGyosT4jf1ZJm8cUX6UuzSK
2N9OjfksTWa4oPJ2/85DvMT7jv0p6Nnthu+DPuSNc9Zhyc+DbQumIahD+j25
prIWg16Q1ug+iECfgJeqEYG12HRHXbddKwrbBXWu2trV4vGDr58eSo5GB7ej
OcxLxH5+q2do2rEYlLM35Z0wqcX3Dm45rW9jsC1/k8mKQS2ej21RqDqUhLUX
WxvHv9QQnTh+5EJPMoaBYuPRhho8fp/oKEKp+LntjXxofg3WPH2rrsRMRVll
0/I4EuGtHL6NvGm4+1RNC//9GpRd6KvedSkNZTpONEdH1CCbXsnVCOtsPJ9t
UyMtXoNzP769mnbIRZGKu5enequx4qBAxNSaPKSPnSE5p1Tj+bIF8DbOwxv6
WQ13/aox+j/PQVn/PHzbF7c93KkaDXa8292Rn4dzlSv1gVbVKPZyeZuqQiH+
d33jJyv7KmxY3M+u6/gA116Xy4v9VIlqnCcbLXmKMNGzJXS0ohJrzFrO25sW
YZcXj2l3dCWG9nDbGQQUYcyJA7JM/0pkWH/WknxQhAFnxdOzHInxldMR7atL
0WMvqT/oWgVGLziC874y3PWht+T6VDkaWN66UNFchiWByhGZmeXoWBAkcIq3
HI/bCI+F+5ZjavVrqotCOXYtHut1u1GOy8ky/SGG5ci38d8vI7NyzFUOsfC/
VImRKqpW+mZlaKtTbyVuXoVdQbu3TT8rRcdl5Bd4XoXS5hfOiCYR5+mPp5sF
harxW9XXJxs8SpEyc9ZrkThX3t/1SefOlVKMkFZd89iwGj+u4q76dK4U5UzO
a7mn1yBp6Jya86kSPBBfLyuxgYibMRnnXw3FGGk3F3D7dC3SLnjdUrpVjLnr
5qw/29bi775vn6uMi3FpypIk5FGLwl7mSraaxTikEXFK6U4tGik1vxBUKkb7
fsuhGcc6jOc/n81YXYRPvdjTpSaIc9fzm8sqzg9wJCYyhCRExkYHnjZHyQco
FkDtWaVIxv1qEnavlwpRZXeHaIk6GX2UDH2T3hWiuk7vUzhDxmfRjnh8qBDl
Gky12bYT5wRDjtPsmQW45LXjbVIIBRXVpekDf/OxfUpPuZRCQRHFxBaVqnws
GZnxn+6moHd/jrDB3XxkdYVtmxuhoPEecx4j93z8pKFK//yWgrtEM18aWOaj
WrLhDck8Kna7fDjpJ5SHTbVS3sJLVMzY63j+gEsuqm8pI2vJ0HDdd0Z0xtZc
3P+zcE2UCg3Dk0/42r3JwdxA/fNbTtGwUvifpQczB/MF11BSztLwb46NpNf9
HKRY6lqIz9HQv7K7dvxDJo4YMFVFVOn4k/nF/xopAyVkYOcJKzrq+Dc3fphN
R2X5jv3sbnSk8h1VWElMR97ttoZdPnRiHo1Xl+3SkT90j0J4MB1303I4vh1L
R9cXX2O/LdNx/YdnDG1MweBm/s3xBxnoe+vLbebtZBQzeynFMGDgi/Oiw44v
Sbj6tl80uyUD5coklIuiSJjvaElJtGXgyJ0TCyo2JOwM2uUv4sDAj9Vm7p0q
JIxcdPW5l8XAyfszVrGLiXj+fJ5pCpWBw/4dJb+NEvHQ2+Eko2YGJtBCGAkc
ifjd7D379jYGLjeJqo+MJqCdE2NxvJuBA8eeSovUJiDfloj1m34zUNX8bl2A
fTyyFY0/5+BjopnChscdT+KwxtuMe98WJnb//eEz7BmHV1o5zx7YxkQu05st
w7pxuHjfhHu3FBPvy15dNygVhxEvJJ7X6TDxXmHeLuWwGOxO5uvKtGAi/9Ed
Ffulo9F+8shr1jUmjjO7OAM9olAhIGG/sgMTl1UbYkS3RuG1E0L/sl2Y2JxI
8qpqicTMCbF3H+KY+NHEiKm1Eo5DKfJcyrlMFBh5WuqUcRdn+D7BnWLie2Oi
417MhmHC1hROgXIm7nZYoq2JD8NhT7fDSVVMVDjg0aVwJAzlKttGU9uZqJW4
mJ/qGowneiqG1IaY6GxiPa637g5uWbUgTR9lIl/VX9215kHY27LWyvIlEw+S
XTa8YQtC2zLP34sTTNQXjihwPBuI4lf7hdveM1GUshhVE+aPEoezTEw/M3FH
5LXoPAk/3Lk9L/DeVybumwwL5HP2RWXO+6sq55mo032Cw7PeB9NVs5NKfjPx
55Y3ya1zN7H7/UMX/b9M3C9/+sXJKC+8TBW/vPYfE1fenev0HfHE9xJri5ls
LCQpmL0sl/HEI5dtHZxWs/Beu/SEYoIbDpGbQ5e5Wdin95D34mlXNI+SslTk
ZSHfVnbHQS0XHKpNxgtrWSgxV6w9u+yEmta5ImHrWVh69VfHPzsHrBCp3RjB
x8J4SU8+9u32yBvUFRewgXi+Jk1wecgOR0KVd2htZGHT7InMqePXMHXf5kPC
AiwU8XNo7Fy0Rc68XX1jhMscNo9VV9igVItEImxiYaZ6o7bjFmvMvkRunCDs
cF/jRkSmFd5K7HJyE2KhQE05eT+3BX45p1Xwk3CcyYN1Tz3M8XTgKku3zSw0
KxATcJo0xf6V6awJwgdV2K9w6Brj6+rBKyDMwu6tmukJNEP85UStSCQ8fue5
mbiUAabze/uNEf7P1cL7zFZd9HVY07d5CzG/D37Nxgun0FnfrPgUYX7n710X
Oo6je5glpx3hgy62D8jHD2PFyMaZ24ThXZjWpfHd6LnO6Uw44cIt8zp7pjlR
55XT4VDCnEceNsc+E4cpQaFiT8K1gboCDmsOwGaLaxlmhD8EX5R2vqAGi252
m/YT/qxic5hqfBIaVskI/CG+L/7Gi4aqgNPQjSVJTMJdD0qu5RfrQcXZVZkO
hI1N3f217c4B9wVt2Y2E630HM5jLRlBxO/JoGfE/jv8I/bYz3gT8L073HSJs
I0WajpW5AI7RHh9p//+/JYJDc8yLEFpkFC1HuD5ro+QZfUvoVC2uiyfWg2/E
QNjA7TJovUiw/CTIwuEdjvtu1lvD3Fr1OBXCB55P86Ry2UCdyaC2P7G+raKd
ptSztmCoFhRWS8TDyt6dnT1pV8GuczpxkYiXiNygqS977YhzLffV1YQzU3Nm
Fr1vgKHr5kYeIr4M6N7PfjXbg3rBLMdHIh6XtxYqzho7wUzC/vl2Il5/5Umz
P89xhuz4a9fTeVhI/k673TjrAsclH30SXsPCmu3qeUx1N1g2C1tu5WLhyUbP
xdw3bqD82Y5kw8lC4RRnztAId/A8+dHmNjsL5zXmK9SeeoBEmGr6z//nk03O
r43enmAvtfHi1RUmXvW+aPV6qxdkejat8/vJxA+dudlSDd4g0KG3m/GNia9q
5n5sX+cDCmQxnVYif9ceVLQQovhAS/RH72Yivy29t1lxXvKFX3Sj+iPvmEiu
mdh7+48/eBZmMopeE/l9TPwnn24AnLmw1UBnionhK/z53QsBkMT+7dfUOBPP
+CamBacHwnD5H2PWIBMvbbsoEiZ2Bxo82/0v9DJR2/vfk/WP7gBFMK6G1EXU
Q1rt3S7hYOjMeL70iKhnEtJjj0MdgsGVsUuQvZGoR7Q4MVVWCLQEijMHaMTz
/mnu8rEOBbmcQ9QiMhNzMDuDnxoKnMdae5xrmJhXPfM+nzsMzhdq/phMYuIe
r7Ob3QvDwXHoVd+bMCaqqhVt6puPgBpOv5ItAUx85zFUYpZ6D+6WLz7d7svE
LLWCr4kf78Flw8OyojeZuJml39quHgkVaiUG288z8U/QPf/bz6NBS35dyRcN
JorRWPsVdsTCokFdwb0jTDz8p2pitD0WJCzif7cqMbG2/eaJwq33IfscPWpe
gaif+YXvrznfh+Tj8clJQ0R/dFhgDPgkQPS/x/NzeQzM+JWxW2k0EZbXl1qe
DGcgs3i/j0VEEvC7x4ySfBiYN363pG8yCYILZ5xL3Rk4v2Q9HLiWBCpW/clV
RH89Hn+NQ+4wCeraZ2wHFBlYk7JDJysxGSg6W1dFCjKwa0lj4JhGCkzMDV7k
52RgTtg195mUFHi95bSAOtHvn5/aUL2/NQVk94jetvhO7Ccizuzw/JIClgm8
J0zJdLyh2tFD0k4DX/kf1IB4Or75tPTX91saJLkeMz0WREdpEoexxn/pkK6n
Yx/uTcendJtTIp7pYMeWYtrqTMcRDkrJbHY6rOP+48T2joZr5iJZCoJZoPKq
srwom4b0cio7VScbIvYEZFj40PAOl0Zn+3Q2vOSK1nK/RsOOR5N9Mko5UMg1
OffhEg3/BEsstV/IgfczvcOmRjRM2RwYbhuUA+68Vxw/k6l42n1KbGkhF77H
aISOWVHRIj4i8XlkHig7l6c0KlPR+8bBosvDeWAYJlgxK07F+PgBzbXLeRCQ
qRT8RZCKTLIjzwu+fLhcOPjmHTcV7fV9HAol80Hgc7brK00KnuB3mN9rXQBm
8nsn2SbI+P3Gzb3zKwVQN8Uyv1RKxrysMyQ9vULw/9bj0hhLxss1lq8veBbC
/wBzUoIe
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13c8Vf8fB3DJV5EKRTSEhi07Qu9IKGWnqJA9MjKKRDJC2akQkr25XNx7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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[{{0.4077466289289061, 0.00023828734526649004`}, {
          0.4077471967380224, 0.}}]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13k8VF8bAHBUSCh7SbKUtShK/JRjyZo9lYpUQtnXRCprItnXUHayG8sw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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13dczV8YB/A0iIgyikoJSVNJofFoUZRo0tAQaSGpjJaiodKeNDVo79t+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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13c8ld8fAPCIQsMmIwlFKWWUUA4a+lrZoWklEtlZ2RKysskmJNvluvjc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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13c8le8bB3BRkSjtSJJKWWX1NRq3MgsRZRQKEU0yyozs7L1H9hY5Ntfh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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13k4VN8bAPBCRbSJSkoUESl7KA5CispSSIXKnq3kaxdqilayJEXKvu/b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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV13c8Ve8fAHCkRBmJqChKopLM7IfsSFIhJEmFUhkR2V+z7JWsbCV7r3yM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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV1nc8Vf8fB3CjZZbRUMgoW1ZC1KcokhUqGaVhhCSzjOyQNIyMkD1Cuvb2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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwV1nk4VGsYAHCpLEXZi+x7lpStVZ9UtBGJKGW73JBQKEUUiVahIhXZQpF9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          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwVz30wlAkAx/HaRe1YTomRuhldLzi1cuflZivXLY3UdopFdDr0ImWU4xZ1
ueiNkpe4RGNJm+uMqHD0Yn5sa1/s27O7rV3W9mxCKkcXMsR03R/f+fz9XRV/
PPQQZcGCBds+978rZ22a39Y+wTurs/diK9XY4TWqT58CJp038lxz1HjY12nW
h3SiiOts98tRNRZGOF9rmelEcm90uNd+NTb9kbIl/UcB3MOkhdORaoTXflkt
zxAg06U8/BlHjYqQGI7zLQEOVLkN1O9Ro46WlvAotQs9FNb7RcvVSPuUb0g3
iLCRfnJmZJZA/F9l08N5YgR1cLclvCWw+FNxYNyAGGPn2z7mvSQQG0EfL7CV
4NGKTv9SkkB14z7fB0wJSkS5knIjAc3Y2nbmdDfuTC0rSy0nsGMnk4zcI8fI
wla/m1wCb0RNVqHzcuT++ypAepCAU1h2w+IwBfY2PnzcuY8AW3Joi+a0Am7v
Mp38IgkMx/BfFt5RgDK/duDPUAJZLkGjN+kEAmzI+BgbAgMBS3cTtQRUPH5S
sUYF/hcG3YEJAoziwCHRXRVSWmiM/M+fNr+pErxvqDATdXW8bL0aPN+oAbJY
hQjBPVve92pcj4s2ns1VgT6aEzORpEFg16RYMaZE/5ErFokLtYgwdR5hVCnh
apxoXbpTi5s1P9xv5CohFUiVguNaZF3g9wTGK0Fp86lYkqOFfMbpqsVeJYRJ
7j7RpVqQK/mO7buUWF468XrH42fIMDvQLWoUeNXtlL6VrYOHp6P1oWAFdj3p
Lncs1cFcqWQnrFTA1v6UpaFVh+03DB7tlgpYnkpkNUh1oGU2c2Jm5RjPZmSd
NupANXuHfhiTQ6Wbul032QOH8AbvDm85CjtK4vOy9Lje8yvHQidDytxWa7FA
D9bWW4IzfBlOeTZ9bBvUg8enDTnky7BmaFN97ZQer1t4m3p+lyFxja0m38oA
H0OWsDBVBtZtfX3B6l7EMwvH7Cu7MXLCv7qloRfrnS0Vc4xuaCIusJInekFd
9zXHf1oKobWSU+LQB/sgN/k3RinMzzfPl63rw5ZZD+pXCinayI79JX59KDrf
N0yDFJNnKi+zWUaIL+b8fa9XgmWNGdYOQiMG6S1N0QclYDaYfO0s+tEyvmF6
sbsEXLZ6kXZ1P/q4zaSvtQQSL3bj7W/7MenHLQ2YE8MqXXoyOaAfYwwyM/gf
MeaO1XwnczWBqQ0rCbQRI2eqYrngmgnNu89lut0Q4TDVpjVJYcILhpJSFieC
2+j2tCsjJjg+XKK8GyjC4Iz1LbsPJlTVFKzy8hXh/eAA5TL1OU5Qg5waXUX4
iWApMnqew7JCnNaxuQuUNTETRZtJBLvExUZ1CXEiVsYTJJPIbjhM25AnBMXu
2Hn+RRIfw33sZo4KoaElPVhUSoK7brxev0+IIv+i+rhqEm/oiT/fZwtRN991
MMTPjOyCvEsvtj3FinP1ZzghZuSX3a/0tHyK/wCjiHX6
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAAegDVfa9V4D8QmkldrEfOv3DbmbnM
S+A/7RytWNBSzr88PGuAdFffP2sRNaiLAM+/6NLZEMW03j/GbdihL1TPv1oo
zArLYt4/eBG/oDB9z7/4Q6wTpjneP2tkZpB8kc+/cYkdrwkl3j9M2lxalZvP
v6yH4LZmEN4/NsNUV6Wlz7/eS65sirzcP1UqR0pgItC/Evu+Iy4Q3D+Vf7sY
aUjQvz0dkONpuds/9OiTyPxa0L/emrLr4o3bP3ws3kwqZNC/cLjOTxZ42z9i
gHP1uWjQv6aYAadDYts/KG+R4ERt0L9R1eZq9gHaP/JiqMxqs9C/ZRakHK1P
2T92ERDgr9TQvxfmOmcF9tg/q4lZ4N3k0L85+fx9EcnYP2MvMZ3X7NC/6Chx
nI+y2D/P470mzfDQvyow8noInNg/HlaEy7300L/Aj+EVGE3XP/o8NMGtLNG/
Z0M4ig6k1j9qr2cDEUfRv+LitPcpT9Y//krevdxT0b8MHkxNoCTWPyFlPAsp
WtG/JTgbslUP1j8WVTvLSF3Rv660kkQH+tU/sTS+RWRg0b9BYT1tKaPUP+YE
4qDUj9G/FNLDjHc51D/8F0NlWp3Rv6wm7i0=
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwVjX1QiwEAh0ecO0LSLId85C4fHZ07ls9uJSIRF2knySnKRxmXIh+1TInS
KHU2VtKH2shcX+K3M25ba73v3javtnq30vms3dFJ7JT88dzzx/PHs/Bw0p64
8SwWa+UY/50dw8muzCSQLmB386VG+MpvhY0bIeDOll7Ou2XE9eKAR998Sbhc
PW7tERmRtkD4gA4i0fMo03dCphERB8X+L/kkPPJtRQsvGuHkfHsTX23EjOCM
aX2rxnqJM7V4J4UDn97eX+9qRPngsoByGYX9AurP1WES4oasCJGOQkloqkPs
IDH69AXf0U0hMNoUffsLiRr6SmT4DwqW93pNft/YR7Dx1fLVJgw5f8dyxSSq
FVr2BpMJ4nqvxvyjJIIE9eol3mbcFPz0YnaT2FF6r+HcdjP2WoInOraQ2N2c
GMI+aEbOYN3SZB4JZcIdbu1pMyT7lcmO9SQSGy3zFPJ3cIS2q20gMLK0Mmok
hMacyJbA/kMEymrnzhgqpMHMCqUa/Agkq8rCgltoGDKCeEmeBG5ILypjCRqK
jMknA1wJkNbZxSm9NHzWRn+dxCIwp6AxsGl6J2za5tYs/3bsO0+4nn7YiSje
Jf4PowFrquTX8/o78XfqcM0vqQEfGcZvwM2CrLSO8HahAdmlLqfcvC349Pqu
XJFigORcTtHy1RbMVG9SXUswYF3FICsn3go6PHygSdiGevezZ2ROKyQqTsPb
qW1wzZEoecFd2BGW0j+F0kPmL1tEJ3QhmSkuGFXqcSSg2ume3oV4ryeFA+V6
MEcW923O60J2Yrqqo1CPVK1b6JTabty35Ko9Za1Q+cmGPbkMRE7eithFrdic
a/aouMDgCbcOVK8Oj48X1MilDKYNxEXbXutwINanqlTB4BCHX2d5poPpZYpH
LhiMzk9qai/ToflBcxH3uQ0fRFvTdM+0GDrbq77JtkP1eZ9e5K9FXV5Mz7tV
dgjf3K58/0cDogJbYnh2THx+pZWxalCy7fsxSYgdnnEb10S1acA5sbjDtMsO
hdDng6FFg3+v7753
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[{{0.5096865834282014, -0.2614901330029853}, {
          0.5067723489282668, -0.2622392729617048}, {
          0.5014115011368258, -0.26357999374808627`}, {
          0.49872087117847247`, -0.26424364073732687`}, {
          0.4973730246697142, -0.26457378093421285`}, {
          0.4960234981074769, -0.2649027970608375}, {
          0.47379838472522157`, -0.27010516357806674`}, {
          0.46252690332151314`, -0.2725924159657098}, {
          0.45685281769206876`, -0.27380724894325914`}, {
          0.4540063634232778, -0.2744074294222515}, {
          0.45258080536389417`, -0.2747057060157391}, {
          0.45115370173036784`, -0.275002771757113}, {
          0.42811499900825145`, -0.27959009565056414`}}]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[CompressedData["
1:eJwBsQFO/iFib1JlAgAAABoAAAACAAAAWhgdH8w31r/PEZtPXp3Rv3b0AycP
p9a/eX7cO4h/0b9eCXnPPvvWv8gTSmVkaNG/zn9toCwl179rcTmfuVzRv6G8
n/YYOte/KmpXCt5W0b+jZv85/k7Xv8eiFFb+UNG/u9zBURGg2L+xW8O93e7Q
vxWJNTy8Rdm/hT8xvTm80L/2nG6I1ZfZv+3H4yuEotC/0m3KlbLA2b8oNFer
kJXQvxLAkSQV1dm/KUWwwhCP0L+wNQWyb+nZvyXJQsGMiNC/Zkx738cq279U
nmOwJB7Qvx40C7dYyNu/GayGYODOz7/8UxoKVhbcv7fbTJVul8+/UI4KZiE9
3L9pTp28hnvPv+xdyy96UNy/5M+QH4dtz7/OygRbymPcv/Ct/rt/X8+/NKcP
VYOp3b9JZxHsX2rOv4S0qUaLSN6/C2cqoY7szb9Eu7IkFZfev5N0woTZrM2/
fmVy8Bq+3r/LdQlXzIzNv+ifFfqN0d6/jUIyKLl8zb8C6odp9uTev35PHpqd
bM2//wdCBeUK4L9zLZXQgGbMvzbZ43IOVeC/J+rOqGfgy7+OAewe
          "]]}, {
         Arrowheads[{{Automatic, 0.8}}], 
         ArrowBox[{{-0.4339065234602687, -0.2753242757631741}, \
{-0.43522848714887064`, -0.27490277481879105`}, {-0.43654842296586427`, \
-0.27448023607925215`}, {-0.45738756306684103`, -0.2675797896585013}, \
{-0.4676056814166415, -0.2640321732307516}, {-0.47266329222111025`, \
-0.2622343891446906}, {-0.47517910153780074`, -0.261329550483675}, \
{-0.47643374053260346`, -0.260875650466665}, {-0.4776861961003931, \
-0.26042076560879085`}, {-0.49880925674972576`, -0.2524726292221952}, \
{-0.5091223957691443, -0.248393004405539}, {-0.5142156088583859, \
-0.2463272945289806}}]}}}}, {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6], 
          PointSize[Large]], 
         PointBox[{{-0.509683995922528, 0.}, {-0.3058103975535168, 
          0.}, {-0.1019367991845056, 0.}, {0.1019367991845056, 0.}, {
          0.3058103975535168, 0.}, {0.509683995922528, 0.}, {
          0.7135575942915392, 0.}}]}, {}}}, {}}}, {AxesLabel -> {
       FormBox["\"x\"", TraditionalForm], 
       FormBox["\"y\"", TraditionalForm]}, Axes -> True, 
     ImageSize -> {300, 200}, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], DisplayFunction -> Identity, 
     AspectRatio -> 1, Axes -> {False, False}, AxesLabel -> {None, None}, 
     AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, 
     PlotRange -> {{-0.509683995922528, 
      0.509683995922528}, {-0.27522935779816515`, 0.27522935779816515`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"u = -1\"", "\"u = 1\""}, "SwatchLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.3]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.3]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.3`", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.3`", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6593319809596376`*^9, 3.6593444514478884`*^9, 3.6593444885190754`*^9, 
   3.660283416929809*^9, 3.6602834559264183`*^9, {3.660283531908224*^9, 
   3.66028355085563*^9}, {3.6602850927997985`*^9, 3.6602851371061726`*^9}, {
   3.660285723245719*^9, 3.6602857395953007`*^9}, {3.6615021131131516`*^9, 
   3.661502119963966*^9}, 3.661864140819049*^9, 3.662015690019148*^9, 
   3.662019992232127*^9, 3.6620201270193367`*^9, {3.6620201634762173`*^9, 
   3.6620201897296247`*^9}, {3.6620202282497835`*^9, 
   3.6620202508427143`*^9}, {3.662020308300245*^9, 3.6620203406324916`*^9}, 
   3.6620203737519307`*^9, 3.662025518510087*^9, 3.6629134737225933`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Positive or negative u compared to ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["\[Theta]", "."], TraditionalForm]], "Subsection"]
}], "Subsubsection",
 CellChangeTimes->{{3.6618634922120485`*^9, 3.66186351947871*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Quiet", "@", 
    RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         TagBox[GridBox[{
            {"\[Piecewise]", GridBox[{
               {
                RowBox[{"Not", "@", 
                 RowBox[{"above\[CapitalGamma]", "[", 
                  RowBox[{"x", ",", "y"}], "]"}]}], 
                RowBox[{"x", "<", "0"}]},
               {
                RowBox[{"above\[CapitalGamma]", "[", 
                 RowBox[{"x", ",", "y"}], "]"}], 
                RowBox[{"x", ">", "0"}]}
              },
              AllowedDimensions->{2, Automatic},
              Editable->True,
              
              GridBoxAlignment->{
               "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{1.}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.84]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}},
              Selectable->True]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{1.}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.35]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          "Piecewise",
          DeleteWithContents->True,
          Editable->False,
          SelectWithContents->True,
          Selectable->False], "&&", 
         RowBox[{
          RowBox[{"x", " ", "y"}], "<", "0"}]}], ",", 
        RowBox[{"Not", "[", 
         RowBox[{
          TagBox[GridBox[{
             {"\[Piecewise]", GridBox[{
                {
                 RowBox[{"Not", "@", 
                  RowBox[{"above\[CapitalGamma]", "[", 
                   RowBox[{"x", ",", "y"}], "]"}]}], 
                 RowBox[{"x", "<", "0"}]},
                {
                 RowBox[{"above\[CapitalGamma]", "[", 
                  RowBox[{"x", ",", "y"}], "]"}], 
                 RowBox[{"x", ">", "0"}]}
               },
               AllowedDimensions->{2, Automatic},
               Editable->True,
               
               GridBoxAlignment->{
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.84]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}},
               Selectable->True]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{1.}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.35]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           "Piecewise",
           DeleteWithContents->True,
           Editable->False,
           SelectWithContents->True,
           Selectable->False], "&&", 
          RowBox[{
           RowBox[{"x", " ", "y"}], "<", "0"}]}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", 
         FractionBox["5", "g"]}], ",", 
        FractionBox["5", "g"]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", 
         FractionBox["2", "g"]}], ",", 
        FractionBox["2", "g"]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"Opacity", "[", ".5", "]"}], ",", "#"}], "]"}], "&"}], "/@", 
         RowBox[{"Drop", "[", 
          RowBox[{
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"ColorData", "[", 
              RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], ",", "4"}], 
            "]"}], ",", "2"}], "]"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"MaxRecursion", "\[Rule]", "8"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(\[CenterDot]\)]\)\
\[CenterDot]u > 0\>\"", ",", 
           "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(\[CenterDot]\)]\)\
\[CenterDot]u < 0\>\""}], "}"}], ",", "Right"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}]}], ",", 
   "\"\<s13\>\"", ",", "False"}], "]"}]], "Input",
 CellChangeTimes->{{3.6602850366300216`*^9, 3.660285048284274*^9}, {
   3.6602851383490524`*^9, 3.6602852712921953`*^9}, {3.660285316759392*^9, 
   3.660285338798477*^9}, 3.660285395984974*^9, {3.6602854402142935`*^9, 
   3.660285485897644*^9}, {3.6602855915874867`*^9, 3.660285600145547*^9}, {
   3.660285631183526*^9, 3.6602856368925686`*^9}, 3.660285681317028*^9, {
   3.6610669791948223`*^9, 3.6610669805447764`*^9}, 3.661502120528364*^9, {
   3.661863532039372*^9, 3.6618635419910946`*^9}, {3.6620155020524426`*^9, 
   3.662015508093708*^9}, {3.6620155702866096`*^9, 3.6620155705237775`*^9}, {
   3.662015614446783*^9, 3.6620156146369176`*^9}, {3.6620198470954266`*^9, 
   3.6620198914774094`*^9}, {3.662019937786833*^9, 3.662019950577346*^9}, {
   3.662020005713046*^9, 3.66202001100916*^9}, {3.6629134319980125`*^9, 
   3.6629134516929674`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxk3Xf8X/P1B3BbqaJG7FWlqqqqNs1FrRoxalMjRtWeFXtvJSKCICJijxKj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     "], {{{
        EdgeForm[], 
        Directive[
         AbsoluteThickness[1.6], 
         Opacity[0.5], 
         RGBColor[0.560181, 0.691569, 0.194885]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxMnXW8lMUXxvfe7d27e++ydy+ISonYLWLxwxZsRexAFEWxQFQQDASxEwsF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           "]], 
          PolygonBox[CompressedData["
1:eJwtnXmczdX/xy/DmBnm3jsXs9w7c2fmzl2U9lKWKFuKLBFpkZQQlUpalEQh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           "]]}]}, {
        EdgeForm[], 
        Directive[
         AbsoluteThickness[1.6], 
         Opacity[0.5], 
         RGBColor[0.922526, 0.385626, 0.209179]], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxMnXWY1dUTxjFRREXF7oS9u3tr7917YdmwWzHAAhUDsLuwsH8mIqFik6Io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           "]], 
          PolygonBox[CompressedData["
1:eJwtnXm8ldP3x29IpcGQKRmSDM11h7r3nHvrDufee865Z2yiDBGNkig0CBmT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           "]]}]}, {}, {}, {}, {}, {}}, {{
        Directive[
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwl2nf8z9X7x/G3MiOzbJWULXsnJGTvTWRnpCKrJFSSREb23rJHRpGQ7E0Z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         "]], 
        LineBox[CompressedData["
1:eJwl2mUYVcXXhvEjIAjS3V0SdhMijUqDqHQIorR0CZIiXYodNCoISEiDCCgK
iCjgn0bpRpB+f+t6P9zXs2fNzJqZtfeZPTP7FGjVuV6nuxKJRN2UicTlpIlE
BtfTkiQSuej+1InEBLpUumz6ROKd7IlE44KJRH66p0AisRd/YbD0YPZB+J90
AekmrsdgNL4tlEhUzJ1ILKCV6EJ6UAPP0UP0T3V2I022RGIJ28j82kIDZY8V
TiSO4wQeU+YBvmvkUxfV8yQSU9l6slUPW85E4pMiicTtHInEx/QOnclWoXgi
MYOul87uegOtrs4YdWvQx9UtpJ+FMVa5/kUTiYEYgJLSJWgJ2oDWpvOyJhL7
iiUSq1wnw/v6Ng0fYIH0OOVeNZYk/D3Ndy1tjNNWTbpffhV92Ed/M8aduC0G
xfi7RYvT42xZlb8iXVj6Ki1EC2KHep/yv51+Ru/oyxzlE9o7L3+Psrsx1/V8
8ZtDv6G9lVlk3F1dj9OPFPxvUm4zrkoXFq8iuGUMt/E+W3llptFu6ozh5016
hp/T+IB9jT6sxjLp0dJP8zXcmFsY8xTpj9WfTJtLf0EPul930aHsSegh6YrK
76U39L81+3DXO7WfXH4lWhmZtHtdfjH512h76TflP6W9J7Fa+2uQ0/UaMclB
19KytKW2pyr7ibqforV0K4xn+07fK7oXS+gXYnOTj1sxFvVuqP8uvUkXi/FF
+h0tqz9lsF6dyWzr6Ep1zsczqPx8vl+h2fm7xJ6NXkZD/Z6g3jHXw8R5gOuB
qMY+kp9Byq6gK/E9MvOxi+13lIrfi3Y6iVU77TxMD+BJfp7CI64fxQRlMhtP
O20cEqPXaCNjPuB6nft3kK6ma7EGo/iebUxLXS/DEuxWZjn9kzZQtzEfGfnc
I/2K69HayKc/ubT3V9w7bHLPBinbVN8qGv8a5Qbw/bmy5dX9ghZDEeMqhqKo
j4Zs9xv/De1tVWcE5rLNZ0upXtW45jOVMd6Le5AS37BNVH+ENjqgY7Sl/c/Q
NX5v+ndW/Dbq24/Rv5iD9L8vnwvpOXnnlW0n/q/hnOvS2jxLz+C1iDPqaye3
9Hrj2xDPqLoj+RiG4bgmPYJepzfxuDpP4Bu+yulHR3TCC+p2oZ3RgM93jLch
PaftsyihPyXYSiKV+p+yfYZPjOtTfKne3ni+Yr6lH2lrlli9JBaz6Sl1HmYf
Lv+RiJfyldmqxJzGVgQZ1GnMf1M0iXsf99i9b09fx2t4UJk36AO0lDop+HrI
dV5+8qCZ9Ou0mvhWxT3KfK+fy7EM9yrbS3974i33Z2o8s+wd0QF79PUo238x
l4lRNf3swedSvl5Xty7f9XBHXgm+E/IeUOZBVBHDkWwV2O6XXqTvB/hZzOcG
tozq3c1PcnTVRhbpzMiErOKUBdNcZ8DLyrenRZQtjEfxGB7Bw8gpbyMfRV33
cm964wXtrIg5nJY3vj+VKUefl14ecUBZ6TKYjC36N0WfLxjXhIgjrulvMWMb
7rooLUUvs+V2PdR1HvqvdGnXc1AQF6QzsXd0fZam8rydo4VxIuY36ZP0N+zE
GeWvaLuTdq/Ss9Jb9LG4+j318Tt9WoIq8YwgOz+llbkfpeIZiPuPpOrfjdb8
J6Ot0MV1a7pDOymV2U4foqnZ6olVXRQTl7xsefCGe34y3tvaTqvu267f8Vw8
p81RMb9iGNtQDInfgn6OdZ/OiP1ZDMFT6g2lWeVdENeLeFm7f6v7Ev2Hjo75
l17Ak/w8gcexVr3v5S3HUX2opvwR2ps9lb7ep60SuCEu11FHv7LTunS0+u/i
mjpFjGWfMe5HG/1YqcyrtCW/G4z3B6wVy3W4pMxX4puWj9vs6eg97CnxhHqP
40F9+DzeiUirjTTx22Bbrnwh5RuwN4z1DD8fKj9KXn3pT+iHbB+gA/vH0m3Y
/4t8dbPRX9h/xTb0l+7L3gd/aiOr9Cn20zEfGNNRY9vPfgCdpbsgPQ5HnHDR
dVb96WxM2egl6Z+N+1H0Uqc3+qCnuPdAVWV6RBov4i80wksYpO1/6VVcQT7p
Z2Nuoand45XaWxXvciyNZ11sl9GRyozX/yWxHtDvtO5XGqTGCHkfKDcN+bR9
Jfru3u7Vv87a6IKuGBzvV7yszkHpQ2iJVmiNt/n+j16P+42i8Y6NeZOm0bfK
2pkn5s/Q3PFblpeHVpAuq2+LtL1D/m84ydaP9vPb649i7k/x+K2xlaD3YbHy
6Tx/6bFROkm89/hMStvqZzu0jjUk2iCv8p2MsTN68dOVdkEa5dOplx7nY61i
/E8r+1XMQ/Sk/OHGPDJihbHSJ5DDmI7T+fqXRPtJUU2/v9OfGnQRrU4X0x/F
YyP+MN68fPxJlxlzbte50FO8O+rjZmU2YVfMY+yH2K8pl5wmpynQXp9yxFwf
vwnpstqtp/yE+M3Rf4yhhb79TdPGe1i5pNIJfelhTN0xib8ybJPpbmPoHn2i
PeJdqB+p1bkqb47rA+yD4p7Tr9m+ivWI/EPSR6I+f29Ix2anv+t++JC9HP8f
0avKTVX/Cn2PPqvsh8p8FPsTfUrHlh4ZUFl/l8dYjGuUvBXxflfue7qR/x+Q
VJlkyCp/iDhkoUNpJ373x3ten09q90G2U7SgOrX0pUCsK+XNwExMxxX5s+gx
uk/d47GWUu8EfYA20qcm2jqmjZTuS6rYR+nbMGNpHOtselL6BO6RlwJv8rPZ
M7ReeynoOnpPrBc9J4fphlhXI7frMzQnPU1zxbvDGC7z9S8u4QrG6fsEjEcz
+ZO1sSbmSqzGRbGppb+l5NeM/Zm+9o/9GR2LjMaQCZlRRZ9XxbpPvXXyKup/
fbZnY90e6/Xoj3QujJH/nj6Npu/Tv2P+xxntn8Yp5I+5xm+phX6NEcexeI99
KqbgRtz7sKGadHXcr05zfdjFVjreufR37MRa/ifylS/2x7gZPlARz8SeQL1J
+lZNm89KV8DdbCXjmaCH2Te7ni7WYyN2GML2NprF75vvP1z/zF85ed3xJg7J
O4hCsc+Snksz6Ntnyv+qT4+6fgxt2f8U4z/wC/sump79efFOF/uVmD/Yqknf
it8GTilXhH0d//O1vQBFpY9KH8HhOANQrqTnbQ+9g+rq36ZJ3LP/6es+NEYT
NEUn/eihnxeif9IXac1Yi8Xzg3vVvxTvnNh/sj8Te5t4FmLdF+8t+oj0VH3Z
LVbtXHdT57Uog218bo93DB9Flb8aa6a8/CKZOsPYUvGRUnqG+n95Pua517WR
WltpkDZ+w8aQ27iGxlwtXd79ahTPn/ov0vzG9w/NR/+mZcRlDN0uZjvwjPR6
ZRdpczGOeEYOoxyf5VEWB6T347K2+upzP/THFvWfkN801tzYx8/+mOf1pav0
G9p5Ln670jXoSfo8bavuC/S09C/xnNNu0h3idyZdM/JjvRHPMP2UDhSH7LRL
7J0wU19PiUtt4z1JZ0hfFNcByvVHjlir8pmTLpXXW51euI+PDurMi/sr/a28
hXjJ2JrFu5c2p2noAm1/i4Xoy9Yn3s/8bVS+cbxT+SjLRxmaVPk2sUcWz6zu
80T36QZb1dh30UbyVojXej42xH483pcx39LKcX9ir6fOOPfpAh1Pp9PJ9CKd
QCdhIpYYbxPtL6UHY4+sbhL9uAsvayd5rP+0m4IOUncB9iu3QPk6+vJ0nCXR
D5VdSD+iT9C0/DwVZ1PSi+jH9Mk4N1B+GF/fxr5ZGwtjDyf9ojh2iTlQOhF7
C/VX4Dvphdr8FovVXyzdKWKg/EsYEu/JWC9H//A2uksPpu+ifrwjpBvQC+pO
53tG3Ct1FyCNZ+4VfSvguiAquh/5aT4UEOPHtTuK7R28qt5xPrbEGpe9tPil
jfMG/XwRh5Q/jK9jrypGX9HZNKV6mZA5xsXP8lgrud6qzpDYn8ZewnNRP9bx
sQbWxlj5VZV7SvrJOL/Rx2z62pLepf1EEO/r2O/TTaik3ij13o09sToPY3Kc
wXguJtGV/K9ASelSyl9y3UKd34xhB+axjaT15Fd3XZvWRR28EPsDWpOOUG94
nCHE/kS5hPhWYJ9v7Atw2bguIaN+FFZmWcxRdDuKxb1kL06v6d92/f9eflHp
urH+jL1l7B+NfWKsP+MsMvzH2Z+85/ShYsy59Flag87T9gu0ivTztFb0E58r
XznmavUr0aTKPU2LS5eJZzP2tco9gzIxT8X5Gboo92P8/pXbRDdiCwZKb6b7
4pyP9pH+hE401rvdx+TILC5Z4pzL72N9rB+QRPpwnOeJzbU4u4kzSe10Q6do
D53xtXaHKT8cQzESI9Bc3ZborL0WtGTcy1hzS6+KdRe+ibPPmNfxdTx7eEQ7
eWOfgPZimYfmjv1b/OZp01hfsjenzWKPqfyu+B3x+wf9Db/jLemdsSeJ34l+
FkR+FEYhfKhe0TjrUq4InRlnhvQ+6XJxdiu/UsxNqBD3L+4dZvHXVrvt4vxE
P9rT16Kvyrehr6IHe2vaCvljbo8zWXRFD3THc3EvaF/0RG/0wpGYvzxjKVCW
n7tpMryPiZgUe072KfE7wdZYL/iN7cYf2BvveEyNtVWcqWJsvAvc72ZxJha/
X4yIM2C8FGftcRaLbBEfY98lFm/HPBXr/ngX06HYoq0FcUaH+fjKMzIv3oX8
HzavHIn9RLxncTTOTvluQBviQeUewgS+82lnPH0g1moxh8ivh/7KH4h9QKxJ
sB/70C/mD3WSIIFkSIr3lc8V62/jykl/57OkcXeULkVL4H50ki5Nf4l9Sqwv
kNS4ktC7kAI3pG+GDbdxC1uVHy+WEzAOkzAxziP4SqhzJ87AtTlXLOahrvRg
cRqEzWL1dZwxRpxivWecc+I9yuduY9oT+yH8hb0xRmOpQ+uilHKlMY7vvLHm
jXHF+SNqy6+FvvHc0z/wG37HTvTh/2Z8H4jzkvi2Et9Z8F7sJ8WogFhkj28a
fBaJc0TporQwiqODdDH6Mz/XjOd6fAvAf7iK5MZ9IdYaSOAyLuEn5d8Vm9EY
hbEYg0J8XZH/L3bEOkUsZqKO9FviNBCbxGo22xzMwmzjnBXnFrH21Pdt+AU7
sD3GaCwv0Joortx9GMN3njhjir18nA3gefnPobfyP9Ot2IyfsAW9Yg9K/4u9
I67jGqYqn02M8otFVrqdz4K0sHQh+oH8LNrKiozxDQCZMCbOhPzmG+JN42tE
X0SjeD/R+ujGXpfWQeM4gxTPKSjE/h6dir1xNiB2X2Me5uObWI+K5TT57+OW
Pv3ItinOJrAFmzFQmSnmkamYjLfifR7nk/Iu4jwu4xLmxBpK/JfEmRh/bcwH
Lxvjq7Q1zhrTOZxB2/i2FXst+e9hCra5V7/idbFuH+sA/e4ifl3RGW+iW8Q5
vuPRGiisXJE4s9PeYOlRtJB0wfjGIl01ziqU70g74XV0wBt4PM5d9fUKWsQz
Sa/GGii+4dDLaB7PJr0Q3zf4zijGmWK+Zs9CM+P+mPNojpi72bPFdzw8xX9a
mg5t2TPQ9Cgde444x4n5nf1emgqvxDco7YyJ7wXs42Kuxc+xPhHfndiBXfgd
U2KNEN+0MFpbb4lpU3EcRAfibQyOdZn20ot5BqRDAc/cNmPpq14/1NbWANof
P2rrS/dgOr6I35Y4zoizPf5/ELON2IBN+BE9Yn0R+3TkV65AnPXynVs7I2Nu
ls6LSvIrorvy6+h6rMZarAk//F+kl2K9jn9xGVPitxHfnowrM/01fBp3e+n8
cY6Igng9zktijcLPOeM5jzvSZ+mZeO95xo/R4zEfs5+kJ2LvHefyYjkCw/BO
fIdGHmVOx54Iv2jzY7H4BLWk+4hTb2wUq8/YPo9vNxEz4/wS3fn8Xt9XYDlW
YWU8v8ZSIc6TkFu5PBjBdy6xGh4qnTPODeSXj2dd+aV0GRbHPgXfhR/+z9Cz
OI3zOIfJymcSo7xikZFujVjRQhErOk1+Gm2lRao4M8O9cR4fa0fPXk10Nb7a
tFbMO7HWjG8dce7IXoNWjzUSxornOBRkn0DHYw8/s8RuNmZibswJKCeWk+RP
xE19Wse2HmvxAzagf6whzS+TMAEDYv8gvqflnYlzMZyL73vhP84s4zwVq/lr
EesOY2wZ5zQ4ZUyn40wNraQLxN5RvZu4jtu4haX8nOfjHB7T93rxW+GnPq2L
hmgQexr9mBt7XJyNtWCsYeJ+icNQOjCeMfY58mfjoPK/0m14OZ6fWFfhUW2c
oqfRjP0sPYP8cT4b+240jWeUHsMqvjPRzHiGPSvNgr/jPJXmjPMk9uw0W3wv
izMLmh7l2TPSDDjKnia+OaAce2p6L0pipHvyDgqwv0tHYbfyX4jPl/gcMzA9
zi6McYz80bG+0beVbKuwAmuwGn2VGef+jcdY9JOeKR7H5B3HPzgZ55WYFWfO
+rAQK2M9LtaNxL8pbYzj7t+JOOtEM+l84nRFvav4F9fwH5bw80/EBY/EuVLc
O35qxfc71EFtHNCPmcrMinsQe5s4Z9NuTvdxcJzbx++dfYb86div/E8x/8Y+
W96WWIfFnjLOkulhNGE/So8gb6w34/6jMft+ug8r4rxdG0nROuYimiy+7yt/
D02JNuwpaHI8Gd+Q1LsTe95YL7ElUDLOPNluoWV8l6bXo2/yhtMRqB/79Liv
+Cm+C4nPr9iK7diGyXEuIH9UoK2+YtNEvPrRPhgQ5+Lx7Ef/xD4lUsT5ijnk
Z2Pprl4P1NRWL9oTP8Q3KnPgR/gg3h3msc/Rjf8F5qZvMR+LsDDe6XyXpeWQ
Xbkc8a0o7oV23qLZ4rsVysh/Gl3iLJ9+g7n4CvPCD/+Vjb9KfCfRn2q0Kuop
X5FWQqc4e6UV8BPfzT2XLdAMrdAyvsWKSVvaDq3xKtpgE/9/q/9PrOGVORpn
ehjCTwm35Wqq////1P8BDmHLJw==
         "]]}, {
        Directive[
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwl3Hf8l9P/x/F3U8OIKClUtKOhSEZLKdEgO0VkFFH6iqgUIpuSrRJRaRcN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         "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox["\"x\"", TraditionalForm], 
       FormBox["\"y\"", TraditionalForm]}, 
     AxesOrigin -> {Automatic, Automatic}, DisplayFunction :> Identity, 
     Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
       "AxesInFront" -> True}, 
     PlotRange -> {{-0.509683995922528, 
      0.509683995922528}, {-0.2038735983690112, 0.2038735983690112}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(\[CenterDot]\\)]\\)\
\[CenterDot]u > 0\"", 
       "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(\[CenterDot]\\)]\\)\
\[CenterDot]u < 0\""}, "SwatchLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1]]], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.5], 
                    RGBColor[0.922526, 0.385626, 0.209179]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.662019866533173*^9, 3.662019894717902*^9}, 
   3.6620200138876677`*^9, 3.662913447969352*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving eigenvalues of",
 StyleBox[" ", "Subsubsection"],
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "=", "Fx"}], TraditionalForm]]],
 StyleBox[" for small ", "Subsubsection"],
 Cell[BoxData[
  FormBox[
   RowBox[{"|", "x", "|"}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.661865906416456*^9, 3.661865916488597*^9}, {
  3.6620169476672726`*^9, 3.6620169711668606`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"A", "=", 
      RowBox[{"(", GridBox[{
         {"0", "1"},
         {
          RowBox[{
           RowBox[{"-", "g"}], "/", 
           RowBox[{"(", 
            RowBox[{"m", " ", "l"}], ")"}]}], "0"}
        }], ")"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"B", "=", 
      RowBox[{"(", GridBox[{
         {"0"},
         {
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{"m", " ", "l"}], ")"}]}]}
        }], ")"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", GridBox[{
          {"f11", "f12"}
         }], ")"}], "//", "MatrixForm"}], ",", 
      RowBox[{
       RowBox[{"A", "+", 
        RowBox[{"B", ".", 
         RowBox[{"(", GridBox[{
            {"f11", "f12"}
           }], ")"}]}]}], "//", "MatrixForm"}], ",", 
      RowBox[{"Eigenvalues", "[", 
       RowBox[{"A", "+", 
        RowBox[{"B", ".", 
         RowBox[{"(", GridBox[{
            {"f11", "f12"}
           }], ")"}]}]}], "]"}]}], "}"}], "\[IndentingNewLine]", "/.", 
    RowBox[{"First", "@", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Eigenvalues", "[", 
        RowBox[{"A", "+", 
         RowBox[{"B", ".", 
          RowBox[{"(", GridBox[{
             {"f11", "f12"}
            }], ")"}]}]}], "]"}], "\[Equal]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.660288760642185*^9, 3.660288863396951*^9}, {
  3.660288977893038*^9, 3.660288998579667*^9}, {3.6602890459382143`*^9, 
  3.660289046720768*^9}, {3.6602893486242356`*^9, 3.6602894065962796`*^9}, {
  3.661502134267073*^9, 3.66150213438615*^9}, {3.661862802921015*^9, 
  3.6618628191603785`*^9}, {3.6618629949193954`*^9, 3.661863032012511*^9}, {
  3.661863070198823*^9, 3.661863070278977*^9}, {3.6618640815247374`*^9, 
  3.6618640879703712`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "50.19`"}], 
        RowBox[{"-", "120.`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "1"},
       {
        RowBox[{"-", "0.9999999999999999`"}], 
        RowBox[{"-", "2.`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0000000112391596`"}], ",", 
     RowBox[{"-", "0.9999999887608403`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6602888450129223`*^9, 3.6602888642255273`*^9}, {
   3.660288978275301*^9, 3.6602889989059*^9}, 3.660289046894882*^9, {
   3.660289349718014*^9, 3.6602894067503977`*^9}, 3.6615021346553316`*^9, {
   3.6618628006093917`*^9, 3.6618628261446934`*^9}, {3.661863015195381*^9, 
   3.661863032207588*^9}, 3.661863072173448*^9, 3.6618657553898134`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure: Timing", "Subsubsection",
 CellChangeTimes->{{3.6618632066454916`*^9, 3.6618632379812517`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"totalTime", "[", 
      RowBox[{"xx", ",", "yy", ",", 
       RowBox[{"Precision", "\[Rule]", 
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]]}]}], "]"}], ",", 
     RowBox[{"Show", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ContourPlot", "[", 
        RowBox[{
         RowBox[{"Evaluate", "[", 
          RowBox[{"Flatten", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"x", "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "k"}], "+", "1"}], ")"}], "/", "g"}]}], 
                   ")"}], "2"], "+", 
                 FractionBox[
                  SuperscriptBox["y", "2"], 
                  RowBox[{"g", "/", "l"}]]}], "\[Equal]", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "/", "g"}], ")"}], "2"]}], ",", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"x", "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "k"}], "+", "1"}], ")"}], "/", "g"}]}], 
                   ")"}], "2"], "+", 
                 FractionBox[
                  SuperscriptBox["y", "2"], 
                  RowBox[{"g", "/", "l"}]]}], "\[Equal]", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "/", "g"}], ")"}], "2"]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", 
            FractionBox["7", "g"]}], ",", 
           FractionBox["7", "g"]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{
            RowBox[{"-", "3"}], "/", "g"}], ",", 
           RowBox[{"3", "/", "g"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Red", ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", 
              RowBox[{"xx", ",", "yy"}], "}"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", 
            RowBox[{"Point", "/@", 
             RowBox[{"findCuttingPoints", "[", 
              RowBox[{"xx", ",", "yy"}], "]"}]}]}], "}"}]}], "}"}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xx", ",", "0.372`"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["7", "g"]}], ",", 
     FractionBox["7", "g"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"yy", ",", "0.257`"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2.7", "g"]}], ",", 
     FractionBox["2.7", "g"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.662910334284795*^9, 3.6629103404911876`*^9}, {
   3.6629105259786215`*^9, 3.662910550953332*^9}, {3.662910751018157*^9, 
   3.6629107522900596`*^9}, 3.662911323584037*^9, {3.6629117358281355`*^9, 
   3.6629117420805707`*^9}, {3.6629119624827394`*^9, 3.662912072001343*^9}, {
   3.662912136619467*^9, 3.6629123183852625`*^9}, {3.6629123682576017`*^9, 
   3.6629123797537622`*^9}, {3.6629124114672194`*^9, 
   3.6629124368562098`*^9}, {3.662912790143544*^9, 3.6629128025703597`*^9}, 
   3.662912932472413*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`xx$$ = 0.372, $CellContext`yy$$ = 0.257, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`xx$$], 0.372}, -0.7135575942915392, 
      0.7135575942915392}, {{
       Hold[$CellContext`yy$$], 0.257}, -0.27522935779816515`, 
      0.27522935779816515`}}, Typeset`size$$ = {312., {84., 89.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`xx$151493$$ = 0, $CellContext`yy$151494$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`xx$$ = 0.372, $CellContext`yy$$ = 0.257}, 
      "ControllerVariables" :> {
        Hold[$CellContext`xx$$, $CellContext`xx$151493$$, 0], 
        Hold[$CellContext`yy$$, $CellContext`yy$151494$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> {
        $CellContext`totalTime[$CellContext`xx$$, $CellContext`yy$$, 
         Precision -> 10^(-4)], 
        Show[
         ContourPlot[
          Evaluate[
           Flatten[
            
            Table[{($CellContext`x - (2 $CellContext`k + 
                  1)/$CellContext`g)^2 + \
$CellContext`y^2/($CellContext`g/$CellContext`l) == (
                1/$CellContext`g)^2, ($CellContext`x + (2 $CellContext`k + 
                   1)/$CellContext`g)^2 + \
$CellContext`y^2/($CellContext`g/$CellContext`l) == (
                1/$CellContext`g)^2}, {$CellContext`k, 0, 
              3}]]], {$CellContext`x, -(7/$CellContext`g), 
           7/$CellContext`g}, {$CellContext`y, (-3)/$CellContext`g, 
           3/$CellContext`g}], 
         Graphics[{{Red, 
            Point[{$CellContext`xx$$, $CellContext`yy$$}]}, {Black, 
            Map[Point, 
             $CellContext`findCuttingPoints[$CellContext`xx$$, \
$CellContext`yy$$]]}}]]}, 
      "Specifications" :> {{{$CellContext`xx$$, 0.372}, -0.7135575942915392, 
         0.7135575942915392}, {{$CellContext`yy$$, 
          0.257}, -0.27522935779816515`, 0.27522935779816515`}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{363., {144., 151.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.662912792669347*^9, 3.6629128032628503`*^9}, 
   3.6629129335962086`*^9, {3.662913124679517*^9, 3.662913128847069*^9}, {
   3.6629132792487946`*^9, 3.6629132886524568`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"totalTime", "[", 
      RowBox[{"xx", ",", "yy"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"xx", ",", 
       RowBox[{"-", 
        FractionBox["5", "g"]}], ",", 
       FractionBox["5", "g"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"yy", ",", 
       RowBox[{"-", 
        FractionBox["2.7", "g"]}], ",", 
       FractionBox["2.7", "g"]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Axes", "->", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "30"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"MaxRecursion", "\[Rule]", "0"}], ","}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"BarLegend", "[", "\[IndentingNewLine]", 
       RowBox[{"Automatic", ",", "\[IndentingNewLine]", 
        RowBox[{"LegendMarkerSize", "\[Rule]", "200"}]}], 
       "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"2", "/", "3"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
   "\"\<s15\>\"", ",", "False"}], "]"}]], "Input",
 CellChangeTimes->{{3.660892194076024*^9, 3.660892327434224*^9}, {
   3.6608923641181355`*^9, 3.6608924326565475`*^9}, {3.6608924652925887`*^9, 
   3.6608925001702375`*^9}, {3.660892535758378*^9, 3.660892542821364*^9}, {
   3.6608925985367174`*^9, 3.6608926105131783`*^9}, {3.660892780873516*^9, 
   3.660892860303622*^9}, {3.6608930272455425`*^9, 3.660893152262849*^9}, {
   3.6608932038662987`*^9, 3.6608932672060413`*^9}, {3.6608933084741907`*^9, 
   3.6608933770396066`*^9}, {3.6608934461784563`*^9, 
   3.6608935392086935`*^9}, {3.6608936036972437`*^9, 
   3.6608936787802787`*^9}, {3.660893844105645*^9, 3.6608939071671925`*^9}, {
   3.660893939159791*^9, 3.6608940186899633`*^9}, {3.660971194371527*^9, 
   3.660971204761855*^9}, {3.660971234859125*^9, 3.660971258626914*^9}, {
   3.6609713410981674`*^9, 3.66097145643264*^9}, {3.6609715244496794`*^9, 
   3.6609716736330605`*^9}, 3.6609722669341416`*^9, {3.660972299678265*^9, 
   3.660972579405093*^9}, {3.6609726469498043`*^9, 3.6609729661738157`*^9}, {
   3.660997925866931*^9, 3.6609979927466054`*^9}, {3.6609985721617403`*^9, 
   3.6609985820874834`*^9}, {3.66099865964093*^9, 3.660998674184492*^9}, {
   3.660998715074721*^9, 3.660998779863824*^9}, 3.6610021291438856`*^9, {
   3.661002533940463*^9, 3.6610026339957914`*^9}, {3.6610027212044935`*^9, 
   3.6610027577241364`*^9}, 3.66100280274449*^9, {3.661003136276503*^9, 
   3.661003143410123*^9}, {3.661003194689917*^9, 3.661003233993024*^9}, 
   3.6610033068259964`*^9, {3.6610034243699665`*^9, 3.661003426574012*^9}, {
   3.6610043652439823`*^9, 3.6610043671413226`*^9}, {3.6610043997096467`*^9, 
   3.661004454204139*^9}, {3.6610045125753727`*^9, 3.6610045672680025`*^9}, {
   3.6610045981788363`*^9, 3.661004616510785*^9}, {3.6610659757146873`*^9, 
   3.6610660545293493`*^9}, {3.661066115881686*^9, 3.661066151817069*^9}, {
   3.661066246730111*^9, 3.6610662578329535`*^9}, {3.6610662900737267`*^9, 
   3.6610664359277515`*^9}, {3.6610664757758985`*^9, 
   3.6610664943830423`*^9}, {3.661066848506511*^9, 3.6610668604379377`*^9}, {
   3.661066917614324*^9, 3.661066917710393*^9}, {3.661066951573312*^9, 
   3.6610670620060034`*^9}, {3.6618632204139423`*^9, 3.661863291430642*^9}, 
   3.6618707730503397`*^9, 3.661870992208906*^9, {3.6618716885180163`*^9, 
   3.661871688557048*^9}, {3.66196442932432*^9, 3.661964438139908*^9}, {
   3.661964492348985*^9, 3.661964511124544*^9}, {3.661964658828164*^9, 
   3.6619646654031687`*^9}, {3.6619647414112115`*^9, 3.661964830546444*^9}, {
   3.662019710802586*^9, 3.6620197209678564`*^9}, {3.6620197531846776`*^9, 
   3.662019781311684*^9}, {3.6620198360323753`*^9, 3.662019836391777*^9}, {
   3.662906127880498*^9, 3.6629061349775505`*^9}, {3.662906197689963*^9, 
   3.662906217762186*^9}, {3.6629062697540264`*^9, 3.6629062750017443`*^9}, {
   3.662911697337862*^9, 3.662911708961098*^9}, {3.662912573935341*^9, 
   3.66291257397537*^9}, {3.66291330287852*^9, 3.662913305837617*^9}, {
   3.6629133508385043`*^9, 3.6629133512387877`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJx13Xm839Odx/FYpyiDYkQVtUxb0qhMa5mpfJGU0kgqlLY6ltF9NDrRqDWW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     "], {{{
        EdgeForm[], 
        GrayLevel[0.8], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxM3QW4dVXRB/Bz4+QFEaS7u1u6JQVBkO6STukuKUG6u1NKuhsESenu+BCk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           "]], 
          PolygonBox[CompressedData["
1:eJwtkj0sQ3EUxS+v2te+mkgMbVVR1EfZJBISwtYYDBKbsBikIgYLo9hIxNem
EzWIUYzYGax2ISabze/kvuHm3XO//ufc+0prW0v1VjOrYAnsIG22mzFbD8wK
WbOnlNk1sTR4FHwBXgHvUZsH34dm80mzHM194KvIrIGN46/S84b/imWxMWKd
cb6K38F3inmX9FfAL21mi8w+IrZBbzexG2qmeauITYA/qN2BX4H3+sEPocfk
K/aHf4v1gk+YMcms4ay/8cz89sg5iYs4Kaea/cBravgLzDkGl8g1AtcsrdK8
nXHN0irNc+Tq9BXBZfK/5JaJ58Cz5rlqwnPFmMdpyrVKcxO9NewMXAZ/Jr1n
CP8wcD4/zMzTP0KsK/SYuImjuAorpxrtVjvW7nUDYd2kI965btvkrcGs3zhM
+I11W914M+OcxEWcVCudqlXPHe+/w++c+AC4Fvk/U4jnSftjxrVrB83Ib9iD
P2N+m++k30Y3agl9pmZpprR/JV27dvAPfPhFiA==
           "]], 
          
          PolygonBox[{{2983, 3121, 32, 62, 3104}, {3121, 2983, 3120, 31, 
           32}}]}]}, {}, {}, {}, {}}}, VertexColors -> CompressedData["
1:eJx0nHk4lH37/yXJVkmWkkRFZU9Ewtkm2RJJlmilQhJFSdlakITsZCuplGyV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      "]], {DisplayFunction -> Identity, Axes -> True, AxesLabel -> {
       FormBox["\"x\"", TraditionalForm], 
       FormBox["\"y\"", TraditionalForm]}, DisplayFunction :> Identity, Frame -> 
     True, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic, 
       "ScalingFunctions" -> None}, 
     PlotRange -> {{-0.509683995922528, 
      0.509683995922528}, {-0.27522935779816515`, 0.27522935779816515`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{{}, {}, 
             RasterBox[CompressedData["
1:eJxFlwmcjvUWxyV3YmZsZbtJ9i1q7q2spR9ZrrJUuLYUQiEx1iRRdmNwiySk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              "], {{
                Rational[-15, 2], -100}, {
                Rational[15, 2], 100}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], -100}, {
                  Rational[-15, 2], -100}, {
                  Rational[-15, 2], 100}, {
                  Rational[15, 2], 100}, {
                  Rational[15, 2], -100}}, {{
                 7.5, -100}, {-7.5, -100}, {-7.5, 100}, {7.5, 100}, {
                 7.5, -100}}]]}, {
              CapForm[None], {}}, {Antialiasing -> False, 
              StyleBox[
               LineBox[{{7.5, -100.}, {7.5, 100.}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.5, -100.}, 
                    Offset[{4., 0}, {7.5, -100.}]}, {{
                    7.5, -38.83792048929664}, 
                    Offset[{4., 0}, {7.5, -38.83792048929664}]}, {{7.5, 
                    22.32415902140671}, 
                    Offset[{4., 0}, {7.5, 22.32415902140671}]}, {{7.5, 
                    83.48623853211006}, 
                    Offset[{4., 0}, {7.5, 83.48623853211006}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False], 
                  StyleBox[
                   LineBox[{{{7.5, -87.76758409785933}, 
                    Offset[{2.5, 0.}, {7.5, -87.76758409785933}]}, {{
                    7.5, -75.53516819571865}, 
                    Offset[{2.5, 0.}, {7.5, -75.53516819571865}]}, {{
                    7.5, -63.30275229357799}, 
                    Offset[{2.5, 0.}, {7.5, -63.30275229357799}]}, {{
                    7.5, -51.070336391437316`}, 
                    Offset[{2.5, 0.}, {7.5, -51.070336391437316`}]}, {{
                    7.5, -26.605504587155973`}, 
                    Offset[{2.5, 0.}, {7.5, -26.605504587155973`}]}, {{
                    7.5, -14.373088685015302`}, 
                    Offset[{2.5, 0.}, {7.5, -14.373088685015302`}]}, {{
                    7.5, -2.1406727828746313`}, 
                    Offset[{2.5, 0.}, {7.5, -2.1406727828746313`}]}, {{7.5, 
                    10.09174311926604}, 
                    Offset[{2.5, 0.}, {7.5, 10.09174311926604}]}, {{7.5, 
                    34.55657492354738}, 
                    Offset[{2.5, 0.}, {7.5, 34.55657492354738}]}, {{7.5, 
                    46.78899082568805}, 
                    Offset[{2.5, 0.}, {7.5, 46.78899082568805}]}, {{7.5, 
                    59.021406727828726`}, 
                    Offset[{2.5, 0.}, {7.5, 59.021406727828726`}]}, {{7.5, 
                    71.25382262996939}, 
                    Offset[{2.5, 0.}, {7.5, 71.25382262996939}]}, {{7.5, 
                    95.71865443425074}, 
                    Offset[{2.5, 0.}, {7.5, 95.71865443425074}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4], 
                    Opacity[0.3]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["0", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -100.}], {-1, 0.}, Automatic, {1, 
                    0}], 
                    InsetBox[
                    FormBox["10", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -38.83792048929664}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["20", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 22.32415902140671}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["30", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 83.48623853211006}], {-1, 0.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]], 
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], 
                    
                    StyleBox[{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4], 
                    Opacity[0.3]], {
                    Directive[
                    Opacity[1]], 
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]], 
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 200}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.`", ",", "32.65139093872514`"}], "}"}]}], "}"}], 
           ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"LegendMarkerSize", "\[Rule]", "200"}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.661871685639984*^9, 3.6618717123938694`*^9}, 
   3.66196453703269*^9, {3.661964743721997*^9, 3.6619648526229553`*^9}, 
   3.6620197487707424`*^9, 3.662019808628938*^9, 3.662906132160555*^9, {
   3.662906179904378*^9, 3.6629062305552683`*^9}, {3.6629062730703945`*^9, 
   3.66290627637673*^9}, 3.662910558919964*^9, {3.6629106323863325`*^9, 
   3.6629106511836405`*^9}, {3.662910683315423*^9, 3.662910716102417*^9}, {
   3.662911678020174*^9, 3.6629117111726656`*^9}, 3.6629118049071016`*^9, {
   3.662912540403582*^9, 3.662912568617584*^9}, 3.662912598686898*^9, 
   3.6629133330228806`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Determining solutions of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{"ax", "+", "b"}], ")"}]}], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6618633134531746`*^9, 3.661863375988749*^9}, 
   3.662016951347871*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  RowBox[{
  "Print", "[", 
   "\"\<\[PlusMinus]\!\(\*SqrtBox[FractionBox[\(\[ScriptL]\\\ m\), \(g\)]]\) \
ArcCos[((\!\(\*SuperscriptBox[\(u\), \(2\)]\)-g u \!\(\*SubscriptBox[\(x\), \
\(k\)]\)-g u \!\(\*SubscriptBox[\(x\), \(1 + \
k\)]\)+\!\(\*SuperscriptBox[\(g\), \(2\)]\) \!\(\*SubscriptBox[\(x\), \
\(k\)]\) \!\(\*SubscriptBox[\(x\), \(1 + \
k\)]\))\[PlusMinus]\!\(\*SqrtBox[\(\(-2\)\\\ \*SuperscriptBox[\(g\), \(2\)]\\\
\ \[ScriptL]\\\ m\\\ u\\\ \*SubscriptBox[\(x\), \(k\)]\\\ \
\*SubsuperscriptBox[\(y\), \(k\), \(2\)] + \*SuperscriptBox[\(g\), \(3\)]\\\ \
\[ScriptL]\\\ m\\\ \*SubsuperscriptBox[\(x\), \(k\), \(2\)]\\\ \
\*SubsuperscriptBox[\(y\), \(k\), \(2\)] + 2\\\ \*SuperscriptBox[\(g\), \
\(2\)]\\\ \[ScriptL]\\\ m\\\ u\\\ \*SubscriptBox[\(x\), \(1 + k\)]\\\ \
\*SubsuperscriptBox[\(y\), \(k\), \(2\)] - \*SuperscriptBox[\(g\), \(3\)]\\\ \
\[ScriptL]\\\ m\\\ \*SubsuperscriptBox[\(x\), \(1 + k\), \(2\)]\\\ \
\*SubsuperscriptBox[\(y\), \(k\), \(2\)] + \*SuperscriptBox[\(g\), \(2\)]\\\ \
\*SuperscriptBox[\(\[ScriptL]\), \(2\)]\\\ \*SuperscriptBox[\(m\), \(2\)]\\\ \
\*SubsuperscriptBox[\(y\), \(k\), \(4\)]\)]\))/(\!\(\*SuperscriptBox[\(u\), \
\(2\)]\)-2 g u \!\(\*SubscriptBox[\(x\), \(k\)]\)+\!\(\*SuperscriptBox[\(g\), \
\(2\)]\) \!\(\*SubsuperscriptBox[\(x\), \(k\), \(2\)]\)+g \[ScriptL] m \
\!\(\*SubsuperscriptBox[\(y\), \(k\), \(2\)]\))\>\"", "]"}],
  DisplayForm]], "Input",
 CellChangeTimes->{{3.6610782250177355`*^9, 3.661078241035061*^9}, {
  3.661078368524105*^9, 3.661078413392025*^9}, {3.661078492986245*^9, 
  3.6610785646428633`*^9}, {3.661079451673197*^9, 3.6610794592915783`*^9}, {
  3.6610795502888556`*^9, 3.6610795540865493`*^9}, {3.661079674912883*^9, 
  3.6610796764399614`*^9}, {3.661863768954985*^9, 3.661863841252621*^9}, {
  3.661863875780531*^9, 3.6618638976355324`*^9}}],

Cell[BoxData["\<\"\[PlusMinus]\\!\\(\\*SqrtBox[FractionBox[\\(\[ScriptL]\\\\ \
m\\), \\(g\\)]]\\) ArcCos[((\\!\\(\\*SuperscriptBox[\\(u\\), \\(2\\)]\\)-g u \
\\!\\(\\*SubscriptBox[\\(x\\), \\(k\\)]\\)-g u \\!\\(\\*SubscriptBox[\\(x\\), \
\\(1 + k\\)]\\)+\\!\\(\\*SuperscriptBox[\\(g\\), \\(2\\)]\\) \
\\!\\(\\*SubscriptBox[\\(x\\), \\(k\\)]\\) \\!\\(\\*SubscriptBox[\\(x\\), \
\\(1 + k\\)]\\))\[PlusMinus]\\!\\(\\*SqrtBox[\\(\\(-2\\)\\\\ \
\\*SuperscriptBox[\\(g\\), \\(2\\)]\\\\ \[ScriptL]\\\\ m\\\\ u\\\\ \
\\*SubscriptBox[\\(x\\), \\(k\\)]\\\\ \\*SubsuperscriptBox[\\(y\\), \\(k\\), \
\\(2\\)] + \\*SuperscriptBox[\\(g\\), \\(3\\)]\\\\ \[ScriptL]\\\\ m\\\\ \
\\*SubsuperscriptBox[\\(x\\), \\(k\\), \\(2\\)]\\\\ \\*SubsuperscriptBox[\\(y\
\\), \\(k\\), \\(2\\)] + 2\\\\ \\*SuperscriptBox[\\(g\\), \\(2\\)]\\\\ \
\[ScriptL]\\\\ m\\\\ u\\\\ \\*SubscriptBox[\\(x\\), \\(1 + k\\)]\\\\ \
\\*SubsuperscriptBox[\\(y\\), \\(k\\), \\(2\\)] - \\*SuperscriptBox[\\(g\\), \
\\(3\\)]\\\\ \[ScriptL]\\\\ m\\\\ \\*SubsuperscriptBox[\\(x\\), \\(1 + k\\), \
\\(2\\)]\\\\ \\*SubsuperscriptBox[\\(y\\), \\(k\\), \\(2\\)] + \
\\*SuperscriptBox[\\(g\\), \\(2\\)]\\\\ \\*SuperscriptBox[\\(\[ScriptL]\\), \
\\(2\\)]\\\\ \\*SuperscriptBox[\\(m\\), \\(2\\)]\\\\ \
\\*SubsuperscriptBox[\\(y\\), \\(k\\), \
\\(4\\)]\\)]\\))/(\\!\\(\\*SuperscriptBox[\\(u\\), \\(2\\)]\\)-2 g u \
\\!\\(\\*SubscriptBox[\\(x\\), \\(k\\)]\\)+\\!\\(\\*SuperscriptBox[\\(g\\), \
\\(2\\)]\\) \\!\\(\\*SubsuperscriptBox[\\(x\\), \\(k\\), \\(2\\)]\\)+g \
\[ScriptL] m \\!\\(\\*SubsuperscriptBox[\\(y\\), \\(k\\), \\(2\\)]\\))\"\>"], \
"Print",
 CellChangeTimes->{{3.661863887022435*^9, 3.6618638981285534`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Determining part of ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " matrix for system of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "+", "4"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " variables"
}], "Subsubsection",
 CellChangeTimes->{{3.661863352621526*^9, 3.661863357733272*^9}, {
  3.662016953962717*^9, 3.662016956378433*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R", ",", "B", ",", "l", ",", "m", ",", "uMax"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "=", 
      RowBox[{"2", "\[Epsilon]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B", "=", 
      RowBox[{"(", GridBox[{
         {"0"},
         {
          RowBox[{
           RowBox[{"-", "uMax"}], "/", 
           RowBox[{"(", 
            RowBox[{"m", " ", "l"}], ")"}]}]},
         {"0"},
         {"uMax"}
        }], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"-", 
      RowBox[{"B", " ", ".", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["R", 
          RowBox[{"-", "1"}]], 
         RowBox[{"B", "\[Transpose]"}]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}], "//", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R", ",", "B", ",", "l", ",", "m", ",", "uMax"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R", "=", 
      RowBox[{"2", "\[Epsilon]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"B", "=", 
      RowBox[{"(", GridBox[{
         {"0"},
         {
          RowBox[{
           RowBox[{"-", "1"}], "/", 
           RowBox[{"(", 
            RowBox[{"m", " ", "l"}], ")"}]}]}
        }], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"-", 
      RowBox[{"B", " ", ".", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["R", 
          RowBox[{"-", "1"}]], 
         RowBox[{"B", "\[Transpose]"}]}], ")"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}], "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.661500270758421*^9, 3.6615003892820344`*^9}, {
   3.661500434250769*^9, 3.6615004486579323`*^9}, {3.661510358216949*^9, 
   3.661510361921563*^9}, {3.6618637253320255`*^9, 3.6618637560687304`*^9}, 
   3.662725111192299*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["uMax$859516", "2"], 
        RowBox[{"2", " ", 
         SuperscriptBox["l$859516", "2"], " ", 
         SuperscriptBox["m$859516", "2"], " ", "\[Epsilon]"}]]}], "0", 
      FractionBox[
       SuperscriptBox["uMax$859516", "2"], 
       RowBox[{"2", " ", "l$859516", " ", "m$859516", " ", "\[Epsilon]"}]]},
     {"0", "0", "0", "0"},
     {"0", 
      FractionBox[
       SuperscriptBox["uMax$859516", "2"], 
       RowBox[{"2", " ", "l$859516", " ", "m$859516", " ", "\[Epsilon]"}]], 
      "0", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["uMax$859516", "2"], 
        RowBox[{"2", " ", "\[Epsilon]"}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.661500384821888*^9, 3.6615003895212145`*^9}, {
   3.661500439403411*^9, 3.6615004548453054`*^9}, 3.661510362170739*^9, {
   3.6618637216439853`*^9, 3.6618637563085184`*^9}, 3.6627251122562237`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0"},
     {"0", 
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"2", " ", 
         SuperscriptBox["l$859520", "2"], " ", 
         SuperscriptBox["m$859520", "2"], " ", "\[Epsilon]"}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.661500384821888*^9, 3.6615003895212145`*^9}, {
   3.661500439403411*^9, 3.6615004548453054`*^9}, 3.661510362170739*^9, {
   3.6618637216439853`*^9, 3.6618637563085184`*^9}, 3.6627251122612286`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Parabolic calculations of time", "Subsubsection",
 CellChangeTimes->{{3.6618633914529033`*^9, 3.6618633957401915`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"P", "=", 
       RowBox[{"2", "\[Pi]", 
        SqrtBox[
         FractionBox[
          RowBox[{"m", " ", "l"}], "g"]]}]}], ",", "uu", ",", "ts", ",", 
      "ds"}], "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exportRaster", "[", 
       RowBox[{
        RowBox[{"Most", "@", 
         RowBox[{"finalOc", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{
              RowBox[{"-", "uMax"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"2", " ", "1", "\[Pi]"}], ")"}], "2"], 
              FractionBox[
               RowBox[{"m", " ", "l"}], "g"]}], ",", "0"}], "}"}], ",", 
           RowBox[{"2", "P"}], ",", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", "\[IndentingNewLine]", 
             RowBox[{"uFromSwitchTimes", "[", 
              RowBox[{"{", 
               RowBox[{"P", ",", "P"}], "}"}], "]"}]}], "\[IndentingNewLine]",
             "]"}]}], "]"}]}], ",", "\"\<s16\>\"", ",", "True"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"exportRaster", "[", 
       RowBox[{
        RowBox[{"Most", "@", 
         RowBox[{"finalOc", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{
              RowBox[{"-", "uMax"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"2", " ", "3", "\[Pi]"}], ")"}], "2"], 
              FractionBox[
               RowBox[{"m", " ", "l"}], "g"]}], ",", "0"}], "}"}], ",", 
           RowBox[{"6", "P"}], ",", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", "\[IndentingNewLine]", 
             RowBox[{"uFromSwitchTimes", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"3", "P"}], ",", 
                RowBox[{"3", "P"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", 
            "]"}]}], "]"}]}], ",", "\"\<s17\>\"", ",", "True"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r0", "=", 
           RowBox[{"-", "65"}]}], ",", 
          RowBox[{"T1", "=", "5.93875245868332`"}], ",", 
          RowBox[{"T2", "=", "3.5855500596036425`"}]}], "}"}], ",", 
        RowBox[{"export", "[", 
         RowBox[{
          RowBox[{"Most", "@", 
           RowBox[{"finalOc", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
             RowBox[{
              RowBox[{"2", "T1"}], "+", 
              RowBox[{"2", "T2"}]}], ",", 
             RowBox[{"Function", "[", 
              RowBox[{"t", ",", "\[IndentingNewLine]", 
               RowBox[{"uFromSwitchTimes", "[", 
                RowBox[{"{", 
                 RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], 
                "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\"\<s22\>\"", ",", "True"}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r0", "=", 
           RowBox[{"-", "100"}]}], ",", 
          RowBox[{"T1", "=", "7.855931082167171`"}], ",", 
          RowBox[{"T2", "=", "3.0153416205911814`"}]}], "}"}], ",", 
        RowBox[{"Most", "@", 
         RowBox[{"finalOc", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
           RowBox[{
            RowBox[{"2", "T1"}], "+", 
            RowBox[{"2", "T2"}]}], ",", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", "\[IndentingNewLine]", 
             RowBox[{"uFromSwitchTimes", "[", 
              RowBox[{"{", 
               RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], 
              "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r0", "=", 
           RowBox[{"-", "30"}]}], ",", 
          RowBox[{"T1", "=", "3.872992220571523`"}], ",", 
          RowBox[{"T2", "=", "3.884717458951645`"}]}], "}"}], ",", 
        RowBox[{"Most", "@", 
         RowBox[{"finalOc", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
           RowBox[{
            RowBox[{"2", "T1"}], "+", 
            RowBox[{"2", "T2"}]}], ",", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", "\[IndentingNewLine]", 
             RowBox[{"uFromSwitchTimes", "[", 
              RowBox[{"{", 
               RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], 
              "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r0", "=", 
           RowBox[{"-", "10"}]}], ",", 
          RowBox[{"T1", "=", "2.386162167685907`"}], ",", 
          RowBox[{"T2", "=", "3.5641009525941123`"}]}], "}"}], ",", 
        RowBox[{"exportRaster", "[", 
         RowBox[{
          RowBox[{"Most", "@", 
           RowBox[{"finalOc", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
             RowBox[{
              RowBox[{"2", "T1"}], "+", 
              RowBox[{"2", "T2"}]}], ",", 
             RowBox[{"Function", "[", 
              RowBox[{"t", ",", "\[IndentingNewLine]", 
               RowBox[{"uFromSwitchTimes", "[", 
                RowBox[{"{", 
                 RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], 
                "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\"\<s23\>\"", ",", "True"}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"finalOc", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"-", "uMax"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FractionBox["10", "4"], "2", "\[Pi]"}], ")"}], "2"], 
           RowBox[{
            FractionBox[
             RowBox[{"m", " ", "l"}], "g"], "/", "2"}]}], ",", "0"}], "}"}], 
        ",", 
        RowBox[{
         FractionBox["20", "4"], "P"}], ",", 
        RowBox[{"Function", "[", 
         RowBox[{"t", ",", 
          RowBox[{"uFromSwitchTimes", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              FractionBox["5", "4"], "P"}], ",", 
             RowBox[{
              FractionBox["5", "4"], "P"}], ",", 
             RowBox[{
              FractionBox["5", "4"], "P"}], ",", 
             RowBox[{
              FractionBox["5", "4"], "P"}]}], "}"}], "]"}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}]}], 
   "\[IndentingNewLine]", "]"}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.6615839581963177`*^9, 3.661584228891471*^9}, {
   3.6615842721449842`*^9, 3.6615843874643373`*^9}, {3.6615844921732063`*^9, 
   3.6615847130370164`*^9}, {3.6615847441659775`*^9, 3.661584751656263*^9}, {
   3.6615863533800507`*^9, 3.6615863536642513`*^9}, {3.661596591083247*^9, 
   3.6615967713186626`*^9}, {3.6615972348700128`*^9, 
   3.6615972641096473`*^9}, {3.6615974564128366`*^9, 
   3.6615974778923855`*^9}, {3.6615975285130763`*^9, 3.661597541658354*^9}, {
   3.661597641387358*^9, 3.66159765469445*^9}, {3.6615976951500974`*^9, 
   3.661597715964862*^9}, {3.6615980085863523`*^9, 3.6615980258383493`*^9}, {
   3.6615980786626773`*^9, 3.6615980790053368`*^9}, 3.6615984421942687`*^9, {
   3.6615984806101513`*^9, 3.661598555700694*^9}, {3.6615985860776024`*^9, 
   3.6615986482043643`*^9}, {3.6615987026594405`*^9, 
   3.6615987202562513`*^9}, {3.6615988004689493`*^9, 3.661598802385856*^9}, {
   3.661599209392994*^9, 3.66159929924479*^9}, {3.6615993310466757`*^9, 
   3.6615993518704147`*^9}, {3.6615994082148914`*^9, 3.661599409550925*^9}, {
   3.6615994632817664`*^9, 3.661599507885373*^9}, {3.6615997776541862`*^9, 
   3.6615998342452807`*^9}, {3.6615999399863663`*^9, 
   3.6615999714441857`*^9}, {3.6616000342736087`*^9, 
   3.6616000902104797`*^9}, {3.6616001899888515`*^9, 
   3.6616001908566027`*^9}, {3.6616004050877*^9, 3.6616004266639323`*^9}, {
   3.6616004615797048`*^9, 3.661600518175604*^9}, {3.6616005559938655`*^9, 
   3.661600663831252*^9}, {3.6616674176448216`*^9, 3.6616675788515472`*^9}, {
   3.6616676222461605`*^9, 3.6616676565593667`*^9}, {3.6616677357602396`*^9, 
   3.6616677762999935`*^9}, {3.6616678565408525`*^9, 
   3.6616681266644144`*^9}, {3.661668160060974*^9, 3.6616682688437166`*^9}, {
   3.661668351665144*^9, 3.6616683605824337`*^9}, {3.661668415866437*^9, 
   3.661668416684012*^9}, {3.6616687515922785`*^9, 3.6616687577356224`*^9}, {
   3.6616688914909706`*^9, 3.6616690142355623`*^9}, {3.6616691564709044`*^9, 
   3.6616692133570356`*^9}, {3.6616692520443277`*^9, 3.661669271125789*^9}, {
   3.661669751932828*^9, 3.6616697671895905`*^9}, {3.661669803498205*^9, 
   3.661669805390558*^9}, {3.661669869224573*^9, 3.6616699169392333`*^9}, {
   3.6616700841842194`*^9, 3.6616701679803343`*^9}, {3.661670225054598*^9, 
   3.661670346580329*^9}, {3.661670384481067*^9, 3.6616703979425635`*^9}, {
   3.6616704509569635`*^9, 3.661670467018294*^9}, {3.6616706295611053`*^9, 
   3.661670662812208*^9}, {3.6616707050159817`*^9, 3.661670754632984*^9}, {
   3.661670790079991*^9, 3.661670797027892*^9}, {3.6616710037607346`*^9, 
   3.66167104280428*^9}, {3.661671169651765*^9, 3.6616712242853065`*^9}, {
   3.6616712943377256`*^9, 3.661671466453147*^9}, {3.6616715134362917`*^9, 
   3.6616716374658275`*^9}, {3.66168112828158*^9, 3.6616811730531654`*^9}, {
   3.661683331454455*^9, 3.6616834267977047`*^9}, {3.661683840469535*^9, 
   3.661683843423619*^9}, {3.6616839103718653`*^9, 3.6616839147779684`*^9}, {
   3.6616840285962515`*^9, 3.661684029367807*^9}, {3.661684188454036*^9, 
   3.661684234889784*^9}, {3.66168500549374*^9, 3.6616850598445807`*^9}, {
   3.6616851135173883`*^9, 3.6616851379193935`*^9}, {3.661686491768256*^9, 
   3.66168650419687*^9}, {3.661686578925112*^9, 3.661686604624752*^9}, {
   3.661686696971074*^9, 3.6616867042414846`*^9}, {3.6616867938708773`*^9, 
   3.661686837164637*^9}, {3.661689876646967*^9, 3.661689916826311*^9}, {
   3.6618634086614227`*^9, 3.661863429397238*^9}, {3.661863608845348*^9, 
   3.6618636592044153`*^9}, {3.661863704269896*^9, 3.661863706988098*^9}, {
   3.6620160335035496`*^9, 3.6620160356470613`*^9}, {3.6621024205083404`*^9, 
   3.662102431914744*^9}, {3.662102482034709*^9, 3.662102484530079*^9}, 
   3.6621025167567253`*^9, {3.662118174926037*^9, 3.662118213337256*^9}, {
   3.662118314524955*^9, 3.6621183339227*^9}, {3.6621184930824776`*^9, 
   3.662118501493438*^9}, {3.6621185795447435`*^9, 3.6621186860392036`*^9}, {
   3.662119463504323*^9, 3.6621194638735847`*^9}, {3.6621197804381557`*^9, 
   3.662119823528678*^9}, {3.662119984974472*^9, 3.6621199854998446`*^9}, {
   3.662386489701027*^9, 3.6623865568358603`*^9}, {3.6623926115727797`*^9, 
   3.6623926136580496`*^9}, {3.6623927348272104`*^9, 3.6623927364260697`*^9}, 
   3.6623927832497325`*^9, {3.662393019889841*^9, 3.6623932632951336`*^9}, {
   3.662393633231927*^9, 3.662393691189995*^9}, {3.662393820550658*^9, 
   3.662393885110404*^9}, {3.662396683411639*^9, 3.6623967464025435`*^9}, {
   3.662396824160965*^9, 3.6623968372958536`*^9}, {3.6623968959146204`*^9, 
   3.6623969902777977`*^9}, {3.662397377178479*^9, 3.6623973827549887`*^9}, {
   3.662397538828863*^9, 3.662397593187257*^9}, {3.6624500603436875`*^9, 
   3.6624501287381516`*^9}, {3.662450230722416*^9, 3.6624502474732847`*^9}, {
   3.662450334528971*^9, 3.662450352249528*^9}, {3.6624504316107616`*^9, 
   3.6624504331658645`*^9}, {3.662716078361187*^9, 3.662716087190445*^9}, {
   3.662724760826112*^9, 3.6627247657755947`*^9}, {3.662836714992607*^9, 
   3.662836719569519*^9}, {3.662913947745011*^9, 3.662913960970947*^9}, {
   3.6629668468002005`*^9, 3.6629668513334055`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"3.3922007431050073`*^-6\\\"}]\\), T: \\!\\(\\*RowBox[{\\\
\"31.077851383095716`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\): \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \\\"241.45821164744606`\\\"}], \
\\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         3.3922007431050073`*^-6, 31.077851383095716`, {-241.45821164744606`}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVlnk4VV8Xx02ZQjIPmf0yu2S4iLtXaSKpUBpExiQhIUXmRFQSokwZCg0i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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVmnk41N8Xx+2y77JUdmPfhi9mcE+iJC2yV5ZURIpsJUXJWsqaJfvMZ1Kp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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVVGk01WsfpeMloQyRojpFZplOpnP+z/klZU6G8JoliUr0hlwltzKXJDeR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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw9yHs41XkCx/EjlpHpIieR5Dpy6fx+qMNx+30/Q9o6EZltUuOSU1YZSs0Y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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 31.077851383095716`}, {-133.3652122778042, 
             15.536534599136111`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xk4FXgXB/CLQtIiSovKkvUiRJZyfr+sWTLDoCK7pFKWKE1FlCREtNAQ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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0GlQk1cYhuGAShlAakApEpgCYRORCIVGJZ7voAhUcayyTJQtLElF9kWB
qriC2ioa0BZskKVumEKtxpaCfq9GaqIDogaCKATBsBQpBQNxQbCnP86cueb+
887jEJ++RWjIYDA2kvf/fyVuy8uYZoSpS2njb9x2AmNJpqOQmGtdpPnadSeE
j5+MSyZOPG3VUutM+r7W3lzioM6aC5GOpEuCu08Rp9QnbQEW6Z2oQ05s+OjP
kiJz0kOWKlz+Qvjutrr6hZM5wODOlY4RD4cvi+BADuSxN1lWKRBuanh6ODck
B2jutNznPsLdHP+1m/uyISAt4+CdBwjzpm4sX52XDaNNBf3pLQhXLZ3du8Io
GxK8xo4ZPERYOyVuVvyUBR9u6R/L2hC+13t9rdAtCzpSlEsEjxGWCXfbLPoj
E/asnVaOPUHY1DHLP3JjJqzzUhhXtiNs7y/bXv8sA3oCJ096qxFmHDJiladn
wI2CERe6E2GrDU/Ly4wy4NfW/JjkLoT3DXWZBy9Jh7yAHT3TzxAOcVC5l4Sl
QcIT3Ye6boRH1QLh69RUKD4Y6MHXIBxd3XRnz/cpcGTb+5qBXoSdfO7HooZk
qPkqqPF0H8IWtvyohaodcFwwZe36EmEdo1jGnkmCsmKe9XMtwn6Xls0LXJQE
Wk2I65FBhA/0Hzhwxms7fIyg91oNI/xdYu6UQ/Q3wBtU5ij+Rli+t4h5e5cI
gip8rke+QniOmGVWUSmEkl1JBsOjZF/PVQbSlkT4KOKOnxlD+KSNX+n9oQTw
2ydycR1HeGtto727RQKU13vOdE0gzHQrzzrrHg9cxu2Xh3VkvwXJ1bygOPg5
/xrTcgrhKx12DexsAXiZoBdyPcL6t/naL2xioVjurg9/S+5raF9TlxINSyte
sPreIWwW3Sc+pYiEkWJO/4lpsqeDXCSe3Qp5l3v/tZtB2DnprolTGB/cutzO
tc0irDoSJ1EVRsBFL1VpIoPCxVeGfvtMHQaJvwSWTxhQuGFw1PKBZygEoFCq
ag6Fo/xL9pQnbAbdm9se3vMoLDH4yJyTtgmalYrGASMKr6vPSZ3fugE6mn7k
i40pPOrJ3vyOFwwytXK1vQmF14iVGruRALhhXHr3kSmFoyc7zxds8ofCePpU
4nwKq8QqzgqtH5zRXEsdN6ewoXBiVeAGX1Bk4lcVCyh8lTlPc36dByg9OFc9
LSjMdPGtPa6yg/3a63W+xBZB4loqyg64khVSHjEZtva11hYumq65uJ44y9H5
Al/PgkMjYRIRce5RXYnTYhtAl789eo545UR/0M0YK5Cx7wnMLSn8+Sg7Xq2a
DynP18csIjbN1PnyBsyAXdoWaUscXqA2rtGbQolhV4Q7sUQ0KU1dbALpfa9C
AomLAgTDc2ONwL2SubKAOLh9Yr+ofYbui/jhy0Li/av1TO8303SZOcvnOLF3
1Kc1M4vf058UOHHOEs8db4TTsXpaG8V1/p14gOc9UNjxDy1ZeNPxFvHsiXvT
tqwROrQF2zcTlzVlMWWCQVrut571hHjrjPnO5s4eOl/30LqLuGcZX/I6Xk0v
l4ZavSC+rNld6N/dSg/HP7UcIpZKR6r9Bm7RlTbRzDFiPnOSw530ov8D4MJK
xA==
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xk41VkYwPGbhNRItspSGrkk2bLTuWci1GiZUA0lUZIl6xiSpVKSUJQo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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwd0H0wFHgYwPHlKi61h3VOxBS1Nkxi1JbV73m6vIXKoc7oahTparurJsdK
u7aiVylUt3kplzmasl1aVMTULu0mdq1ddZK85kSJwaao7ld/PPPMZ77z/PPM
37YnbLsxg8FYS+fLvrY1rGdLLcGzglzfhh4dMBbtc9xObV746qBPtw42DJ/Z
yqduauSWl3TSntLYkfilO+kXnm6nPS/w+dmvfZbJuqe0PyUt8q9d9EhTT3uI
q5JdR1DbGL1OV0o7d9r1IWoLJ3bksxQdCJzWswqUBC2n8/3ELB3UcCflXo8I
Zo1uj4q40Qy+v+89/KCeICvMRrgguBleV4m69zRQ96cmpXdoIcZj6ISRmmDE
yeJ8x2QtTFUbtGUaglaxqbmhTC207FYtitYS1Ettig8UNsHB1ZOqoWZ6Py3m
WTM0gZ+H0vSynmCmk0adVqyBdv+xM55PCO742Xe5vF0N5aIBds1Tghw+p9rw
gxr+aUzawm8lqH4jHo9a1QgC313tk88I9h33E9olNUBM8+iU9DnBnizRHbOC
x5Bx2N8t8gVBzUH2d2P19XAs6sOVlx0EK1K8y5dPq4crawIqz3URFI/ImVK3
R5AePW7j3ENQlXz7tjBGBZIMH5u2XoLj8fOsRCeU0PsixPlYH0HbdROnEmQP
4fPGGqF1P0EF+IQ/HqwDnz5VvPIVwZ8KxhrXs+ogIN9LtmmQ4Ks5cyRL1tRC
VsJOo/7XBFP2lwi/PaKAz3Hc4fNDBKd4ZdaWJXLgpcSxnYcJmthzPif0PICL
NxZ/bB2hfbd5rtnMB8Bl3O9JHSU4lrcjTOJ1HwqTblmwxml/vOGWcVsNeMwk
nXIDwQFeHdvLtRoy5C6GDRMEGe2zvB0kVeCa32nX9Z7+k3imTsyqhIEM9+7T
kwQ9hbjUM/oOCK52vLX/SHDnG3bagqYK4LRyLmk+ETzFM/ASHMqhyEOXHcsA
7KjKzxSfkEFsif/FESPAkClHh+SpUvAl4VDwDWCpbaZFy9qbMPruvpvndMBM
/Y0ATaIUalXKypczABXus71l5tegperPyExTwFVmzjmJd4ug7Ilq5byZgC7B
I1xpbiGUm2YrmswAlwScLvzLuwDSttWcjZ0NGBgsu8hk58D5F7d+G2YC6kwV
yhxDNij34WC+OWCF8LXjmkMnQeXmfnOxJaC2jxO12pAM4l6ZdCm1Ik7K5B9N
Bm7e8us+1OUGD0WWdTIUmf1YFEQtmcFz6152AI4MROTFUccuW/tJnCgAcvXA
8UvUM47uu1IzEQ9lTg+jmSzAgaD4lv0GPuxuC9ryPfXzICFRWPPBKVuzaS61
etfRYkvuLsgybt3oQi07KUkqTfwV9nQNhvhTpw7cs387EQsuly1WiKj/sDJr
0Bs2QdfGC8vSqHdE2F/az40CCdPOK5066pz7XktBJJiIFrjnUK/Wh1uFvo+A
3l+4CyuoeZwVdy+8C4Y8q3uO1dSLOZs36wWBEN6A82qp5189ZGT5wRfkvCC7
ZmqH0HPZtu95kDSqtmmltghtbzs/6QVLrodbd1IzC0ICHadcoX/bv6z/qE3w
bqmH8Vy4bLvZYoiawRBX/r3yOPkfmh4wFw==
              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {30.8, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{30.76707286926476, 
            31.077851383095716`}, {-0.04828830680067836, 0.3107786817544218}},
            PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxcmHc81u/3x8nMyl5Je0lllVVOy6hoGNkjVEayt0TZe2ePeyCy9zw2N0Up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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw91nk4VO3/wHHrMGRX9gdZw4w9W9x3UWSNPAgzBlkqM0qUR5SiKPLYohBJ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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBwAWIQvbkkbI6Ex1I7BjD4YH/WPKfZsfWxPYxfx/5nak74
Fziff39V5zaLf3D+nkPskw2/MDvA+FYFu/bLmnLC+VubOf94yPDB+XsLErhd
twnC+aGLGZ3/BYrA+W84CpmuHxCD81dMFtlolSIJ5ycFtj3fe0sazr80yfbE
TRc5OH9LjYjPgUIFOL/O82P54lWKcP5tjQzpM3+V4HzhU4wiB71U4PxTLU0X
XBtVEfJBc1kELqnB+Xcs5v/J5NGA882NrHM4EzXh/Ny3Pw1K12vB+UqH5u8s
eK4N52etvL9zo6UunG+4iq2uqVQPzr+cEzBdfrU+jL+fRVFKpLHWAM6PnVFv
ZyVlCOczSG5SETuC4E/4VWp6I8sIzn+QoauRxGYM51c+2HiNbz2Cf+mJZnqz
jwmcL+FlrHTvGYK/fAfnzOg+Uzj/2+bLHxdomcH5fTuy2DivIPjPPL/+sSgy
h/O1bQTl/Hkt4Pyd5r9+tW9F8NkPXNvZEWQJ588LbDBZ8wfBV3bZfXPrYis4
P/3wy4R2e2s4/6v308XVLxB8p8QrJ8zbbOD82ushErcUbOF8xvBFyvNPIPiu
yY8FdFLt4PyH3lfY3gnbw/mTDr697tR6GZ7ez2l+lp51HRF/Td2ruQIF4PFl
v137YX6HJiK+Jl+/zd27B2H+LanIIy8PIeJb68/fgB2xiPi+dvjKWhZzBL/O
RP1LdguCv0bd4c4qZQSfISGzPs4LwZ9+s/TzX0kE/2Ap19FwXQS/Z5NAvboo
gr+I4Xb6FTkEn13+nsseIRgfvXxgYEANHwYGACkFRjQ=
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{50, 68, 66, 64, 62, 65, 60, 63, 58, 61, 57, 59, 26, 
              54, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
              42, 43, 44, 45, 46, 47, 48, 49, 55}}]]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{1, 67, 66, 53, 56, 25, 52, 24, 23, 22, 21, 20, 19, 
              18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
              51}}]]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
             16, 17, 18, 19, 20, 21, 22, 23, 24, 52, 25, 56, 53, 66, 64, 62, 
             65, 60, 63, 58, 61, 57, 59, 26, 54, 27, 28, 29, 30, 31, 32, 33, 
             34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
             55, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 31.077851383095716`}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"0.000024083069266340825`\\\"}]\\), T: \
\\!\\(\\*RowBox[{\\\"93.23355414928714`\\\"}]\\), \
\\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\): \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"-\\\", \\\"2173.1239048270145`\\\"}], \\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         0.000024083069266340825`, 93.23355414928714, {-2173.1239048270145`}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwUmXk8lN8Xxy1ZyxKKyk7Kvu/LPdlGxjaISllKRSQkKRKSlJKsJckuUnbZ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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwU2Xc8ld8fAHCy94gSUkZGhOx9PhfXvLhGKklTIQlJJaGSkJGRve69z5VK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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVlHk0lH0bx/GWShE9Wh4RskWyG2u5UJO9wdz3XbbkGb3JVoRihAnZkrJU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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw9z3k81fkex/GDHpTGPtUNR4iaaYx97M7vzXF+35N9qfMriTop5aEypqiZ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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 93.23355414928714}, {-1160.4060692937655`, 
             46.60960377633496}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV02k4FVgYAGBLmRQilzGTQraK7K5JnHNCN3uldBoloohQuLZ0ZawxJjJ2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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0ms0FGgYB/CJNWHD5JYudmbcSShjnDLWmxh7kFziLXLJsiGpwZDD5BpK
KNnWLSk5MSwjJyanM8/KKUayNdNSuS1tIoq1rqfL7rsfnvOc37fn/J8/M/y0
b6QChUI5SOb/7SQVWLhpYSQLv/ecq1UMMPbilQfxlOIpzSVaMTgt7bzgTfx+
r6XnTXVi+ut3R4mrsruFn1SI+ey6WOKGyAhtEYWYOU8vIa4wmirf8rEInFLC
dEaJNYtv8CZ6ic0PUBK0MYpjVPDCzhVBWWCqulgHI8+/btmcHSmE/mhOyTtd
jJJi1KZfuhSCyPcFc7MeRlEy2ZW+lkvwcdP4jN9WjNJM+rLvqF2CjXXxppnb
MDIe6mJ94BdAinrK9Z7tGO3quPhI/flFqPQJoCvrY0RN9jDutroIZfEPdG2/
w2gtgrHj32sXYD7iZ24yHSNR0qZ06mI+MO1WZ+sYGMWY1F6rw/mgMG59fYCJ
EUuuCquQB46Bw7k0Q4yUdsU9oW7PA782jSmOEUblPBpVmpEL3aPtgixjkpde
kxvn1XmYnGAxH5pgNClUfB7JOg8j3Q775kwx6ivbzwiuyAGb5HsF1uYYWbCH
GtYXsyFUWewbbIHR/OaSz7yAbJiO2eV7eydGs9Ye9NymLGDcSQl+a4lR56wl
RChlgW2X1xjNityL0p3sozOhpunaL/7WGCkHJDdVQQZM8088zrHBaOPQklCB
mQF/6mlsaN6NUdjRcHq5ajrsLjRPXNiDEecP7ysuYgEEj/cf02dhdDmwHral
pcEbhTeCH+0wYnYM63wxSoWtlGfCWjZGX26ky+/KU8Bi2PXggD35x6RXZGfZ
WSjNszLT3IvRgxa92EfOyfBqc81ZtI/0ScOPaq+YBAP86RdRDhjlqshEddJE
0G+sjRZyMDqUqS7W5CeAm+RdwqAjRo+rSkI22sdD363q9u1OGHU/SgpaGT0D
ZpFjcR4II8qHsdCv7NPA3rC8h78fozwHNOEiiYXquHPWYmeMFEodvDM1YmDi
/uWbbw+QfF29PpkVnQDBoI6npStGibMt8z2DESDt5ymc4mI0t9q68mBnOCzU
BFiVuZE8av7ZUn0sFHjc5pKRHzBqY1uGPVk+Ck+lRbHfumOk0xm4GPX+MLw0
4fqyPEi/Ne+lfr9wCBz9z5xJ8sSIe4QvUmW5guC44Te1BzHKHxiHqhA2cGe5
zvXECaUzDYZKbKDxYzJ+Jd7W/rBQ2GgHt/NbP3cQ89rcDojXWNDf4rTcTyyD
oCh5iS3s+Bo0tUJccLJOpNxjA50Vpb3uXhjZGmvJx0NMIMdITPUm9unzSZtr
NAav5mEXf+Lj2Un09TUjmOwy6AolrtBzOKx51RBUZkT3E4lbXawFLj0MOGL/
VFhNzDE4+fehUF0w6FqYriXWZ3S1RK1rw5y7tmkDMTvDIirzqhZkhATVthHX
20l77/bQoP78TGUvsa/9T/UWYVSI11B7/ZRYdmv/SFCpInDKbfTkxDvUClQL
eynwrCm5dJQ4YUW3bez4iqSCXSmbJHaurF9FfQuSiN8ktGni9fnOOG7klMTK
fdLrA/FIrP7vOrGDklW5UuEisWuvkTTB0UPyHyQnPVQ=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV03k41dkbAHBkjKQwcVNGXHsl+zJ0fX2RJSGu5atuWqiEmFwRclNZSoaM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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwd0X8wFHgUAPC1fuQmWboyJLYt8jMiP6LV+yYtt7Jl0bdQ0ulSk/zc2DlK
kUvXj8N2t0c5tUxxcVumWoac3JXckrJ1wvqxaBfrR87vUe5bf7x585l5b968
9xhHYrlHqRQKJYDE5wwv0mx9v8bIRykMe/BmFOq6Ze/8P9tKXxzaNgowZZe9
97OPZWhpviKmdygPfKmPKQ+SEvPcSk5+sffS1FNixjg9l3iXUn3bXUzMP7xa
/sVouOYSsc1OSuIqjFhKVcpzGAVh6Pf6ktUYNXq2hqObapAeZ+YqjTBqKvJL
PaOtBjFXxjA0xkjqECx+FDcCY3o9Q0EmGL2kzZZxXw7DspIEq3NrMOJq2vVV
bh0Gvj7/5nNTjILZM/KU60NQELiPrmuGEa4KHnefVoEwocZoizlGHZ4+zJoI
FYxHXWcl0zEKp/2zp7hWCQzX2ZGSdRgdmlEUBm5UArXH8WYLA6Ne7avU+Zz3
4BXamWWwAaPI6FZ7rQ+DEFRJe8+0wOiIXJQrCx2EBvmjtPOWxCX6dbqSAVD0
uTCebiT91/Uo7sYD0NWwzVNthZFcWJBqm9EPm5Mf/uhog1H7WH3duT4FROhK
uAdtMQrC/O2FbAWoTmziFtuR/Vc2Zpjf6YN1d/gHB+0x+mumVC7U6YMt9Zxu
AweMmKNrE9vjeqHo3s+/hDhi9F0Mp3D2Rg+oeMeeZW7GKMTyQnNjTDf0GtM0
KpzIPzYpLK/6yMHpik3ShDNGrl0xy02pXXCwRxpu5oKRldg02vlNB/RT+9O+
dcVoje1coOG1d2BCaS0TuWFEm1qIGuC0g23nroAWd4yW9dPHd1j8C4IfHKxX
emCkyU/UOdb7Bt4ZFqUgT4yoLkMCowcyaOGpZNHbiOHC7ursNjD7XXS8jEk8
sSfH0u81+D5RJr71In7GDDBd+wqabhc+MgWMtLLE9vfLX4L10e5T/oi4ya4c
cZrBTWPambeDzKv476xkoQkKT51xlHgTdxvH1CU1Ql/VT7cGdxLvP+/XafIM
0t6u3m2/C6OH677ZnnW5AV5I46kxLIxOXQ7PMlleDxNF+xyEvhhtuhjNzzhe
C/GsitwuP4xi816vmcQSaH5x9eRyNkYy57+Fl25UQvtGFtfFH6MR29unlR/K
wSskLu70boyczB0tZ3pFkBa5QUsUgFH84XyT+3MCYI2wvO8SK1s/9rYUC8CA
dyK9nDjcKfKueq8Aii/eX3xMvGPSyt26NA+kf8C0lHg+8WHwbwdyYe2nsPcz
xA5jRXRT3jWozhc0sjnkXltX6MnmMiHTQqKzlzh9ri2fFpgJnIpOnxDiBUm+
jX9pBijq19dHEA94WPs+PXAevhoSVyURr3ycpRXJOwv73ZvLComdFycnTOaT
YH39hEpEXJmarp9Tmghq9iqrUmK7jyvsdUMTIP1QmKiSWGcxsEXNi4W7F4YK
GolFn2qrS+ajIIG2oqOZmLHUPp0XegSYv242biOmLykjtZIjoPVeskBOHEcJ
5tQuBEO+W8FrBXGLxqrsLfw9EPXnEwMVcQo1nade9AEHtoIzSlyj3d7A1nCF
2TbtK5PEFIpetAf/1vb/ATsjLGM=
              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {92.4, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{92.30121860779427, 
            93.23355414928714}, {-0.4346011534160866, 0.9323360241898873}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxcWnc81f/3NzKyigh9GkYqVCgz6dWgZCUj2ZuyZY/svfde9973Ncre+9hc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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw91Xk4Vd3bB3ChUkkkZJ5P5nme1m06BwlJ9UjKVNKTSoSQHg1USg6JMu2E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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBwAWIQzbO+8ZXKm/12DGDwwX5zsJLrI/e/9jC+LfevB0rN
fA4wvg+/zPOOVWJwvvSS7hivd7Jwvs6V0/7XnivB+SeV2PeaTVWD82VWCkxM
n6gF5zOWNqX8rdKD8zceu+K4UMAQzt+Xd55Fh9sYzufauySX74kJnC+npxe2
eLMZnM+3W65owSoLON/23Uvjr/VWcL6HrYzmphobhPvXM81TLLCD86c9Toz5
ouAA5/f+LWXukXWE8xdnldf6czrB+ctTdQSPczjD+fxFu59MZ3aB86dfNO+e
8hbB592f7u362hXOX/S/5Z7iDTc4f3ZgzcbwA+4w/v4mQ/V5jns84PzOlP2x
4cs94fxaVW5zxWVecP617wYBLgu84Xw/WRebyZ0+cP6WC1xO09p84XzL6/uk
jhb5wfnK732MfaP8EeZ7Hd90RCsAzv9xLG7rj/kIfhbXhSNs8oFwfs737XtX
TUXwFd72hP3mDILzT6+0/qPageCzCSR2P/uL4FvYJqg31gbD+TLFPsknfiH4
E4LWdyzND4Hzf/14vSvmHYL/xWP+tZUpoXD+goX2kxbfQPCdD+6MKg8Lg/PL
ulbxPDyN4L+wkG/95BcO50cveuL8xP0tPD9ExH+bsjkREV/zVjCcsPGBx5d9
38GLy33sEPG1/uGTE5m8CPMUrjgF6wsh1MvU7rPxakPE991J8U3OmQh+TLrs
94DFCP4+WQPVA1EI/h/2/vvHyhF8veQZZXXBCL7fjeOXGZMQ/GetPvPv+iP4
ZQ5PfOXDEXyn6cuMef1gfPTygYEBNXwYGAAq7kxx
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{50, 68, 66, 64, 62, 65, 60, 63, 58, 61, 57, 59, 26, 
              54, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 
              42, 43, 44, 45, 46, 47, 48, 49, 55}}]]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[
             PolygonBox[{{1, 67, 66, 53, 56, 25, 52, 24, 23, 22, 21, 20, 19, 
              18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
              51}}]]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
             16, 17, 18, 19, 20, 21, 22, 23, 24, 52, 25, 56, 53, 66, 64, 62, 
             65, 60, 63, 58, 61, 57, 59, 26, 54, 27, 28, 29, 30, 31, 32, 33, 
             34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
             55, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 93.23355414928714}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"1.082696410730553`*^-6\\\"}]\\), T: \
\\!\\(\\*RowBox[{\\\"19.048605036573925`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\
\\), \\(0\\)]\\): \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \
\\\"65\\\"}], \\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         1.082696410730553*^-6, 19.048605036573925`, {-65}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3k8VO8XxxFCSsk6dmXMWDMKCc8hJKUkKltJKYpQlGzZsmULRbL0FRGS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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV2Hk8VF8bAHCJ7DtjSWHIMsyMraTkPiSphBRKWlREokjIUgipbKFCxjJz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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1nk01c0fB3CEeCRFSSRLRVHc+71FJc3QDRXu5eGWrIkQyrXWYwk9qChb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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw91Xk0lO0bB/AxY6JB1plnkDQzJTNIhpIl8yWhoiIktKg3pWRptaRfpPRG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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 19.048605036573925`}, {-64.9999999999997, 
             5.938548097404523}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVz3c81/kfAHB7hcoeRWT30+XzrQuX1+ddDg3r0rhQCoeSFVnZZJSVkZEQ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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0ms01HkcBvBxKZRIm6YVtumiQla/v7ZcZs4Pi9MFRRJqhpkYw2IsxVYr
91mF3HKdFpN0UyiWreb/PU7lbKpVtHIIUaFhS8i4ZO2vF9/znM+L55znxZfF
j/AIVGUwGK7kvmZuWmX1jW6EdY6wPlBzIlgS8DSplrhUO/Cu6YwIEndOetcT
28WF/MZSikA8ZM+QE7fJ77B0J0Sw16ln3xPiLyhyv0IhAnWVleMK4ke2NpfK
ukRwPDbBavMrhB1nucbL7ojAV3j4Txkxv1X90LtYEUxuyuRV9SDs1lmWIB0J
hm6T1aEVvQg3NsxmVAmDIdtpcVFBH8JJJh7J7oNCMHARC0pfI5zNyclT+gjh
UyrKPd+PcFd5e8VMRxCUXBXzygYQjhGHuDB2BcHK0RVulW8QppXSoSJ5IHT9
tExW/Bbh/mtu0kzbQIh+lpRz8R3CuiF1npKbR8HvZ4/h4kGE849vqek2PQp6
Vin+GUMIuy4UmD24KoDiTupY3jDCn+uKzGqMBBB51+Zj2nuEuWfcm6eL+bAm
Qb4oT4GwGedK3I/L+JAXVMEpGkE4oCPm2IbEAPA98+ZV+ijC1BXGRAAjACaz
fmee/xfh0QKliSzKH7r/qW04+wHhWpeVd+Nf8+D8PJ7M/4gw4+J3Y033uWDs
ZOV5YQzhJ4V+mlurjsDnltPMnE8Ijz3yb/W6fBhKKZfYknGEq0N87yem+0F+
VxAndwJh65Nc5/BkXzhcrjBJnUQ46kFWWEqCD0ztVlzP+Ez26RQ6lwUfgh7k
kJ80hfB1Pm10ku8NBfP6RplK0pdPOfg4H4S1w67NudMIG9tIowXfe4Fyee8L
yQzCAzf15y3MDkC5oeJ01izCWfGRafPLPaEwyC1LModw+q3s9ZlaHsB9tur+
L18QxvUndu7V2A/Thn458fMIm2+V7DLodYe+y8rmY/8h3BHREreu3RWK9JcX
nl4g/1NfaGgp3QNlTfF/xzAovEaCDj48swtiMrw2hapQ2C3EQdKQ5AIsu0rD
KFUKZ5th8+p9TrB6i3uMSI3Cv+qLPC0dHWFgOio8Wp3CQs0bs39o2cOp4S+S
E4sonCaPjt1RzwbBqt7FEYspLKtuCGLKrMFok+26WA0KV21VtVPbsR02HB+T
RWhSuNnxnJcGcxvMvdVy5mtR2Mq2rDqfaQqXfihNES2hcKPV+/XW+1kgbU43
5S2l8L1z9RnrHFYAbSCMEhAnSbtmVGf04HW4/T0h8Te1fwW+qdaDjcwpVzHx
3F41doWRHtwU8iITiNnW+m17xnWhSRM1XiQOV3UQe/gvhcHdL52GibnGHWKe
nSpoltZmjhKPO9zmrL2mAqYTZ1+OEQ9wfLT7mSoQUYJFM8S8IW23h4ML9PTI
1fQl2hReeGFe9/jAHL0041S7ObGsdlVkp+U4bdF/0HAbce6pVA1f7U/0vu3b
ArcTl6jH2Ta0fqTzet5NsYmTnS1y5ewR2tjC3cCduGBtKqfl2wEaJ24ReBJv
fuj7vLi8j+Z3qFV5Ez+9tXNjuW43fTmuke3/1Qmdj2+MPKdb2nJSjxKvyQxl
B99uoUdNwlqDiSsv1A1En2uidU66rA77undot67ayxraspUVEEkcyn0ebaMT
w/kfL1VAkg==
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVznk01PsbB3DZsqWyXzJSyVK3m++UqIwPhRJZuj9luZQplGuPJIUYS5Fp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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Gs01HkYB/ChknSRlrKt2qyJRafD789qWzyPWs3pIpOKE23jsliby0ii
3FmjcllhcqudUGxHki3RhVzCrJN0byOkIdMMM4lccttfL57zPZ933/N98eh7
Bjl5q7JYLAd6XzLzVHF5WSdBbfj2xisPMWh4tCVUUAsTrl9Q8sQQv2nUpfKL
WzipCw6JgT9gx6qhzuHyfcxdxbDLvov7gDrPs173lJMY5qtof5RRFwi8ojZt
FcOx8DiL718TvNJWsi2bLQZX34O3Cqmb3Mxe7RtogVGjNN6VLoLTy7h1cZ4t
0Gmoe/hiN8Fr+dypiHfNcMZeLTe7h2A/2s3v92+G1Ry+l+gNQVEkts9Jm2BY
QDKFvQSdz6xTDAQ0Qf5lPu/CW4KZ1prtcdL7oD24YnexhKAjSxF12vs+dPgv
LczrI3jyfFmsu7wRjj5KyCjqJ9j8KMJe6tMIbkecpHnvCMZ1mRyykTeAlkWi
e+oAwduqrT+rHGmAvP+Y0CwpwRO1YUPHFPUQfGez8tR7ghZ71WS3Qurhm7ia
BVkygqHRRX9fVdRBls9F21w5QabBzHKFfx24npa8Thkk2FlrYyrouwej6X+t
Eg4RPLDeir/zdS10Pq+oSlYQfGj78WBpfw0IZ3D0rJLgrsTWtsCOu7DW3mLv
+Q+073R8h+azO/CpNWZVxjBBK8OZtJ09t0HEcMLzP9L9IrNaZM9vwdkOH9vM
EYJrBUMl7O5qOFggMxSMEjxdZ8i2llfB2A5ZaeonglOGUewqyU3oIlvOJowR
9ELhgwdDlZA9o7MmbZzgY0HrhL3kBqyTOjRnThDcPNtTd67rOowv736WNEkw
16jKLO39P1CgJ4tJ/0xwJqqULXlTATk+u9OTpgi6JHnUPXl/DQ49Wtl4fJo6
QakEZTlM6LllxM4QVOc6+xb0lkFPyXhz6CzBS/G4cdN4KeTqLM+JmSO4TdN7
Rii5DBfqYx+GsRh8qrJUz3ikBMJS9xsdVmHQeV/okbAlxaBvXawXospgB0v3
ccp0EegaO4b5zWNw51e2MS81C+HtREjg0fkMHp2zPvxkRASR0umkEwsYtMqJ
5vh35oPXym61IDUGX003N/AX5cAao5++C1/IYKDOH7vn9WcC+9iHwiB1BiWT
nOOshekw1bdom+ciBiOtvzaShp+ESz+IEv00GFwylBwpt42Fc80pJrzFDN77
XXfdSYNgqF3tG+JFXb/jxYnP3Xx4E2h315e60STruX8eH9avGnPgU7d0aCbv
0eLDVV9ecBz1OeGyQcvZAKhXJ9VF1FWWg9lulX7wbsdLeyl1j7BEWWzgAeqi
irRB6t79BpeS89zBZCT55QdqiY7Ila/lDkH56DdJ3SbfkBwy+wtMyC+naCxh
sLNUwyq38gAsTo18uoFaKW9K6zPYAxt7nfXMqYdNaybLtLjAtTT3tqQecPH7
VzHrAFld/WM21AoXTqj2ze2wdqPjakfqCRfVNh7bDjDe2Gsv9Wj5W/v+ORvw
fDHvigv1WHndsEbVj1ASXW3jTj1dHrHdeb05tD7JEPxKPcWrkI1XG8OgYUD7
b9SzvIAtW430YVkERzeAeu6ek8UaUy0wa9f3CKamr8z0z/Zo2/8B4W5Bcw==

              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {18.900000000000002`, 0}, DisplayFunction :> 
           Identity, Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{18.858118986208186`, 
            19.048605036573925`}, {-0.01814141850846942, 0.1904861573698261}},
            PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxdl2k4ld/Xx1MqoRQypUKDoYyZEpYkVCoypVTIPCczIfNM5nk8CiHzcA6W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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw9l3k4Vc//wLnXFsl6nUL27LJnSWas1+7aSiXqFiGRQooIkaUia6QiZEuh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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1AkwVHEcB/AXbXYcybPWtdvuWiHHLq2xEaEcUU1jo2YidGBoTW1Scsx0
aHW5m9lioiREjHJkarSzru2QRFEaOSqjspGjxGg6Zvx+05t58+Yz/+/7/X/v
///P4+w9KIpQIwgi/M/99zmQMpRdSM9bT/y7JtyLd5D7p1W97otOKp8olI2P
guuPSb7qSyfBp6Lv/JqMnwWfVF9nUDzyCywgbvqVHlHzWPRD0YsLEfUU8JT2
kM/4KBWcl1BTF/9BCxzcUG4ZwdYFKwPvlpSRemCnJUuOpqaT4GrD4bZLVjTw
e2mxhFtmADYP/3l1xNcQ7KySS3UHjRYtp3ZHPa4PMQG/NytKz/lpCk542lgx
lsgEG787sDmJwQJv6mrtFgazwQN72ngSEw44xSLrScsn9DGZf+7OCjNwyLCb
CzOaC/357p3jLDiZgzMzSp0YP9D948yLQcpVYAObZ3JFrgW4nIxlx4oswd78
HsUajhXYbZafJRxGs/KbXA8WrgZT41ZaK8TW0N/WHzFeIlsb8JXqE4UL82hP
eprlaKMtuDuoLZ2SbAcWP+lwdPPngfd8UVJrNfng3Z7nmd5v0UUNG84uDbQH
t5SsNZLWoKP5uY9opg5g1+WRus1JaMquoNbzfegAj1v5YZ5rwE+T46mB19EF
b27vkmgLwE3bkinfVUo4z6lTHRqUBDqsT1VJCDmvj+eHPahvta/AGDwXquJl
+JuBP7u2RLpowv7KRWYMnk4n7neV3/HIbg9cf1raIYHRMlh/d+s6r3vn2nE/
HG2y7wz3YP/R6javJyrxfNvHaCw86sP5TbKNG5q7sP60X8YWSiL2f0P3ZGeF
M/azPEVZJXbG+docyAdfErG+T0mR6RQH83pqDEkTC/vVfrVxZmYQ8nLieNiZ
/QGY15o9PEbfjvUvSwQKOh3Hc7x8RCoS67mI70XGKbHedJ/e0ed2mM+Sf8uU
2WK+363zdMIc5j1753OtVmC+Syhh3b2P39M5KCXsLPD9ca0DX5cyMH/j2kKl
40ust60ghKUmwDxdMzzFQQfzBcyOpIBarD/BK+1t52NeXCwrZ+ljfpmI1kwq
MF+lQ0YJnTDPHvhI29iyOE4QJ7jkZJ0WFxzaOqbZJbQG//9/J4j/zzdB/Aac
UL8q
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{93, 92, 76, 84, 71, 79, 53, 65, 17, 54, 18, 19, 20,
                21, 22, 23, 24, 55, 25, 63, 56}}], 
              PolygonBox[{{50, 96, 94, 67, 73, 35, 60, 36, 37, 38, 39, 40, 41,
                42, 43, 44, 45, 46, 47, 48, 49, 61}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{1, 95, 92, 90, 81, 87, 62, 68, 16, 52, 15, 14, 13, 
               12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 51}}], 
              PolygonBox[{{93, 94, 91, 85, 88, 78, 82, 70, 75, 59, 64, 34, 58,
                33, 32, 31, 30, 29, 28, 27, 57, 26, 72, 66, 77, 69, 83, 74, 
               89, 80, 86}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
             52, 16, 68, 62, 87, 81, 90, 92, 76, 84, 71, 79, 53, 65, 17, 54, 
             18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 74, 
             83, 69, 77, 66, 72, 26, 57, 27, 28, 29, 30, 31, 32, 33, 58, 34, 
             64, 59, 75, 70, 82, 78, 88, 85, 91, 94, 67, 73, 35, 60, 36, 37, 
             38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 19.048605036573925`}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"1.4164113112815863`*^-6\\\"}]\\), T: \\!\\(\\*RowBox[{\\\
\"21.742545405516704`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\): \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \\\"100\\\"}], \
\\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         1.4164113112815863`*^-6, 21.742545405516704`, {-100}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13k8VF8bAPAkshPZGWMLM0NkBgnnSURSKRVJkigpS5GEbCEpVKgQkX5F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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV2Hk4VN8bAHBbsu9r2cKghsyMJSXuq5AsWSIVSSVCliIJ2ZKEZI9knTuK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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVUnk0le0eNaTICSFySSQcJ8PhfR+lol8kUxIpkiIh1xi6PuoSKiENJF/i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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw91ms4VGsfBnAd2DpJZgbFrDVlFrFGVIYi1p3NTqmIVERUJIdCqZ1DJRXS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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 21.742545405516704`}, {-66.67402856795715, 
             7.854721496609974}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Hk01ekfB3BJkWGoDMlaNIwasjxyk8/3GVFN2Vv0EzOVpZShZClTKZJl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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0ntUzGkYB/DBRM3BtJmQQrqsObarenUZ8pKpzuhidGWkMVOGNLm0JIu2
Rqs6SmVLTVFRypRGU26p37OtKLrvUqILKZdjkzTVMmHf/eM53/P583u+zwrR
/q1hM2k0mhe5/3OMObIx8jeEG3H/5rRiKQxNVxYeIub3Kv5Zd1kKXe+O0KKJ
l71fkvK+QAq192hULPHo8eEWtzwpJEaznNKJF24w9/iaIYVlAxzramK9Un/L
8F+l4FmRbPiFWN1YrnIVSKHUk61OOI3wFodmxYSuFO48X2xxIxFhA6/gysf7
I6CoYI5nRxLCbtolvoKeffCuyLZ/OBlhuuaqTQd3HyRqdKf0ziDcLqqn6orD
YUbih6mfUhBeklef5qcbDo93x8XuSEW4zGQtTxy5F2Yk+MScPotwqn6eQNi+
B7R7DAUX0xAWNDI8tTl7YG/shXst6Qj/wA3xXimXQJFgKetNBsISbs3sT7Mk
4BT9tEtzDuF5Fdz75Qd2A3vYw5idiXDRZ/azvo4wGEu8xcdZCHMubNOr5YQB
K/a5zoHzCL/8t32OrjwU0qud7eXZCI+H8Fb7acTwdnm22/UchOW+OgNuEjHk
9CkG+uQIW5lmKSseiMCs865wKhfhz/75NfdtRMBYFL+HfQHhepeOSH7qLuDl
yQZ9L5L+S0JFbR+EIA6UbdqXj/BJeX+LZpsQukMdLeUFCAdEyZ85HwwBs9L3
X6sLEXaU1AW8cN0Jzaue4UeXyB6B3iPhRsHQ+v0EY+oywkwnlWPfcwGUMoxr
mcUIp8SveVl1fTv0S6LV668g3BSEFAcjtkEknZEfXoJwuuwKW98qCLq75LZx
pQgbZrbSl2sFQq7mBU95FeFHtOXnmPf8wSnA3POhAmFRq9VZSZYf2H4sgr4y
hO3zju4q2e8Lst6eOzrXyF536y63Wm8F5be5eSsqEF6w4wUtWIsPKGqCzlci
nLQw265Y5gOZS3v9I64jzCsrPxy60gt85nxbHF+JsI6DUDjZxQOx6xORUoWw
vlbW335+HsC/ofi9qQrh4R/dVyVPcyEnBnl9rkb4uPN5wzOHXIFzQhNtdhNh
ruprmEiN4dZNSObcQvhp59U1ZhvXQcpGJ7Pw2wiPMJ5YLnNwhHX0yuJTdxCu
HRfXtMbZgbtWaE5ODcJiPm0yoMkSyoJaFjy4i7CzJ/PY5gZTePdy9ZH+WoRv
mo8XhnWzwCjCYvsr4sL0o1UfZCzwnjR3eUts71/eEG3DAhXDYPYn4l8aTV8n
JS2AY3bfM7XqyP9NHzav4OjB3ITmGxbEri5JliPrmWDFDp04RpytfJszv5MO
QlVwTyzx1GjUNeNVdMhYG1h3iphjd+2P1bJZMLmFl5BKbDFm9zoAzQSIsdG/
RGwyoBK42H2ntjRP2z8k1lWdFIc0qKl4/8nFbcR742/Hy46MU9UDo9N/EW9q
yy8sYX+iDNSDDb3EO1/p1w0YjFKDRg/9PhL7ZD5Q0MqGKFbJn44TxIhhPezB
HKTcbGuNvhBXdp92MXnTTym4yqFZFMIRQgdz16OPqd720iZt4kP1zdYlcW3U
/O2XyucRHxaeYDXpNVB4KDdNj/hgZdBYp3sVFRWZ+fMiYnXBogMNO2Nc/gP4
W1E5
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Hk41fkXB3Dp+hUxlD2JuCaVsvVJV/XtO9kaw0VCo0ULaZVBGS0kTLJF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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0n001GkUB/DJ5jXK0Tim0zTpRM1RKdWzm1XuDankbRpi9T7phZU2rFn2
tGokUtpJqWGoIdWEEs2YZLAhmfmpZIU2ItUKSW1ki619+uOeez7n+8+999xZ
on3rdxqwWCwfWl/7uymDbpFHCOr3BPRntjDwYrwkN4raa6gzObyZgda+WJaY
em3sbnuXJga0tayqhK9OjN/WwTCQImY7n6T2zFG08moZ4HW5LFRRuzW/rrlQ
woD3tdTpn6i/c0mSXz3BgNKbP5yUTNDOosz79hoGyp9w5qtTCMYejgywL9FD
vsLYu+konWey+eaM2Xroy3d6+jKV4PTXpmsaZTpIGbMctTpOcFf2lnYw0MGE
lDej89IIlm6VhVX/3AAtuw4lbDpB8N8RvuLXzrswIckvLvl3gtA1rfzz6rtg
8nj6xnNSgkeeDDWnaeshLCGntvEkwfoCbvoP9vWQv3EGuzed4KQ0x/VOsjvg
LG5vHTtF0LdGMfzA4g7wX66x5WcQPK4PW14oroN3KRoBniF4/6VNUvpALbAT
npj+dJagSQs3ukxYCydV3y/NkhH0sJa451bVwKuZMs/rmQQTwxrZsiU1kNlZ
0NWZRbBKuvcYk30b7B5WbBuVExzXvzeYZHkbzGwke/g5BNVtTTOTxX+AV3Zi
j/Acwe5Iruvp2mrYEZTo8eN5glsCt7suLqqCttBlC7IUBP/sFh5de6AS7JQD
/6lyCQpOWbb+ItIC4/AX6vNoPpDWS3wq4N6XA2ajF+h+fTfdI2xvgdLMVjvl
IsFmi2u5t4zL4elu8TBcIujX5u8ladNA5ESz8+GXae6p0rQVlUFba5bTISXB
rZ3P5qw6owb5WLdX8RWCvZzK7nl7VOC8wd5bV0AwLl6U7eB7A5ze5ld3FhKc
KmngapxLIbHjcbnpVYKXF3b0ai1KoPizefasa/S+RjFh6oFiINEjEwXFBO98
TJU9P34VMmZ0BEZcJ2jt/C2zckMh+Bl/5khKCMbUiZIrHK7ADvdHouJSgk3y
/va5TZdAoC443XCD/mO1kWNdTj5kxhGfjyqCGsffOMLleeByYExsV0ZQ3DLI
GWPOg6asOtVFQ7DwubHJ9X1ySHNztgu/SfBNavssL/UZWDGx5OLhcoIh+odu
HuvSYbVhaGbmLYL33OWD/W+OQWFw49T6CoLs2axCm2MS6Hu2OPaplqBwZ8Sg
iTQauBHzQ55TC4guQLcyGnw/2Lu+ova1nqM9+j4KSs2mGf1DvfZRV6pZUBTE
L/mSYVhJEAOFfHPefjBPYtTzqbeEx9TzgveCIz90JJ7awcGydJ50B2wr3fw4
gXpuv+5g0XsRpC8PqjxMbV+Q6LcgSAQf/L2STlDbOoy+duRth+q4RdZ51IvY
Wr/Q4M3gz4wv1VFbtwS57JcKQRL4gXOf2iqAaY8KWg+qrqHxZmrLFtfYGJ4A
pg331HVQc/jrREPBPtDD1QW8pZ6k/NtnXOoO7Ms1y0aoTZX3Ur7wVoKnk5b7
6WvuH5ZsGLICClYVv/imiqChv2G0VfoS6HigbDChNlJceui0aQFMDskrsqA2
ULhVup6eDfhCLrWinoCVgrOyqRAdmRFjQ81iHewRiA65/g9LGjnZ
              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {21.55, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{21.525119951461537`, 
            21.742545405516704`}, {-0.02363556584780589, 
            0.21742557470208218`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxd2nc4le8fB/CkVJSUlYqMskJKJMmnjEIqyd4zEdkjyR6Z2Xs79t7z+NjO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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw91nc81d//AHCbRORaGffaRORSRsY5knEp3EvciNAg7aWUnUpGZGU07ZGR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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1A0wk3EcB/BFnI6Q5qW8TazRNk15q8yQolAj7vSy2slaFqGkriIqbk3n
qlM3ie4SYsVd3E2yrcls3jtjrlTn6EVXnLkWen+58/tdz91zz33u+T6/3/P8
/7973JLS43hGBAKB++f8e42KMzMhq8uDCf+OaZYZmVvFZo+wFtydfP/qwexP
YONJD84jDwN4qlQxLvr4DczP6aM23lkUsuCSbPLokLUJuLXTuShHYwY2twta
23XUAmwnaeuN0lmBrWJO+NQ+XQbWH2bOd5xdDubni5kBdFvwi63hP1KM7MES
hsfGgGYH8Gl1/EzHtZXgl3scKLXJTuByG+vnZHsX8N6Tiaa8KdcFK4LyBImu
WhI40jH2SJrSDVzhm9+aLFkFdudGRdcWuIMpY7IVO495gPdkd5HDdpLBw0JS
xmvKauiv1bvMjdhQwD9TpfLVU+h7wXNtAyOe4LLi8yaeKi+wfLq6sKtiDfhA
7fEtfSIqmJH1IsyVT4P+22Wi3BUsOnh83/hslpc3WGKpa3BevBY8Y5dZRdGj
mxy0qSw+A0zk2VQrtOjGl+TcjG0+YAGn0BAhRXOXPDZne68Dn8kiKmmV6PqJ
FluG9XowSei3JLkQXcf4USb/jN4t/tA7yfUFR1DrKmJ06Gi11HJwsx/YqMk/
zV6O3n1iID+O3Q3z3epPzHvPdIb1+x7elK4ygvlgGTjdk548nI8QWvttzSju
t/icYfuVx7jfCTJXX0457rdlzNJDPUTcH40lpf3LHFghEz/kOmlxv2qYszJD
Hr5vDzXpruEyzu/81wOBKQXYj7iv9+KYEuvT9ptuun4K5ztwcRFHqoc866wy
z9icgf1azpN4idX4fEksJ+EBE79/IjRksFKHzx/1O3039RW+f7uggZTTiP2E
HUPvuizw+yO7hUkbSFjvyehNq5WdWE+pqSyp6cd6o8M+kW57MW9d+VZMf4N5
xzvsJp+PmKcxIukJbXhfcK3ZQqXB+y0l6h38aKwXf3VS/7of8w6/ip1EOsyb
Ot4KHUnB/NiwS+uMHPOs2TbNLhWu1/H5d+G5SZjPFmZWSFWYv0GvZ/v3YP3S
oNjgwExcr2eSL4pLaQsmEGRU0YVQGRk82C4TWKip4P//73/++f/NN4HwG2Sw
yZ0=
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{93, 92, 91, 65, 72, 19, 54, 20, 21, 22, 23, 24, 55,
                25, 63, 56}}], 
              PolygonBox[{{50, 96, 94, 81, 90, 76, 84, 71, 79, 59, 67, 33, 60,
                34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
               49, 61}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{93, 94, 87, 64, 68, 32, 58, 31, 30, 29, 28, 27, 57,
                26, 73, 66, 78, 70, 83, 75, 89, 80, 86}}], 
              PolygonBox[{{1, 95, 92, 85, 88, 77, 82, 69, 74, 53, 62, 18, 52, 
               17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 
               51}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
             16, 17, 52, 18, 62, 53, 74, 69, 82, 77, 88, 85, 92, 91, 65, 72, 
             19, 54, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 75, 
             83, 70, 78, 66, 73, 26, 57, 27, 28, 29, 30, 31, 58, 32, 68, 64, 
             87, 94, 81, 90, 76, 84, 71, 79, 59, 67, 33, 60, 34, 35, 36, 37, 
             38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 21.742545405516704`}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"6.347668278810899`*^-7\\\"}]\\), T: \
\\!\\(\\*RowBox[{\\\"15.515419359046335`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\
\\), \\(0\\)]\\): \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \
\\\"30\\\"}], \\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         6.347668278810899*^-7, 15.515419359046335`, {-30}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13k4VN8bAHD7kt2MvWSZIdskFSo5b0gIFSVL1iRSiCQVUhKiL6JUlihb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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3k4FW8bxw+JbAdJIc4ROnPskYjK3CEhCmWJZCehLIVCoUhKSZZUtnPm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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13k8VF8UAHBEZEuSbLMhwrw3Q0rJeKdNKZWtQkkpIiVFKCmSEi0qZSup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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw91nk01OsfB/CxZJkx35nKCDFjna/CRHcqlTwfa5dQtoguFRLqWrqWbmix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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 15.515419359046335`}, {-29.9999999999998, 
             3.8727248878752025`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Hk41tkXAHARUq+fIioSIrJ0XxVJ5X4vyqBI2ijJrmT3qiiEMSFjTVQM
NUTZG7t8yfLa8maYsWQZ6ZUtKhWR8jv9cZ77fJ5z7znnHjk7D3NHXh4enlSI
n2eDjmQeqxyRS9lu0pxfVChEt0/4gz2tmIL5+ipUMg5WDAaXfazQj6ZUKDdq
PO13ME+PcslRLRVKQrc0/hFYXtPXr1tRhbpw0PxqL7jKuebmJ34VinE4Uv9A
BfibcdWlBmXqpMViH18lIg2REUEn9JSpzHq3e8VViGRcM5oqVttOraiwzTOs
RsR+er7uK1KiFl7u7PqHRsQv0yXbar8iVaiVGBVSi8gBKY/9Q3u3UT7Kfsli
dYhwTzQcFDJRoL5c+qDFrkfEcSH0x9nj8pRYh/6kZyMiSS/ryzQctlI69Ib3
P9iI9FwtP+IbKUcpfg+8md+MiHa/4v3tGbKUJNvJW7cVkc5A6QYqU4bKKVTx
fNGGiO+qxIYn67dQ36aCV/i1I7I+XZ4R7LaZOlVkObrqJSI7XEJrXaclKc+m
BqvKDnjfdvl2t8UmSml5zZh9JyJdR4WNw3s2UBO1XfUfuhARjfklpd1fgnLp
Qhpp/yKi52aQv40hTs15rJ5X70HkVtP5o621YpTuOT8Tbi8iDraqckmOopSy
a0NpzCtEqtWf8xZvXkdt5o/13jKACOe4nsTOCRGKMzPznDOISJzBVeQfKExF
2XHs7f5DJHQtMnxuvoZ6Ox+xcWYYkaOyfpNhBkLU8mCvzf0RRG50Z5T2KQhS
CqbZ31S5iHhfvi+tr8NPrRJZozI0CvWrSjUdDvJR4R+NLoWPIRIkHdN2z3UF
td5aaFl8AubZVjhVk7CMz0tZKTZOQv/AcEWxPUu4xI6ZfvodIu9MebvtdRZw
dtuQ2sg0IlHjzZLp1+fwmTA5k+j3iMx5KJZX533CG1q4NdIfEannK04R3vcR
J5zbz+bMIqKqqmIrETyNJa+Lyth/RuTJoaUp5X0TGD9rjHz/BRFJ8dcLdmdH
sZwJIzJ1HpHPGXH/6oa9xiIXuvrRAiK9qiH862MG8LOuHc9fLyISy2kbMTbo
xgK2DhVRS4jUCmxUSnzVgc9elVop9QMRi1Nf7atnmvHSg9v1cuB/NG39brY1
45Q24dDt4HW/lvRfzG7GA1t4ePeAWT1KN6/YNWPrRu6yGbg3y9mvtKcJ24jm
f/sN/Jg796KOzcaOueTTLDi94KKOeFkD9hh2HGldRiRe8ljug+FavJehzPwb
3JKQHO/WWIt59r671gPWN/POMn1Si+NivMW5YM+kESszVi3+CwcZfgdvWfV6
7phQLZ5PSc5n8jAJv/OJv++70zjIss3/NtjKSynlmEEVNgyLbroH3rhDVUxT
vAqvLTq2/gFYqbV4TI9biR+s6s3LA0cWOz4eDKnE9WXcYTa48W5CjEhdBRaU
+GGwAL6t1DLhYFiOYzrVxaxXMInEubHJf1kleMidIg7gu9Urdr82KsFqa0zd
XMArB+t3icuU4Fb9S02XwZp5xpbzLcVYoCTzWgy4VPgvvQy5YhyYJMmtBRuO
e0ak9z7FblYrS+R5mYR0Fi1udSzEz76KjiiDR76Z6RyiCvHqRDkRdTD/H5+0
YjcV4ux2fPHAz/tGqU9IagHmYj/pk2Anawtbc998bCU3E/YbuCTzf32VGrn4
8NueUxPgGf3UTekfsvDAS43VH8D14m1vfn2chd0r4qrnwOue7b/VYpeF46MO
K6zkYxLb97ze3t2P8KtdNR+3gI/PfknTq8vELkGPok6AZ327Qwdy/sThG33r
asCxf4fqTP+ehiV5O33ZYAntOZy/IQ3nTiHldnDG57ol9PAP3EGPx7wCpy9m
5nlUpOKNjlbnvoBlD6m9nf5wH2cV6X9VWckkX5eEagZDkzHbWBTdAQ+5RF6+
pR2Pb+ypcE8Bz+azt0a9jsP7ttoUPATv9cqq3x0Zh/MX8tQLwCmCv725MhiL
k7KNdjeDI+SE9mVtiMEXBIL3LoIbe4Z5n4pE4q2zSn48/EwydmfttzhWBB4Y
5FQIgIUYAkM1r8KxWcnm/WLgEoMHDvw5N7G2Q7mOGni36u4rWmfD8Oq693rW
4ATTJLbW4g3ckHcn1AEsOmR0ec7nBg68q9PgAj5SGaAgMBSEZz1vHboCniv8
YwujMwD3yygZxoLNJgx1nfr8cG6AtUkd2Cb9zcXjjt7Y6SJ/dDO4O37UOTrE
C8uezOVwwI96HHUdH3ri22qLR/vBxIUSae9yw9f7E80/g5fizrxwV3fGJtrt
pxUFmESDYXbSuPkkxjMp5jvAR3bJmzZFm2P1P11NNMCGrRrxkQ2mWFSYoa8H
zh7USAi30cPdw8bIGnzD1sbrVrUC3ZQoqewIlrVY2FyUoUmXG0/Ku4I7rNpU
j5wl9L3iiE3+YIuMdJkdMofp8+HNK++Ay3fJ9LmUnabNdJKXU8BP7N7oDsqe
ofVmnRf/BMeHzSWZBljRClaCH4rAnHOzfEk3behxpkF/O/hQ1Nw7jzYHuo8r
3v0P2LJzQ7PCC0e69e5oRz/YD1WLW7Kd6Fy+MPYEODgqRIBkXaC9euqL+AVh
n2XXmYJSrrRdVEIuA5zhpB9bNuZKn9C1zxID64lcOj+W50bvyeFNlQOXbm0z
aFT0oJVsOpO2/8wPLJ7z6fOgN4o/jGeCfaeeeXboedKLgbrhOuC0hcfiOqOe
9NTudaEHwXbyx7/G7/SiB8aHAw6Do2SkYrP9vWja/IaPJXiq9segKJ83XSBo
5m4DFl5OTHDW86bTn8lcdAa76+p/vxboTYcq1lj7gvcyeqbevPOmWf3Rltd/
zr9N21NLxod2irU+EQrOuZadZWzqQ58+hI5Ggg3aR+Kk/X1ow8XvRnFg7nQm
KnzoQ2sXtB9MBn9/XBDA2+xDqzikUmlgAU514PpJH1pqk9u+Rz//pxi98+0q
Fs3gHNDMAz8PGkq8osCiv4cw1It/7vORa07zARY9ozWgUgVucprz6jvGov97
l7OtDuz2u/bEY3sW3fHgmmwLuOXtp7X7vFn081OHpTrAZtSb8YgAFv10jZRE
D/iqfaPn3TAWnVE7uXYIrCZrkX0hkkUn+lauGQWHEMuY+Vss+v8pFls6
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0XtUzHkYBnDZkWjabosyLtuWURPfqXXJrfHOhC1jwpRq6DrTOK6liWMS
UnZtOydKNtd1YsNKJQpnG/zerkNopFBtSo1Uk9W4t7pov/54z3M+5znn+ed1
ksdKlSNHjBghofc1K70nFmz/m8CzgtL8WHclEqbGuIv6SfbZEp2bEo8LkrnJ
1BpTpG6yqxK3Lu7OPkgdU7Tr+X0XJY4X3si8QB1hy7FxnaLEDUuk6kbqpmTb
zW02SmSLNT6LSgikn+8avfpTNK4J6W/6RkugVfugxbMsGs9XbD157SaBR4mq
YTP/aDQriSrwvU0g6V2Mo8qgwM8PPesfMwSOLUiJGlQr8IpXVlpKKQGj5CD8
bq7AeLeE4/blBMqu2RY9OCXHj5vfeOkqCMQLlsTZucrRvtanZ1sVAeWyKRtV
N6LQm5lg+qIj4Di9MTV+RRRyh/b+evkugaIFxy8mN0XiRN16lfAeAYt3gQLP
mEjMu8Lb9uA+gW/f2+cOsCJx4FWyWUINAcxfnn1+WgQGXZW9tHhIwJDS3n5s
VThuu1MZqq0lsHtn9YycjWE4fdiyS1FH4EJzrk/HgVA0ltZXvKkncHbFuJWb
itfhpnoyO/sJAS8j772Ffi1+ih3b59FAwL640PZ1nwyFYQmSjkYCL3xzYo3W
MnTbUnkj/R8C7icc1k2aEYKTRmWopjwj4MMfvJAVHIz63t4yfQuBVypVKzcu
CNPkeoX8OYHQw6mmLyfWYGffbw69bQTypur2fXsnEIdbGiNPGQjsPNajnWMI
QBf/iwPuHQRWm8ZnnWMHoIW1Ja/1JYFqPxcDb5oUU9/6bU7tovt5WV3dwtX4
XfiY4XFGAqLRip9MW1dhBCeUW9VDoCMx54WjzUq8LuefCf6XwNVLg0Wdcgle
vN86w/CaQMY8XpILI8a1vzhJDpkIrLjOu5Lx0Q8nVHfg5LcEtgsvH0kX++KR
sIU6/TsC+Vv012/tWYYTd9tNVXwgoHJ+P3ePfgkKblVpTB/pv5dm3iuc7oNO
ErbmdB+BYu+jf9qECdF6Q30z+UzAZFhcZilfjLfqZ5a19xM4IM2tk5YvRPOo
6JK0QQKFzp2ipFnzcJ2aw+J8ITBLzQt62j4bY9uUhnvDBB6yL+3S+Hpiep2H
fbgZH7oTJ/z8uNEdxZ0NQcaRfPivdviRXDQNdcvtyFEWHzyl8TLZ/EkomV8T
zDXngypOLxNVWaGg9w/pTGq9dqzK2d8KPXK2SGZTJxeP0bAa2GhnxfYRUb/Q
BpToui3xadtyEk6tTvQcJ2aPxYjUu6yj1BydoTwgwBzjGiqujhrNh1zkfa4u
H2LkaUfy2dSF6u7JaY8HmUCh4i976gTtepF/5wAzN2/kaSfqpd35mrox/Uz/
XmGqN3X8mUyH5lWfmP1cDN9BHWVdEdR4+zWzvfmQbDd18Qnrk6Htr5j1GeGB
+6mzIxxa2lg9jG//kN9h6h+YGLlR3Mmw9YvmFFAXrXV98qG4hRlKYXtco87c
FxIy1N/E9Ho9492kXla7qHmU6ClTezbx+2pqOSupdOaZGqYsSMyppW4Oa6oU
EB1TZMkZ30DtvOny4Wz1beZcaY9N69feyvHH/W4FTNYOreVLajvuUpbDnQDB
/y+ATAY=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0nk0lVsYBvCTTOV000FxlENEpI+iVPL5DHWllCTdTMlQIUIUZUziSqmu
UI4pwg0ZQkh7mxXhREXmdDLloqLBdO7bH3vt9Vtrr72e91mvnP05Myc+Go2W
COf3XavDzPUuJajEUx+9dmVEYAI1j14CF9uq/Gv1IALHkyGKIWD6N3JzQFIE
dtMdSb4B7pvkyFTFRuDVeiV3MsCrdeIzD4RH4DOGZr6dYJp80SGvMxGYvj/S
YHcZQXGk5GZ/qETgo3/Nvl9aTlDOCa1Px/PD8cMat/tFz+D97RmpyznX8JKy
k7lGzwnqZ2NcvjcKw79at7S/QQSV3VXSP/n+Ks7Xuht1pZKghpJzFi8Mh+Lz
yn7xYtUEJai7Y5n+8lA84zqlVV9DUIYOJc8YslewGMdgzKOOoHSThJ1rdUOw
DlozuVhPUHal5P3r54Ox4kJg+OMXBHWU91BDRisIM+tPeek1ElRO64oF6ccB
ODtfxeNVE0G9r6frnd/uj+c+hyzxayYoKXGRVan/XsIWBcc/CbcS1Ltb/jW+
en7Yo6HWupxDUArJm/6Qqr+IlXgiww5t0M/ajaKvrS/g0cr2mql2gpot12zt
kPDBLu2EZvJb6GPziecMdB5/P7f8h3oHQSFnhpBzuBfWs/Ez4XYSVEbaylfD
ep5Y+WxtSXQXzP/RLTFmhQdeK3DLS6aHoApD3IcXJt1wy8REVUsvQXn4BunR
clxxlH2Lg30/9GHlzRRPc8ZDP/6WnBggqI3Je7/nPz2Neb2ddgmDBCVjePzy
zlInrHAwa24Tl6CMig1StSYdsPBKEZW+T9DHmjeU0Gp7HPFln2vEMEE1bynh
77Wyw+K2y3gSowTVL+4mO5Bhg09IWyvWjRGU71xBpVWQJS62V0s5Ng75rY4Y
Xyk5hrOa+lQH/yOohOkOjsT6o9gyTM7k5iRBecfuo3kHm+E1L7l43ReC0t/N
J3BA0xT/Y6Nd3/KVoB46Soc71+3HTH8Gy2GaoKoaPA2u1vyJyYq6yMkZgjri
o2OiLW+I5UzokYk/YN/ILEL8OoVXnmnvJn4RVFtR2q6Apdq4on1z1YdZgnrx
8tEyM9ltWPCkY1nUPEEFhgdgE7o6tvKV5pdeJKh9HxrTtw4o4fnUmBo5cMp6
1bztWAmzm1aEbgQfLVsIOJykhHtkaHzbwQkdX840WSth2zouzxRs1bjOm9Ol
iO0Yj+eugW0Srp5gdW/ATjnUt6/g0+1RkZxxeXxuwGmwkUdQB42CtwSby+Id
dGW112DDD75x/NqymLZj/HIH+ItB2Fu2nCy+He0lwQXnZxc+WdXHwk/IIKMF
MN2rVzBJgoV/sOMfq9HUqGsv2UVKUetw0PGmSzFg1vqqzbxYJjYKu9lwHzxj
nra4cIaJRQsOi6eCb4rlBiloM3GqcGduLpgnoXVnpF8K1zzlDtSDBf/c8OvA
JikstHpx7y/wVWWXlmsv1+DoNnUx2yVq1Gv3mFgkL4H73HUpR3Dw3K97IXPi
WFXkoJsLuHjdbJVLuzhuNHBtuAD2XtIYlBcqjgWLH16OBt/0zirkGxLDgXFM
biV4sPvETGsBA7tZ8xfL86lRmfueTgicEsUVPxmDymDtI+5hN/RF8fK7civV
wRKfMaXNEsVZzaTzbrC9qZMxo3Al5pJ+646CvWi5xr3sP7C13ETYNbDlNCFQ
FUzH+4c6LEbBfCdmT+IQYdzTqrl8Cvwx5fFHeV1h7F52+/l3sMjI6S2D80L4
TtR+Bf6lahT/g1H1s35CuGsr/iIDlipRriy+IIhdgjKizMHDYwks1hV+HCHp
U43BGj8NB417aJjJ1+ZTD5ZYc587kk7DOZ8J5WZwmuZ04YAbDXPQSHQXuNz5
6ZNeGg1LOlnbzIBTLL9FMi0WUWaBwU8VfjVKz6rrSJjsHKo3ZhCxYG685H/0
3TMoeHuZOxusk4kNk0an0a71dnkPwDaS3+eb4qbR41+56nngWNaq6PmZbygu
a5/GC/DnRN7OwrKv6IxgyI5ZcHTv80fnbKfQ+q9KfjQByPfEUqRBYgr19LaU
CYJXoRX3fBImkWnxWm0xcL8j88NE4ATa6Viqowr2MEsLjDQfR8urJ/Vtwex0
r0mnXSOoNjc21PH3f1tiq1MqhlHgPZ1aF7DDwU4LcWoYffW4vuci2Ea9tPqh
8RDqZikZ3QJ7mQ9lerpzUU6ArUk1uJJ/LjN3agCdcha4+QK8vFbwhve1ASR7
NKelBaz4U13De90AilGdPdQN3u5RFaad1If8u++aTYOLWi37Na50I5OdzccU
BdWoId63hbP4LSIn2GabwZbn7PUZi2+QetpZE03wT03eQrXuG8RYQTfQB8vs
qO3a+6oNvRswJmzBsviSSucyDmq4y1R2Avu5lpoWVrWgUuMx+bNgg6mOXU0+
zeh+0d9Sl8BiCapdelON6ETEC/5YcOueTXv0iXpkqhPPY4Ntxl4/maPXIf2v
p2fTwL5P3oi++lKDFKyFpgrAx/6avFvQXIVG1PZ2N4NVdf6LZyU+Q++5Eu/e
gOf3LlgtqShDjfc+cbrB7uZ1c6LDT1HO0rD6UbCtWsDrspNFyLOjpkBACPZH
XyzboS0b2Uf9k0MHz1/Om+dvz0Lmeg6ZYuCNG8uF+MYfou3ZfIly4GCLtcYr
T6cgJbu2uI1gTYMhPt07CUhS4sEdNbC/kwd3dXgsmg3Ui9ABs/dspXUJRKLP
GqtCDcEKpu7e78RCUM/IQMB+cKVWNTtU0BMhs+Dzx8H5wTZbXYfcyDwhU3c7
MCdDKLSuKYBMqWA5nwb79jzjPJsKI0MVsa0PWOObcLKo523Su/vmcX9wMUOy
xcIxhjx1y9Y8FGwZeTDyk2IceWwPcSgSfKMru72i9B5pNLuw7/bv+UvUH/VI
scmdec2G8WDKpXfFHuMkUsUxUTf5dz7Wcd6sQgopLeW2KwNcVXkMXaSnkvSW
3dtywTHPx2riu1PJhSt09SJwljZD1PbOA3JCq0flGdjdruVBg3oa2T+evaEa
fOQwy/9tSRrJSb0s+xL8UkOAHa6QTlZZ7JfmgHU3B/P1+aWThSLSqzvAGxxu
5XWWpJPplWOifWDXxW1pF7vTybs+5SKfwEuZnr3lw+nk/yOzjO8=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0ns01FkcAHBGUWvKnvGoTCmy2koXm9AW3zvLFtnpIettyqPWQUjTltTs
oscklDy2tE6kIlYHMTXeMz8mqVDjMdWQJK1Hk8ciU8ze/rjnns/5nvP93u/3
e40DI90O0NTU1NjkfL0b7A2LuQ8Q9l19Q7xUTgGqfTp4gvjaqpaM8y8puOIQ
ZxZHvMxIGaKUUXAI/r2eTJyyzE1H3kGBAUtw+TZxpi7N73orBSFObsdlxDOM
wMnvKAroromOW4UIC+xNvt9YSMGvXsoXGpUI77XLS2Yfp+AWdSirvArh3Dd6
3BV0CtSFAcXONQh/TkKVS/PFMNNqJW2vJXG5lYuOkxhKbDOS4utJ/uq8iRyZ
CI6sjbmiK0Z4j7Ry1p8rgsmwUVsJhXDGY4fVAi0R6LY5DkU1IuyudSd1YXY9
2Ncu+TgnQRhvEuzjb64Hs1neubtNpJ9In8tO1+rAUHIwmtWMcLf4gmnrs1oo
KlkX9eQxwlWhp51302vh83CcesxThG0ELnlaNjXgUer9bkErwvYVu2r0I6oh
6mGDX2UbwsqE5Yt9MqpgjUr7fdBzhM+o3RlNr6+EwXopNSpFWO8+97KZUgih
UmR9vYPU058LVZgIYSrym2nLLoSz8xtpi3weAMs/ht0vQzg53PFZwJ/3YW14
g+DiS4Sn0mOsigsFsHz+pWgjOcIJexS7d72tgBaFQtTSjXDcosX5a7QrICmw
JSjwNcJ/bAuv9mCVw8D0+aWKXoSPlcYHnYy9B6pu2f5rfQj7L7djyW6WgenO
gs/r+xGe+AH1JMpLYYGO9rqedwg3c4SlRzRKgT/mEsZ/j3A7b8JgLyoBPc5C
lf4gwqbRb39ntN6FfUw/s8YhhO+lfjAfXlkMFYEWOZ4jCN/uig84nFwEBY97
zPs+kP10xwr7aYXgc8aYnfIRYWFuMK/BowCWPOqvWzGG8FhHn2jPw9uQ5r9F
0jJO3sewi3Y1uAWGJxkrg/4j809ZkzselwcO1Y2JHycR1uw+MnF2MheM2fTE
7GmEI7cfLTu3PQd0QqSv0AyZn8C+Nyw8G6qlG0RvlOQ/G1LWuZpZoBkQLEz6
grBLe2drSUkm+B5nzmPOkX0hvxBmehpE9h7oa1YhrBYtecGxvgQXn1vqctQt
cJBPcKqSmQiuA10egzQLrBT/9WVYkQCSHQyUOc8CN9oMWxkdOwHszU89zTQt
sKcsU5wzHAYOir/dNhCPdx5+OBEbBpZ54WxrYm2jX55so4cBYxHd8SfimI65
jhHzUOjs3YE4xCG/+Q3aRYTAPn7TvEzivk/TOs9Gg+FwF1U6X8sCJ2wOENJG
fCEwKe0fOjFX/4O4gO4L7qygfF1iK96xJzs3+IBNES3bmJifwX+dFeEFSh6L
b08815U1f+OYOySY1XGOEnt3z92QjLgC91WK90niLTojFQy0Aw5e4rgnEMd7
dDZxIp3BWTnrkkq8MThPMTXmBPSWrZuKidMGf+TuVGyB2Xi6ZTmxMn3o6kCU
HShs5euqiD8NpNfxJqyhLTd21SPin2fK9Dlj60Hk4cpsIz7Ne78/ZcoUyrSZ
Bl1f61018To1zYSb9UPf9hBXXaiRV2nQIeNopfY7YpVKtXjhKb7D/4S4Ojg=

              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {15.36, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{15.360265165455871`, 
            15.515419359046335`}, {-0.01203580535041065, 
            0.15515431884366646`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxd2Xk8lN/3AHCECpWtqFRKC6UIiSxHZauElDXKln1fEtn3fSeyjxnZ17GM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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw913k8VN//B3CK7JMKUXalLDOWLH1kvG9ZSqFCJSVKsrVKpFIpZcmWlCVZ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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1A0slHEcB/AHtzuRSF46zZ1zIp2j1lG3zEV6hLyOXad5yVuuU2R1NLVa
W96qVTpczBkmmpQyL7vyVhRjelGoKCklp7dzvTCjl83vl9tut8+e7/2e/+//
/z0PKzopOE6bIIioP9+/v52yA/dfCPLciH+fr4I77d47bh3vFyx6U56O5kzA
O/ATo/YEbe5nsDygKiJ1ahpcLNlVH8aZAZOqkpESo3nw29d2dPENrW2L7vc/
fJvpQwHnJclJWhMVfFc5uS8ubBm4vdEkRfNQH5zM36Sx4q8Ad6gF1GiJ0aJb
lawn1N7yleDxuPTgQz+MwQlTjLBxDxPwU1/HgW9ppuAjbSHF/G4zMLHiwxBd
ZzW4LflCpLOQDh4y5ZUxKyzAzy9tF5UNrwEb2e3fE+VoCd5wae5xg5gBrnLP
pgwrmNBP9Skzd0aqFfhnIENZuIoFHrl6c4jXjP7C9ghtiLEGS3N0l1MW0PL0
sISkSjbYUTQ2f8XTBvxVuG+68xXa703qOe2MtWCmsGWvvrUt+IzwwsuNPehE
T/l5G7Ed9HM0uLh0Xmcd2ErFFf2oRrsma3yUO+3B0yfIsSI1eqA2bzD28now
t8+CNsvjgJlSzvC1EXSGXoqKk+4AprfV78415YJJ4rTErBk94ZDTFC9yBLvc
dtYapzmB2Qe9Ltcdv4fz/otdl0MxgH6PnRedVGcaQl6gl00toOG8WYXX5ev3
4nknTnpIvClwvq1tF2tYJBvPN1RYqVBIcT/n/GTOHAvYT0FKT6H8YgPur6Hm
9XBFLa5fGksqs0fxeehrKWEQjThfHcG5WdfVWN893KW8xhyfFz2z9425QTh/
PO/8sUp3vP90n6vw2Vmsv/WkbOXn9ZiX+5qe/cjF/MxMgKUbD/fnefXmiM1p
mH9EmvPjQ7GfkHpJS5E5Xt/i1KOK0cP/a3cNGGT6Yt7atzl2mxvmlR1P/VdH
YF7RKYzdEYn50YBBmdoA84Pduv3S79hPUZZLWgGJ6++yICY8Wf/1JztHCWJi
fTEttVwaiPVtLQ0IxjLM2xZUkoQK608kxNcwPbF+4alS+wfGmM+aE0d+WoB8
q38VdbuhN9bfEMOn35pdvE4Q3TpV9XVUJviwXBHe72UHXvp+J4il800QvwEx
B72B
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{50, 96, 94, 91, 76, 85, 73, 79, 38, 60, 39, 40, 41,
                42, 43, 44, 45, 46, 47, 48, 49, 61}}], 
              PolygonBox[{{93, 92, 90, 75, 84, 71, 78, 53, 65, 14, 54, 15, 16,
                17, 18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{1, 95, 92, 81, 87, 62, 68, 13, 52, 12, 11, 10, 9, 
               8, 7, 6, 5, 4, 3, 2, 51}}], 
              PolygonBox[{{93, 94, 82, 88, 67, 70, 59, 64, 37, 58, 36, 35, 34,
                33, 32, 31, 30, 29, 28, 27, 57, 26, 72, 66, 77, 69, 83, 74, 
               89, 80, 86}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 52, 13, 68, 
             62, 87, 81, 92, 90, 75, 84, 71, 78, 53, 65, 14, 54, 15, 16, 17, 
             18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 74, 
             83, 69, 77, 66, 72, 26, 57, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
             36, 58, 37, 64, 59, 70, 67, 88, 82, 94, 91, 76, 85, 73, 79, 38, 
             60, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 15.515419359046335`}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"2.654284016794084`*^-7\\\"}]\\), T: \
\\!\\(\\*RowBox[{\\\"11.900526240560039`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\
\\), \\(0\\)]\\): \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \
\\\"10\\\"}], \\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         2.654284016794084*^-7, 11.900526240560039`, {-10}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13c8Vf8fB3ASsrfKvNa9ZJVVVD5vIaNSWdFAiiRfu6KyyYqsiMyy1z1k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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVlXk01P/3x5kJreST5k1UzMhQsvZtEV5XypAKRbYSIkJZosXyQRspWmQ3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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13k0Vd8XAHCEUhneaHrGh5cKhYTiblIRGYuQ0iBCGkiGyJAplTGUCoWU
imTKdE8ZkvoKIUqSTEkJKXO/8/PHsz7rrnXuOfvsvc+5codPWrvwcHFxHcM/
//9PVm7VP2UWr1/z7/9/bCQ2YPerbegEUconLvN/K35PqUkYCiJ6LJNCFrBl
JkN4PnlGEtlfhNgz2A+9ShVPD10hVpfH8k9i35w+m81TmEjQ2wXWjWL3PxUp
feOZQlRvionvw15zJv9livINYvkngc0d2Cc37Oh2HrpFTLyKlW7Edjx36uy1
1kwicEFo5zPs4E694LmCO8Q9n6TCPOysTauiDl7NJs6oizumYNcld8XVeeYS
nzdl7gjDHp7KSVM2zSPGgtd4e2KvtPHOuqr8gLguWNS3B9uKIvR039AjonO+
MVgW2+fUx8rqugLCxdG2YBn2G9c9hxNaC4lkrkHZwSU2Gm+Q8/hTUER0SPK/
vIMd4hs9vibjKTGckDYfjE1VGvd2vFpMXN+9/rQ99qaIqvPIs5T4fM1ORgC7
QZPNPeVYRpyRH7frXWSjfQMxEYqm5UTu76jWJ9jnt9ldvaRcQUwcr46ywX7B
PZmxZ6iaWJW2mStsgY32PNmnENVRQ9y16gYT7EFnMu9ZHYn34/wLIWxe54Z9
ca2IUJNtiE6ex/Elkw79LnhB7Oc5Lhc7x0YTzJd3r3BqidkRursRdoXX3KBS
Ri2hxXgxNT/LRqbSh9ztr9YRifqyTS7YXkGq3jWeDURL+/cwhRk22txxqMRu
oIE4PZL17u1fNuJSufb3l+NL4qmBvYs/dkLPfCDbtJEQq39t+vIPGxVveXUx
WrmJcBNGCubTbDQ3eyTFeug/QqFokH/FJN5faRPNeddmwj1B9cOVCTaqMlRt
u/utmVh3gZVJwQ6KnRGcHntLyEUOL6P9wvG+2vDi9WwL8d5Ad93iDzbikXXU
9eJ6R5w+1Tbj9Y2N1It2xxgavCNObfb8826EjY4YQRcz7B3xfXX+kBZ2nZui
L7msndjzVTTjzxAbRTwZfyKyvIOY0Ht80mmAjVZsu6j8VPA9Yffgv7jGXjbS
7vD1izJ/T4jYl5etxj7uevylY9x7YjvTuM38Exs1xZq78FK6CLkq289vPrJR
bLtY1l56N5FdssG+sIuNhI49EpuR+Ei8P/j+Nb2Njegxncv11nwmfsWPP7Sp
ZaOiqNtR9Uc/E4z2cH7XF2xkGXlsuXnWZyIkVDjF7znOF4PAcDXBPkJVUtAu
hcTrJVaFQ2QfMWCS5VxVyUYBOuvCDvt9ISqTVRKLnrKRu6pHSO7+rwS1r8Nr
5x02eqZigUYDvhJrPO2i5LLw+lQ0uNSufyUiDrd0zGawUe66+QtlHV8J5tU8
es4tXJ9rYi80mg8QiX0T4kNpbOTAzg8ehUFi+syIITWOjUzEvp9XVRwmju52
EaIF4PWvdiE/GA4TEXE5/1X4sdEu7s/cUc7DBHtvXrvzOezRtsjP6cNEp/v0
s3s+2FUV8fHUEYKGHn2RPclGZs6Xsif/jRCTlNQcdISNzPOU35R+GCW22pj9
KzFlo+abd4WOzIwS07yfSpV24ecJUlbCzO/EOt0NpdeM2cgigNLpavWdWK0m
fdlrO46f2exnscbvRJ6h2LVVBK7vX41TASVjhCElQnJqI64fbTdJIv4nwWtm
MHeOifMxo1nzZOFPQuGBAT2WzkaZyzeZZ7T8JIptddfcpLLRWCd36D+RcUI6
na5fLoTz5Wz6EJkwTsi1esp18eP8tR/el2nyixiYyG8o/SOPLqdIKMiZThAO
/C6x4+3yaFwktELefIrgDXyxaB4rj3ozjr/jOE0RBRHGaitj5NEbVeux9Z5T
RF/EzVu1kfIoz4wtvfnSFPHh2OMNG8Pk0eHo+lDThimCk++/4a+fPOr8J2Di
o/+bUNZ7nKJ6TB7V/Ex8X686TTRFxi3uIuTR1TfZv92E/xIhheqbdMfk0NiY
7eq1cvNEaxKnfUFGDp1++tL3u8w/QsF0YQE2yyLXzJ1//3pyw3MTvbP1YdLI
9/pk1uYzy2BUc2Xv2w0sNDlt/E5sLx/UKkTa/hSVQKE5SyoBqsvBozasoBfE
0KmowL9iGwQg9d4hwdwLTBS5pmrm2mYBeCbVaJ/kz0TprxZmqYQAzFs4cy56
M1HDquCF1eYC8GFEcccpVyZixYdwc3sKwOoxvsQzFkz0Mi1i1bd7AqCjLX5E
RpaJpB/EyTyTWQlVw5dHxesY6M2buzvthVeBy928q4lMBsq/lKF/TnQVeEeE
pf8SYaBLxumbrsmsAp/Q2AbrVQxkXJfIblVbBZYv155jczFQXWXoP2PLVeB+
6bbhn290VPngYJl2wipQ+ekQdqiGjh5ES3LEaKthYh0nx9ydjqKMkvjfMwXh
RIigX3gzDRVd0FxqlhYED9crSUuvaKi3omO6QUkQVsysuBdUT0OaG8UGS7UE
gcWcKomqoqE+qVu1KbaCULQ9yfv1AxrS/ZsbYpsiCLFnlnlRomno5/2KuQ6G
EMzy3D2Yup2GxAcdJ/+TEoIXUmkBCQY0ZCS7+K1eUQiU+6OvxOnRUHoK0V2y
SQhaXZ3SUzfRkHF4Xdm1vUIQd6zN9r0iDd3Z3+yz95oQlG8cM2Msp6G9wv0/
2+nC8Gqpd1PsGyoSmrnluY0lDJxbuwUMXlFRQ5/96BO2MGQbuVjO1VORdlHr
4FV1YVh4HKdzjqQi1t7nPcaWwqA00XLuRhEVDdzIbKqKFYYD6/iyI69TkU6S
mo01twi4nNOsnD5ORSlRgokCfCLwRKdumYQrFU0Gfm9BK0SAxbdIGhylogdH
75mriYiAddnxpPQDeHwtmV2rZURAM0Yt18+Giri6hQwatorA537PwC49KmqU
/qmq6ycCr088HlBlUFFM1v0Rg/MikG60fssVKhXtUnC5YxIiAhuD12eNC1PR
f8o9DPtoEXgsXpyOVlJRm2bTwrk0Efg18XlXEhcVfdyV21RSLgIJnAcJ82MU
dPO/Qxerq0QArTXvuzFKQQcspfTrkQgUx/vo649QUN/e5CftjSIwftFYOeEr
BQ04h6VNdYnAIyHBZ64fKOin74FjG2dFYPu9Fc/fN1JQway4rM6iCLzrbFte
3kBBp853dAM3BTjHZQ7crKOgqVCz3ZYCFJAtJXROIwqauayreVKcAvYTN++b
llMQz10mzyMdCoyMvTpTm0dBjLfNt9YEUCBw5kduzWUKup2XeuN7EAUKxBUt
tsZSkFKYc+rjUArke82EVMdQkNamyXjNGArMP/UObYqkINt0xkVIo8Cf/Kpp
oVAKSnHd776vlALOVmn5Br4UJG2g6CpZQQGRgsQff30oKFfi55HeagpEg/Kz
J94UVPrfBaej9RRoXlr7Q+00BXVq3LU81U6BZyMhjbaeFMTkGtWKnqQA1xlf
M/MjeH7dRRqmfyiwfrXmGr3DeH5PAzcIzVFA5sOVK2qH8PyOCa5N5qaCE4U5
LX0Qz+/NBqlMESpo/fDbvMaRgnpzZsWP0KmQqSjmrOFAQccuvGAqiVGhNcGG
amhPQb7qe0QeylAhli+D5m5HQalp55aVq1LB0SE6ZsCGgmTPAFegOhV4Ngr8
W4WdZyqwqKdFhdNblJa0rCmofOnGn1o9Ktz7rnk91ZKCuo7WfHtrRgWvZ9mG
4bspyFk/aijRkgp7VJfzvTSjoBFRy69791CB+z2flRD2TNOXno+OVCiqfR9x
bxcFiW3kaxl2x+OvbD7Ma0xBfNfzd857UWHp3EY9u50UNMllTQp5U2HZRL/+
4x0U9Lrl9uNNgVQ4y7eh3G07no/2diWTC1Toz3yt9saIgrIzv9/aH06Fhp0l
zRrYwae0r4THUmG67EyY8DYK8ujq5U2No4JB6I7UcEMK2gcR5x8kUYHX1u3d
vAEFqYu0ebSmU2FCLuX5DFDQYIHHLpmHVDi+7cZZBYKC2kSpL9QLqXDGrbfu
mT4F1Vwo19lRTIWptFNbbLDTLPiUT1RRYT/rwu1EPQqKKMvPDEFU2H5y/pI2
9hkZa7HkOirk/Fd/u38rBZmN315e+YYKbx4abd2GrWO3/UJzCxWSVGbrZ7fg
/Se///nSToW2Z/O+xdhUTqLXdBcVoq3MLLyx/13VHlrxiQplv0fNtbDH/vQ6
sb7g/Lj7/uyiLt6fAxEdaoNUCHSi1jVi1zes273tGxUo7HSdNOwi1bY62x9U
kP59utMDOyPFb6v7BBXutqTc2IZ9eUm6OGga51O5QKQMtt+x+nUJs1SgP2xK
+6dDQS7NHnezF/H+5ne3fcW21qJKlnPTwKVES/MNtv7t8sTXfDQweP2lqhx7
Hf/BlZ8FaJA89sHzPraYF1/YpCANDorLG93G5uvMn+Wj0uCOVZlhKvaknvVp
cSYNnK7dcEvW+X9+z4ysl6BB3MDrkmvYrwUznEGaBrqE6dp07PKz27ts5Gmw
P0esIRs7+9N3C1clGkwzNWOKsBO2J74MWEuD5cm3vOuwgx9pE1dVaRDP2hvx
AduD8bk0S50GCYUONb+x9wVFqJZo0UDA8rE0Da/faHBdbqMuDebmLHI3YW/c
3SbVo0+Dw0+IvfuxpUv8ro0b0sDQO2hdFPZKKRnBZTtpcB0ElEuxB8Y8FpQt
aFC4uPKGLN6v1j1UHz0bGpz8ESK4H7umqvy7pR0NckaM8tKx0y7zfTx3kAYB
3GU2HJwfEb/zrWOP0EBUxuWoN/aZ/dZNt11poGJ86GYttun6jGf1J2lAVm0L
O4Xzrdc6bWODNw1spx76vsY+5Z9wv+EcDUzW8nuuxfma0hB+/eUFPN/r0fa/
sZV/nKc0htNgZ+sTq4M436tovjGNUTTIE3i9qxm739nN/1UcDYIC/yPKcX2c
jTo08SqJBhPFpVs0cP2seOxwvCmVBuhnnHYRtuq8mf3rDBqcPkLdVIXrLeDa
Rp3/CmggbWWnw4XrV7Bq7ZP/ntLA6wramo6d2c9Wbi6jgXiTuIEurvcGNab4
W5IG4UY3zS7ifkBtmptpeUuDLL0vXsa4fzxYqi1vH8f7aeDRF4/7kZ5i9YaO
KRqIhLdPelhRUItpaV7HXxr41Kvwm+L+9SctL63zHw0sTQvVGHsoyFDjil+X
MB2sHKevdON+2O1qq92jRofzly+ck3emIM+rFoU9GnTQbx9J08P9d6nYeM2n
zXRwYBlW7sf9WYFni1gvQYd7j+p47h3F8b0pM/PZgg6X2gVueRzH8WgdKft6
Eo+nkbxUjM+Dw+bjZzK86SCl7FQ7g8+LqtfTKo7n6BBqr8wL+Dw52cCT3RZM
h2T317Ndfvi8qGTFP79Ch6+7tUo0gykoJ9fSLSOfDori9zyT8Hm1xLZjOxbQ
YbHi7oQQPs/2ZTn1Mp/SIS317uQVfN6tvum+52oFHcS5H7mlxFGQT8JFCHpF
h23XhhRar+H1ny8Xcxymw9YXvz/9uIPP89mad8zvdDAVUWRnZeN4+dZfbfuJ
53t934BdLgXdP93Gu+sPHVY5vvrw9j4FibiO/dLmYwAlszX1WyHONyvZV0w2
A56rBlnXkRQUyIn2bzvAgOID0MTsoyBdDc+C3sMM8Ll9ota1H58H+paDo8cY
4D+2rqNqAJ9PtmJWy04ywPapo6H3NxzPiLw1mhcYsHcsahtlioKOfm18fy2D
Ae6raF8oy6nILENAy76PAROLU9GK6lS0Mv+Hh8sAfs6/LXlWk4pelbZmnR5h
wFopdnnrZira0Xxd8NIvBgSeTTG5iu9HsKg8WMHFhCOtJknaJlS0yXFXMkuO
Cbu0vj63OkRF0qKxk58PMcGnuC82JZmKsv3Pe9xzYcLtDUZvi1OpSLnnxIDX
cSZMHyvP7rxBRZpZlp2Lp5iwgecdn2IWFZmsY1ZIhjChZbIlc+wRFfkQWaF2
t5lQVzWuw2mkoteuZSJvP+Dxp8pnTP5RkV/5V9UaG1Eo1DDP2+5HQ9ndnLwz
dqKwsGGjnuZ5Gno75yHHcRSFT19TQCmEhpT0ftPiD4tC27/RRDq+D7c/5509
dFoUUpUqXCTSaGjja8VavjhRUOmj1zWV09DoJ1e73U2icCj6+dGaBRpi/stv
4W4WhV8L1mkS3HRkIPvLpLRVFGL6Nhic5aOjtMN+W2W6RUFr4MBOWSE62jEc
LTcxLAoBn8IVd8vQ0Z1f978n84nBw9SJNTwGdOS4bOxCD4jBs7X7zbpD6Wis
SNDni5EYrF7KmZGOpKPzh9XchozFIMqDO935Eh3dfH7G8pelGMzQfzx/n0hH
vRdmZXkPicHbrNS0a3fpyHmB/8W6UDGAuzrHLero6Oi0HG/gczHYvP1JaiUP
A/3O3jZzoV4MypxU+UP4GejiHpexi6/EwFmk2h1WMlDO07z2q61ioGYkzCyh
MNDQabWcO1/EoGYwcvqELAMd/7l1RxO3OGSJ1L6X0mMgr2G7aHFDcTjPd1LZ
15uB6n9Ekt3bxeEIkigI9WUg1u+SP9dNxEGB62BhjD8DNXHRXSSsxEFL6Ili
3AUG4ki0GEg6i8Oto4EfT8YyUJ+Z8TwrWBxOz+V5R99hIOsibS/ZCnHQaHK1
ZTYz0P1y15y+anHwllWweNLCQFxkSk/mc3G4Ou9Xa/yOgR6//r1L7pU47IEx
6RNdDLRqsJAj3yUOcryzmbH9+HtMVPkL+4841Prkt8r8YaDNQeJ7OOoSIDvn
PZgtwUSTFCV+bS0JqCVMMxdZTPQ4V73cWFcC+qv8dKxlmEipxZTlbigBKU6d
/ONsJmKygwceWktAu/ZNwb/rmehPY7+PurcEPLC1fg36TFTkNK607ZwE0OlX
POyAibwm57tsAiVgYYX06HFDJhqSZOidDZcAuG4YFraDiTq8dvKVJ0lAhk2K
dJg5ExXTH17TK5aAEjW35ZVOTHTqfvlO83IJGDnKfyXuIBOt16+fPVAlAamt
c78OHmKibNdep5A6CfC0GrL5fZSJkipElGrbJeD76MuI7x5MdMb5bKnxtAQY
RpRcp+HvZdXpUDf7WQnQUy/jzQ1gotGYqxLui/h9TGFzzfNMdPjpveBYPkmQ
iHweaIS/t634P+xoZkjCs6UN2zQimGjDQ/33NlqSYG2nG7YrnokS/92KsdKV
BMVAu/LkBCb6bb24xUJfEt5eFpr6kMhE5bOVmbt2SEK2/y5fx2tMBDt13A1s
JcHOf/bp+htMdOdGGotwkISPq4aE7NKZiPfn3+atByRh02VPr6CbTNSYXKqh
fUwSPGx3bqm5jefTr7Go6isJn0U0V4vcxfHalFSwPkAS6NRfsRLZeH9iJg+t
DZYEae4dInI5TPRB7UmDYqQklOSRSvL38PqCVONZKZLwXWr00u8HOD5iyuyV
pZLgnym54cMTJmr3iO5YXiEJQhd8Z7OLmEiLHI7iq8HPTT1eejxlojmX3DGu
BkloeyR/+kcxE4U9ZZf+7ZCE2LTGeVTGRAP84W7T3ZLQMjj5zaOciXY49EtM
fZKEMdmyHuozJlrJnXXh56Ak5DgLtuypwPEzlzYZnJYEGf6JH3lVOH5ZQfP9
s5LAeDHKpVnNRLbTPY/6FiXhi0ewWCW2xM10ag8fC+ajvfdW1zDR+fG5um4B
FpgstAdok0zUa+hw7r0gC044tWQXYN/5JtbTxmDB5m/J/IkIx1fP72qLOAs+
0Q7oL2Ifi38PzVIssF//PODocyZauzkl55UiC9qV9nJzXjDR5UvTdi+VWdC2
ItI0DPvnpz0r61VYcK/L8kY39tOLtJNoE35uULz9fC0T9aiGHPXXYYHVZYvC
F9i83WP26nosmNxOzearYyKVcHuL78CCEq8F2e3YtioNRtlGLLjOL8QJxb7w
Xl3XyZgFtwV3lj7DzgvNUGOasaAu/F7zT+y5Dj+JaBsWnK3uvWFez0TskEFh
AzsW/AspMffHNltrzTfnwIL8p09jM7HPttfMFR1gwbm93VZ12LeD1/3yOMyC
Y8eUsgawX65JG1Q4hscbuuHP3cBEv9p4P346zoLcDq2PEtjiQadbUk6wYEZj
rn4DtiGnt97iNAs8uQd1tmF7tO6qXHGWBdz6f7WssZMDywqf+7Gg7NuGaifs
akWF3IDzLLjKm/jGBXvobXy6RggLoq5KuLhjCwcsxo+FsyArqinSA1tbwT0y
J4oFPeNZG49jOzd3Bh6IZYHOy0yXI9gxfttOi8bh8QVfyjtgF8kXHmtJZIFd
Lf34buwPb1j7Y1JYIDoSo62HvexcjJXhDRbMBiolKGOvl/uzY/4WCxaDR89Q
sfe+Pry1OIsFchMdn/7ieASffbvxRA4LXNtGWrux78ls5SjdZ0GzPNuiHLvl
VR7r80P8vv6Le5OwZ70Z1LRCvH6K0KA7trx02HKrYha8eVyzqI9t2vhzQaCc
BeWVKRnC2D5nHCdfVLKgYXNKUw/ez1usxuFAkgXT8tXBudgNDZqfNGtZsCNo
VZUntqikUGNuEwtML0i3/cT5BPUB1Qeb8X4rfX3wANvt5HCRWBsLOvTerj6C
XVGLbl3qZsFAuZTnK5yfBzy9vb1GWJA0kJTmifM7itnnxhljgTVfcsVq7EJk
dqBvnAXq1ypd7uN64GEomVj/ZYEtT6hdF66fnOouaS1+KVCjDuatxvXW7Lqd
Pi4gBbP5svQEXI9/KEUCeYJSMFAcvoKKbXws9rc4Qwqk6OiyAK7nMSH9pkW2
FMiuoC57i+s/YGe07vI1UvBKaOLlWuzlIW0PRNZLweEt3f5huF/ITxyLZWtK
gSt/fbYi7if27+LMTIykoPzIStEtuN8MrfpQZW0sBUPX1Y18cT/yMVJQ2W8m
Bbx/jhx4hPtVfEm54Mk9UkCT7bcXxv2sIfVLc/JRKfDfYnbiziMm2tOyjrjt
JgXrs6p5qh8y0ZcVvgX3PKWgZb12xLt8JlrwXxlf4SMF30qMrX7fZyKN/RpW
fRel4Ejcez6+XCbKlI14ty5HCs4dfNh3+BY+T+zfbtt0Xwo0FQp3bMX9ujJB
vFj/kRT0C1Vfp+B+3snzONmqRApEbCf5C9OYSHCwc++5eil4mt+0WJmE43F/
TdeLQSkQ91F3EolhohX9Z4zffJOCvtTGpLwoJkqRqC7v+CEFaV9cy7ZGMtGT
WKvrI9NS8HHoef2+cCYaORHgIMQvDffKvy4dDML5rP6mx15JGg769/Y/OMVE
D56z46XXSoNtao659EkmWrIM3PZVRRpWfE9RuXoC5/fJtQ88N0nDLY0ZoyPu
OJ8fRp+7YCQNcSYl3f1HcH5ytlNzDmNHi6dvtmWiQVbNzl+3pWHJ+lLQZm0m
0n3ImC++Iw3716SZ62gx0dUtJx7750qDr0ZL4mZNJtrswGIseywNPaM1Psob
cP2mBvQzqqXhRG/K7X4O7ofUzUFbPkrDw64Nlx4wcb9aXlgUKSoDaeKCz+Mn
GOjUXodj2pIykMxDNVEZZyD3u7wSo9IyoPWryLVhjIGcCfvQ3UoycLy70e3n
MAPtOsdjSd8kA1e+GgUwehlIdnjPjyxrGXjTGfSBfIXvYw2znOorMqCiMxUX
cRvf3+jZH70SZOBtqd/34nQGwh9gcbLXZICpc+NTXxoDlSzd+RN+E7/f9EmE
ahIDZWqZ1e/Kl4HdeWqDmVEMdDb39uGuRhl4Bie+fDnJQCK1Wc2z3LJw5sf3
5nZ8X4Qng4Nzy2TBy/v4ZktdvJ4M5cV5PlkQfBad/lKLgd4GPlm3JCAL6uEP
bR+oMdBVzefRPFRZoNFi0gg5fJ/L7TNcJS8L+nIpu+4vYyD+GJkylqEsrPn7
z9W/no4WzG9lEGGyYBdDjV6tR0dxI677pC/Kwic9ekS7Nh3Jh6lTFiNkwX3f
Z57rmnRkXPIyrCJGFtLI1hDR9XR0TXLSZVOCLIAtJ3JUgo5UR3asX5cpC63Z
10pH/tKQc+ivcmaNLPxsCH68vYCG6p5ua/sxKwsrZcLnQmk0dIke1Ph7Xham
ohrdFgRpyOJsac38oix0J/FWnllBQx+0lPMFeOQgIdl5lc0iFf16JnRRcaUc
PNPJc+wfoiIW6t7kJCEHo1Tfii3P8PfPm5PX3+jKQTfX6tPdDlSkMJjunB8o
B5+bZF+gBAo6OH7bsvW3HLAdxGL29wijg82zu1I95OHOkQpHB63V6K8/f5bn
mDxIaVqyMuuWI/el6n0PjrJBWVb32tsTy9BZC47n3yE2TAXc6+4/tkQanR2J
GTimAE92yPU+lvxLjnvvEdDtVYCyZXa+xzUnSNZ3dJPoU4Dz4Y0Bz1gT5K7D
Khu29yvARs6PLnG+CTLbkt/OckgB8j5Y3FnV+Yvcp1KefeynAnhMBBx/6veL
xBdeSFpSgEtVbxM5YeNkvP1X3zFpRUhy18lQqxoj1YkzA7cPKsJc4cCofeIw
+eKQi3jYIUVgBRWtQSeGSZuL+8xdjiiC++rlw4Ymw6TPK/3yda6K0OtjNHiL
a5gstVl1udxLEZo9RUbunxoidd2yNdqCFKFzZoxfwnaQNEjoDOO7qQgpoeX3
HbS+km1PX5WN3FIEsuTAjCXjK3m4s2rsdYYi6D6KfXnkdz8ZJnnXNvGuIkwN
+g/3FvWTdTkn18rkK4JZ8D2VdRv7SeOKFW3aFYqgaLrznaTGF9Lyq66cZ5ci
jD5QX16Z1ktquth1bv+gCHXbPIfHD/SSosPesTI9imBDT4x3VOwle0cfTrd9
VgSR/Xf03hd9Ij0npZt0hhUhPLKDx7mlh4zhXua9/I8ibNoZqVPG+Ei+kHld
d4emBE5+lH3nX70nc7OG/c8zlKB9WdveSynvyRg2r5qtqBIsNASz3h55T1py
9K4LSCrBr6mbvItLnWSvasGJU/JK0DLynRjd3EnO6SUx9TcqQYB+++GVxe2k
xn5Ht25zJdh3vdn+UEcraZwz5PDRUgmMxuP5L+e0kgd+nt79yVoJQuvVN/w9
20peColW/2KrBJum6HNXRVvJ/uyShZEDShBpY+NW59RCJv4QTpjxUoJ0i1NO
V8b+I38F1z0TjVOCtfpGDVYFjSR/o8VD8QQl4OW9b9dwsJFkUT7elkxSgodN
b/orRRpJ47sT4TKpSuDrYDWk7POSzHwpbc7JUIKucPM7FIMG0kLEv1+rQAlW
LYn9FJ6qJR9nqayyfasEzdKf7sedJMk1KUTGplYlaDxVULx2tobMumSlwXin
BMdnnBxyw2vIZO+zju2dSpB7z8KXSK8m/bdX51v34vVGRfyaaa8kjb6ZmVn8
UIIeky0/o8+Uk9WfDvSpjuP1TLbkqqwsJ7XaTvkITSjBixbDuaI7ZaRyZfLN
/34rAUWl8vTBzlJS6ErPmOmCErw5tnSHMC4huzd4XjFexYGcT81CUrZFpLVi
sNwaQQ586+GcfT3/hHwjHl+yXJgDLhQnX4c7T8ganuJPDVQO/JHYbyIxWUhm
t8+rbJfggKGT/RFD7QLSyy+22UCZAy1P1UTTNB+QI563Dsut4wDloBux4uZ9
8tChgj9cKhzwOWt/S4fvPrln1ztptIEDTv1H5z733CN1WJIn9bU5sKtGVmdL
Vg7Jix4Ib9nJgRVB61+tC84id19wcbc24UC5BINpPZVJpujL1h835QCTulY5
zz2T5FRfC0iz4MB6VtG2l+RtcldFyOC0HQfavVMq1F7dIJP8t4CgAwf+maiU
+XVeJ3u0/9xQ2M+Bi+/wHXMkjfQq87C0cebATS7+v/FiqWRCsW1loRsHjtVy
zY4+SiI/eFOYje4cOKDptG9DbyIpr/Hm1GdPDojYU406qIlk8RMDJaHTHKiu
jER6MfFk1+P1CR7+HLjWppZO3RtLynkNfw8L5ABt1FsmZT6GdFe5s+NGEAe2
uR2v6noQTc7niy40hnLA+LobpLMjSen7PK5Klzgw0FR2ihEcSrq6VT/Xu8yB
ftGoigT3ELKQ48fae5UDiqnCujfIYNIg90dreCIHeN/q7uN5FUBecslbn57M
gbjbR59MDfuRbQpHoopScLy3Tmw5InaOPHq3a+uXGxw42as+WPXIm3x0OCl1
5iYHUr4OL7tHPUP+kTOfFM7ggHLpPxvhmFNkdGbtPf27HGBHFYiU7PEgWw8G
89jm4PguqHUHPHAjJWR0nE7cw+ML+vLqsY+R+bceU2/mc4DBZRNeGnSI/L3/
+Imnjziw98W7Rx9rDpBbWQqNTQUcoFddltjW6EBGfOyV73/CgexvLWZ3Re3I
5hvXg2afcmDeLNNo4aENKeqwp0uklAPSQ3Pc5tGWpLO4sMaacg7IuD8X2Ghj
St7venWFqODAXe+7N8rkdpCTqRdHbKs48N9IeqnaeQNyix2xzauGA6ZJeyvV
63XJi8y5WxGIA4fWZ8p8u69Bvukonrn5ggPChJom3+51JOPaSZviOg4INZ/b
u3RWjjywZ+3j1w0c2C6muSPwFo3MpQ2u+NrIga4fdj6rnbjJ8baMI3NNHPD1
eqY1NtNXo53oUEP5jwO2GVub3tXE6/8PkTm41g==
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJxF1Xk8VPsbwPGZM9aSJZozlsKMjJBokYTzVDJFIVnTFS03WwiVLJWrBW1K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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 11.900526240560039`}, {-9.999999999999883, 
             2.384963436032505}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Hs81XcYB3B0iiS5p8lBK19NjNLRku/vm0UhFiLmIOR26KBWmUXkMtGG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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xs01GkYB3ByrSXjrmZRObztOjpEQ0a8KQ0TI5eZ1o7MHIuZpdNOKy1b
TYiOy7bKUBJzltza3NbJbDL7e2Ym7KCbS+mQYkMX7a5KknLsu38853s+/33P
99kY/11k4iodHZ0wcv+n1fGLOU5nEd6TPCKe2iGEIwx22GZimecqL7mfEIbn
lqzdiP+8Zb+ynykEWWJsPYP4XSoq7fcRgkW4Y18IcUp7jqrNUwhmm2rNJMQs
c7FV1hdCWKNtLVcSV+SMttpbC2HFUtvKPYdwXUh8RtNDAYyIJyurihGW1q/v
H0EC+NA1XzgiQ7ihrdvxenYc7LlRn2hUivDBvIXJoYkDkHkwSCfiPMISceCy
l8cB0HcZv5RzAWHh2s660DOxkFYhWBwoQziL6SK6MsYH88YsvK4cYQ6/Sb7T
jQ8Lmsp89iWEB+ciZ88WfA3a8zWy0grS9+h9Y+fRGJg6XCvvq0TYvFE/W7It
Blxngko/yBEe2Vew8l72FQhsB0IDf0EYx8TTuqb2w3g4zyCtCmHvR73zrJ37
ITioR6quRrh5LMSXdpYHj4fuPzWqQTiNni2z+osL1LdPQnxqEbbsyPAcCOBC
oXJIkl2H8AU791WDRdFQbaMpU9QjrBqmRxfORkGd26Us/SsIK13yG/O2R8H9
cUte6K8IX52wl2gKIoFTetpVehXhUSeVQ/uzCLi2ekrd24iwBWt98ywjAhJy
mTErTQj/UOMrGDu3DwLKtz7a0oLw1B9Og2YT4WB00GpDeivCjvOMlLlMDqwL
mku4+hvC/fc+LO3aHgZ2Y4rkxTaEPWyPPXF4sBcC19jHBlxDuPhuZENqBhva
8QmOpB3hvn9oND+vELD20up2KhBWZyU1FA6xALaYKv79HWH3iuc+4QV7oETz
muvQQf4ryheeYQUBz1KtSLqBsJ2O7eXIF7sgPqXA7mInwi3LVck/VQcCP9Of
Oa1E+P1TPb8wvBPkFa/i6BTCIQ+PqwxmA8Ak0vfQXiB72uhuFcXvAFHX9/6l
KoTvDE4qH1T7gol/rVmvGuGf+2+Oulv4gPyIpsrmJsJ+pmvtLrK3AX/3Sce4
LoRX85JNFou2QjydIS/qRribzhAH6rsDr2VkfLQH4Y+zGm/GqS+hhJ3qQNMi
vKnrVjTwnWFZ2swO6EX4BU/W7M3ZAFGSYe+8PoQ/HSrpKK+1hjfieefOfoTX
xNwxnhs2BAPW0UwV8Y9u0s+KMwzBznlxtJu45oTlWi8HQ9gx+bHoHrEtZ84i
XWQAeTF6S9PEu02ldJ0lPbBnW9yh3ULY4C1rM81RF4Jd3Y8mEftV6omEgwsU
f3XbvRTi7HahqIa+QB165ul6mJh56rLoecI7SnbZe+IY8fT1cZHk/VvqMT2A
fY64JZgpyvz8NZVqwnFQEh9uaurCt2eo0y/vpquJve2fabSCaapMGzHUQ+y8
ZKje9+YpReVw8waI5dwVpdB2kjJejn0zQ5xoZSzWvfmAoo89Dn1FbENnfmP+
fIja0iGsf02c78GN22g6QEWlJcR+Ij75sqwhu7mHSoqaUejeRnihWCCvXlRR
6R5icyNiw+gNm3NzFVSh2csUE2LTeaVLgWcdJf87pcecuETZcUAljfb/D5RA
RFc=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Xk0FVoXAHBTUclM5EWkzn15RIkeX9dJKSFDpjxSScJFMkV5hpKohAwZ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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xs01GkYwPEpt2i2GTOuq0Yr9nVWpHIptfO8q6gkFZlDOZGdURkb1ag5
idWuLaUtYuQ6NW7jMpjEuI2fS4xbN+XSSbS6yHY4lRwn2bJvfzznOZ8/nn+e
7w+hkb6CxTQabReZb9vobGbCqmSEra+tcbA6TYHIxWuXLfGq0EcDTSIK+t9/
NrYntloXHRt4goJUQZDchVj2qOFu8m8UsHZb9uwg5rA9hQu/UsCwKmREEUvS
goqf7aHAoEuZpSbWu37R6vpPFCywu5T+KQgLc16a0EebYOjIWK7sGsL2jhsv
GW9ogrn2maShVISnOUnxnFw1eDbIBXoShF3ETPlaHTXER3jQ9qYjPLPfNYAf
0gjaP45kJ1xHWJWx/3K6pgGic4I/9WWQ+2DLnROWDWCoOIfNsxAuTzF123q2
Hmbbci96ZSM8xaErbrysg670glRJDsJy57zi77l18Op4obQnF2GB3MlWkl8L
duMekjkpwkV/fh4yp9dCsGmft/tNhIP/PcSiDqtgZDdPJ1qG8PLSjgeH7tfA
dg9NXGsewv4zPaY2tjUw+njgpV4BwstKtJKnE6qBOvp8x4ZChO/VbUhqnrwN
SerHUX8Ukf/4MgwV225DnklbhkqOsKfnC/OM8iooss8+p12CMK2dV56vWwUD
I2yedynCmxVfo+pDb4GP5LxdXBnCse/yau93K6Fa/1VrtwJhN/VEopa1Evh/
bQpcKEd4ttO/IZJVCZC17plDJcLnJvGdyRfloBdhtFKsRHixdeRYcaYCzD3e
88tuIXzFMF2HH1YGZsOq8E9VCBuxaHDQvBTcDVYEQTXCN988fBLxqBhqcKxP
VA3pI8oSn5HJwdipa1GjCuFOtty+k1cEzQ7fqd7VIsw/qphgWRVCWtsHf049
wrppZtonP+YDj92qCmtAuKCv04lVlgehwktmmY0I7+qIFCrFMjgQz930Wk16
9+6v/Xv1TZDmTB60oBD2Noxl9U/mAt3X7djOZoQbnVinay5nw+H2E1xJC8J2
cfa6xnMZQOcWMrpbEa5Y7yY7kZIOUlGbzOQOwmsZ98J8ZlPhwNbfLQ+2I6xJ
s5/yPZwCoRYu0qsdCA/TF76WLrkCvMqhkacahJ03V4oVw4mQ5nWSw+xCuHqL
u0GpbgJ8iavwgm6Eb3DH3KZT48Avqt81sYf0usJbetFbBNNHZmwaexHebrfK
1DFcADrbTsW3EHvO/zJ3wUgAZjafnnYQb+kNGX5O8eHnsfmrD4khRnrjKpsP
iYFan18Tu/aa275Th8IKL9Z95l2EbWOYGysYIbDdzvFUGLF1+nxNQLg/HNCv
eigktnLZeGZJ8z449ma93XFiy8FT3Dr2PkjNd/0nhni5y7TGtMkXRi3AK4XY
aHBiaJCxB07SfThqYnaE4mNJuAecf/tA3ErMVKCz+kZbIaNr72MN8bLV+dpH
m9yBSvBP7CM2UGQa2zIxLPkSND1OrB+wLNJb6AwWw6Pek8R6T7Tjl1LrwKE+
RP6BWCdgPrmH6Qh+0fyg/4i1lX2ClAgbCPMbVy26h7CWkrrAYK0E8dojhnrf
HBLoZxFpDEmMt0I68aKWMIc1Ih2QTgk1hsQ0WrxzxG4R93/OrxqJ
              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {11.78, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{11.781520978154438`, 
            11.900526240560039`}, {-0.007080885139952484, 
            0.11900533320983492`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxdl3c81e/7xyki+UhWg6JQqSQaoriIMpLsUckqomyyN9myZzjH5hjvjErh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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw913c8lt//OHBu2SO3232nbHdCi1CEnMusVBKlgVSyV2VEAwkNZEWiRAmJ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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1AtQy3EcAPD/ppq8tqi2obJWLa/UMN3K5tnkkbCEnDfrsrNEXY95hCOP
K0cnyUoUWiFCHhcxjsta5T1vi4Zmm78x8yiPu75f/e/+97/P/b+v/+/3//85
SxQzl1MJglj05/x7vXo5XJQ4dbeI+HdYxd8dS/fNbKkXd9h9+0Pa6MCX4EhW
qzLI3wiWhsb3E+82gy2MzEu+UZ/B2doSWzzdDjaZZvcYxPkBXl11K6XVpx0s
OySx2+WUMR1OySeLRyV16fBV8suke6wYZ3BmadvQ9CAaOHFbhp0V7ArWao9I
5tK7g7dN2OvyyLMnOIZuMN93p4Nve5uDhKkMsEeDThWY7gZmhTg3GhN6g6cM
Kbp4U9EH3LXpXXWzwh2cwctKu7vAA+zN3Em+XOwJTr3QHHRlFhMc18W04dkY
Fjz/KmNsFnscGzxqHVvK4/cFB1eIHs0S9ANXbemjqB3ZH2zqJar7xfUCx/C1
z+YGeIOTaZVntjJ9wAxNsc5BGQD+GaUqEm9C36gaf/ejA+33tmBReQYHvNBS
GN1k+886x+S8lb5ge5pLsdyETmirmaNexoXnT57Ok9tb0BOS321/s8IPbFkj
dRW+QPPFSW8KF/qDo5uFHPlj9PD5cfH6qADwyeKh3Wc3oJ1q1fQwCQ8cumfe
Fbd69HUKWSRtqYH3k1ETo09ZT8D85v4qbZ6CCj57SyU8vtQJ8u/IqhkNT3C/
PzyXxU6rw/1e9oXjlHEN93uwH/GVUoHrExxuUO4MxPWwHk0yNJaivcuosoAd
OK96AflaYsbvJ+SOv8Y5B/u5x9l6KbthPv+ppNpoxfkPW8tac51xnmlejR8O
RGD81oRfsWt/4HwMJXlNXIn5EcYszicjE+tNab25mY35UqGqIicEv+c2R925
UC72E5GZSutnrL9/SWq4jx7raXaQp8PcIF9cb0gd/o0K9cW2lfkumq8Y//a9
5FjzDOw3doA18nwT3v/OV511o2A9dcDliYJ27G8pIYZlvcL4XQbJqeUcrGct
FHAuuWB/z/byRooO448LVJXRbIx/URs7SO+E8fKxIzQJDzA+MZs8kT4Q46nr
PFgFXXH9zr+ShER4dNwniI1m11yelgl29Dx6UE3jgjv/3wmi8/tNEL8BngPL
+w==
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{50, 96, 94, 91, 64, 71, 59, 67, 41, 60, 42, 43, 44,
                45, 46, 47, 48, 49, 61}}], 
              PolygonBox[{{93, 92, 87, 84, 90, 72, 79, 11, 54, 12, 13, 14, 15,
                16, 17, 18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{1, 95, 92, 76, 81, 65, 69, 53, 62, 10, 52, 9, 8, 7,
                6, 5, 4, 3, 2, 51}}], 
              PolygonBox[{{93, 94, 85, 88, 77, 82, 68, 74, 40, 58, 39, 38, 37,
                36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 57, 26, 73, 66, 78, 
               70, 83, 75, 89, 80, 86}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 52, 10, 62, 53, 69, 65, 
             81, 76, 92, 87, 84, 90, 72, 79, 11, 54, 12, 13, 14, 15, 16, 17, 
             18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 75, 
             83, 70, 78, 66, 73, 26, 57, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
             36, 37, 38, 39, 58, 40, 74, 68, 82, 77, 88, 85, 94, 91, 64, 71, 
             59, 67, 41, 60, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 11.900526240560039`}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}]}], "}"}]},
    {""},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"9.704901501457949`*^-6\\\"}]\\), T: \
\\!\\(\\*RowBox[{\\\"77.69462845773928`\\\"}]\\), \
\\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\): \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"-\\\", \\\"754.556911398269`\\\"}], \\\"}\\\"}]\\)\"\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         9.704901501457949*^-6, 77.69462845773928, {-754.556911398269}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwUl3c8198Xx5GEZBbZq2Tvve6xP/jYKiQkNBQVSkZkV5JECQlZWZGRfWWv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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwUW3c81e8XF5JR9kpSyZbI3s+xLq51VXxpEBkJFZEikRCRQvZ27zXKHve2
9CCrJTspspKihUSK3/395XVe5zzPmc/nvN+87HE/e9CTmYmJ6SYrE9P/f37g
83sqkf3QkClS6/ry0lqTrvdu8h+vTCTzjHpVf4sudh+fPNPuVYbI24XJdDYi
XhZvG7jrdR+5f9Z8eHzzEQyPGq7neXWh/jsBSiFMp7Enp9JEutcwSjwk0Xlv
/hL+feDzzVSvWRTKJNG6kBeP24494emS/4wCplzdOD1u4NvXU5P/zn9GbgXb
LlyVT8ByowZpnufn0MbxR9phdYn4SFxKrlbkNxSX/d8xsce3sMv3vMGv1gto
RVbvxqbBFNxsZj6d7LWCKri9h6tPZeIlppQRt54VlPMY2PzaMrHc4/c9B3RX
EfadlQnZlYVvqwY29W77g4Ijd2me68/Crrvy0vka11CAd65xqWoOXl9ZsEhm
2UCVzWf+Y3uZh1UbDJCb/wa6IP+HnLAjH3uejdM48GYDPdYWo+qczsczC9zJ
pxyYIGhmqoRtcwG29aGEs8tvAq7W50mCooVYwvG1o0UPM5Sc22zuqVSE79cv
2atsZoGYudNHftgU4YN8YjaiuiyQ0L6HtuFfhGNfepjMklkgSaO5u7SiCH8z
/qMcF8IKe46eMtwsVYzjCncpnqtghaq9m2yzoRhLrpvKOE2wAvlKyqOKY8XY
8cEtcTmrzbClMgcTUovxE2Vpji4JNnhkxRKu96cYO90kstYcYoPXG4MOpfxk
vPDl7EZGHBs4dr/su6FAxjIlD395LzD0TfLjjU5knCROmtzSsQU2PI4OxVeR
sVxo8Oj3P1sge7PUxcJWMm59kz38RpkdmipNp+WHyHg55WN3aRY7+CSXrqas
kfFxjrBH5v4csI23RLEaUfBClL5SVT4H8IccabawpeC4v//yBXs44KtRfNrJ
YxTc8D0yakKVEzrW/aZ3hFAw0cd4ydyDEyxTq/vvX6Pg8UkWr6o0TlC7/25u
8BYFbx2KtQxbYehXuKJulVBwsZ3Fowl5LlhtzAtWrKVg7WccShZHuUDcUj2c
8IiCu41f5FclcsFiVPqh8TYKPvk4kVfoCRe0qifUr7yi4BUN26iw71zwQvnt
f7eGKDipmmdpYvdWIJmZr5HHKPhhccqbqmtboWeAZkX4SsEk8cOWQo1b4f6s
YEP/IgXPpAk9CpvZCkZ77l4aW6Xgyzxv9k2KbIPYt0ejvDYomD8+M9/CchsU
+/E0+LJScRnzEd7q0G1QrXF36Ss7FRte3hElVLENnt/iU/i6lYoHfr1fDBvd
BtxDCro+vFTsczbfc5KbG+6cfMfpLkDF67OubyyAGy6lske9EaLiO+57LKsD
uGG4OSPmmQgVK7yffChE5oYXhDNrWtupuNmBsu/yADcIHzz3TFKMih1fe+ZP
buaBS236Y/EMed5CltdSiwdc+fzN/BlyVOvs1epTPGBocon3FeO8qP7dRaFs
HkjyeEsqF6XiqkZfz8sveKA9YrMoM8OfqbLSm8m/PHC0IDjkjSAV+x8OoUiJ
8ELHq6JIeX4q1uZzGn2jzAvhQsxmK9xUzNKtLZxgwQsrkdxDJlxU3H1ju52h
Gy9UiiGzrVuoONP8z/Wfl3hB4CsXxZ6Zik+yvmumpPBCMfNXFsF/FLy/5dHq
f/d44bXnkQuHfjP6F56rytXGC3OOV7fx/qTgp7rhvk/e88LSbafvll8Y/fx9
nBLwixf4SLH/bZqiYOcGw1Epbj5wMOyM0nxHwVIBu4SHZfigd/Nw5ec+Rr+/
jF83dOID3HV0+XkzBceUtjT/PMewF7W4uUpj9N+jeJUSzwdnPi8Ll1Yw+j96
0pfrER8E3k/6FZFOwbXZppQn/XxwjfPn03s3GPPwn/RowDwfnIhlv/jfFcY8
9M7YDu/kB47TfXHKHhQ8erPzeoImP2j9Dr92zJGCy4hlzYZ2/JCRGEHltKBg
wzYfVWokP+h6Gq3NyVOwD31eKHCKH2Dqk3L3JzI+ohhkVr7GD92s/y36MN4j
sWAtaFxAAOZyd08ktZGxwnXOAVtTAUh50YSDC8j4i6NciiJVAF6sKXxvtSPj
kefVLe5NArBQakSu1yXj54ZaP7MGGTLnCbkD0mR8V4ZAYmcThF0pMy0DK8X4
9PJJ7o9eghD+9fLvl9nF+MjpOQPxCEHozFRbVY0qxsSxQP9DGYIgq/4fq4JP
MVbouPqypVMQmo3VTrzSKMZf0gpu5MsJQSd1bNvasyJ8WuMdm9MXIZhu9E69
PlaIj5S7a95iFoZ7BiUtRFyIiTu/eHaICUPU5PWQ8oJCrLB5tU3dShimZscp
+q6F+MuA8DW+CmEwS9yIL6wvwKeDDm489xeBruez1k2hedi3/tlvg5+ikPg3
Pn9nXCbuVim/E8W1HTi12SJS92Vi1aq4A53S2+He4rZNrj0ZeKXM3Jd0ZDuI
B6/t3yScgWPz28fcn26HBI/vwg+z0nBxfEv79TQxCBk/dtg8JgWPuD5I7dUR
h+zEc0RbpjhsubVc2TNqFygbipY9CTyO7mYMbfmcvQskuMLFFf65oa17Wcf9
6ndBqavX+VjwRN06rreDpncBLE2eJLf7orv1N1aM9u6G7z+b3+edDEIqE+Bs
H7Mbzsn3ahVTI5GefqXYOcs9kOxhvzSteRPNb2pjq3PYA5CSbP/6z02U2zmy
sOi2B+QVEy9uepKE1g+yvwgJ3QMNWbYbgntuo2afk2ER9/aAlt/1AzGFyYiQ
sf190jZJIPNq3Ey8cQcdXIjJq+yVhPQpk7rmtSz0+LEFLI9JwsqSqAb9cDaS
vc41ZTgvCXsSAiq+V2SjvzuS5XrY9oLocL2W+NEcVGKWW7+gtxe6L6CKPVW5
aDWz7plWyV64ZLnBM7CvAHmcDPaLrN8L+SuShq8uFqBuJW2eZ817YcmhPmjq
aQEqbm06fOTdXjDuXnGrVixE1vNdHy7zSsHWAI+Gew8KUSH68KslVAqqdZh6
up4UIU7O4kzOOCkYmqvepDlahIIHPPQOpUkBm3PrKcm1IkT0+RI5XS0Fny8X
OgVrFKPFlF9cWz5KQb6I4socuRi5HL9fZbcgBSNBZ5z0nhSjLtkw+8wNKZBV
PprBMlyMch8zZciLScN7ibfv1zjIiDDDJWltJw2/qZvuh3iTUU1Nd9udY9Iw
VsIJoeFktCMs2XvURxp25GsI/Ughox88IpVnoqWB2i8VrfaYjI6MvLWjJ0vD
6Y7lbUw9ZNROyV3YyJeGfmHuNoMpMsrWkdROfiANl3Tk0jjZKYiV9ePI2w5p
UGzWLszcTkFnu0vDJQekwX/bXXqaAgWZnlR6Wv9NGvwGn8+NECnoa6K27dBe
GXB3+pQbHU1BX+ps58dVZKApb2TEOJmCZoY9bswZyMC3rIYDgXkUNC6V3MHk
JAPcn7LfSjZQ0Cix1IPLUwZESV5R5CcUNHKuiVk4UAaUC9MXU7soaODxZ0PF
RBnYXfLgQ+sIBfVObrzXyJKB8TLpF0xTFNTNLhwGJTKQpiYWVPmFgl7s37fd
ql4GKF80Grp+UlDXYWO6Q7MMBAaKeB5coaD2UCeHE68Y8Z49foK4TkGthWcW
T4/IwHBMSUQNCxXhjujk4E8yoHMkOTeanYoez2crRy7JwOztx7c7tlLRA/7a
Vzc2yYJld4fGBV4qoml3+qZxy0ILzdYzVYCK6l1GOQp3yELDt4WVncJUVBO9
WHpXjiF3cHYJiVJR5V0OQqOGLBASEzpDt1PR3Z5d09hYFkTvi7LaiFFR6bJG
1HM7WXhpEXQjkSFTxK13Dx6TBTaDE946DLnI2P3JBx9ZOJ2aX3qIcT7/1MVj
Xy7IQg7x53/vRKgoJynpz9I1WTBwE4vpEaKizAZK5sZtWVgcfKenxogvbeSh
Jme+LLiV/o5jYcSfwtQ7IHhPFuQHlC8ZMfK7JfMpcNd9Wfh5hLD96xYqSrT+
x6vQLgtHdf8FszHqEx8oUK3eJwucAcK5N/9RUGymvA36IAsTJwbyon5T0LUn
aM5yXhZsVi1qP/6goMhph/jDq7JwLXVIjP6ZgsI5/WRd2eTA/++sxO8JCgpV
iWr3EZCD30zzm0reUlDQ5apNEUpykMJ7/oJ9JwUFFLcVxOvKwaXG7tu2TRR0
pmvE4I65HJTLP895VEdBpwS3hJa7yUFyvV3aTA4FeeruFG04IwcSJ2u3Um9R
kPsJNdqTMDnIF3KPHYiioGMVrgv9aXLwp34g/bo3BTn3Bd8eK5aDg5FnJric
KchxJWH/52o5eBahXMTMmG+S6f3T68/kYEqp/bTl/+f/Pe+U3LocXP6QfNty
moyMmGWvqnHJw+VR+rczvWRkKGewy1BUHvR1jTI4n5CRdpDP0UOq8tAlLV5X
kkZGiltb+8O95KH06g+FSEMyktGJ4CkLlIcI1oC/v+XISNJL36rvijzwFpd9
X+MnI7FmWqtMBsP+s1TA3Y/FiDPoXu3rTnkI7yl1ro0pRl/e3bm1R14Blmgf
t0zXFKEZ9oMvrDQUIPGp4hO3O0VoUoNnywUjBWDeJLUvOKQIjdyKv/LcWQF+
bPnKdEK/CD03ueJ//oYCJIsoE51bClH5PW+r9jkFeMnjVfLrXAGiDEtd//5b
Acx4kYSDYgEq3DzZup1VEcTC+PavTOejTNdjumfEFcEiNK2PxzEfxQnYy4vY
KMKl60+cG5Tz0Kkw3S0+VYowKVhy/lAr43tute3p1oB98HmCGLY3MA29v3yh
0eDKPpDi4Muc4k1DKVUfSs8k7IM7D3R4uavvoHW+usQe6j6wkkrkqvycigaG
HR3vjOwDYSnZv65OKSjKq/DzDlMlSHZ6bL9ZPwm9v6rGqyiyH+5deUNSb4pE
Kfedj1s2KcMW0Vs6IdcuYPOfPl+zninD1GjFnY69F/Ff+dDwL4PKoO163jLy
6SXsmZOdl/BNGZqiyjQ4N4Vjcfz12wyPCuw7rztW+eAq/la0X1neSAUWH56b
lBOOw6neNdWVZBVI49jK/0IhBX+7dv/3YLkKyBS/tPOLT8EWhc1ovVoFjEYP
9mZ/SsF/h3te2z5WAReB4sT04lTsRfz5/fuACuw+NevyjD8NayupqqiyHYD9
eyce7BnJwKML9TW0UwdgJKHqzpdfuZipyXMZnzkAqxdi56MhD0tdF9F/FnQA
Utdcb567kYf9doR1vos8AM59WS4a4vn4j4nxGFPWAbB4q2loqVWAhdN6uKye
HQD9epNf4tRCrOsaZX/49QGQ8o8TTW8rxMfl1TOODx6A3bpuNvemCjGlKUPy
3MQBKAhX7CzZXYTVZlx00lYPwNCXnVyv0oowSeur1wd5Vai5RLCz9ivGQZsK
KmaVVeHVCvcRjZhinPGCtPBTQxVebOXUqskrxmOuDeGsxqrQbnpss/OrYuwf
F3ZH/ogqJCu9NvGSJePbB5VGVE8w7BNvqLzSJ+MG8Q+79L1U4Xvq6v4WezL+
W2N8zzZQFWSYrpfbhpLxjbccredvqMJygt3UUjsZV5EfbQm/rQqiqlx6D96Q
ca+/v01suipIIqnYLZ/JWJS5dzizWBXeLxw+C5wUrP8ySqK4TBU2XnywVBCj
YNd0dY97Varw9VzV7VwG/i1RyPze9FAVdl77907UnIKfL1lqdDarQo/kT3FJ
Bwr++mQttKdDFdQXuU3q3ClY/ZAr21SfKqzdqKZ7XqZgp5181vPDDPtoqnFc
HAOff2pN/jWmCgUuLxVV7jD4Q5jMTvY5VeDt+bXBfZeCTS32P7nzUxWMBI7K
SzRScJugpuueFVW46evCmosZ+gkDpqp1VdCxG3eJe8bQV5oV6W5Wgzj1FoZf
hj7UxriTSw0eJ088u8fgG+0Eh6lD/GogNrrnwiSDj3R88JD236UGTiLRLZkL
FEyo8OtYlVYDvOD1V4TBJzsvBnnH7lMD57S5/1gZfNLC7DK7gJoanA5eKDrO
4JNdfNHlBTpqoM5xrGwvBxVbjCUQ94EarHaw6zhuo+Jnd1Pn7hPUYF3q7Z5f
DD5JDMlJNLNRg+isShUmBl97bkJW6jukBq+zvdRChBl63nvdLkfU4P2Gy6oz
g++9eF93du6EGvhWXywpY/BB6/KHvBe91eBlm+ORkwy++DK4tZb1jBq4a10m
TDDiszZ+fjA5SA2agmYuVDH4+ivuvsWdYWpQbqJ2YU6CwcdLJzS04tRgx0yy
ToseGdsGfR56mqQGltuH1E88K8av4WcIKY2RT0RFYJhjMe55y/TQp1gNwiTv
H1Q7W4T7uHYb5j5WA+GYA1nMmgX44LDsB7mnatDteNqaZpmP+ynKkY3P1CBX
tCM37VgeHjBArd1DapC3/G/pR0QOHjrrQtj0Uw3mxC8x9zVl4Lf9ubZe0uqg
v92XtEX8Nh7P2e6qkqQO2pU74gMUjPH43FK39R11ANma6/krGmhcr8fQJ1sd
2mb/8/PiO4zG38VKFJeog/vR6nfbck6h8R1LowJYHVakr/DcexeKPuR0H/v9
XR0U3xXWDn5OQGM51448sdcA4VnhCHGZXDQ25/J85D8NuBBzr8+FNQ+N6enq
/j6uATm1/Vt+TDDkdz+2q5zWAKsjtW8/ZxegsR0ub4uiNIBvJjuj/2oRGs3R
doqp1wCXtLDlyUEKep/z1cFaSBOyrvrMPtl+D+l8k9gzv0MTaD0SqUOR91A6
kOYTJDVBk/qOQ/7TPWT3sS7qhbImJBILvgfWVqDW/ReriURNaLpTV07Ur0Ll
LcwclhGa4GHYNUq6U4PYBNUHZmM04e2+4vatLTXI3cuzIC5RE7QsT4aTvtYg
ca4uja4sTTDf8NY8bVqLbh++6W7eoAlT7YPktvladOGTyGOzz5pgJ+JxU0S6
HvXrWF7/+J1hf7mut9WyHqkkhh6MWdaEhpmO4in/evRZZXS2jUULpoPIElEN
9ehYaLGQqYQWpAu9mRbRa0APXvaPT0lpgajZpt+HjzYg4V2bK64pagHby4a/
G6EN6PVTb+On2lpw1P6fcO79BmS8Tems8SEtuOtKeT6wrxEVuLroTjprwYAe
r5mPRSP6W3trc9QJLUhxNpD1PNmIGh0Xclr8tYA7vVXsdkYjkiukd0GcFnz6
bBCXt9KIYhZmU8eTtECsf7uSEw8NTZqKuUamacFNrvmIIGkayv18+Rcu1oLh
j22/X9vREI+asSRq0oLbRVF3mfNoSFNt5xx+qgUHuP976FNFQ8fUVurhOcP/
FomfapiGytSqzIzfaIF95kTj9zEa6laL5346qgUSE9csxr/S0JKaxxuTaS2Y
er1DTfUvDYG6mI/ZTy2w4PcbXRGmIy/1Xwc6fmvBiV1tLP576ShRvecPYV0L
PMzs7YyU6ahO/d7TTlZt4HY7eT5Yl46G1WMTLbi0YYcdcS+HGR2tq7s5POPT
Bst5B/6/tnQkpaEvQRTVhoNCQ4s2TnR0TmOh2kpaG76Gnz+6zYeO0jVeXXyp
qA2/L6hYhJ6jo8caZUY2qtrw+kzRkmkInYF/rnF2a2tDB7wS8w+nI3ZNl35b
pA1PmpbzF6LoaL+mTu5rM21QDKYFD16no8Oagp4ka214WFyZKpRIR6Ga35V6
D2qDcFT417pbdFSk+XzZ3lkb5m07QypT6KhLk4r7XLXho+k+2c1pdPRNMzLu
kJc2VBfY/HiQTkeCWkftB/y0YSn7ZeeLDDrS1dIUczivDW6BxGLdTDo6ocU3
NXhJG4rcTgWxMeRYrfl7jpHa4ErpVFVm2FdodQa9idUGiwscfQ2M+/u0ig2c
bmoDu8BrQkYqHa1ohbO9TWXUi/YgZug2HUloO712ztaGpPjHiYE36chUWy1z
pFAbEkedY3zj6ei0Nrfb0VJtuKb5nNoSTUe3tT/Lv6/UhtkQglRwBJ3BZ9oW
jjVog2rMFq3YS3T0Xrvg0ehDbXhjRBD8FUhHzDqh0S4t2mCdrLfQ4ktHcjoO
Nh86GfH8t3vL15N0ZKujInyiWxsiLyjFXzhKR0E6XB/GB7RhX39OlctBOoNv
zpS6vWPoSZRKqgUdNeu0nJuc0IbF3ojHVoZ0NKOTq3NyVhvWdL357NXoSE33
4AuPX9rw19XAK3QHHR3RVbrzcU0b2j52j+Vz01GkLvtxL2YduCxx9cHeTXT0
UvfJN28eHfj3n/9Z0jQNLehm0WeFdMBT5aHW6gANieoFRfqI68D6aRt91nYa
8tBT4PeV1wFmmt+AMZmGbuhtfjenrAPc+VwOIck0VKM3TvbT1IHEDOF5ngga
+quXrnHGRAd2nknXOutEQ3f0mZ0DjutAiVgYcZGFhnSba35cPakDFJbph+Pf
GtEHE9e4FB8dsE3edoD4thEpWD2m1wfrAPvkxwupFY2o2fmC8PJNHVCxiXLn
sWlEXqNSVWx3dCDSrvPPvFoj4nLrNxPJ1oFjMYfkrcQakeMplWDtEh0Q7Y9O
TvjYgL5e+NIf+kQHOn5wZey70IBS/mT6JrTpwM+qI1K7nBuQ9hVzltznOhD3
VcQog/H9io6hqDYN6YAhgV9xx0Y9ErvjkrzxjeFvNKgnNrIeEWr7bKN36YKq
Ye2XNP86NK9+deaOtC4cj+T+pWdZh5LvK1+hKuqC69GA3+el6tB7nFjZoaUL
rFePJuW9rUWB3YStHCRdMOaxuvfDsBYVzD18djNSFzRvVtd2zlejFWmyacaE
LhTUXk9rN7yL/twr1VKc1QVz50ExsaFy9O9AhQL+pgtfjhz0pfuVI2bDRt5P
a7pw77/jR4YzytBWx873msJ68M+qM4xjpgTtip0LGiLqQW/jg7xhj///vkSN
KtSgB9/2OZP4WTNRaknb5jux+mDxo6Xlz5HLWLAmt5OeqA/ZryTjMpkicfqD
oPh3KfqgWqAnZ99/FWe/lNq2t0Af+Ju7e/1DYnDxQrRgHV0fxplR6/YHibjO
0Gxvz6w+CBkqsGonpuGeoXbYamUAtKwd83eeFOGD43nMKvYG4DJktnNOoRgP
fA5uO/SfAQjOZAX0phfj4b/SFjknDcDR39fA1J+MP0jG2ilcNoDZIu/gUAY+
+naG4GJRaQDPBPsvfrEsw9u2dIZF8xjC+wia0wiqwvP8vzIVhQ3B9W10xEhh
FX4usZfWJ24IonJNZ/4yVeM4zYgfuxUMQZp3pDDnSTVm9dLybDI1hMI/HumR
GTX4T1up7fIlQyhqHBjc8bMWv+0Z9M2LNATlVyxvBcTq8P33LPGm1w3heYNp
Y5xxHQ5ecn2acscQfO1kf08l1+Efe0W1lasNwYH7/XcjhXo8ExW359S0IfR6
y/q3QANuT6IZ8swZwq+CR8/Y3RowJXv6KO2nIZyRNnz+OLIBu9VBOuuGISw3
HhjyetKA30+scBZtRxB5WF64TLURP/oqI2exG0GOvPmGjm0jzl49bPZdBsGT
3U5JB3wa8X98tREG6gjWj0xvsctrxH3gs/TWFkGbRa7VgfVGXGudwXfVAYFP
iKX5mCAN33Zq3y93DMFkKtfjOQUatjm3x+eCDwLVy66h0g40vO+yXezOcwiY
Hj24SPKhYc64cHLbBQQxrx44v71Mw10Fb0f5oxGUH9JXYi6m4dJ7W9Ye3ECg
o3t9oLCehmPpGqJuyQi+ivJ3ZbfRsMnr5IPV+QhStY+l50/TsOQ7fNaRiuAL
ObindJGGmT59Tfx3D8HVALX3nMx0/GTdstPqAQJNcqHWqDgde93fM9mPEYip
1oQKyNMxd+Dq36MdCAR+v/YpU6djmmKvyPRLBCVzbx7nIDp2+Vim6teP4BhH
oeJXSzpmK4i0WXqL4JEl05ncQ3Rc5eR06vI4AsuSHr3yY3S88WJLfuJXBDzZ
e5xH/Oi4LObDfcElBA5SB0XXz9MxCdH7c/8gmKo5aHwllI4vXzYPSWECMNFZ
SzoSydA710cPsQCs0fbSUmLoWEpzV4rYFoDkvZSzMjfoeIU/ocCFE+CU8e5L
Qkl0/PL7ckXxNgCWKLN212Q6Lnzp/nCGF+B6j8LJzXfoOKi8u1NBEODIfUV3
tnQ6tojVHTwjAjD2lNzrnkHH4idLJuvEAC6Ff2sWy6TjH4j/x/JOgFtnvdF+
htwmfuWf7h6Aa1Knj+Ux7DNXP3NGSAE8kjkoe4pxn9+Qg+hTWYBsprDqJIY/
qG+R3qIIEKMPrHwpdCx4W0nNaj/AB49/6t8Z8c76ZcGtAwA8rNz28gl0/Nhy
s20/A45foLzyZjQb35YJOCqiDRDWkxFXe5WOPVhGTx3VA4jk72rdCKNj7XGL
CwWGAHNLD6TvBtPx1qaGa1NGALuYnzXXnKHj8azdybJmAFFtJLKANx03XEjM
97UAkNuC3/e50HHcoZV71VYA2qsDqd8c6FhlW0+H1kGAg3Nb/uob0zHrF72B
MAdG/TcXXzqnRcfDHaUT2AngtcXHzcz76DgyMuKvuSuAxmW3KRCg48PH5zgS
3QF8rots+r6ZjuV0/xPp8QRg/3Gu4+9vGu5Z3K/q5Afwkpt9QnuEhnd7j3mf
ugSg+zs/2jCDhpdMiMEVlwFy3M25f0Uz3sNuWtSPCID5tOsB3IE0fG7kZt7F
WICi+GfHfYk03Gxj0B+XCtCkuzvh3WIjvqNQPv4yHUDk8GIf7X0jPrVF6Btv
NsBh/yHKalsj5m2ZZ88qBEilU57fT23Ebuq5huWVAG8PEZ0PKDTipb4AtcYa
gOhg+07E24jjAszlWuoB/ghrRXX/asA1VQt8bx8ALKbYap3FDZhJ3vIjewcA
W9Q1rm7rBpy/cznh1BiAV1bhrTRSPVZ9/CIyaAKA62Pum+X99bjjSFFw5DSA
VHr60NTWevw1w9o18wsAp8QhgkdnHdbnJ6t2LQOUXSplE9aqwyNspLeyPEYQ
7e/9d3lTLT5Dle5W4zeCNYdmlYtvazCz6VorEjKCRKH3e1JrarD81ZKK/3Yw
7FdvymQfr8EX1/5GXJc1Ap6nKy68XtVY+Ee5zCdkBLebHx1MzqzAB9+yBJWc
MwLJE/eVFiNKsOClaOGl80bwL9Hj2gBvCR4S3fzAKMQIBDnEA0SLqPioE9v6
+3Aj0AkvDxnAFOzxhj1OIMEIMpbqUoKWi3Hw4LbcSKoRyNi6/bJOz8eZvSJt
R0aMwEVtf9woNQl/eKYoyGNqDBJW/3Z5c91GJxSF86XMjQET5sT3Ld5Gk4lM
crpEY5j2qi29PpKMZuwG9TxJxtD0OJFjvjQVfRu8cvLRMWNgPv4t4JV+Blqf
6K3zDjaGh9+poYLEfCTxJ8S+ucQY/JPJTMdmqKjwqPu7wXJjOMUs+djJtgRJ
Nll7zlUYw5/S7OrnjSVIJnLPJeF6Y9gznnqU9Vop2s/2otAPGwOv8n+p8cLl
yIBf4ofosDHMDEhdpe+qQMcU2pICOEwg+/zTmwaDNajV/VpGyFYTiC6ZvXnx
Xw2SzzEuDOcxgQKS/bSNdC1a5mqpjRcyATRfytZ2nsEXvzYNFO0xARCL82rn
qkPtNXSxPh0TOPjSAP8nW4/2fb6wd1jfBLyJX8RfW9SjlD2a+8aQCdTeHdLr
96lHJ1IaDL6YmcBHH7/KK3fr0Z/ztSeYD5qAW3j7d2uZBnSi4pwPuwMjHhWH
34KmDahzWjmQ28kEuARiX510a0B3HKquibmYwNKeB5ap2Q3oz03/xN1uJmC8
r64okNaA3Dr2pcl4mMDzPbr7hnobUNf6XN4+bxO4FGBt3DTfgPZr3StRPW0C
ejem9WW3NKI7Z09Xa/ubQFnNHx9WwUa0Vip/3/CcCZhOrsQNrzYg9/HZZtPz
JmC366mh8gfGfaJlz4gXTGBBr0GMo60BKdt795EumYCEfHu7V1kDSo+Xeed4
2QR2tdNXLRIb0Mk/lHn3KBMYeKGVkHewAT1X9fh1KsYEjAIe6/BpNCAV373r
Z+IY8Svzb98q0oDW3xXxhCWZwET4P7Xst/UosylfNTXbBF5Qriruc65H67+O
62XlmcDxLx3JX7Xqkef+naYFhSYgqibCpy9cj1QLchzulZiAK7/vhWu9dehl
ZObFp3UmUOhT29pnXIc2maY8WXzO6G+kv9EBvlqUHv43SK/bBGYfujA/+ViD
9tG9FK/1msAQy4e3/Q9qkKOCXib/sAlo+j6sKjhRg+7yTgcc+GgCmVkxlQ32
1ejgqIb02Q0TcBZS2P7bsgIVX3ib8EXNFM6sGRAW7lKRcflu54lcU0j67v16
5FgCyqAsLf8oMIWt34BDMykezRd03WEim8JCtnrV0pPrKC39XM+uclM459BT
3iURjWavNZu7NJpC6wv4xVp3CSW5nNB898oUfiymi+2etcIjAoUCg+umsGU4
mVX9dRJW5gmqnd5kBqcHzR7O2tzG0ZwWdkusZvB1pe1Sv1oyVtr044YAlxkE
BraA93oKjvyGmA+KmMG2nt8W32+mY5lnH350K5vBjVt95Y+T83DglV3dXSfM
gGnyxP3oa1T8KzR/u5iHGVz8l3Hy4yIVXwzZ6enrbQbCypvlyk6W4IhzO/5u
O2MGv5Ze+pobleJEdxGFQ2FmcPLDxuc7S2WYSuCJHU0zA6/76+ot2hVYziSp
d3+WGeioaIT251XgCrRtZ2SuGbySW+0XYa7EddpcDZJkM1gfNlVX7KrETxS2
THrXmIHoD/1IJWI1HubeMFh4bgZ/WzwM7/LV4qNcV+JNus0Al6py7DGoxWNb
/g3c6TWD3J0lmTtO1eKPTGu+WsNmMPObejDjcS1eWFjOuvzRDPbW/O2Kd2Xg
1+/BH1/NmsGhrZd712Pr8MrcksqueTNQZ7FK/VZZh9enFzpbFszAId+hQ+dP
HeZ68+0XGxMBOFeLXrkm1uOkfn8jJxYCcPTnjCZU12P+nvnEcjYC9PdeN1Lo
q8eiz77std5GgC8RxWYPhRqw1KMZ+2QxAsycGd60Lb0Bl9I98yZ3EsAeOQfV
NjRghYbpWbU9BNBu33jU3NeAD1RORgzJEoD93Ovz4tsasWHBWOUODQJUHChN
rA9txCWBqhePaxPAJFrJZM+dRsxNiDUu0CNAnWP0f6sVjXh0XumNpDEBxJVl
Oz4y9qtp89UiDzMC7ORppK0w9m9F6qBviQUBjtN41M9z0vBl3XAmBTsClHI7
J+Vq0PD0tt7nvgcJMLc45E5k7G/rCam0SgcCMH8OLDruQsPicS/lDxwjwASu
sK5j7P9HgzsOafsw9DZPZjc/Z+Db8rM7Q/0IEDjamtPzloZvXH766dFZArR9
wXl/Z2n4yF7fy+gCAYwMnkmFMPBH6/ITwtVLBNjzbteWdn46VnjOz/f0MgFY
bk7MBO6i4z/nHlIJ1wgQE2Hi/FWTjt1Nuc/FxRIg2kfV8oERHT8Xcdd9Hk8A
44fyP6es6Fh1rpF1600C+HX0bPgx8FLWE47XNrcJUDPZvfcwA08xpRzPupVK
gGcjL7iyvOj4lGftyd50AmDTvnN6DDzWo715v0A2Ae7uPLZfj4HXtLc6rxzO
I0CT5ibZTAaeK/xQ0ZpeSAAZN2eDgwy8x17PdHOYTACRM38P+TDw4LnYw/+J
lRKgeX+UzSgD/w47l+05dpcAh4KitlYx8CQo/Z3LqyTABk/a+XcM/FvGRKJ9
qCHAcp+9pycDj/IOkCP3NBDAJ4nUZsXAqyGlv4kn6QS4LiB/PomBZ8dCrYSo
DwnQ25d5WImBdwm2BR9mmgiwpUbomBxDrtqzWC7Xwpgvc6a8CIa98C9C0Ok2
AlgcI+1XY9x3pSvbsKKTAFF1/2RMGP5mcr6xf3tOgIxtTPnVjHhszxr3K3cT
YNcBu7sXGfHSjNPzAnoJUDs+6Z7PyEdC+It3/QABpj/Uje1m5Bv72UD11xsC
2C3Q1JkY9fj2OPmv5jsCJLybCdNn1Mvh9seOi2MEUHHVfTEYxMDPJ3WSH04w
+psaqPvSn8EXtG4e/TvNiLcjdWUXox9Lo+o/IuYIIKlkGD9+mI6P1cY9bPlG
gOQXXT9tGP1ti34fzbJAgFWbV/3bGf2/oxi9/foKAeIHCCrdCnT8d/3NVNca
AfJNmoAuwcDjfYpVnBuMefGrWd7go2O1S/3GSZvNobCFJ6J2mTGP3MlLGezm
QEWXpHZ8puEosm1JEZc5fLV4Z/6HgX/7Xj3jaOQzB5tkr3qxJga+lWzuebfT
HG6rH+b9EUrDmfTwqI+7zWFqsjKSj8EXsbWe+ve95mBWmzR4z5GGuUNoGcwK
5pBJezdhrULDFS8qXOQ1zaE5/3iI9WgjHjhxmldNh6GPu7sOnY147Zdsq76+
OeRp/xqsrWnExN1kaZKxOfSoyjVyRjXi2aCs+Qu25lCe9ePzXYlGLC0RG9rm
Zf5/fr+oyuDb1vUm+7p9zOG7OZ1FS7IBB1lsGnvjZw7eG72+LSwNuC3wstFc
oDkM+7PO+rbXY/fOQHb+CHM49ZK1W8mkHuefc013zTAHwyPiwTvl63DH5p0W
PtnmwJQ4kPSRpQ5/zR5ZDcwzhyNft4/DWC3Wb3c4Hks2B1HBsvMNybV4ZLu1
VGW1OSgXdPWXLdZgkafadX86zUG12CWJYFmN/Z2L+AgvzOGJwm2dh1+q8NPv
HAHJ3eYQk8YTdDChCp8Vf6csN2gOCn4LVX+eVeLO4PBKh0lzeO8mzRdkUIFD
5FrLav6aw2/5T19ubJThNzetCrwOWMBtByO2LtZinOHkktiXbQGxjsJKBMUL
uKJGpf9jngXoascpPb0aiFvZWcRWCy0gWiZROafaH3+7X1q6q9QCZj8pBaVy
uWDT7T9b/eotIFOu829y0TG08PbaKttLCxj/XrfpqnYUsj1a7qX3zwLkBPYV
CiVkII/6sEpbJktwad4vvf1MJgrlsl1yY7EEB/VbBTGkLER9tHA1jsMSzAM8
jlwTyEF/d+jnDQpZQgpThVtIcj66+767/+x+S9gx+/OEVUMxYnNZAoqrJfSt
XjRMVS5HTDdz2MrcLWEXm2tvyu1ytPbI+OU9T0vg9TCp/vOjHP3Ynvxfva8l
ZOQJ2/2pvoveDiqdaQ2xhC1dh9RDZSpQhY13zvgtSzgubLPnxmIVKrnM7Tad
YglyKsVvWInVqOheo8xsmiXQ5K7WtxdUo3QO1rrvOZbQ8rxZJF6qBkW0F3at
l1pChOEWI9KzGnTQYOSXeLMl+DY1nFnYqEXWflcf7X5qCbdHv419lapD5jly
V6U6LMGbaWp/uGUd0l+9sHXfS0vY/q/L63ByHZJuFNirN2wJWVXnWHt21KPd
0w9nDd9ZQqyHDTgY1CMxAfcq4zFL+JNx2+aUSz3iDqjRIU5bQhOr5KB6QT1a
2WdDcv5hCdW9Dl4HdzSghaNLQscXLUGQZLWmotOAvt7IeXdi2RKcvRwPZTg2
oMnZz16n/lpC5Kdos5VbDegFJTY8hJ0IYe6+y8t/G1BHv5JJGBcRWk1u9WwI
N6Jm5kH2CG4ifG2gWSSoNKKGE3vvxAoSQfjQpVVZ90aUL958N203EUz7K8p9
cCPqtOaXeLeXCKwGJ50PvWlEPy57JO+WJYITefspyrdGZDTKfvGeEkOWqFy8
tIOGTm87OvdDhQhHbu3c/k+FhlIMKl001YkQ39jwbdqMhqbz7M1adImgMhK+
9sGfhrZ1k++zGRJhQd3k3c9IGtJc/6VobUSExQ/V7Z6pNBTnks3/xpwIqmh5
ZyCNhhR3TX2YP0yE19uSJQR+0dBhO41Dqk5EuHTzFr8iCx1djrjeEXKUCPtk
/2gU89JR9wfFSmZ3Ipj0D5dUyNPRb54ruy08iTAZqmyMNOhoN/Sk3jxFBB5v
epky0FFgYVCo6Fki3NLafV7uMB3l9HR8PR5IhL21U1Iqx+mojWm7GzmYCE+z
8gzueNLRvIrvwOxFxnl95HHYn46E3JrM918mQvnkA3QuiI4Mk3kenY8gwt3S
Z2GfQunIq8Vt/4MoIvht9C4/iKSjWz/ri9ZjiBBUEVv5KYaO7u9hEzKNJ4JY
NHPeuRt0NGHvFBefSAT60ROth5PoiDPq7lr3LSJQ2R+J3UmmI9W6v2cEU4mg
f0KJvP8OHR2dtJ10TifCsFafk1Q6HUXzFzkUZBGh16NNO/j/f18xXuyaziVC
5GMJ2JNJR4OBZvoKhURAgn99GfsVrRdnVJ8lE8HbKOTBDYa9bP9nycYSIhza
fk/agnEfiUU//U85o78BdZUnGP4uqSVxQCUR3kiU2Q4w4ik+OX45poZRr98l
m8mMeF+kqv54Xk+EzNfPXr9k5LP0NPokL51R33DFu/axdCS+NDTk8JAI7kMz
yQeu0pGZlDwxp4kIPi/GY/zC6OjM4bCm8WYi6L06WcUcTEfp0a9UZNqIIBqx
9fgSo964YRfFt5MIjZYGH4286Gh2OkCk9jkRXqY5Zc8x+sUn1HZj+RWjni+b
X/9k9FPXTHhdr5cIjg7Dw4et6CiR+nC64w0RrrIU1Ktq0lHj4Fanre+IML3K
v69KgY7GNru+sB8jws4Z3H5dgo6UvVjq3k8TYc3Y9q4jKx05pTtIS84SgTdm
Kcd6mYYiO0ozveeI8NH1+N+iTzTUJ2MdsfCT0a8opv/8umjooSj7yMYSESL+
fU5jfkBDZM429W0rREisPK/IXU5DQd/0vsiuE2H8Ifli7HUaEqYpOhzntIKb
I7Ih7IY0tF76qfr0NitIKmj7e1iBhj5lkTkv8lrBs3vsqWLCNHQ/fEdzirAV
XGnj4haYb0RHzbgUuySt4NOu4s1dyY3IVKszZlDaCoQsdg7PXWpE++SvjU/K
WcH5rcSlRLdGtL51Le3ffivYdsdAxlK5ERUOfGFS07OCNM88w/sMvjx98vlQ
3iEr6IpWGmcdrkcvHWIP3HO0AiV/Fxbz+/Wo0dw48b6zFShues3Gl1mPYhUf
GvW7WsFKvFcacqxHcovlFex+VuCk2nxN/FUd8ouKjzofbQWSHGO6adRa9KvQ
Yr9lIyM/iTrZGp4qtPVOtWbmfSuwzP/w4HtlJZK8Low+PbKCw+enxo5YVSKS
/7RdTKsVXP2+lxdfY+wDnciAltdWYLQU6bht7i7y6KM36Hyxgs0a57Yap5ei
ARZZPYVd1kA7n6fnHFSI5pZvmlyStIZIsbAPN9cKEPOXJasuaWsQq/CVjt5W
gFR6Wo957bOGuLq8g+/356HEXJcrxTrWYLqu7L3inYVMNdJbxA5bg7X4SfeX
D5JRg9dmC654a3iXMbVMdD+BEnYMaUkmMs77Xe+TZj+I3HtKZHVuWUOZcvhm
uSMKiEfXYot3mjX8OEf45rL/CD69LaGjtcgarpGHRjvMgvHuBl6z0IeMePbk
bH9qE49/n5pQT26yBr7TBWOvdyfg7p11UmXN1nBk5pmU2mIiDrt+iHWowxok
vs1unSXexkNH0p8e6LeGfoP7v1JnU3HCJnHjz3PWcOD3DXEdrhzsTps/wPTd
Grp4PQdfz+dgbd+mPSIL1nDvk7jl/Ve5eGbAZZPZijUs3RjKPXUzH0NZUXMh
qw1seJCt3mwqwiLHA2voW2yg/U+AR97ZIvyNz6Swm9MGohVPpC+/L8I5YdMR
f3lt4FwQR8R/tGIcqNJ4VkDQBvbVSa05S5KxxccYVwURGyjmCGP9eJOMl21l
kdNOGzjA1O1w4yQFv2JZ2X92tw3wiJv5FLyiYMr9LonYvTbA5PKfXoIYFYf6
Z3HnydiAxY+6ZGmGbC95er1e3gYMtbT36W+nYrk3ut+e77OB3sMZvK9FqHg9
gWtsQtkG3KmmFmNCVDwI71+tqNrA08bYcR8BKq74VdHEo2kDj1v+TQfwUvG1
u+GVMjo2EP/ytvfyVio+4mqbZ6BvA7UZI9d+s1OxiuCum4eRDUQFYdtgVire
8uz7ZV9jxn2tfeNnNyh4LLzZL8rMBmL435z4tErBDarJx7IsbCD4XuG3d4sU
7J6rqt9pawPqxzja9WcoWEJu+G63vQ380nxf2TNGwW/rw7cPHbaBzU8y//s0
RMGkF13L00dswLHO+G5eOwVz/XfGc/64DdD6g9sNHlNwx6TAwOIJG7h1b+aS
Wx0FG/xxqWX2toGyQ1fS1fMoeCWGdTfnaRtIyvAMnE5mxMN3N4nP3wYGeu6/
EY2lYAX5X767z9uAnNTZEF5/ChZ1SpAxjGDIF8rIJhoUPDClkmYWZQPXRkT8
d8tQ8K2zQyw2MTagc9LyYLQwBbNd3zNxNMEGZFqp3yZ/kfFiIz3nUoYNvH66
KsxWTcZVRsc5r2bbwFa1rHiZXDI+/Yr5UlyeDSjJv3DojSPj8WkbxwyyDWwb
6mrtPEHG3QLTvI3VjPmws9ltxkXGNwriIx7XMeLXqI1vXyrGZorK35422sDX
Y1IaA6PF+LFx6Iu+RzYwc0nCJr+qGJcH8Mb+6GTkP2N0+hexGEe/1l9THLcB
iTiBfB3GvDIWpo/alA0cXXYmTNsX4T8z14d1Z2xgrLJ/Tka9CAes9zVazttA
T7y+QsjvQuyi5HPOe8UGbA9M/Od0qRDrJKR9LOa1hSJrvtX4wXwsKTqzaV7A
FtbOzgrGxeXjrVRNCQ0RW7A6ebW6Sjcfjz9549i50xZ2Lq/wX8nNw3EL27vm
FGxhb3l/gLtjLh5yzr+rbmYLLcET8wbULBwoV3q245ItiHImnbZpTsXHGn8n
8ITbQkIsa+PcsVRMMLYoc4q0BbfiL86bVlPw9mOfx7/E2kLUyCQlTzkFN99S
PMhzxxbUsroCPqXfxjy/q9WdqmyBn6OI/XLhDVzRfn/186QtLCtw5OVwhGJH
wfP//ny0hYpf67+LfS/iDXelTVs/28J4C5Eg+OoCPshUzL7/uy20lr4PPpZ0
Hq/oJogErtkCSzr3JVWR09i05rjGHwE7YPpSOTT59q3haDZzAKeZHVw5qL9w
QjgUxX5+HLTDwg4sJWk1DfVhSEU75OI+KztYqhOTdSGFo+jBuQhbeztof0FR
bTeJRAq8g0kpx+1gIZ+lTvTCNXQhprRC7IIdrKb+kxV9Go+4z1nPKpTagYtb
UU/AtxQ0g2uzwu/awZ/Ho0k3D6WiJzwiVj2VdhCvmFS7834qOlM9URncYAeP
x35cuRVxB3V/u3C+ucUOtN/r/zu9JR3d9C9ad3hvB3oXBE6XrGQijya2mrIP
diA8lfmm6VAW0t/m57Y2aQdbz5aKSlRlofkKzbbCz3Yw8CR4T/WJbGQ9/yJ+
btkOpFoyPrx+nINiNcJuNLOT4HngpdoftvkocFRpyoeTBA7Ku/jO5+Ujl5hx
PYGtJNjHp6onOpePNAfNvnrykGDbntWC1msFaCaIl8QlTIKZR82t+x0KUZ/4
07IGERIE1jFzjF0sRE/agje5bCfBL5FBT+HcQpQu+K6uRpwErBLDehIThYjQ
QBVy3EuCN3rbhc54FiHVY05nNqRIUOe/SYIYU4QkWLk6y2RIIHiat7KUUoSW
D527uCZPgtUO7+WpiSJUsqj7rlCFBDsOuJ60dCxGKTlf1YiqJGB5M/58e2Ax
umJSmLioRoIEksAXj5vFyDF1syFBiwTaDn8WvVuL0Wa1nsI5AxLEtZkWbpMh
Iw/CV+2biAQLV/uCVQ3IqNWZs3e/EQkGDMou9x4ioyuRppsCTUlgn/GvIiyC
jFZe3XdbIZLAS3xb5NkeMnKcGFzNsiYBv8iVzsNTZNSwtJCsZ8uoT/sb9+pf
ZBSwQ6n1ij0J3m6yH28VpaAvp4okNzuRYONT0Zf/nCjI4vKThyXOJPgB5Ivv
vSio5Na7gxZHSeAiUSzbH0RBJ2lC1xJcSNAcX3xY6BYFtT5T3aF0ggQ68uXs
J3IoaPeoXX23GwlUz9Etd5RS0HuWG1N8niR4KvJrbOIxBemKlIbVe5EAONjO
zndQUKZCm4DDKRK4ynsoePVQ0LLBxL1lHxJQOIY/2b6lIAf7dZNMXxKQb6ld
KZmgoAaPHe91/EnwsdCize8zBfFf1A56d4YEvyU/3y76QUHnEhy2hp8jgd/a
zEPT3xTUnR9IkQgkQT+P4HbHfxS0r+6WfvN5Ejw2M44aZKaiG+0VA27BJKBH
mbxq3UJFs8PP/FhCGPWt+NyzcysVmc/PsFIvkkCijM1jhoeKSjZY8gihJCg/
6ndcXICKWAX2aMyGkeBqxXwqFqIidxnDV/HhJNCMdB5j7FPUrHPUUzGCUY9N
T4VstlORhM3Ffy8jSXCKJK+uJUZF4SfS0s5EkaD3T6p1EkN+f75OiTea0a+Q
u4EHGbLu9dfttTEk2IMEH15jnM/Mnj9+6DoJ/nZe1JQUpaLlSo7lpTgSfIuP
WFMSpqLDLTJJ6TdIEPD3tXjp////ZMBERjuRYZ/OV3WTl4r4Z088eXuTBJy9
c60TjPzOrYU7ht0igYgk21kyOxV1c+d8E08mQdYm9o4+FiraJ3k/9kkKCTg+
Zb47u05BNzQGJU7cIcGk5YmnoSsU9NligbYpnQTpRZuTF38y5uXsvk+mWSTI
33mcoDxFQazXLCNmsklwNzimdGGEgtzTvUTickmwmajwUqqPgnY1FZq/KCCB
u8NswdATCrrS0/TBr4gE5iybvjs2MOZnaiSEm0wCsx1pRubljHnhFCqzLyEB
Ctl/4FIyBQ2tz6i9KSXBNO3bWnYMBQku3sfHyklg4KB8Ey5RUPK7Y2+8K0iA
WRfYRF0pqOf1/pNfK0lganQ4gGhPQdxtTN8Dq0lgovabusmEkV8Fhe1KHQlI
2DNrQ4qCugovpLA0kMAuLEDOXIiC2NIsJOIbSVAyJcgmtJmCosLnNe7cZ/hT
8T1jxnhvYbbqnnefMPJZJelvziajh8ZsP5WbGe/HSSg+IZbxXjWHLze2kCDR
nrk0J5CMgnZdvtPcRgKj+HyRo5Zk5Pfj6dOh5ySIPx0gd/JnMXJJOSTJ8oYE
Sy+PP+PbV4xyY6Wr4oYZ38ebjYcD+YrRSOhvHe4Rxvy/osR4Lhchx5M59ttH
SdAtt8maDRchO/WpSOUpEgPPpuYaWxUhGAr8cPQ7o146YZImpEJ05bmp78QP
EuTu5f4goVyIHj8R/u21QIImyS13M7cVIp3Sh9yBv0jg4VfC0p9SgFQvMhvG
rTHef7v8XcVL+WivWEpuwxZ7kHcCgdK9uWglSWfjCIc9aPAdJdm9zkHdLBNu
m7jsYSzy2sCB0Bx08auyrC23PUiPaClVv8pG3c2vaj8J2gOpo+PKK98sdMmb
o1NM0h4CBMon6mLT0euGyJ+R+vag+cPldI3lbRRmd5ZgE2AP08nvHFl2eyIV
6ovcN4H2wHzs+1PFYTc080d20S2I4X9kV9/zXccRqWS84EKIPQwFL6YEr9oh
6X/2qwXh9nBO3vByepYpfn1XvWIh3h4mDxQI9XqcxXvZ/vBlFttDolHd4Mtn
0Xj4qOMpSYo9VASfp5xIi8FJtXVPKqj24GHOkn/mRCxeOebr21JmDzU/R1I+
Ll3Hr+rft32psgeZRxFb6cIJOMQNhxg8sodVtSH9vtzb+MXj6NHJfnvwaxO8
1eufjhfCrc57DtpDsaOK91RbOhZD/ByzQ/bwylPCxn9HBj7dUqD+9a09xN2q
6R3vyMDsHQ8Tfn+wh8e9xNFtIlnY9PUPna3z9tD1+9Gu8ewc7Heb/jrpqz0I
1w71xs/m4FT7K5583//XcL3H1ZxtAQDvoePqMRUpDDmTmagMGZRwtSoRSrV+
TaKHJEdFHkmm21tFD6HoqZzX7/TxahRCwur5YWImkfQYo1LdOoX0clQ39/fn
/nzWZ3/W3nutvfeXy1chtklbnU+drzTS9YdcgVma8S2X80tcs3EvX+EKySoN
4dmjBfS4wytr9TSE/uKtz+p0RdQjWbT0vhpCcbdrnOpKEWn5yyvXTkdo9o+8
38aIyKvnxAdrdQTNyOn3918U0bg8Y+NWHYQ9wlSvFh0xGd3Y2fpcF0FcZhv5
dZmYtgTzjzjP4uLTS9fcdhRTzqeiS276CLNK8jIHT4nJcuTpkM98BK/NCuvo
MTH5lJ5L6liA8EuJqNBdV0KnwtwN/RciOHfO6Koyk1CT4v2WQCOETif9N267
JRT6vynRsSXIvU+uHi6VEsp/XGsxZoIwMR5gWtYsoeqYM89/M0MYlogfl3yS
0EyVeYqoZQhpfdGLXOZLqZi32jlpFZfv+UW5K49I6bBDQ7mZBUJqiMXRu4lS
WpYSvKTeEuHg0WiX4jwpXdcqVNZfh1BUMzOFV839151tD5WtRziUo5u9p0lK
S9L/afXagFB1+prOij4pFeoZ3JHaIPgZbSoz1WJpn/tt/mY7BBMNaQ9jyNKP
Oc5p8o0IhnGT8Z+WsST+PkmwwgHhZbPfo8jtLOUbfZ1D2xEEmT8PdXMe8fTP
TPRzQYizFwpyL7A0r3DFkBoiuGkkX3koZCnbJOiZ468I3vkn7VzvsuR+gLdm
0B2hfMvn4coKlvSKJOwFDwTthky+uI6lDPO2qFZPBMWKDQVX/2bJNeSEPMob
4eoH0caXXSzp3Jm144fdCLmbv+gHDLBUP3qzusYXobV4kII4r521dDQP8EOI
yFvf38J5zim8N1/DH0F1AbuplPOeZnnCjJv7uPzUOq9Nch6sm+SH4X6EbqF4
TvEMGSVveNQ5GoBgoKWdUa8lI4fYnc65QQgbg93neurKiFc1Wr7+IMKTdmkx
6smoVjVjSXswgnLSol139WWUYL8sM/4wglO88pxTc2Rkd7pOefFRhOnDgQOV
nHdV/hAcqgtBOPMlqSWQ83ClumpbcCiCVUlKRxQ3jnUUbtYNQzgAl3hTXLz1
2XV37pxAiKnt2Srn5puqf8P3CEdo8M0ttuW8/FA3NG3iP1y9/fLOajrn5QhG
Z/xyJEKhZ1ev5UwZrc28IbCNRuiYaKTG72SkaHJ41R2D8GLl24q36jK6N6fb
OjkO4fkik4/Ik1HYrrgbS+MRVg50bVmlLKPV+QvmvkhA2Fu0vilugqWRt2WJ
x04hxE76Za4bZenWQvch/SSE72ocLu/5yNLRPUM+D5IRamLNYITzsrn07DPv
VITsW9mvhjkvf+wyXaOchhDdMrfEl/PywYC9ug7nEVbwMm7EV7Nkdu1bVH86
QpeGOGJtGUvy/kvysxcQAnmKsd2/s7T/cGP16yyE0pabboosloxLjpiH5yB4
3DLpPZDCUteQZsH8PIScmAUpzlGc38Psw/YWIKR/YT0D9rCklJvVJL+M0FbL
bxcyLAnL/2sRIkLQOKe0wdOepb+VUr7ESrn1ZN2R+SxmaUfqX79dvoqgrhem
KuqW0ljRwpafriPEP19iP/VKShdfHLEqusH1r8Luc2ellF7OnjVefhNhW5PO
bRvOz46iHREtpQjz3pxX898mpf6qK22+9xCmds6qnmbBebn767re+wjVhfet
zflSemKaPzlWjmD8x1ORybCEbEvbo/SqEOx3p5qWXpCQZV1grPNfCJODT0uv
kJiaBh60N9Vz/dQgIwupmEK1NW18Grh6aQ156MHdZ7fcflcObuT2pyL1iuc2
MS19N3QypRXBXRA1FfJCREYjEYm1PQjHH/wrxvSckCr0/+x27OXOe7lsNHqL
kHZbGW5q7EMYab64UE9VSPnRFbz3Awhj8XUVvNDLZDBDLUlpmMsnxy3eyqmA
NA3Ppqz7hhAUIms/9k8eoSL08KASA/E/C0JXJeRR9ktPN5kKA+0D3wLMTPLI
6LSJoTaPgcYhA9snR3JpzWBNSacmA/wIR1eVL9nkXzXRnDyPAa2Emu4PHRfp
oSBwcfNqBiTGlu+d0s6Qio2LZpolA4I+D+1LJam0+XvLzzZWDHhVOMHs1yn0
sn5a+fX1DAg3Tc2/PjeZeteItsfYMdDDy7s3Oy+R9DTeHDd2ZaBEw3db5EQk
7ep+tKsNGTB7dE5tbHkECYm1Pu/GwC4XXrhobziZhobMGN/BgLru3NzHT48T
vNUq+NOHAVZTsNbOIJhO3RuJO+nLgIE8KNc+LJCepbcJLP0YONHxU19i4z5y
33TVXLyPAe2r3tE+ht6Uzz8/230/A63e5wTCN79Sx3jYuHogAynLY1uP8Z3I
+LX3OwpiYHqtXCnrh3/TwZsba0IPMjCaZB6He8Me/x8WGMgz
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13k4Fd8fB3AUEllLpRIpFCEUsszHvddSJPdeRCIpe8g6lmTNtZRKtmRJ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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJw91nk8FXsfB3BUJEILohIpWy7nzCRL+H07Yz9LzjklSUgckRKJyiVPi0jc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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 77.69462845773928}, {-754.556911398264, 
             19.41755531361318}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0nk01fkbB3BRulwpS2WkxVhSsiSkxefzwZ2UyPLN0s126RJuhDvSEJKh
KaGSrEVJi2t+Kn5DzCWyh2osJeIiyW0hy3QT5umPz/mc13nOeZ7nPOet6hXk
wBYXExPLgffjlz6lcKBiJ0UKTpF1MUFcnFseb1QFfsBdfMaew8VGMyKVWnDN
X1kaan5c7Bk0IGwGH5Pbo97gxcWlrKI/esAbHl1dKu8E9T2WdSKw1kyWz8Pd
UF8esdtkF0WujKT8oS4N9RuDm0vBmydDoqpvhWLtMDmZJ7spcijaff/R9hDc
Ld4nqjalyHM619iLHoKFjPiJMkQR19e7T8jbBmOuUfLHOkyREyrRv6glHMf9
bwxnqglFlAPHBkheEK4y3inx3IwiIhWbuSvrAvFSxlrlXnOKJPpJRYrzOFhf
Ose004Ii1hmTc8eYAbgtKpI9xKDISEP8JeNpP2zD+5rR/wtFjNsjvtGLj2LD
ZIeXXXsoEuVkW6V40hdf3CCzZsiSIrxp/fJAfR/c7u/l37eXIo0tG1XFJNk4
1luJ/2EfRUp22DSdavHGOXK8Nf9aUaRKEGHXed0LZ4T3/v55P0XGAt4GnU5h
YekkztR3a4o8NmqMVgn1xK6uGUFfbShijibUdQbdsforjc80W9h3bEkaqnPF
B+kp4Yp2FJG2kjK49YSJ2TNpsrL2FLm74xAlmnHBwuS5OyoOFHE+a10ToeiM
HQbF7H6iYL5t+OJZL0esOiYQkzsI+2/IVvnURGF27s//X+tIkYBsTRFtgwM+
v1wsXMmJInek0iw8btphTR1TpOVMkcDahIIdBgfwJjEX2W0uFBkuu8rTtd+P
lyUuF2ofgvs9jursq9mLfeo1n+5gUoSWLdcYrroH8tRTbnSYImd92mP72iyw
uRfn/hZXihzlXD79+rYZZpa7FZm4UaTbmV7kI0SYahKWGrhTJMnaLuTcyl34
ccKrGjMPirisbr4cYLwdr1jw7kWeFDG5xstv79uGG7SfLhizIL87G2OyuvTx
pGTqRoYXRbpUPrYb8LTxoqyvh7E35MN4ejo1QxPH9VWm2h6hyBHXxckRf6ri
oE73biabIpv+HddJH1DGu+JzNA/6QH77PUOUxRVx2YLQwwUcO8OVOjeigI1P
7sxwBQv0wm7KtChgfU43nQ2exwcHrFIVsLqD3MSv4M1m9KjCjQpYZt3vFVfB
H2qbbObs5XFvKcfuNVi2uJg1VLICR77d9ZuXL0V+utI8yvWl497nlQE+4JdL
Yrf37qZjU76pmz84X5vLOyJPx/NpmISANUI3Sb36WxrH7LWQjAWr3ahMsl0l
jeMKrS7lgS8f5j0PbaXhC8GH7g2AW2VHgzIOSuJPbj1Zw2Deb61XNHQl8QGr
wxdGwXqmk4MvlkriFWpux8fBRpYbJlMqluBLHZ7GYkcpklL4VpipvgSnbT9a
sx7sZcHYM/JdAl+bC+txBz87n9DNrF+EOzzXl3mBM5X1bMryF2HpJw1XfMCW
Wwtyjc4swmHnlOwDwV9qVQXJZBG2Xf2o4RS4bKVmU02lGBbbOleS/aO/hlk4
I2wBeR85k9wDHnL/oyH5+izKbNA+9gack3eRYX5kFj3b3GE1CKa90Yg23DSL
dk+oS46Bf76vp/Py4TekGFUfKQKnL5wIVHkqQvVXpfyV/CDfyo6X02lfkVZL
MsMJrFYo98Lj/hRSKtoXxgR/ma8oLT45hWjJEnfcwfRZ45vW5lNo1OEE3Rf8
IONjFrtjEt3pcX9xAvyPXpykyvcvSGtMxzMDHPNX4vPMQxNIS+ppRC/YUPjr
xccZH5CS8PeiAXBXy5afNE0/IFor7h8Go66g8g0CIRpNeWj+ERxdu53xcrMQ
3VHKkpoHt51SSbCre4+0tPyvrvenyCfWrWH2qndooyXtoRdYGKEor7FpEH3L
msr2Ae9bFhdqMixAbeMD8f7g5YtjzrVdF6CwzHJmCLhLP+dVrJIAPfnoLx4L
LrkmXKCvGECeqa32eeArgutyZnq9yPB9+a5b4GM9i/P5pa/RUlSgcRe8sfj0
LTPT1+jPd1GiYnDG5poZZ9se9H2nfl412LLW9VVd9EuULrg03g+uHH7XVSDX
iTjG0T1D4PzuqvCIOx0Inw948g5sH/rnBUfSgUYMGemfwXKf2uSUQ/9Bhmen
8QJYZ++ac8PDz9EzXZfkdQFw//68t/NfWlH+GcbJn8F9FXKNTmat6MRLfW9N
sOdpXnr5xadoXazUdl3weARLMtekBXE6H70xBYsq6lTHrzUiWuRaXTdw0San
xpzWWtQTmJLIAn/+J9hvTLsWFbEkhGyw77V9ZTWJNcjB8v3tQLBF4jRrldNj
lC1fqhoDps15T1yW5aPAJVoxcWDnjZbGo5OVyOxr5puz4Dn9agH1pgKN9MVk
XQTHFkmEBNeUI7271itvgi/L/nWtrqEUiWdXhd7+sf8ZA9zZWYI6kgxeFILn
h1j230cfonCuUnIJOOe8/7OUdQ9QDR6m1YPJLyurCy4UoVQDZ99msPXXVf6m
s4XIV6O5rg184+2jZRKh95AMvTi2Gxx5nGaz5vRt5NQV8X0UbPIlQRS9+gbS
avrE/Ahudj3GT+rKRbMVrPIJsCDKUzMDX0e5eZZh38DJlj2f7uVlopDURx3z
YL1uoZJZcDpiJOhsk+BQZKXsVLiRYxp6z1EYp4NHtqhNmDAvoUqP+AMrwI8e
+irujUhBSQ4iniJ4UFS5NIB1ARmY9PutBfO8d1Q43Y9Hi7UdGlXBRj4SBb5p
Z1D32jpNTfC/FQWORvkxKFKicEgX7CIa9pDlhqEDM2vNt4HNxXiCVXHBSPV9
Su52cP0+jUSDFj809VpiYRdY5rd7e7S3slB9W5gbAcfYViF9rgNKf/y+ggGu
Hr2oneqhiwJKXJX3gcfF7c8/2WLBR7fbw23ATlW5Ta0PHPkrMs277cHyf9d2
3WZ48gcTS42cwArhO55OyrD5pdFaqUzwTeXKdCsDP/7ZkKwv7uALah3LeSUc
PpMta+8NbiuQXqKUGsTf4nL6f75g3dXTGpajx/nzVlPLOD/mb50/vLQ0mP/M
1JdzHBwXzk6y1g/h39TvaeaC56s+F6xihvD/A1jgaXY=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV03s0FFgcB/CJDev97CipoY2JikbjTZdosFFcrx0Mxg6G8aw0O+jhGdnM
dlRHW5rYatdjy9G0YXd+kWdqtDkeDVK0u3nV2u0MNrK3P37nns/5/e45957z
/Zlx0oK4ShQKxZ/Up1M91yCg1Rmj/pC+rYtGpSBuLmIAsWh1i9WKQSkwFMub
HxLf9Y6zXadfCjFpL2cfER9bkNpqaJeCJLahRE58O7qPslWF9A8wO5eJ5V25
L7wVJSDRyXZ1dMHofEjmedFQCcRUT1pJiHXV/5rfeKkErLP0NDtcMaKOxL/3
0SqBYaXx5QduGI0ykqVhZWdg1qto4b47Ri96f7Zr1DoDRxnl8537MPoguPxG
o6AYJl7sVTxAGGkIz02FKxcD2Dsr/+6B0czLDdurjheBqpfppjFPjPp2mNBs
3haCrfpVt8H9GGl23EzsSCkE2Ykc7pQXef9JmxifyQLwr1+qnPDGiNNTqSKP
LoC95UEjQwcwamrvDHg0kQ/fUTVNppgYUeTMZXFwPvQncZLGfTByZKsnXXiW
B3lxxtI5X4zmTdfSeN55cFWv3mTRD6OOlM+Nq1pOQ6VgrPDdlxi5OxR+XHM8
Dern+O9XDmLUw+Vdd64/BZGRlWlL/hgZvB4T19JOwRfPt79TO4RRa49b96jd
SQjWEAkMD2PkdPzGgrPJCeAqLmprB2LESKe3UY1yYbZ89cfNQeT/ba6/VS9l
Q9Ak5fBGjJHUYtig5a0QzGZeUfSCMbJ/wsjrnv4GuGLze6YhxLX2LxNlAjir
QxEYh2IUnnbkyS+dx8Fil5s7LQwjRWiCfsXNLNhBCde2C8fojrZjQErZMdAq
05m1/gqjlQGDMfXCoxDfZfHYiYURjVM3YJtwhORJ3syIIPkSpe+xjMwETw6/
cWckRkNOGffooRnAao5qcIzCaBfVvf6hUzrg3lkJnY3Rehdnm/SYVGgrft7u
EY2Rqn+9fTSVD7prcWPuMRjxdBxcrVSSoNv68Zp9LEb7fC/meCgS4F+VCksv
DkaDSkp10c1cWPf9UsS+OIzOmLzSFVbHQcH4rxWHvsbIIjnF8Qo7FtIG2cMs
LkZRt3z7XfzY4FJ01SI4HiO18fOHMraxIOcPFyEngeTjSm9DZ3UIVK1mydmJ
GDG/NSxOTg0EWl+5VygPo4HIqsItVX5gyVRr4iSR/fFry31a5wFqOaa7o5LJ
vOCCcPkHOshTRWWxxKleyvd5LDo0xCrPconz7UYXnuvQIYg5fSuVuHtcOaJF
uAeu6EvMThFrLsk+yz5sCzY/HTSqIa7yUClaXLSG0KHslTfEd6/RrylumAOt
9y1rntg9aJo/pGsOH1pjmxeIR1w2ONzLNgPxdWbWf8RzQmbbsUAqTPMN/tbg
Y5Qxw4uZXjaBHOW6qd3E6aLAba9v6UOAwtTTjniiviexJlcPzKZFYgfiGpqs
loN1oUuWFYWIN10a9Wtf1QDdy57DgcTzlncVrXVKMFkmYYQS34nfH+YcRgHJ
SVoFi7ix1pyXsX5FyuJqB8Z9ut8ikCU1/SPdGX76dgKxuFdVITOck370e6/F
J7aeYvv2tE9Kn7ol8NOJRzLL9+S/eiatsZU/Okq8f9xc78+WVOn/v5hABA==

              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV03s41NkfB3A1ta7rvkW5JNKIhlxmScbJjkuTivlKKEzuySYqySUqJl3E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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Hs0FHgUwPEpbakQaVthKm1h12Pb8mgx7s+sGBN5/OQxDGbseDUn1bbW
Y4ReUg5jwzYVaTmLoq1jZzdb6SFR5DEeM2ZnZEYys0Nl17FUtv354557Puf7
7z3XipsawltKoVACyCzuVdmme2+7YWRA9Qm4p9BAVfMp53uLltSe65RrwHl2
3rKVuDB/pVwq00Bc6qju6WL/uyvhzYAGxJzGAvlib8e5Vs9I9/Ftmyc2PMxp
On6X9DVZHrvcMSpqF2xgVJL+k/pzMbHJ4abx3lgN2KWZGDzywOjHQr+9cbIJ
kC5Vzt+nYXTJ5XiSNnICdN6npm95YnTFXn1uSvkSjjgXT7UBRts0ycWp4S/h
+YjT7H2EUf2OMg/d8Djcc3HT6/PCqIGubX4RPA4rvKnmCjpG1yu5jMiuF7B9
VQVt8GuMHM/knG4PfAHdRwW8MW+MHNzbzjd1jEFAw5zo+W6MrmVdZ4mYY+BU
HCIb8sHIVv+uw9tuNZRsNrAY88WoOnKmV8ZQQ08KN0XJwKjSrWfbzU4VHIs3
a5n0w8hMJWGu8FZBhUmDxb9MjEr63+XKWkZBlK44+XoPRmf3dSRV00dhVRF/
5r0/Rivdsrxk3z+H6GhR6lwARgsTDevYghHYOrzttX4gRtObtp9W7ldC6Gph
+rogjF6+XqCGximAN1tuZBSM0cjI2k9aEv4EXfFCnWUIRtKIjBufRsghRE0J
2oAx6p+2bhREDYPVXyqKSShGki2bujrjZcCr2vIbdR/xSNLZ9eFSOLuGkm4W
RnxrvjE0egisHWietuHEVMXBIv9B+IwSYbQzgth8ZViL1wAYFq7R2UUSu2RX
qhj9kPDYuusrFrGSnk9xl5B7kjc7RxFXB/avhT6gc/k37aOJl9R6WTB6gdXM
btzFxqim/3KVZ3o34Cc68Y4YYlXOCYcTXfAgf/ihVyzxR3r1pglPwfhDvMIz
jjhxXeno/g5ot+v64MLB6If5P1pFWY/hn+WlNt5cjCKvLHNich7BkotzURCP
kf5JRYoq5SGcUN4pDfwGowtHw9WpzPuQOhgjZfEwogX1eAwm3gH3UxXWoQkY
+W8yoJ8/dgsE4+6Z3ESMdpsXd/j5/QqVC2nymCSM2CWOio7wG2DbWewdloyR
Td+baTRTBza++k3cFIyeSI0dnwmrQF9AdWTvx2i4ol9fm1EC8gPCQg6xJPvn
4SVOJdDI0dPxiLsDMq6avxJCiK+29gBx68JGf3+uEC6tFVvlErNvD2yMLSuC
L+r9P64mNo1aaj/pcgbChrLea4gvZ7J9lmfmge2TV6wpYpGbnsb1VS68u81p
niYuldcVJHNzoeqKb9pbYpPvNCJR2VHQ8k3frOZjNOm0vtbaNRMEetfGHIlv
HDn0AGUegr2zVPpO4qszd5bVcA+ClVZY5Uq8J9lYaFR+AB53p7ERsYuWVnHR
NQWML9ClwcRm2vO/izM5oC4UO4cRb5XECubKY0CcY1vKIraUFBac3MUCFs8o
OJ6/+G8mqi9nBYN9RN4vicSGNXbcSDcm/MecMeQTr6jJF3yb7QW9tET+QWI9
RruDRd6XUL1d/vQIMYWyeaqAVuH5P5KmNTs=
              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {77., 0},
            DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{76.9176821731619, 
            77.69462845773928}, {-0.3018133830417386, 0.7769466885810359}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxcl3c81f/3wCVEQyrKKlJCRhmphCOpJCl7pEJSRmSPbLL3zh732tvl2see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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw91nc8le//OPCDyCqyV5kZlXUOyrwuWSkjyY5QNqFwDkWOcIQoyqZCAy1R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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1A0slHEcB/CnJHnJXS+W5OVizlDEOS+lO50Txzkdq6VFXLny1iFJXW/r
xSq6lpeII2SHMPJSEro5QsV011qmvKWNsEIibXrb/H7r2Z49++z/fX7/1+fZ
LBD5hy0nCCLkz/33ObAmSmGc3cAg/l1fmXIPz5HbwnnmkoM0xU89ozXdlhz+
eEIv7uNacGRN59zOKX0wR6fUNuySCdh/+mpuxWtT8GSKM++tGRVsrdOiOie0
BFv4rFboxG4Bp9YHBnGabMEfpmuqHh2zAyvEVKNV4/bgwZyNh7ZJHJb87H3O
5F6uniOYRGOZMpucwOmuywNjg1zA8+b32ZlD28Fpslb19CRX8GqNdvEVEgPc
vMhp93nCBIc6SBmlFW5g/161eFnMLvBAp/V6EpsFPmjVKonVdAcvY6c2z7wA
M1mllMAhKRscd96kuyPEA8y411+xib4bTDutYknUPcEbFM7VC+3ozP3BKcps
L/DK4G9uRYc44DxD+YMMijdYSeVemJ5Cz+Z72XDqfMC1QnUv7etcsEBq79rO
84X5uCRnfCok88DlbfU/xobRujHcUatiP7A6rSd/fOcecJaWXglfhjYzSJXW
avDBYj/Rbt9Y9MvGKx+GVeiqlXS/aw7+YEGCR8LhXLSOseTGjl/oqEp2a3xU
AHjObuxmmnAUvoc9TpPCAUs8b0ptCkPaSIN8f87lA818Oth44RRfLmOBbZzK
ZPYRuN+FCb3Jn2m4v2/ULHZYmeB6Ji8zZI2No7vXjZDrKnF9G4XhFu/oON4X
7ve3KgNgPMy2qscGShfsj1JL9jjTgPV6VVKe0By/l6ymPPu0bDx/33kWzP1G
0B/z+cAR82gTrH94oWhCcAnzbiUF8vwVmO8uHqI7XcP1eXUxK1FRjfny2fIm
kiPOp0O/pNM7AdtfnWx5uOI4vs83jVisscT8Yl8BSSzBfE8v0RBeiHmNzi9n
I1mY/1lsWc+IwfzL99Wi8RCcT1F9h3GSGebvXKf27TuL+S5d5YyRGOsvJmv3
D9liPl0UUekcjXlvcll38AGs36U2byOi4PoIBkfl7BOY55Y2kBOPYv5M9F3d
XCrWT7nFCG2OWGoniFCVVlldpDvYOXhQtrDZF/z//50g/j/fBPEbvTPPsg==

         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{50, 96, 94, 82, 91, 76, 85, 73, 79, 38, 60, 39, 40,
                41, 42, 43, 44, 45, 46, 47, 48, 49, 61}}], 
              PolygonBox[{{93, 92, 75, 84, 71, 78, 53, 65, 14, 54, 15, 16, 17,
                18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{1, 95, 92, 90, 81, 87, 62, 68, 13, 52, 12, 11, 10, 
               9, 8, 7, 6, 5, 4, 3, 2, 51}}], 
              PolygonBox[{{93, 94, 88, 67, 70, 59, 64, 37, 58, 36, 35, 34, 33,
                32, 31, 30, 29, 28, 27, 57, 26, 72, 66, 77, 69, 83, 74, 89, 
               80, 86}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 52, 13, 68, 
             62, 87, 81, 90, 92, 75, 84, 71, 78, 53, 65, 14, 54, 15, 16, 17, 
             18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 74, 
             83, 69, 77, 66, 72, 26, 57, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
             36, 58, 37, 64, 59, 70, 67, 88, 94, 82, 91, 76, 85, 73, 79, 38, 
             60, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 77.69462845773928}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["x", "1"], "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           TagBox[
            TemplateBox[{RowBox[{
                StyleBox[
                 TagBox["InterpolatingFunction", "SummaryHead"], 
                 "NonInterpretableSummary"], 
                StyleBox["[", "NonInterpretableSummary"], 
                DynamicModuleBox[{Typeset`open$$ = False}, 
                 PanelBox[
                  PaneSelectorBox[{False -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAVYiwzdwXtj4AYIxE1zcwvb9iyUrU
Q/Q/h/gJ/ObIir93dlctAx4FQBly6JQIA6u/dP302cFfD0Dux+r5iny6v+AB
D2j/thRAj0jzH06Rw78ZAsqsNSsaQExu6Oabhci/RWPawz5CH0CDxkJR9hfK
v8KgSNIvYyJAjAd9SL79x7+17wbVXxglQF+G2xd9scK/Iu/vQPmeJ0Bf2oAe
mXK4vxctrJEeXCpAhCTl1EL/pb+HG5NLreosQNGQ3hz6nIO/y+ncl1tsL0CA
ZSnHPlEwv0z7fORKEjFAtJPe6q1ok7/v2aCxHFcyQPUuE2l5Da6/1lcucTS3
M0AE8ovWa868v6dF7fnbEDVA68ulbLAWv7+1i0E3OFM2QJvcLSRjLLK/CHH/
ZtqwN0A9A2vZXbOgP5euUksx9zhAMWifL0wHwz9riw8izlg6QFbxYcNdoNA/
Kdj9wfqzO0BHZ5bOkKHUPyR9gRbc9zxAii3J+7mk1D9jwW5dA1c+QPfAsylw
mNA/313xWN+eP0Cu9Y5qDBrEPyO10o4lcEBAfggEPp7LpT/4imFqfh5BQKsJ
9w60VrC/7Aw7oDHBQUARx09aQYy+v4JeSc+HcUJAZTfM9v9kvb8NaPDipR5D
QBbjXRip1Ke/th3iUB7AQ0BlHDaTgXSpPwKjCLg5b0RAtNPVLx7TvT9s1Hl5
rxJFQOW+C+F0w74/y72DH+2yRUAhfeGKUUaxP8x2wr7NYEZAdsEO8Z74or/s
20u4CANHQC3P79gxhsO/rhAKq+ayR0APZdhF9MbQv47xEvgeV0hACviqfrqS
1L9jirQpH/hIQEZ4lBcptdS/2/KKVMKmSUBRNPFn39DQv3EHrNm/SUpASJXr
nvPHxL+p6wFYYPpKQDxoDLNO2qK/1ofwusinS0Dful6UE0KxPyLQKXiLSUxA
Am8QJwbSvj8Q6Jcu8fhMQBSYx8nlEr0/HKxQP7GcTUCwaH4m+0iwPx0oojQ5
PU5ASCksnHoalz/BcygjZOtOQEJjq4QrW0s/g2v5a+mNT0CMW0f9HJ5+P3SZ
/9YIH1BA8CJrP4N8pT8h2U7qgHVQQDdn91/n8Lc/3W7DKibGUEDdGhq6J3PC
P2ps0uecHVFAey0qKFDhxz8HwAbSQG9RQBVYr5P9Dso/dXvVOLbHUUAijMzJ
5JnIP92S8JGPHlJA6BzJIAq+wz9UADEYlm9SQLzsGp7Gy7o/ndULG27HUkAZ
WujNzuOpP/UADEtzGVNA1mdipWsOjD/qP2XFdGxTQCRHARgVWnK+7qXSTw==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 
                    77.69462845773928}, {-0.32355716040354243`, 
                    0.3225541075559809}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}], True -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAVYiwzdwXtj4AYIxE1zcwvb9iyUrU
Q/Q/h/gJ/ObIir93dlctAx4FQBly6JQIA6u/dP302cFfD0Dux+r5iny6v+AB
D2j/thRAj0jzH06Rw78ZAsqsNSsaQExu6Oabhci/RWPawz5CH0CDxkJR9hfK
v8KgSNIvYyJAjAd9SL79x7+17wbVXxglQF+G2xd9scK/Iu/vQPmeJ0Bf2oAe
mXK4vxctrJEeXCpAhCTl1EL/pb+HG5NLreosQNGQ3hz6nIO/y+ncl1tsL0CA
ZSnHPlEwv0z7fORKEjFAtJPe6q1ok7/v2aCxHFcyQPUuE2l5Da6/1lcucTS3
M0AE8ovWa868v6dF7fnbEDVA68ulbLAWv7+1i0E3OFM2QJvcLSRjLLK/CHH/
ZtqwN0A9A2vZXbOgP5euUksx9zhAMWifL0wHwz9riw8izlg6QFbxYcNdoNA/
Kdj9wfqzO0BHZ5bOkKHUPyR9gRbc9zxAii3J+7mk1D9jwW5dA1c+QPfAsylw
mNA/313xWN+eP0Cu9Y5qDBrEPyO10o4lcEBAfggEPp7LpT/4imFqfh5BQKsJ
9w60VrC/7Aw7oDHBQUARx09aQYy+v4JeSc+HcUJAZTfM9v9kvb8NaPDipR5D
QBbjXRip1Ke/th3iUB7AQ0BlHDaTgXSpPwKjCLg5b0RAtNPVLx7TvT9s1Hl5
rxJFQOW+C+F0w74/y72DH+2yRUAhfeGKUUaxP8x2wr7NYEZAdsEO8Z74or/s
20u4CANHQC3P79gxhsO/rhAKq+ayR0APZdhF9MbQv47xEvgeV0hACviqfrqS
1L9jirQpH/hIQEZ4lBcptdS/2/KKVMKmSUBRNPFn39DQv3EHrNm/SUpASJXr
nvPHxL+p6wFYYPpKQDxoDLNO2qK/1ofwusinS0Dful6UE0KxPyLQKXiLSUxA
Am8QJwbSvj8Q6Jcu8fhMQBSYx8nlEr0/HKxQP7GcTUCwaH4m+0iwPx0oojQ5
PU5ASCksnHoalz/BcygjZOtOQEJjq4QrW0s/g2v5a+mNT0CMW0f9HJ5+P3SZ
/9YIH1BA8CJrP4N8pT8h2U7qgHVQQDdn91/n8Lc/3W7DKibGUEDdGhq6J3PC
P2ps0uecHVFAey0qKFDhxz8HwAbSQG9RQBVYr5P9Dso/dXvVOLbHUUAijMzJ
5JnIP92S8JGPHlJA6BzJIAq+wz9UADEYlm9SQLzsGp7Gy7o/ndULG27HUkAZ
WujNzuOpP/UADEtzGVNA1mdipWsOjD/qP2XFdGxTQCRHARgVWnK+7qXSTw==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 
                    77.69462845773928}, {-0.32355716040354243`, 
                    0.3225541075559809}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}]}, 
                   Dynamic[Typeset`open$$], ImageSize -> Automatic], 
                  BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
                StyleBox["]", "NonInterpretableSummary"]}]},
             "CopyTag",
             DisplayFunction->(#& ),
             
             InterpretationFunction->(
              "InterpolatingFunction[{{0., 77.6946}}, <>]"& )],
            False,
            Editable->False,
            SelectWithContents->True,
            Selectable->False], "[", "t", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "2"], "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           TagBox[
            TemplateBox[{RowBox[{
                StyleBox[
                 TagBox["InterpolatingFunction", "SummaryHead"], 
                 "NonInterpretableSummary"], 
                StyleBox["[", "NonInterpretableSummary"], 
                DynamicModuleBox[{Typeset`open$$ = False}, 
                 PanelBox[
                  PaneSelectorBox[{False -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAVYiwzdwXtj4AgP1BuEvzvb9iyUrU
Q/Q/lr8/oPCulL93dlctAx4FQMp1+707fKK/dP302cFfD0CjgpDC8xmlv+AB
D2j/thRANqQbFsVHor8ZAsqsNSsaQMFfacucGJS/RWPawz5CH0C036NGULNI
P8KgSNIvYyJAseOs2138lj+17wbVXxglQFAaGA2wBqM/Iu/vQPmeJ0D/9k6E
ww+lPxctrJEeXCpAwOhukKI2oT+HG5NLreosQILgdJVK3JE/y+ncl1tsL0Bo
NiZXuY9nv0z7fORKEjFA7O5fElKDmL/v2aCxHFcyQPaYLwVqHKO/1lcucTS3
M0BwNrUoZfifv6dF7fnbEDVA+TTqkAHJkj+1i0E3OFM2QJIegRJPvq4/CHH/
ZtqwN0AQw3zXJ3q2P5euUksx9zhAGl/36vsXtz9riw8izlg6QDuACxdrBbE/
Kdj9wfqzO0Ay6RSX8geYPyR9gRbc9zxAUGBaEai5l79jwW5dA1c+QJHMBOGq
EbG/313xWN+eP0BIoDhnDeW2vyO10o4lcEBAGDYB27/Htr/4imFqfh5BQN/M
z5QUMrC/7Aw7oDHBQUDnzHqYcquWv4JeSc+HcUJAron13WwxnT8NaPDipR5D
QPpq9gvi5rE/th3iUB7AQ0Ay1LO4V52xPwKjCLg5b0RAg/iu9uT1mj9s1Hl5
rxJFQFV7zE7SNZW/y72DH+2yRUClnn9p7JGvv8x2wr7NYEZAf2zV8Vuetr/s
20u4CANHQPhI42SPAbe/rhAKq+ayR0DhLghtosiwv47xEvgeV0hACkHGXZxp
mb9jirQpH/hIQCwrZ2+aEJY/2/KKVMKmSUAZgChptLiwP3EHrNm/SUpARZCs
pzTAtj+p6wFYYPpKQLPl+k6KnLY/1ofwusinS0AIYmybv5WvPyLQKXiLSUxA
evObMcDOlD8Q6Jcu8fhMQBhrHsL1vZ6/HKxQP7GcTUCz4V7IOo6jvx0oojQ5
PU5A5MUGwod7mr/BcygjZOtOQHyP7dvIj3W/g2v5a+mNT0Dsc5j+uLqPP3SZ
/9YIH1BArS7EGKwQoT8h2U7qgHVQQKvGXNcaCKU/3W7DKibGUEDsYZ5JzzWj
P2ps0uecHVFAjUfLdqmHlz8HwAbSQG9RQL+LwK4qfGk/dXvVOLbHUUD0tzu2
eZ2Tv92S8JGPHlJAB1dYQkkdor9UADEYlm9SQGDzPCeXGKW/ndULG27HUkC0
N/NaYDqiv/UADEtzGVNAH3ea8Foilb/qP2XFdGxTQBz/dSCFL3W+bhTUDw==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 
                    77.69462845773928}, {-0.08986755574304428, 
                    0.0902097176216298}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}], True -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAVYiwzdwXtj4AgP1BuEvzvb9iyUrU
Q/Q/lr8/oPCulL93dlctAx4FQMp1+707fKK/dP302cFfD0CjgpDC8xmlv+AB
D2j/thRANqQbFsVHor8ZAsqsNSsaQMFfacucGJS/RWPawz5CH0C036NGULNI
P8KgSNIvYyJAseOs2138lj+17wbVXxglQFAaGA2wBqM/Iu/vQPmeJ0D/9k6E
ww+lPxctrJEeXCpAwOhukKI2oT+HG5NLreosQILgdJVK3JE/y+ncl1tsL0Bo
NiZXuY9nv0z7fORKEjFA7O5fElKDmL/v2aCxHFcyQPaYLwVqHKO/1lcucTS3
M0BwNrUoZfifv6dF7fnbEDVA+TTqkAHJkj+1i0E3OFM2QJIegRJPvq4/CHH/
ZtqwN0AQw3zXJ3q2P5euUksx9zhAGl/36vsXtz9riw8izlg6QDuACxdrBbE/
Kdj9wfqzO0Ay6RSX8geYPyR9gRbc9zxAUGBaEai5l79jwW5dA1c+QJHMBOGq
EbG/313xWN+eP0BIoDhnDeW2vyO10o4lcEBAGDYB27/Htr/4imFqfh5BQN/M
z5QUMrC/7Aw7oDHBQUDnzHqYcquWv4JeSc+HcUJAron13WwxnT8NaPDipR5D
QPpq9gvi5rE/th3iUB7AQ0Ay1LO4V52xPwKjCLg5b0RAg/iu9uT1mj9s1Hl5
rxJFQFV7zE7SNZW/y72DH+2yRUClnn9p7JGvv8x2wr7NYEZAf2zV8Vuetr/s
20u4CANHQPhI42SPAbe/rhAKq+ayR0DhLghtosiwv47xEvgeV0hACkHGXZxp
mb9jirQpH/hIQCwrZ2+aEJY/2/KKVMKmSUAZgChptLiwP3EHrNm/SUpARZCs
pzTAtj+p6wFYYPpKQLPl+k6KnLY/1ofwusinS0AIYmybv5WvPyLQKXiLSUxA
evObMcDOlD8Q6Jcu8fhMQBhrHsL1vZ6/HKxQP7GcTUCz4V7IOo6jvx0oojQ5
PU5A5MUGwod7mr/BcygjZOtOQHyP7dvIj3W/g2v5a+mNT0Dsc5j+uLqPP3SZ
/9YIH1BArS7EGKwQoT8h2U7qgHVQQKvGXNcaCKU/3W7DKibGUEDsYZ5JzzWj
P2ps0uecHVFAjUfLdqmHlz8HwAbSQG9RQL+LwK4qfGk/dXvVOLbHUUD0tzu2
eZ2Tv92S8JGPHlJAB1dYQkkdor9UADEYlm9SQGDzPCeXGKW/ndULG27HUkC0
N/NaYDqiv/UADEtzGVNAH3ea8Foilb/qP2XFdGxTQBz/dSCFL3W+bhTUDw==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 
                    77.69462845773928}, {-0.08986755574304428, 
                    0.0902097176216298}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}]}, 
                   Dynamic[Typeset`open$$], ImageSize -> Automatic], 
                  BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
                StyleBox["]", "NonInterpretableSummary"]}]},
             "CopyTag",
             DisplayFunction->(#& ),
             
             InterpretationFunction->(
              "InterpolatingFunction[{{0., 77.6946}}, <>]"& )],
            False,
            Editable->False,
            SelectWithContents->True,
            Selectable->False], "[", "t", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "3"], "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           TagBox[
            TemplateBox[{RowBox[{
                StyleBox[
                 TagBox["InterpolatingFunction", "SummaryHead"], 
                 "NonInterpretableSummary"], 
                StyleBox["[", "NonInterpretableSummary"], 
                DynamicModuleBox[{Typeset`open$$ = False}, 
                 PanelBox[
                  PaneSelectorBox[{False -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAVYiwzdwXtj6QkvaNdJSHwL9iyUrU
Q/Q/QvFe4QmOh8B3dlctAx4FQKP7TY2VeIfAdP302cFfD0CrLa1B71aHwOAB
D2j/thRAXqTW3y0ph8AZAsqsNSsaQJLWZQFB6YbARWPawz5CH0DeGvp3LaCG
wMKgSNIvYyJAOSJZZltChsC17wbVXxglQHj34YJy14XAIu/vQPmeJ0Bf96YL
gWaFwBctrJEeXCpAhJhdMp3dhMCHG5NLreosQLVFJYRHUITAy+ncl1tsL0CP
g8CBCLmDwEz7fORKEjFAhlwWircGg8Dv2aCxHFcyQKSm9tf9UoLA1lcucTS3
M0CLwFCVT4KBwKdF7fnbEDVAbaZ81vK6gMC1i0E3OFM2QLQv2jwqDoDACHH/
ZtqwN0CvHX3uNMJ+wJeuUksx9zhAFeGVdBKafcBriw8izlg6QDHCiP6JdnzA
Kdj9wfqzO0ACgKddA3Z7wCR9gRbc9zxA13ra6DqhesBjwW5dA1c+QMoP6vV2
13nA313xWN+eP0DrapFKQjZ5wCO10o4lcEBADbVrq7GxeMD4imFqfh5BQFve
4H5nPnjA7Aw7oDHBQUClbC2ul+13wIJeSc+HcUJA7BZ4ADOzd8ANaPDipR5D
QLu2J01pl3fAth3iUB7AQ0CRaq+dCZF3wAKjCLg5b0RA9DLxWMJzd8Bs1Hl5
rxJFQGaLRtlnPXfAy72DH+2yRUAE7AKfy+52wMx2wr7NYEZAey+R2iB9dsDs
20u4CANHQH5ZvGJz+HXArhAKq+ayR0C1Xr9blkt1wI7xEvgeV0hAZ3Wu7OaO
dMBjirQpH/hIQFUhi0ZZvHPA2/KKVMKmSUCgKjFWV7tywHEHrNm/SUpAjj1R
oJqwccCp6wFYYPpKQPHvQKtCcnDA1ofwusinS0AJyFBmKThuwCLQKXiLSUxA
OWy4WtKEa8AQ6Jcu8fhMQFryqkdzXWjAHKxQP7GcTUCBVYUeiFJlwB0oojQ5
PU5AZW1zQ22GYsDBcygjZOtOQGnI9kPWbF/Ag2v5a+mNT0DzHlSi/ZdawHSZ
/9YIH1BAVVYnmuPPVcAh2U7qgHVQQMEWHCkSlFHA3W7DKibGUECeMuIVEhVM
wGps0uecHVFAkjeFEp9ORcAHwAbSQG9RQPP1rke9pj/AdXvVOLbHUUCmbEl1
Dpw1wN2S8JGPHlJAmb7dO+E3K8BUADEYlm9SQItk0BfkOB/AndULG27HUkCA
uK00Y5gKwPUADEtzGVNAYrwnvOXp6r/qP2XFdGxTQAWYoVouVeQ+rJjTEQ==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 
                    77.69462845773928}, {-754.5569113982656, 
                    9.695405271691751*^-6}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}], True -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAVYiwzdwXtj6QkvaNdJSHwL9iyUrU
Q/Q/QvFe4QmOh8B3dlctAx4FQKP7TY2VeIfAdP302cFfD0CrLa1B71aHwOAB
D2j/thRAXqTW3y0ph8AZAsqsNSsaQJLWZQFB6YbARWPawz5CH0DeGvp3LaCG
wMKgSNIvYyJAOSJZZltChsC17wbVXxglQHj34YJy14XAIu/vQPmeJ0Bf96YL
gWaFwBctrJEeXCpAhJhdMp3dhMCHG5NLreosQLVFJYRHUITAy+ncl1tsL0CP
g8CBCLmDwEz7fORKEjFAhlwWircGg8Dv2aCxHFcyQKSm9tf9UoLA1lcucTS3
M0CLwFCVT4KBwKdF7fnbEDVAbaZ81vK6gMC1i0E3OFM2QLQv2jwqDoDACHH/
ZtqwN0CvHX3uNMJ+wJeuUksx9zhAFeGVdBKafcBriw8izlg6QDHCiP6JdnzA
Kdj9wfqzO0ACgKddA3Z7wCR9gRbc9zxA13ra6DqhesBjwW5dA1c+QMoP6vV2
13nA313xWN+eP0DrapFKQjZ5wCO10o4lcEBADbVrq7GxeMD4imFqfh5BQFve
4H5nPnjA7Aw7oDHBQUClbC2ul+13wIJeSc+HcUJA7BZ4ADOzd8ANaPDipR5D
QLu2J01pl3fAth3iUB7AQ0CRaq+dCZF3wAKjCLg5b0RA9DLxWMJzd8Bs1Hl5
rxJFQGaLRtlnPXfAy72DH+2yRUAE7AKfy+52wMx2wr7NYEZAey+R2iB9dsDs
20u4CANHQH5ZvGJz+HXArhAKq+ayR0C1Xr9blkt1wI7xEvgeV0hAZ3Wu7OaO
dMBjirQpH/hIQFUhi0ZZvHPA2/KKVMKmSUCgKjFWV7tywHEHrNm/SUpAjj1R
oJqwccCp6wFYYPpKQPHvQKtCcnDA1ofwusinS0AJyFBmKThuwCLQKXiLSUxA
OWy4WtKEa8AQ6Jcu8fhMQFryqkdzXWjAHKxQP7GcTUCBVYUeiFJlwB0oojQ5
PU5AZW1zQ22GYsDBcygjZOtOQGnI9kPWbF/Ag2v5a+mNT0DzHlSi/ZdawHSZ
/9YIH1BAVVYnmuPPVcAh2U7qgHVQQMEWHCkSlFHA3W7DKibGUECeMuIVEhVM
wGps0uecHVFAkjeFEp9ORcAHwAbSQG9RQPP1rke9pj/AdXvVOLbHUUCmbEl1
Dpw1wN2S8JGPHlJAmb7dO+E3K8BUADEYlm9SQItk0BfkOB/AndULG27HUkCA
uK00Y5gKwPUADEtzGVNAYrwnvOXp6r/qP2XFdGxTQAWYoVouVeQ+rJjTEQ==

                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 
                    77.69462845773928}, {-754.5569113982656, 
                    9.695405271691751*^-6}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}]}, 
                   Dynamic[Typeset`open$$], ImageSize -> Automatic], 
                  BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
                StyleBox["]", "NonInterpretableSummary"]}]},
             "CopyTag",
             DisplayFunction->(#& ),
             
             InterpretationFunction->(
              "InterpolatingFunction[{{0., 77.6946}}, <>]"& )],
            False,
            Editable->False,
            SelectWithContents->True,
            Selectable->False], "[", "t", "]"}]}], ",", 
         RowBox[{
          RowBox[{
           SubscriptBox["x", "4"], "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           TagBox[
            TemplateBox[{RowBox[{
                StyleBox[
                 TagBox["InterpolatingFunction", "SummaryHead"], 
                 "NonInterpretableSummary"], 
                StyleBox["[", "NonInterpretableSummary"], 
                DynamicModuleBox[{Typeset`open$$ = False}, 
                 PanelBox[
                  PaneSelectorBox[{False -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJw9z2tMkwcAheFPGMIYrqQqd9rRjkKBFgrlNpEexAptWa0FUxIFCoghllE6
CoMIZsoMBjKdMxlZAOlcNiYCA22LI1Fu0yIXt3DprJS5AAFBsbCxWJyMsaTy
4+TJ+fn65SileXYEQcRt7X+PXugYNbvr4wnNWs9rN2l8T84D4UTiGu+Nn5TK
WPYUB7xRvbFm6ssibfvHDlL+pn7Ptp52Q62RwV7b8nMfD8QfoG7br0keC82l
bauz7JzM8vCH1ibNYsH61QC8Z9Od1XqZcjwIu21We18RtS2FoMrm8KK57lhB
KAZtpvxTMSckcyC0aTFpOn1k4Vi2aZSxVdyuCIiPHQzU+UWgmb+8PuUaicqP
zjftGuRAV5sQHZMaBWUAJ6fzfBicVJsnH3dEI+az+RMUCRt17VIR52UMvN5G
Q9FAMBS1JNrD9A9QdPj+iyiCCeajjb5Xt/ZhTbfYPi1g4P3Ks27ml3F4rZhx
8O6nI7evMMNeFo/KWceyEXs/PMlYTX9ylQeXow52zKc+oOvGLvoXAQX0SEv5
jDusNdmnzlAScE99l3xLScZzl30aTl8ChENzhnCtM85lCn6pVh3ARPZmW1PG
Jm9X/srMd5RETMjjPu4unuXpfWcklN5EpIWZSNlLczy7b51uxyoPYlyTqReH
ECiYKC//kcyHqks12pLrjOE7VdTlm3x0MJzq+iPIGCntvzsqPwT9i40vDNfc
8XxKdNvJPgk/uQsymrQ+aHd1vjF/MwmzmY3lBk8/XFwlWymyZOTN9Lb90LLV
W6NlUq3J6OYnqa+zGZj6syat/3sB6hc01KjFQKgcW009AiH+ivXnhpQE4/qz
HenyV0KMD1Ww2qPZMFavdA82i/BzY725uTQMtF+ZZbWCFBxnvytjdXPg+rSO
vWpNQWzm0oDVIwI+rRJeZ8OHMI24aYvKwuEbeI0bu18M40TxA3k0B33FgfQT
z8TwPv3w0V59KKoU64rFzw/DtaFGR4SwoP560+hElaDiTHFbliIIfibx0qcl
Euw9u05u6grAdOFAEOO+BNzxNFJJuD9OFYwtNPgewfC8mdFTSoNj784xKLf+
FXULb5yKktOTMXrDEayYL+xfFHlh+suVy5coUpSe/O1G6u97kEZwPL5SSvGv
7zeXjPUkNE6+411okGJBfYhr1LyFvwkXUbFnKgZ3n8uX967xlnh599QFqSCI
5Cx/+p34/wCG46c6
                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 77.69462845773928}, {0., 
                    19.13167049092163}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}], True -> GridBox[{{
                    PaneBox[
                    ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                    Alignment -> {Center, Center}, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJw9z2tMkwcAheFPGMIYrqQqd9rRjkKBFgrlNpEexAptWa0FUxIFCoghllE6
CoMIZsoMBjKdMxlZAOlcNiYCA22LI1Fu0yIXt3DprJS5AAFBsbCxWJyMsaTy
4+TJ+fn65SileXYEQcRt7X+PXugYNbvr4wnNWs9rN2l8T84D4UTiGu+Nn5TK
WPYUB7xRvbFm6ssibfvHDlL+pn7Ptp52Q62RwV7b8nMfD8QfoG7br0keC82l
bauz7JzM8vCH1ibNYsH61QC8Z9Od1XqZcjwIu21We18RtS2FoMrm8KK57lhB
KAZtpvxTMSckcyC0aTFpOn1k4Vi2aZSxVdyuCIiPHQzU+UWgmb+8PuUaicqP
zjftGuRAV5sQHZMaBWUAJ6fzfBicVJsnH3dEI+az+RMUCRt17VIR52UMvN5G
Q9FAMBS1JNrD9A9QdPj+iyiCCeajjb5Xt/ZhTbfYPi1g4P3Ks27ml3F4rZhx
8O6nI7evMMNeFo/KWceyEXs/PMlYTX9ylQeXow52zKc+oOvGLvoXAQX0SEv5
jDusNdmnzlAScE99l3xLScZzl30aTl8ChENzhnCtM85lCn6pVh3ARPZmW1PG
Jm9X/srMd5RETMjjPu4unuXpfWcklN5EpIWZSNlLczy7b51uxyoPYlyTqReH
ECiYKC//kcyHqks12pLrjOE7VdTlm3x0MJzq+iPIGCntvzsqPwT9i40vDNfc
8XxKdNvJPgk/uQsymrQ+aHd1vjF/MwmzmY3lBk8/XFwlWymyZOTN9Lb90LLV
W6NlUq3J6OYnqa+zGZj6syat/3sB6hc01KjFQKgcW009AiH+ivXnhpQE4/qz
HenyV0KMD1Ww2qPZMFavdA82i/BzY725uTQMtF+ZZbWCFBxnvytjdXPg+rSO
vWpNQWzm0oDVIwI+rRJeZ8OHMI24aYvKwuEbeI0bu18M40TxA3k0B33FgfQT
z8TwPv3w0V59KKoU64rFzw/DtaFGR4SwoP560+hElaDiTHFbliIIfibx0qcl
Euw9u05u6grAdOFAEOO+BNzxNFJJuD9OFYwtNPgewfC8mdFTSoNj784xKLf+
FXULb5yKktOTMXrDEayYL+xfFHlh+suVy5coUpSe/O1G6u97kEZwPL5SSvGv
7zeXjPUkNE6+411okGJBfYhr1LyFvwkXUbFnKgZ3n8uX967xlnh599QFqSCI
5Cx/+p34/wCG46c6
                    "]]}}}, {
                    DisplayFunction -> Identity, AspectRatio -> 1, 
                    Axes -> {False, False}, AxesLabel -> {None, None}, 
                    AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                    Frame -> {{True, True}, {True, True}}, 
                    FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                    Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                    FrameTicks -> {{None, None}, {None, None}}, 
                    GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                    Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
                    AbsolutePointSize[6], "ScalingFunctions" -> None}, 
                    PlotRange -> {{0., 77.69462845773928}, {0., 
                    19.13167049092163}}, PlotRangeClipping -> True, 
                    PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                    GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "77.69462845773928`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                    AutoDelete -> False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                    BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                    GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    BaselinePosition -> {1, 1}]}, 
                   Dynamic[Typeset`open$$], ImageSize -> Automatic], 
                  BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
                StyleBox["]", "NonInterpretableSummary"]}]},
             "CopyTag",
             DisplayFunction->(#& ),
             
             InterpretationFunction->(
              "InterpolatingFunction[{{0., 77.6946}}, <>]"& )],
            False,
            Editable->False,
            SelectWithContents->True,
            Selectable->False], "[", "t", "]"}]}]}], "}"}]}], "}"}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.662396743068206*^9, 3.662396748846792*^9}, 
   3.662396840028285*^9, 3.6623968792341986`*^9, 3.662396929458366*^9, 
   3.662396995778482*^9, 3.662397386109003*^9, 3.6623975027126966`*^9, {
   3.662397579628933*^9, 3.6623975956733627`*^9}, {3.6624500723972383`*^9, 
   3.6624500891581163`*^9}, {3.662450120984659*^9, 3.6624501316992645`*^9}, 
   3.6624502500811434`*^9, 3.6624503571029673`*^9, 3.6624504355635824`*^9, 
   3.662716091551535*^9, 3.6627247769976745`*^9, 3.662725127570041*^9, 
   3.662725669397422*^9, 3.6627259641125937`*^9, 3.662836722859*^9, 
   3.662877525506434*^9, 3.662913988599485*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Plot of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", "(", "t", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " crossing ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", " ", "t"}], "+", "b"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " line"
}], "Subsubsection",
 CellChangeTimes->{{3.6620182158535957`*^9, 3.662018243645214*^9}, {
  3.662029787277489*^9, 3.6620297879249563`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Plot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"0.03", "t"}], "+", "0.4"}], ",", 
       RowBox[{
        RowBox[{"0.015", "t"}], "-", "0.2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.07"}], "t"}], "+", "1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.1"}], "t"}], "+", "0.6"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"4", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", "\"\<t\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", "300"}]}], "\[IndentingNewLine]", "]"}], 
   ",", "\"\<s20\>\"", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.662018245411442*^9, 3.6620184065249577`*^9}, {
  3.662018577356539*^9, 3.6620185854762697`*^9}, {3.6629139827074995`*^9, 
  3.662913985159585*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.368417, 0.506779, 0.709798], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJwlmnk81N/3x20VhRhL9hkyY0ubtOKeaM9elnZZUhKSpLIUkRZCUiR8Utn3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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.880722, 0.611041, 0.142051], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJwVxX081HccAPCL8lR0J1nm6RzO75QZ1XjJfD4lSUtdN0kyVJJKd2JpiVpP
epKHq9dxlYqGHjz1cK7WiYb1stfSbUM7nDvOna9iVEIet/3xfr0ddgh4u/Ro
NFrwf/5fv8akSbM8x2/r/o4CsVgBTEsm2+6SACpHg0RHryrgozJ7g0J4DAxP
SM/vzFeAemVjd5UwCx6JhEluBQpoSdKWFglvwPzatQHPbytAnvGBkS+sgAZz
CSFSBQSLU+rzhDXg8fiiu3erAjLsn+WLhK/AWB+qW83b4M2owczKJDV4vph/
eo2oDbyncrgPEwh4ZrWcojHaobEz7KSe4xBcevbYm3euHXBVyETxjmHg25iI
W+d2QHhC0JBk6xgwj3I9ik53wDMH1xO1RZOwzmxOcrGxEkLyXG8p+TR8Pec1
Hy4owXpOtX92rB76zLp+gzW7E84sbXhQe3Y2Wi7+K9X7TCcEBK6LLk43wMaw
qZy8WSpoODfMPpVihJ0Dq7dlH1bBm4sWMlWeCcbfH5f/PKGC7YfuZw0J52Gc
jFeT66OGNFa9xzGpGW7xiorfl6qGL6bTRvT20HF0V8oHk2o1vPgu7AMzhoEn
LLNFGz+pweP6/tdp35tjUGdHVplPF6ze9DxckrgAJ12ciioPdcFi7caGxekW
2H+2kP7ySRck0g/4Xr+8EDPy3UMl412ws1zOe5ttiYuWSaWrvLqB7baPe6jw
M1R3HRT0/dANl+xWDygLFuFlhrv/8qpuiC6pEOE1KxwbHhla/74baIxQl+57
n+OVwY/DaUs1EDTgsyXyjjWy4wctQhI0EHM3nG8ls8HBGfsL/g800DU9Tyhv
tMU9gVHt0+81YPDrVMiOBjtsoosDo9x7YGY/Z8az1R4T3hmbKBJ6gFsf5CTY
y8Tpbw+S0bIe2GS79tWqXib67h282d3XAzKdZkDCd8Cq3JsVOlctHOmzi7Ac
cECbwPVtWbu1cCti9GvLZBbWmLpv493RAtNYINAfYWFw6LyxJzotbJj1ZQk/
yREzeGP8AZYOtHsyeYcnHNEo1trXJ0YH8rkZwQdSnJA/4e28pEAHznYuMqPZ
zmh++2KMl0YHrqlzPewuOGOs0bs0M6deOLUg6yPTmI3FbzY8PB/dC4HWlW51
OWxk9Wj8mIW9EBmRIOExXPB8VJIuXNUL7L7D/tGZLliYyYjbbk1gi44ZYGpJ
4UizDo5HEFDa7BaVXKbQK79q6RoxgVBnX22HiMI6SW3G5isE5G6MZeZiCrlN
v2ljrhL4xe/pH6n5FMbNdOaezCdwO3q+Ka+YwrzthpO1BQQSf5KenJRSOO4c
Vr/iLgHDJUYHNrVTKCv/FOLxlMCPy5Q16UoK177QL0cZgXHfB2YyFYXNKlND
bjWB/uCIUnYPhf101hN+DYE/BZW9E/0U2iatsy2tI3DtYVhk8TSFR72uatm/
E1gocytrp3HQhFvk99VLApn1epN0fQ6K4ipyA5oIHG8pFR8x5GC5uC4oRk4g
dpTWwqVzUDXxtqygmYB6psUx3ZyD8RYjBvdbCGw1upf41IKDY0to0bWtBNZb
baazrThIj7QwV/1NoMHBNWqbNQevJdvt+0dBwM91pizbloNUFlU/1UbgsWfz
ZIM9Bx+VeNqadhDwWHHnmwkHDmKtb7KNksC/2J9I6Q==
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJwVi304Ewgcx9eU1uvNSyvJGststGLVpZL9SiouHU4SS5Lq4jJv5ZCzVGOZ
jdEilJfYNO9aIvxWNtlzL3R3rjopRyrkHj16e7zk3B/f5/N8ns/ztQzmex8n
EggEj9n9TwNc+NvApkznHp1vZm6uHmkUGoOaxede3DaUf/uqHj/0Zux/Kkvi
smsTlJ1X9Ni3Q99/RyblCvILcZ5Mj93RgxWlshtc6+jh0cjLeuwSjxsVyKq5
fNpP7u4JevTIjdfmyJBrkFBqMMnTo3h1a4Fc1sm1s39/hkfT4/Anw5kd0X1c
4g/0qrf5Heg4nelZH/GGS7x5uIpj1YH6534XiPQxblFM/ERf+UOEnT6TZcHv
ue0U1jWezUP0j3AbUx/6zDVV98+RVLZjq6VtsqZ0iju8Zl2LmNWOPjm2Jb3h
BDjM5mnHFTo0n9fiknGCCBMOV7LI63WYskFXp0mdC1RS0J0JlRZd97gHlQkN
IezvTUXXHLSoE71nXIwnga/rv4+LG9twON20+UXOQug47xj84+Y2PBpbKx2T
LYaQpvTbBq0PMNFK65DUsBSE2hh/3tYHuO5L4kfiKTLsPum8z6LxPj487DdO
CzECe0MTw2y4jw7XTz9OjDGG4rNxJk9aNLjL676/OsoEnAaG3zxy0aDd4Lc6
O6EpNO58RuckIUaRI52uZy+DzWOKJZkJrXisqst7JIMCJLkoJUDUggx2mGds
8XJ4/Vyi1CQ3YxZ112hv0QpYQbt1KDP9HgYpquWQbwZC2eViTkETEox8bfpV
K2GOUiILz2lEt9GtBwPLzaFTrTSmlN7FkFv+4WbNq0B14tUWv4IG/OfLYlmX
3gLa9g59Dr12Bw3bp32CdVRYTyfuHVKqceY0a4bz12ooK3R2JpbcRk+t2xp+
KA2iKJlaYVU9elns7dz5mgbxLcr+ntY6bH41MKoOtwTJ/JeKn5tqMWGIyqOM
WsJHt03TjI4aLOF92k45awVPAn3GtyRXI20Bn2/w0Qq+Xxm6eFpeifvn2CvC
o+kQ4bjwwFG1CgdPSbzjJumQnf9uZOJWOXYtEntExq+BoHdzS8LaFGhNtWkm
zbUGEB9RGtWXou25RQ7UNGsoFO3q9asowYsm0g+0BQwojD3Aie0owj3mNey2
TAYIDgaorsTewEBehNrbyAZIRcc4IyV5yBiKcwmS2EBqtWDFhYGrePAVzXUJ
hQmO7mvzLj3Kwt5VJ+WKbCbYt68P/HpeBvpaOw0+kzOhL35V3vk3UuxiG200
zmWC56mncfJ2KT5wvvfoXMGs7/5usyZZisqgr5Z4l83+CXvqTCYlGHWz4cJU
AxPIMeuUTSPpOH8tKdKrhwmagOks0q9pKNjYi8JeJoB7U5SFKg0nnOqWNr+Y
7Y6xXhxRGr714FUwXs76sndLea5p+Du/5vXkWyYUdr4UVbdcxvx6v8CyL0wQ
uPyS5FslwmXN7MoeAgsIHFFgmFiEEi1ximzAAgFt93ZBqAjPd1fkJsxnQcQ0
TpQzRHjiE6Hbk8yCoIb6M9PXU7FvppsuNGZBV2mEj3FiKh4iqaLumbLAM5u9
wSYgFfeZHSAzzFgAkYoxz+WpqLO0PRJgzgLNkZDO4x9S0Nl2pjLDYrbvt6yK
/yMF73L+nNKtZkGN03OxtDYFHbaVfzNpyQJ7u7ywm9IU/A9J81an
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.922526, 0.385626, 0.209179], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJwVzH081AccwPHrNEmy83Sxq3Oezu+UFrXWSn2/pKRNHl6o7JIu09rGedgr
eeiVSkeIc5loaKUQKjHJOu5unJXXOiSpcTkuT8e5XstTO9y2Pz6v938fGw43
4BsyiUTy+a//1RMZypSf5e66Ucee1ek0wKAymPQrXHATpG1sX9TAjJx/4LXg
LPRG10bkaTWgcH869FCQA0YbDXqJOQ30xA1X3xZch/iKugb/KQ10Zr03KRbc
hwPFhgml/RrwKUxsLRCIQMt7pN3bqIEs6+bifEEHBIaYL8uO1YBqTl/nHqcA
WfsvHltfT8G2xVy/uugxSDyWo16xfwqevjl0gWz3DtJ1NT9XNKkBPQK1ZZxp
OHKiPOW4gxpCor3f1R+eh/AZnczr6iQ02zidF99eAFcf58C9ixMQWOBUKo8i
4fHqy/1mERNA+6hpNz+CjFIXP5nhaxWkbZbWitOX41TK6CwNVbDHa39YGU8f
vWcV6cEPxkF6aZqZmmiA+nGr6WEO46C6bC4cKDDEzEZj1YXLY3As/kHOO4ER
ujNjrbt0o3DGttXlbIMxNrMrM7dFjMLGpTOz5JMULLlmoY3qGIE/jhx6zwg3
wftLQ90yjxFwKYnsPfOjKaZvuKjcVzkMnv6SkPpYMxSkXGJP0oZh/bCvdD3P
HDklHKPKc28hlhLjVpJngVdbokRbVUo4fq8zYIJPxQVjed8kWwlM5+/94m+u
QcKe8WlTyxBcoXuq5TcsMfWodOLhliEIK7+fj0VW6HmzuOpsxSCQTIIdh6o+
wT/v7b/JoQyCt3r7wdA7NLw4eJjMPa+A8MqQKCvhWjQUJrmu7xqAwSUjQefT
ddjZcieCWvoG9NsWAzlSOs6vKYoMvCQHXSRL5/rSGu/pPh9qO9gPfq3e9tzv
GNi2uYCVtb0P/Nft6/AYZWDZqdB4je1fIBxRquujbNDUR+aa9v4VJI3T2VS1
DQ5xyZKYV71Qyp7bST1li8hUCPm3XwJjJZerN2uLS8T5THJaDxxYtqk8Ks4O
U7dnhJlGvYDhk9kBCVo7LBjYURq8sxs6V2X5xCTao3HXg0dqxnNwoDsKDZY7
oGlw147GyU5wSl7lQs90QGH33Yw9yR2QapYzw1jJRPM8993NXs/Ai1bj3JLL
xKwkove6sh1C2dH1ASaO+ER7leJY8QSY4wm7w7IdkV/YHayKb4ODI4w9q6kE
ng7lnKZatoJ87Yn88jwCGcIEGFNIINjBbbg/n8Cac7QqvV4JdDqbbDEtJNDN
q4lq/UwCv+963JVcTCD7OWkqqFECFWEfrw4oI5A/llbUkiuB2FsNFxYaCDSw
yP9Q4iGBFRsMYvz7CJyOrK0LuiWGlC1yEU9OYOrmQOuYa2L4x63WWDhAoNGH
mYwsvhgmfdjVzLcEbkj9gtOSLIbn3JpR7SSB4dfEFJcgMRTVHQotWyKwv00W
aaQvBguh890+EgtfWQ7W+s6LILuVvEDRY+F8qX0G760IzvVUFyatYOGm36q2
TQtFEDFH6vGjsLBipPGnjkgRKHQ9djxTFopjFn/QDxHBYYOq2MfmLFQsoOfO
vSL4yiqIwrRiIcXsyd+VdBFIbZyOfk3771eyqn3QUAS7nHR3+etY6MfyvWE5
1wyPXF8sSK1Z+O2vgtO+ymZw2XHnS60NC9PhpS+voxn+Bc1WSTI=
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.528488, 0.470624, 0.701351], 
        AbsoluteThickness[1.6]], 
       LineBox[CompressedData["
1:eJwVxX0803kcAPAdkh4UJoXMNja/zZBSr+4u+36SimoarwhJyCmuDHXXk13X
A12v5GHY5U6dpzwzKa3XkW86S9y9PJ2Raprt5yHl0oMSw9398X69GREiv2/0
KBSK4D//r48Xt2vXZ/AnE2NZ69ZpEd2CzqZlilCkNEK7eI0WTarSffolZ9Hf
soB8DU+L1JtbNXclaahWw7eRsLVIeWyo8qbkNxTntXzFW0st6kx5b3pdIkOv
qDUGMooWCXJON1+TYKQpf6vltmtQim3jdamkA3U+OV7AjNagsU+G85uPqdH6
kVUUauog2jibIbwdN4rUOfYVl5rUqHUg8IKe3QRKhLK5ubcvEHjsmSmO+IB2
1XoenuAPoOA474m6oClUekR2ZKz0OWpkcM8/uKlDVin+a4cnnqI917iFqlgK
TPh57hiFfmS94P6W9Cg9EEbozb6r6kOX1ilqH/xkAC29M3HzU0q0dfuOsOJk
Q3ic2XzWPLwHKS5/YF88bQTOU0q1S1c3Grtq3vDi2mIob2LqC2y7UPiJW2kT
kqUQWSL+cci8A4mZza5n5csgN5sndiv5EznPiT/qRZvAje4jtHTvx6hlf+B7
eqQp3MnbOaljKZDrjaN94uNmoNuY73O0sQl5+jYF1yVQoaaZW69i3EeOQ7sV
jsnmcK+CMjDCv4sSTOI33chaATVh7zItpqrRwepOv1fpFgDV+z0KggsQ2+lb
4YmClUCRpI+9uXMeZdI8x1X5q4DisWG8zSUdh5XIpJBrCeCY7d+TW4QppgEO
mgorOGwYnP101S3sPf7V3tAyazDyr8wiRHIcWR4ca9mwGoTLTdNEgkY8OLdU
0tlqAwZSTl570kNs+Gh2T4SCBl5U3paecgWeP8qZX9trC5GP5Ad7qa1Y2Oxt
L4qhw+HRIp8Wj7+wr41Xh8cIHYrqKdkV4R24YVg7XhfLgGBNAm9bRBc+85IW
YjHOgECa9H3Vx25cGPLJ3eJ7JvAnxZ+pVT2Yvkgk0v/IhF8uSCPjt/Viny/W
lMQes4OsmCjx474+PBSd6ndqxg5Ovp7usbnSjzuXpAjiT9tDO+tBRgzjGWbR
HBqMDFhgNu19ta7/OeYmLnGlXWHBP+wrG6YvD+CL1LRJ+iI25Cf9wPx1mRpv
t65x+iODDUhh6b3xpRqHhsTV+Zk6wM9hAqZv3SBmvzy1JSzVAdxLQ7qjxBq8
d5i+1diCgCD39vwzAVqsWn1IWpJFgIvzE7ulDBIHsDYNPZcSsFf5OT/LnsSd
TqZuZjkEnEu0ptsQJH7Ir+9KvE5AV1voamcXEpeGLTf2Kybgu0ND5kJ3EicU
yS/o5ATI894tyAoi8UKeUbzvMwIQ1XjUWkLiH91UOFlFwKHfnaOKskk8val2
WcMLAjLChSQvh8SvBSGVbJKAQVmm2j2PxN2impGZ1wQk7bLqP1BN4tzbgaHF
cwS0JDm0FbaReEWDU9UzCgfe8Ly9eO0kTm3W05noc2BlT8yjO10kPqeszDmz
kAPRzOqHiickjvpEUQpNOLAEu9WPDJNYPa+0SzbjwPqogC/jxkgcZFSRUG/O
gf3GJ+VT4yTeZelvwrbkQNW++tuLJkmsYHAP7LPmgFJP5SqZIjGfO1+VbsOB
2bI5mZWOxPfW9ugUthxw8KU7F86T2PXrsp0zDA7sntpc6ag/hP8FtZdYzA==

        "]]}}}, {
    DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 300, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotRange -> 
     NCache[{{0, 4 Pi}, {-0.9999996654606427, 0.999999982048042}}, {{
        0, 12.566370614359172`}, {-0.9999996654606427, 0.999999982048042}}], 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       RowBox[{"sin", "(", "t", ")"}], 
       RowBox[{
         RowBox[{"0.03`", " ", "t"}], "+", "0.4`"}], 
       RowBox[{
         RowBox[{"0.015`", " ", "t"}], "-", "0.2`"}], 
       RowBox[{
         RowBox[{
           RowBox[{"-", "0.07`"}], " ", "t"}], "+", "1"}], 
       RowBox[{
         RowBox[{
           RowBox[{"-", "0.1`"}], " ", "t"}], "+", "0.6`"}]}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.528488, 0.470624, 0.701351]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.6620182965052824`*^9, 3.662018361560207*^9}, {
   3.6620183917385197`*^9, 3.662018407064329*^9}, {3.662018582107893*^9, 
   3.6620185857194414`*^9}, 3.662913991064352*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: Trajectories in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"r", ",", 
     OverscriptBox["r", "."]}], ")"}], TraditionalForm]]],
 "-plane"
}], "Subsubsection",
 CellChangeTimes->{{3.662027962621642*^9, 3.662027979605631*^9}, {
  3.662028022046399*^9, 3.6620280259011197`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"CC", "=", "0"}], "}"}], ",", 
       RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], "-", "CC"}], "2"], ",", "t"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], "-", "CC"}], 
              RowBox[{"-", "2"}]], ",", "t"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"-", "2"}], "\[Pi]"}], ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotLegends", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<u = 1\>\"", ",", " ", "\"\<u = -1\>\""}], "}"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], "-", "CC"}], "2"], ",", "t"}], "}"}],
            ",", 
           RowBox[{"{", 
            RowBox[{
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], "-", "CC"}], 
              RowBox[{"-", "2"}]], ",", "t"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"-", "2"}], "\[Pi]"}], ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}]}], "\[IndentingNewLine]", "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"CC", ",", 
         RowBox[{"-", "130"}], ",", "130", ",", "13"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "50"}], ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<r\>\"", ",", "\"\<\!\(\*OverscriptBox[\(r\), \(.\)]\)\>\""}], 
       "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\"\<s21\>\"", ",", 
   "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.6620279835990562`*^9, 3.6620280682800364`*^9}, {
  3.662028228599197*^9, 3.6620283283746395`*^9}, {3.66202836468626*^9, 
  3.662028421772558*^9}, {3.6620284536870985`*^9, 3.6620285213658633`*^9}, {
  3.6620285823178997`*^9, 3.662028625947688*^9}, {3.6629139956363344`*^9, 
  3.66291399842122*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxdmGcgFez/xgkZka1zjKhQ6rHOKaXke1sV4jEbEqVHKSoR2UVkF4VUtjLL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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxdmGc81f//xgnZ2TrHiAqlvtY5pZR6f6wK8TUbEqWUohKRXUR2UUhlK7Ps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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hk0VV0bAHBj5nnoXjIUKmNIvW+Svc0NhoN7S5SpDEXmZEgoCamUWShk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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hk0VV0bAHBjMmbuXjIUKmNIvW+SfcwNhoN7S5SpRFHGZEhSElKpzKGQ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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hc81d8bAHAzM9nuLURkFSH0Teoco5T6cLkyGlYZRZGVVUaRWZKErJBZ
kYSscwsRMiIk2SujhBDid/r399d9vf855/Oc13Oe5zlX3MbZyJaBjo6Ol56O
7t+v131nZYN7VEiS1zFeEyfTKpVGot9FUSFbQhE9myiZ5s+dKa8WSYWrTOIF
gtvJNN+wrbtEw6iwr+8vmzIvmWZ8yX9pLogKUyNLkQMDmRYy2E+ke1Kh1Izc
nq5hEm32WWTJfgsqVM3nYXiZQaLRqjKceRSo0Eh2oMBuN4nWY2s+wPHBCIIy
RckHfEI0NxXdj1+uGsF4TcqfUT5BGuPlZ/DUdiPYlD74Vp0sQFu2zlecemcI
X8ZJZxiy8dNC87j2OHsYQqZgjbEoDj7aaJVSwsRuQ8i+hRVGrPDQwhL4flD6
KHDKQudu5BQ3jd5pbHfBYwp0upjsY/dtG83+ieSDP+YU6Ki4k12tYiuN0c7f
u0qMArV+aZylVHHQbHQHx5Z6DGCztcYD1w9stKdLIt6KLgawajlnXTCfhVYj
s8UpWNAAhgS9lN7ykpl2R+Zum1S1PixVlr59PZKRNnDhV6Gxiz5MjLlZP3eN
nlZ8U2m5fJ8+zG8Zib+0vIHOelV1nJ8n4Ny7TOal16tIXE95MOwXAR2yLkbx
Zq2icbXByyVzBBwMkxTYF7eKnKwnVrl/ErCNkinp4LmKLq2mMzdPE7CgP0O7
V20VSWu01pmPEfDqanpgdekfVLKxNtfRQ8AZpSd/Q96sIJGArHmttwScSEv+
LVS1hBLXYv39aQQMn528O5i/hCp1S9MqEQEV1FVkchOX0C/DR6n/VRPQvaPx
jLrXEiIr1N07UEFAui0r6Nz+JXSZueeg4WsCkhyNwp/k/kZcir3FC7kEPKHK
snNP3CJSpWk1aGHPBBqVLdxeRAziA84xOQSMbkk2rHRbRJHGr3z3ZxOwy17l
NmG4iCxvfQj2yySgTaL1d2fORcRC9/yCXCoBfTYrXhUHLSATD8qx37EEzP/g
cvyI8zyiMex7a47dLLEgZmoxj+QuTjZWP8D73fD440zMo8306fDwGByPsk/e
kz3zKJNbpUommoCFibc4mSd/ofH85in/CAKWOMa1NVn9QprDwpcTgghI21pp
Zm40hzJ/nqZtwx60P6LkqjmHWNsvPQ0JJCD9OxpbhOIcat22S9gzgIBannXl
lVxz6MyNzoqzN/F5ViUfhHE/kR1Js1bTh4APLWvefrzzA53WP/jHy5WAeRlc
nyYvzyDzF/sV2bAPCsnvszw5g3LWA0cSrhGwIfxk5Oc9M0j24nZU6ULAsWuh
x97NTKNSC3U9VmcCikGGisdXpxEDw4HCEkcCPur7naHvOoUo9BIVLrYEvC3w
zaPYexI1yD3248bmC1v7JHdmEkVo2ZcXXiRg+jpZ8Yn6JPqtsZY3fwHHO2Iy
FbU2gYzP81r52RBw7WWbhf2NCQRP/SVnWxLQVb9Wd3vgOGofrms2P0NAyzv5
5IDQUSRg8cyIAVvn42CCvt0o6v1QdjnfnIByfILbRXRG0birtuGmGQEXUwK2
l2+OICYOsZXnpvh8Sk7vWPQcQeepS8+kThOweGxT2MF2GOV3HTrdY0zAhD2q
yWraw8hbL/teOPbNa5dFmMWHUTzjXPkcFefX306R9L4h1FdxfLrGiID9/Hmi
fdQhdEtH6FUwhYCsOsZiFK1B1NtacQNiz4aFpYmKDaKikyG9awYEfJp6Q7N3
bQCN8kfpuWOrlxpp8bsNIMqsNZOTPgFtx9e1Q637kU6JzIDnKQKW6xjquhzp
Q6k5ckqrxwl4gX6VgCvdqDtVMLkRu4EjPsuurBtF2FwKfYytIKi2GenVjWz1
tL8dwV6Vcy38stKFBjIa/CN0cf4bT/G6/fmM5m6QczSOEbAqu7f76WoH6tvr
yi6AvavIS7G5vAMdzVaamT1KwNBKwbB5nw4UsjEq/wTbuN1IHax9Qu1qInlb
sadWG5N61trR7ZaO4A1tvH+SZ43gaivarZrQ34/9p7DI/YJPK9K0rytB2LV1
P3YXrragaXmjsSDssz/tQk+sfUQsRw8f2oYdqmVK+K03oSCWg/cWtAhINX2w
0eDXhLwePrbpwRZ1ai0Q+NuIuvke3snAfv1Ql7fg7wd0NtG8EWAPTx7oHtqo
R4VlEWQZ7Od/3UIV/OtRQLrkJDe2F2/hQd/N9+hBTzjjqCYBt2nIJPHTvUcB
LTL7o7E17pGsdelrUcHx+zf8sFkyjXljA2uQ+V0r3UvYn8qiawbpa5CY335z
HexLw6xSPgzvkMdQngcddpzqn6lnjDTkoyDO9gsSMMnp655lToSSJtmEhrE5
r9YGxvJWI/VM5fQ67GmXOPlWkUpU8tR1Zxn2GVf/W04SFciAf7dQPnajm8MX
Ntly9PW/IY8Y7DxP9WAdlTLU8mOqLwR7u5fE16GDpWiAx77aFzvcm1PJH5Qg
89SSOTvsy379fW/0ilENW7jmeezeG/XKppRX6ORQK6cxtp5/Yeji6SJU3F3E
q40tGxSkss+6ED1cMiAOYSuzdPMnfHyBYoMsGVSwedlzaR09z9BL3yEleex5
Tl8nrtE8ND30+asUdvs2gnTiZw7Sfq1BJ45dyLuz9tZqFnrzWyB1B3a0wC/n
auaniMiwLhPEdiHV7PjDnYE2q3ae4sWm7HhYv1/4CWo5SjnDhW2p0TLep5+C
KtUXhtmxRbVcjxjZJqL6JNZxFux+XcG4et849NMx+gIzdjJRPqsRE4PUcsLP
MmKXZVWGXzSMQomGyx/psQ8UMakb3AxGIg5d5XTYjr4Jn9xMfFHVtPSuf26T
pNrEWNkjn75pxn/uLFYO4igwACbqu6z+ORmU8HAmuQED5ia1f+tR+B+Y73gS
COwOj99h+Bc/68k8Rfcw8HjYjcqEnXsz8G96RjT4seiWsAV7yuvbU/moWGDh
Pm7Ohi3ndlC/zDMezFo1xXL++54rD5e0rJJAQvkuPW7srldereOSacAmcMab
H3upMEviGTkd6L2WkSRjC77ovH6NKxNQTLqPi/6LL5+hWY0xC7hdXJmQwDbL
URRbX84GxQMR9HLYXk8t3N/O5IJ7IuyZB/6dT2q58Kmu50B2cHEvwO5JmnTh
aSoAw9uMFHWx109F2EwPFIL8kgtZZtgiem9KCjuLQJU8iWyD/eJ4mxVf6ysw
wwO2OGEf0Z1g9/xQDDLFRw0CsS10BCwPVZcAecLmWST2D629bCllpaBjzOhW
PPZNTe1XdK/KgLdFRNpL7JQj11jeZ5eDvVfM479jD/z3sYByvxrMDywJrWJX
ZsprzqchkMBVKM2B79spVt3vJ8xoICLVY1kBW9Y922fa/i1Yv0eY3cAePumQ
rHCnBjQPNZjFYLcFkuw2uWqB30/L79nY1aUNCm1xtSDgyFB5J/ZjCVnataw6
IJSvuFMV1wvjte/DxXX1YO5rWJo+tpZSYn4w0QByGzZeOmAr2uu5m3xuALTP
h4JTsLd25DGvjH4AftUMs9y4nr3Pc5Q5xNQM9jbWvOXWIaDw86USK/E2IPSm
R2c/Nl+D/o4Ttm1g5AKbmQk2+0iWv1JuG9g5W6WQgr1CMj3OoNQOpFrcklVw
vf18u/RLBvwELjfyBvjhen33nNf6uGUnsL8+wpSDHXy9zao1oxMcG2wld2L7
xcjUlU50gpyxtQV5XP8dG3qiQp0/g5XqtEuT2MdVDu6U8+8C7fkiZ7xO4PmC
c1XzSkoPKBYdNc/FtsgR1W/+1gPKpmW7e0/860faZ/aIfAHisfv1gB7uzzci
Xb8//gI8RQEv10l83j9EM2wTeoEC+YBcDe5f79q1mSxi+4CgwgL9OrboVQfu
qo4+IJqsYKpK4PmKPUpYmO8biA6T8MnFVtbuUum9/w0sPWZOf4T7YUaxg63J
vX7QnpXnHYH76bumYxekjw6CqvPnZJux58jm37suDoLGq1EmWw3x+g6OziG3
B4FO6hXZ+9g+TNG+YzWDoPKg1MsU3K+VD395kKE1BN4Yex1vx/0944Vj7U44
DCZ2pcXF4vnh9v3o3aRDo+DPqlfZNPa5rZGhzudHwbxJ5RVtPG/sD7sz/d5/
FCQkBsUsYg8H3HzpUTsKEGVr3flzBNR0cTrcQYwBB68dLSfx/LKhf/z0Xatx
IP96u0scnoeuc9IFM4VMAml2nc1NbP3QtYmzOZOAdaRb/LIdAaWYlvVeNU6C
QDEgDu3x/V+b5bbZ9h0cb+RgW3AgoMr01yQU/x2ofkn2c3fC8X8oLfbJnwIB
o5kLY2643t9xHp1rmwFRneb5lu4EPDa53pA9PwOslyV+fcGWOBH+3IJ/Flh+
XpZq8yBgH/tTz2bTWVAwn3yo5jr+nru9rDn9syClaIS11peASg+PylvO/ADV
uqf3K97G+dS+tWL81hxgrG+rL4ojoPbACOPp1Hnw3wFVp6OPcP4WiohxFcyD
skOqkT3YnwJMNeqr58EjelZAl0BAq11N7gf758HngBXn04/x/bctGhMRWQCn
COZNwTScX9MB9eOJC0BGtKV9Cc/vyisiEV5xiyA2VVhPFr8PxHjMeJOilgCz
XMSX79iVXltEclOWgAAyXc3D7wmzwWLpkoIlIMjGMafwjoD3C3gOt7UvgXjh
3vzDdQRk0G+yZxJcBvGa2209mwg4Gn6kyillGcTc2tVvjN8r2Uy7HQ4XrAC7
CaOpugU8z6z8qupvWwW5vSdyBOT1YcRv6nhE0wZIMM+tXHDSh+9OeKfxm9PD
E3mBKX3l+tDU7azwkCcj5PLriXrCYQD5cp502bgwQ0HIWbDpaAAdSn0sbWJZ
4O0aE0WtFgM41l4qJRTLBkX6r1Xv3UGBBRp8LLVhHFApReLaiikF8gbRl/zI
3Qpl2z+UfoilwKRP1IyWp9tgNG+WhMRXChy8mbRPcJwbTpfqXHglaQjjNUS3
ay7ywOuWYhMmVwzh6GZ7xrE5XpigpOPrSzOEfoqt/BH0/HAjg/nzAV4jmGO3
IZlHJwD9S/SYVeyM4FptpWbdqgBMVfjLlllnBBOja4/uZBeCRsM1w2gXFX60
3pikspCgEsfZEAdJ/D73yg+p5iDBkODl6zxSVCgTbSYpy02CUVfh0YuyVBhU
XWS5QSJBfl7e0K2KVKi2w74rR44EmVOLX1w9TIVpna01fwkSdG1b8nc0o0JX
3Scp2bEkOCn936jIGfy+t9DX4E0gwc62m3FtZ6mw2WPti18yCbILCY+pWVKh
dOZpAaMsEvzhHifHYkeFfXTskeulJBjvGW5S4kaFR8tdvQ2/kuCZMbHHVzzw
+u07hSoHSDDmaaX87ut4/8nmYqlRErTYznT4oQ+OR1B6bm2GBF0+f2L0DqTC
F25f7bI2SLCn9UGZ8i0q/BoeysTDSIYlO85UzNymQtZ01XRfFjJsyV7Ksw6l
wgtt975RuMmQbbL5kXA4FUZPaPhW8JNhuXfOp+4IKqze+E6SIpNh/7mwsw+i
qHBa4FFJtAgZ/t//IfB/RQgOHQ==
         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8lU0bAHBr1mR3TiEiW/Eg9CQ1t6WUujkcWVqQshRFtoSyFFlLkpAt
ZK1IQraZwpOQJUKSfctSQgjxTl/fT+f3/zJzX/O75rquOZK2LiZ2TAwMDPyM
DAx/f73vuaga3aUjiqKe6aokFVWqDEe/jaIjjoQiRg5xKvLnzVTUiKSjFRbJ
AuGtVOQbtnmHeBgd9fb+4VDlpyLTC/6Ls0F0lBpZCh2ZqChkoI9M96IjmWmF
XZ1DFDTzNLJkjxUdqefzMb3IoCBUleHCp0RHJvL9BfY7KajbzrKf670JAmXK
0vcFRJC7mv6Hz5dNULw27feIgDBivviUOL7VBDWmD7zRpAqhpbP5ypNvjdGL
ONkMYw5BFJrHs8vF0xixBGuNRnEJoJEqlYTxncaIcxM7EbHMh8ISBL7Temlo
0krvTuQkL2J0Ht1Z8IiGnM8n+9h/3YIcHkvf/21JQ07K2zk1KjYjZnv/a1US
NKTzU+sUrYoL2eoPjC52G6Gms1r33d5zoCeLYteUXY1Q1VLOmnA+G6qR2+Qc
LGyEQoJeyG56wYpuy91plak2RKWqsreuRjKj/nM/C01dDVFizI13s1cYUfEN
laXyfwxRfvNw/IWldXjKu6r9zByJZt9msi6+WoGSBqoDYT9J5Jh1Poo/awWO
aQxcLJkl0UCYtNA/cSvQ+ez4Cu8PErXSMqUdvVbghZV01qYpEhX0Zej2aKxA
Wa2WOstREl1eSQ+sLv0NS9ZXZ9u7STSt8vhPyOtlKBaQNafzhkTjacm/RKoW
YeJqrL8/IlH4zMSdgfxFWKlfmlYJSaSkqSaXm7gIfxo/TP23mkQe7Q0nNb0X
IVWp7u7eChIxbFqGp/cswous3fuMX5GI4mQS/jj3F+RR7imezyXRUXW27bvi
FqA60qnXwZ4ONCmbv7UAmST7XWJySBTdnGxc6b4AI01f+u7JJlGng9ot0ngB
Wt98H+yXSSLbxLPfXLgXIBvDs3MKqSTy2ah4WRw0D808aYd/xZIo/73rkYMu
cxAx/fPGErtJal7C3GoOKpyfaKi+j/e77vnbhZyDG+lT4eExOB5Vn7zHu+Zg
Jq9alVw0iQoTb3KzTvyEY/lNk/4RJCpximtttPkJtYdELyYEkQhtrrSwNJmF
mT9OoC3YAw4HVdy0ZyF724UnIYEkYnyLOCKUZ2HLlh2iXgEk0vGqK6/kmYUn
r3dUnLqBz7MqeR8R9wPaU7RrtX1I9MC65s2H29/hCcN9v73dSJSXwfNx4uI0
tHy+R5kDe5+I4j/Wx6ZhzlrgcMIVEtWHH4v8tGsayp/fCitdSTR6JfTw2+kp
WGqlacDuQiIJgqni0eUpyMS0t7DEiUQPe39lGLpNQhqjVIWrHYluCX31LL42
AesVHvnxYguErX5UODkBI3QcygvPkyh9jar8WHMC/tJazZs7h+MdNpuMWh2H
pmf4bfxsSbT6otXK4fo4JI7/oWZbk8jNsFZ/a+AYbBuqa7I8SSLr2/nUgNAR
KGT11IQJW+/DQIKh/QjseV92Md+SRAoCwlvF9EbgmJuu8YYFiRZSAraWbwxD
Fi6J5Wfm+HxKTmxb8BqGZ+iLT2VOkKh4dEPU0W4I5nfuP9FtSqKEXerJGrpD
8JpB9t1w7BtXLoqxSg7BeObZ8lk6zq8/HWLpvYOwt+LIVI0JifoE88R76YPw
pp7Iy2Aaidj1TCVoOgOwp6XiOoE9ExaWJi4xAIuOhfSsGpHoSep17Z7Vfjgi
GGXgga1ZaqIj6N4PaTNnWZwNSWQ3tqYberYP6pXI9XsdJ1G5nrG+68FemJqj
oLJyhETnGFdIYrkLdqUKJzdg13PFZ9mXdcEI2wuhj7CVhDU2Ir27oJ2B7teD
2CsKboWflzthf0a9f4Q+zn/TSX7335/g7HVqjtZhElVl93Q9WWmHvbvdOIWw
dxR5KzeVt8ND2SrTM4dIFFopHDbn0w5D1kcUH2ObtplogtWPsE1DLG8z9uRK
Q1L3ahu81dwevK6L90/yqhFeaYE71RP6+rB/FxZ5nPNpgdoOdSUQu7bu+87C
lWY4pWgyGoR96od96NHVD5Dt0IH9W7BDdcxJv7VGGMS27+68Dono5vfX6/0a
ofeDR7bd2OLOLQVCfxpgl8CD2xnYrx7o8xf8eQ9PJVo2AOyhib1dg+vvYGFZ
BFUO+9kf91Al/3cwIF16ghfbm79wn+/Gf/B+dzjziDaJtmjJJQky/AcDmuX2
RGNr3aWc1WeshQVH7l33w2bLNOWPDayBlnds9C9gfyyLrhlgrIESfnss9bAv
DLHL+DC9hZ6DeZ4M2HHqvyefMiPooyTJ8ZMgUZLzl11L3BAmTXCIDGFzX64N
jOWvhpqZqul12FOucYotYpWw5Inb9jLsk27+N52lKqCR4E6RfOwGd8fPHPLl
8Mu/g54x2HlemsF6amWw+ftkbwj2Vm+pL4P7SmE/n0O1L3b4NW4Vf1ACLVNL
Zu2xL/r19b42KIY1HOHaZ7B7rr9TNae9hMcGW7hNsQ38C0MXThTB4q4ifl1s
+aAgtX/OFsIHi0bkfmxVti7BhA/PYWyQNZMaNj9nLmrvfgpf+A6qKGLPcfs6
84zkwanBT19ksNu2kJSjP3Kg7istBknsQv7ttTdXsuDrX0Kp27CjhX66VLM+
gWTG2TJhbFdKzbbfvBlwo2r7cX5s2rYH7/aIPobNh2gnebCttZrHeg1TYKXm
/BAntriO20ETu0T4Lol9jA27T1847p1vHPzhFH2OFTuZLJ/RiomBGjnhp5ix
y7Iqw88bR8FE46UPjNh7i1g0jW4EQzHHznIGbCffhI/uZr6wakp2x1+3StNt
Y2wcoE/vFPNfdxSrBnEVGAEzzR02f50MSvi4k9yBEWujxt/1aIL3Lbc9DgT2
B8ZuM/2Nn/1YnrJHGHg05E5nwc69EfgnPSMafF9wT9iEPen99YliVCyw8hiz
5MBWcN9nWOYVD2ZsGmO5/37PpQeLOjZJIKF8hwEvdudL75Yx6TRgGzh9TRB7
sTBL6ik1HRi8kpOmYgs/77h6hScT0My6joj/jS+fqUmDOQu4n18el8K2yFGW
WFvKBsX9EYwK2N5PrDzeTOeCu2KcmXv/nk9quejxzmdAfmBhN8DuTppw5Wss
AENbTJT1sdeOR9hO9ReC/JJzWRbYYgavSwo7ikCVIoVqi/38SKuNQMtLMM0H
NjljH9Qf5/R6XwwyJUeMArGt9ISs91eXAEXS9mkk9ned3RwpZaWgfdTkZjz2
DW3dlwwvy8A1q4i0F9gpB6+w/ZddDnZfsoz/ht3/74cC2r1qMNe/KLKCXZmp
qD2XBkECT6EsF75vx9n1vx21QCAi1XNJCVveI9tnyuENWLtLWlzHHjrmmKx0
uwY0DdZbxGC3BlLsN3hqgd8P62/Z2NWl9UqtcbUg4OBgeQf2Iyl5dCWrDojk
K29Xx/XCdPXbUHHdOzD7JSzNEFtHJTE/mKwHufXrLxyxlR0MPMw+1QP0aX9w
Cvbm9jzW5ZH3wK+aaYYX17P/8pzk9rM0gd0NNW949Ugk+myxxEayFYi87tbb
gy1Qb7jtqF0rGD7HYWGGzTmc5a+S2wq2z1QppWAvU8yPMKm0AZlm92Q1XG8/
3Sr9nEF8BBcb+AP8cL2+c9p7bcy6AzhcHWbJwQ6+2mrTktEBDg+0UDuw/WLk
6krHO0DO6Oq8Iq7/TvXdUaEun8ByddqFCewjavu2K/h3grZ8sZPeR/F8wb2i
fSmlGxSLj1jmYlvliBs2fe0GZVPyXT1H//Yj3ZO7xD4Dydg9BsAA9+frkW7f
Hn0GXuKAn+cYPu/v4hl2CT1AibpXoQb3r7dtuixWsb1AWGmecQ1b/LIjb1V7
LxBPVjJXJ/F8xRklKirwFUSHSfnkYqvqdqr13PsKFh+xpj/E/TCj2NHO7G4f
aMvKuxaB++nbxsPnZA8NgKozp+WbsGeplt86zw+AhstRZpuN8fqOTi4htwaA
Xuol+XvYPizRvqM1A6Byn8yLFNyvVQ98vp+hMwhem3ofacP9PeO5U+12YgiM
70iLi8Xzw6170Tsp+0fA7xXvsins05sjQ13OjIA5s8pLunje2BN2e+o//xGQ
kBgUs4A9FHDjhWftCIC0zXVnTpNI29X5QDs5Chy9tzUfw/PLuuGRE3dsxoDi
q62ucXgeusrNEMwSMgFkOfU2NrANQ1fHT+VMAPbhLsmL9iSSYVkyeNkwAQIl
gCThgO//6gyv7ZZv4EgDF8e8I4nUpr4kwfhvQP1zsp+HM47/fWmxT/4kCBjJ
nB91x/X+tsvIbOs0iOqwzLf2INHhibX67LlpcHZJ6udnbKmj4c+sBGeA9acl
mVZPEvVyPvFqMp8BBXPJ+2uu4u+508Oe0zcDUoqG2Wt9SaTy4JCi9fR3UK1/
Yo/yLZxPbZsrxm7OAuZ3re+K4kik2z/MfCJ1Dvy7V9350EOcv4ViEjwFc6Bs
v3pkN/bHAHOtd9Vz4CEjO2BIIJHNjkaPfX1z4FPAssuJR/j+2xWNionNg+Mk
64ZwGs6vqYB3Y4nzQE68uW0Rz++qy2IR3nELIDZV1EAevw8k+Cz4k6IWAatC
xOdv2JXem8RyUxaBEDRfycPvCYuBYtmSgkUgzME1q/SWRPcK+A60ti2CeNGe
/AN1JGIybHRgEV4C8dpb7bwaSTQSfrDKOWUJxNzc0WeK3yvZLDsdDxQsA/tx
k8m6eTzPLP+s6mtdAbk9R3OEFA1RxC/6WETjOkiwzK2cdzZEb49eSxO0ZCSO
5gWm9JYbInP3U6KDXswEj1931GMuIySQ87jT1pWVECa4CzacjJBjqY+1bSwb
cavGTFmn2QiNtpXKiMRyEGJ9V6p3b6OhAi0BttowLkIlRerKsjkN8QcxlnzP
3UzIt70vfR9LQ0kf6RnNT7YQ0fxZUlJfaGjgRtI/wmO8xFSp3rmX0sYoXkt8
q/YCH3HVWmLc7JIxGtloyzg8y08kqOj5+iJj5KfcIhjBKEisZ7B+2stvgnLs
16XzGIQI/xIDVjV7E7RaW6ldtyJEpCr94cisM0GJ0bWHtnOKECZDNUNwBx19
OLs+QWejECpcp0IcpfH73Ds/pJqLQoQEL13lk6EjuWgLaXleChF1mTh0Xp6O
gqqLrNcpFEKQnz90szIdaWxz6MxRoBCsqcXPLx+go7SOlpo/JIVwa130d7Kg
Izf9xynZsRRiQvbfEbGT+H1vZajFn0AhOlpvxLWeoqMmz9XPfskUglNEdFTD
mo5kM08ImWRRiO8ecQps9nTUy8AZuVZKIeK9ws1K3OnoULnbNeMvFOLkqMSj
S554/bbtIpX9FCLmSaXizqt4/4mmYpkRCmG1leXAAx8cj7Ds7Oo0hXD99JH5
WiAdPXf/Yp+1TiG6W+6Xqd6koy/hoSx8zFSiZNvJiulbdMSerp7uy0YlmrMX
886G0tG51rtfabxUgmOi6aFoOB1Fj2v5VghSifJrOR+7Iuioev0bRYZKJfpO
h526H0VHU0IPS6LFqMT//R9C/A8i0pcd
         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk81c0XAHBrdnFt95a1xVZk70lqxlLqZ72SUk+2CpVSlISyFFlLkpB9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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8lU0bAHBrdnFs55S1xVZk70lqbkup25IjKfVkq1ApRUkoS5G1VBKy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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk4VVsfAHBjxkrGc8xKpi4ZopKsZWhvQzhJom6mCpWuolyh0GgslYRM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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk4VVsfAHBjxkrGc8xKpi4ZopKsbehsQzhJom6mCpWuolyh0GgslYRM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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk8VV0XAHBExiTjvRVSMhUZUk9Se3Ou2ZWEyBOiUOlRlIQylDKWJCHz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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8VV0XAHBExiTjvRVSMhWJ1JPUPpxrdiUh8oRUqPQoSkIZShlLkpB5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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk8lc0bB3BE1iTrOQkp2Yok9CQ1ly3OKZJQWhBZih6iPEJZSllSKgnZ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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk81c0XAHBE1iTrvQkp2Yok9JCascW9RRKiBZGl6CHKI5SllCUlSci+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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hc81d8bAHAzs+IaXVulpRJSfX2unMe6UhFKmiIZlSJkFloyGipJQkZ2
IkQD52ZEkawQsrJXkszwO/37++u+3v+cc57zec7znHNXnnQ0teFgY2OjsbOx
/fv9uar9VHQbE+ibdQ/MrZRgeVp/WHmjhQl8j7PY+WQlWAvyu446NDFhlmtl
hrikBGuSJqWrUcuE1tZ5PlWaBCu5dmG4s5QJT2/lYXsOCZbg+4InuulMWDus
uLGhi85qPixxzu4SE7alCXO8jKez/Lz121dJM8F0Q3uG7Ro6K6Miq3CFqR6g
18oKD0RWsHrt70RkR+lCuJbxTLeIOIun/tCV8AkdqIjreE9JiLFGig9a1evp
wMuwdfEmfKIsITOZg22p2sB1Q6PntoAIq8zbWvWLgDbwL+GF4GlhFm3rutZY
Dy0YtNC9c2tQiMXR9GmPxRSAw6koL9vvy1lV2gZrf7sAnFWW49/+bimLp3Jh
3IsdQPuXxlHjAgFWyR1WxYgKgkorjQfOH/lYe0YY45aWmlAwlfxXPI2H5W8i
2MSfvhP8r75ct+QlN2u5iXSs4V8NyFNdd939FieroKzLKsVSAyLu+5SNXWBn
2c+fHL3YzoC0qh/hp6cWcN6YV9K7UwwYK3rGPflqFuuEnmKJWDPAPvHUbVri
LK48x/rqYMWAjkAFsS1hs7ipqOrPSgsGVBs/U7B3m8U1E3oC4eYMyGiL12ne
PouNPKKDs3cz4Pxs3JXCvBl8dn6qM0mFAcMqsfP+b6Yxg82w5wYHA/piov6s
KJjEalMbFhfYGBA00n+nI20Se949r+W5SIESpbY+JWISd8YroQt/KXCt+3SE
8pjEqseC5BwnKWBbMo2PbZ3EX/kzXeIGKaCfNQ2KTfmDpSxzTvfVUWCwjUdu
Y9gEPuN3I+RGLQXDV0xf/74+gbm0C9sVaigIqYoyyXeZwCtSbKdsqyhosFO7
bmgygfGSBwIz5RScjLAacBScwEvZjpQdKKTAa/Fdds7V3zhtMObWYAoFaR+d
dmk6jmM/bour2ckUVK7+LW9uMY7NyqsfXk4i812+OONoOI7n9RrFxBJIPKpe
qbEbx7HBSnsvkxgKMiOuCXL3/8KV5o+/LoZRkHs2rLrC8he+UqJer3qDAtbS
/EOHTcewQXuan9x1CjrsNFWctcawUFzd7qXXKGAvYvEFK4/haDnd/4b9KNB2
K32bv2wM58wmu+ddoiCoIEodwn7iCuWrAddcKXh4ovj955ujODXSefzXKQpS
45fV9p8ZxlnH7CxpxOorNm85sWcYG89wlm21pqA8aM+trxuHsWm5mo+nFQU9
FwKYRcND+HyBa6iQBQXywPHuyfkhzMl13vKcOQWPWv/EGzkP4hgOplvnbgqu
i32/mOPZj++abZ+RJxYJnKtVPNKPxW9UuVoZUBD3V0I5lurHA56TZj36JN4f
Bwdvz/XhpLcKrGldCuZeVlvYXe7DvuGzW40QBc5GJfqSV3pxfGnw42w1Ck7c
TJPwC+jGG/MPJXAR637ueGxk241fPbjw9eBWChRFxCVldLtxRY9/3IIKBRPR
fpJvF39gHnEYO7qF7E+umdSE2w/8JnH4sKEiBTk9i9L2Nl3YLN09NXMDBY83
bovartOFx0ON5MSIfS6ckeFe2YWVeToudq4j+TVfLxPX2onfuN9ruLmGgjbR
VNnW/Z14SaCSrcBKCnh1D8gba3fgV0/d5/zkKRgJDIyRle/ANo8EX03JUZDw
9LJW81w7/rhB8mG/LAVUnqm2qEs7jmku5m2SpsCm969OgFUbvulgUjhCp+Ct
rom+k2Yr1jQxOzkhTIE1+6whTDfiDLSZekhcLhCeaPu6Ea8orRXaQawkvn3x
lkcj/hTq//ayEAWzis6Z36YbcKH+vUXx5ST/DwzSXGa+4vY5VWNPQQoKkpob
E2br8JvD3aKKxKuyPJQr39bhQCPrphYBCgLyxQPHverw0vmPR7WJD9SYUmiu
Fsefow5I8VMwOPspsmmuBvNEJQnM85D5I92KxWe/YIMzqgUFxDOZWa7WXl/w
1aqgc77EJaWjazJnq3DD0WefuImP/rQNMJj7jJcFebnJLiHzaZsbXvpbgbmW
O8v2cVOw3/zBQvmlCvxLcUdpJrGsw5cMsflPOH2d4nJ94lcP9WkZ8x9xrlp2
qC8XBV39Oxo7F8qw5YUVW42J0+ddApR8yzC7nkH1SmIPWqa69+IHvPalGE85
JwXLNdZHirJ9wIuRJrbyxBp36Vb67CXY4t6quWkOCnieHaCFXinG2dLv79QS
174OKe5gL8Za07ZZAcSnu3jXenEU4cEisyE24rBtM4PPOVn49zFtWhc7BZEO
LRunBDH+r0ZEqYRY8HzJlVBaIXbdZaMbTDzkFLb5i0w+PrunR9OJ+Iiz7zWH
1e9w9PrdSgeJP7nYf+Pb8BbnXSgaUiBOdaNu6Kq9xpHfv75ZSizpsbqlUz0P
F6yuujTFRvLbU1DFF+XibM1znZ+Jz1xqa32zOwf7i4hee0vcfLlM1dw4G4cV
PZVIJt7tmxkwYZaF7TNs1vgTb7h6VW2LVSZWHHka4UasytMo+vjzC7yeG3PZ
E9P4U1h1Tc+x1VSR9RHicUFvh2XdqbihOC3PkLhmuSHd4GcyvnnGk02bOJMm
V3JtNhG7DG3U3EEcIvbLsZA7AT9hFjttJnaiF0vNCMXjBW8UrkBsLPWwbKt0
LI4KjsmRJj6hUdXbahSN3S/2looRy2o7a5raRODb6sKVy4nb9MXDyrzDcHuj
fBk/cZTh2xGN+/exg7FY3hLi14n5QadMbuNt8aNPOIl3ZHFR+3xuYPXq5xfZ
ic96P651OeiNPRv36bIRVyvsP3nf0g7/ed3I88/1OapXBTL2oeeuuqx/jkK5
woKRLiiaP+wcx7/1ij44LBV7BVV6VS7n/hc/755UZddAtL20L5GXOMXnynxc
fAhqHehTXUo86PE9YfPtUFTQX5lNI1Z0UTd67RaOvr0P2yDxbz3nHk5qW0Yi
lYt6ofLEDdkeX3oVYlApx7ff64knMxNXP5eIQ6FnTHapEou/qHe/sOwZevr8
xT2Nf/GlcVRu50xEPeVjX/SJDyUry/+dSkJ2eAXnAWKPBAvX98MpSJYhusvx
3/48fSu9tyEd7WcNHPYhborsdxKuyEDFcs8s7xD/3Rt8cqg9E5mfK9v7klhm
95vczPos5HVUWbWE+MWuakuRL9moabWPYBOxpn4fv9vHHLRLp/wpB8lPC12x
E4zCXHQ4ouSQBPGo9ia+6Nd5KLEiYYkKsY+WTjZb9mv0O19cy5o4WvMCz4ek
t8i8OUu5jrj9v88ZxvcK0Q88smWCOP/ZZq3xGIxUZCz3iZPztpdXf8DgEAuJ
oaHR48QbXJO8huzeo2m5J5mzxF177KOUbhajR8X3XiqQ8119hW67uKwETbfh
2n3EhXnlStVhJYj9ctHFFOInqzewLiSWIqWDVppnSL04MDfQlVNahtrzRLSi
iLVVItJuGJaj/ffmrWuIle12ux78Wo6upLnz7yT1aGldKvd090c0c4m7eSWp
Zx9Sz65ncFWiQ6E3r63kpUA6fTLXcmU1UnJ+GWhLLFJuJGVgU43KymiZz4n5
fyT6qqRUI9TsfVyDj4JpuvkuDpUatCeyjzpN6u3X63nf4qEW1YWuYZsh9frO
MY+/vSfq0ZfRD3zGSym44V5t+SW+Ht1mPd2aTHzp/vrSvL56tK9iqu/oMpJf
5U23Axy/orHLWnXVpB/sUlOXU/RtQLHmjJwxGrlfCM5qnYtuQqd3lmebipDv
lyxrVPm9CV1o3P/ilci/fqRzZKPMN6Sz3i7UR5T058u3nAeefEMjGj4K0uJk
v0dl420eN6OjqucP+EtQUFSjw2UR2oo2HevlnCaWPW8vVFDXinZSx1+ckST3
K/7b0tIi35G8iP6EqRSpNzoNas33vqORHQK6W2QoiM+xtzl4tw3FGpr9Fif9
taiCab1OrwN5vXttGk48JnF4oOFUBwr9LpkuuYqMb3/W0f96BwrQbDFdtZqM
zxXi3VPcgTxc9p7cSfq16s5vD+K1O5FzylhIHOnv8S/OlshBF6rSg80byP3h
+r2QNXRGN/r155dTI/GxpbcCHI93ox/pHi3+5L6xNfDm0AffbqS6jXvNwDYS
r5/Py4sl3cg3VjLo3X8UaDk57Kwz7EE1Y9sjH2lSsGC0y+yOZS86cmZbx6Y9
FLgLst3g8u9HRqIBC4vERgFzfUeT+5Hwhwyd+r0UrOWa2p39qR+xa/lo+xmR
8z83InRy+QC6F7qC1mtCgdpQSyQOH0Cnsxgz/YdI/B/zcrzSBtFiuUFfhR2p
9zcdu8eqh5FkSvZBbE8Bs/9vedL4MCoe1e/KPk3BaoOgdAvREVSY+tMw5iwF
rfwJbpXmI+h4D8Pd35Gs504zb3LbCNppUyYc4E6BykO9zSeGR9Hlu6m2lgEk
n2qWvuu9Noa478TetUmnQKf9B6fZ03HkdP5MU9ALkr+ZMvLLMojdz9BfZpB+
6WeuUVY4jpQ4hXzYsiiwXFXhqt42jlLZf7Wn5pLzb5PVIyPzG4VH8C9sZpH8
GvIr6434jfZpRMaPkPu86rRMsEfYBFqP1ENNF8j9U/gQLfL2JOI/IJ5dR94L
+R5LZFKiJ9FGn4wJM3YGHOrIWZebMYk20cQ7jnMx4F6G8M7qmkm0RT3H3Juf
ARxGFXZc4lNI5Zrap2FxBnQHaRY4RE8hBR69/BRlBiRxrbHfmTGNPlcl1Afb
MUBp+ldBW/UsMnn1wHhjMwOC/+zvDa5YQCrZpp59hzWgyMAzRvQwO9w/wLnz
zR8NMHc5Kt3pxgnS05lSOo92gkhybMNJJ27Y7Ee3WDTXBPs8rxMnQ3mA92a6
5XVpBD01eWtXhPKBi0fZTNYwggwNEZ6SQAE4qaHfNeYIQLvKnjuashRM4x44
PhgAiKzdH1+VsBzk1uzVZ7ppQYdP5BbxXiFodAz8YMunDeEaspJaE8IwWghV
6RHa0L1YE88co4GqdcDkJOjAJeUvosHsojCnL5Dq2K0DybYLCqlsYjDv8JDf
/pYuzJXka5XOioHm8VmRXXv0ICKkRE+OfwXEl9ws9eVmwmerhf79PHQ4KZ4r
WMNL3uceaf6FAnQQFPj5c5UgE9aHHFLYIEQHye9+QeU0JlwtzDqxQKfDegUF
ISl5JmyXsmtIVqQDv+bp498pJsTUfymeN6TDj5iRxQYnJjjrx0YnhdKhep9T
OcOVvO8tjDRoj+mQHDu/KdadCZUX575diqKDqNJ/n875MGHdMzMx00Q6tAxs
Mlt2iwmtbPy3/ubRQXlENN0hiQl6b509TVrokPNJa3tLKhm/Rm5FfjsdFPZ4
Ht39gszfX5mztpsO+Wq8XoqvSDzi68bmhunQkZrAM17EhBcuLbaJC3R4+XTd
BZsPTGgJCuAS5pSAszty3L59ZAJv3LY4bx4JiNw3YlZczQTr6rvfjYUkgFb9
eIt6PRNC+jS834lKgMtv44SMRiYULgzQ10pIQP4bWt7aFiYMiT3KDZGRgP/7
PwT+Bxu83ok=
         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hc81d8bAHAzu7jWtSktlZDq63PlfKwrFSFSKRkZSZmZhQYZDZUkISM7
mVHCORlRZIeQlb2SZIbf6d/fX/f1/uec85zPc57nnCtj5WRkw8TAwEBhZGD4
9/tzc++FuB46ou7RMl6REUHe1h9lArvoiONZHiOHpAhakz5s5thBR8ssMtlC
oiJoniKmpdpMR93dqxxKFBGU1rw22V9FRy/uFkF7JhHE/aH0uVYWHW2blNvV
NkBFnadFLttdo6P9mXxMuUlUFOCr07tZnI6MdvZm226louzavDJhI20E3irI
PuYXRsP296PzY7VQlLrB0iC/EGJrPXUjak4T1Sb2fSBEBNFUxUnLVm1NlBu5
PcmQQwDxmkic7MnQQCyBqkP3uPhRta+1UgOXBuLcwE6GLfIhyr7t3Qle6mjc
XOv+3XFexNTx+aj5AokcL8T62H7fhOo1dLf9diPRJQUpzgPveRBb3dqsDyOJ
NH6pmhmUcqHK+6h2ShGgOkvVx66fONDRKdqshYUaKl1I+yuUyYaCDLk7OLMO
oaCbuds35LKiTYbiCXp/VVGR0vbbnneZUWn1gGW6hSqKfuRXPePCiOxXraav
9tJQZv2PqIsLa7Boxif1/QUamil/yTr/ZhlqRlxA/NY0ZJ9y4R4lZRnWXUZf
HS1pqC9EVnBv5DLsKK//I2NOQ40GL2XtPZZh05w2V5QpDWX3JGl2HliG+l5x
YflHaOjKcuKNsqIleGl1oT9VkYYmFRNWg94tQhqD3lAgEw2NxMf+ES6dh8oL
O9fXGGgodGr0fl/mPPR+cEXde51A8oTyjvToedifJA9c/hLIveXzGcJrHiqd
DZVymicQw4ZFeHbfPPzKmeOWOE4g6iWj0IT0P1DMouDiSAuBdPezSe2KnIMO
AYHhgc0Emrxh9Pb37TnIolHWK9tEoPD6WMMStzkonG67YFtPoDY75dt6hnMQ
bnjMtVRDIKtoyzEn7jnIw3Cm2riMQD7r7/MLbv6GmePxd8fTCZT5yfmwmtMs
DGA1v5mfRqC6Lb+lTc1noUlN45PrqXi+61eXnPRm4ap2u6BgMo5HyScjYdcs
1JWx9zGMJ1BO9C1u1tFfsM702df1SAIVXopsrLX4BW9UqrQqBRII8ZScOm00
A3V7MwOkbhOoz05N0VV9BvImthzhuUUgxnLEEaYwA+OktP6bDCCQhkdVccnG
GViwnOZZdI1AoaWxKmTkT1ircDP4ljuBnpyv+PDlzjTMiHGd/XWBQBlJG5tH
HSZh3lk7Cwq2ivCeveePTkKDJebqfdYEqgk9evfrrkloVKPs521JoCGXYHr5
5AS8UuoewWtOIGmS6f3zKxOQmeWKxWVTAj3t/pOk7zoO45noHv1HCHRb8PvV
Au9R+MDkwJI0Nn/ISrPcmVEoFFjvbqlLoMS/IgoJxCgc8543GdLB8f44OX5v
ZQSmFsuiRS0CreQ2mttdH4H+Ucv79AGBXPUrdURvDMOkqrBn+coEOn8nUyQg
eBDuKjmVzIKt9aXvmb7tIHzz2OXryX0EkuMXEpXQGoS1Q0GJa4oEmosLEC1e
/wHZhMgZs714fwpNxOY8fsB3KZOn9eQIVDC0Lm5vMwBNsjwzcnYS6Nmu/bEH
NAfgbIS+lCC2n4uDBKvMAFRg67vavx3n12qrRGJ3P3zn+bDtzlYC9QhkSHaf
6IcbQuRtuWQIxK5lLG2g0QffvPBcCZAm0FRISLykdB+0ecr9ZkGKQMkvrqt3
rvTCTztFn4xKEogoMtIQcOuF8Z0V7B3iBLIZ/qsZbNkD7zgalk1RCVSsZajj
rNYN1QxNrOb4CGTNuKxHLrbDbLCHeIJdwxWVYvu2HQpXNfMexJYXOrB+16sd
fo4IKr7OS6BlOdecb4ttsEzn4brQJpz/xuMUt6WvsHdFycCbm0ClqZ3tycst
8N3pQQE57M15Xgp1xS0wRN+6o4uLQMElQiGzPi2QZ/WTmQa2cZMRAVaaYdJl
wliMk0Djy59jOlaaIFtsKtcqG54/xqNCaLkB6joolZZiL+XkuVv7NMCb9aGX
/bErq6a35izXwzazl59Zsc1+2gbrrnyBG0N9PCQ34Pk0TPWu/a2FLJtcJUdY
CXTC9PFazbVa+EvuYFUOtqRjQ7bg6meYtV1ukw72myc6lOzVT7BQOT/Cn4VA
A6MH2/vXqqGFi/A+A+ysVbdgef9qyKit2yiD7UXJUfFd/wi35Qqy1TATaJPq
jhgBho9wPcbQVhpb9QHVUoexEpo/3LyyyEQgtpfGlIgbFTBf/MP9Zuzmt+EV
fYwVUH3RNi8Y++IA+zYfpnI4Xm4ywYAduX9p/BUzgr/PalAGGAkU49i1a4Eb
wv+a+OUrsbmvVN6IoJRB98M2WmHYE86RexokSuClo0NqzthnXP1vOW55D+N2
HJE/if3Zzf4bx85iWORSPiGLneFBBGopv4Ux37++48EW9drS1a9SBEu31F9b
YMD57c2t6A8KYb7a5f4v2A7XerrfHSmAQfwCt4qxO69XK5ka5MPI8hciadhH
/HOC50zyoH22zdYg7J03byrvtcyBclMvoj2wldjaBZ59eQ13sEIWe2wKZzpq
6XgFLRfKrc9gz3L7Om4czIBtFZlFethNm/Souj/T4B0HbwYN7ByKVOWt5RTo
NrFL7SB2uOAvpzLWZPicXuG8B9uZWiG2xJsE13xBlCy2gdiT6n3iCTA2LL5A
HPu8av1wt34c9Lw6XCWILanhqmZkEw3vqfDVbcLu0RGKrPaNhL3t0tWc2LF6
xVOqjx5BRwPBog3Yb1NKQi8Y3oP7k6afM2MfzGMhjvsFQpXGV1cZsS/5Pmt2
O+kLvduPazFgN8qesHpkYQf/vG1n++fWAqWbXNnHwSt3LfTPsaCQjzvGDcRx
Rl5m+rdegcenxRJugDqfuk2s/+JnP5qh4B4CDlSNpLBjp/vdWE1MCgfdYyNK
PNjjXt+T99yLAKWjdfkUbDk3Ff23HlHg24fInSL/1nP5ybyGRQxQvKodIY3d
lu/VMCwbD6qYvv3egT2fk7LllUgiiHAwPKyELfS61dNl40vw4tXrh6r/4stk
qjvAnAKGamYadLBPpSlI/11IBXZQmNkY2yvZ3P3DZDqQpAkcdvq3Py+KxY+1
ZYETaOy0H3ZHzKgzX202qJB6aXEf+++xMKuJ3hxgern6WC62xJF3hTmtecDH
TEGpEvv14UYL/oZ80LHFj7sDW01nhNPjUwE4rFnzggnnp7mW4HlaWSE4HV15
SgR7WmM3R9zbIpBSm7xBEdtPXTOfIf8t+F0ipG6NHafmwvYxtRiYduYptGD3
/vcl2+BhGfgBp/bOYZe83KM+Gw+BooTFcSF83o6x64zpnkJAEExMn8Pe6Z7q
M2H3ASxKPc9Zxh44ah8rf6cCPK14mCuLz3fjDart+sZKsNgDm49jlxXVyDdG
VgLG6+VX07Gfb9mJXFKqgPxJSzUHXC+MV8YGCqqqQW8Rv3ostoZidGagXg04
8XDVuglbwe6I+8mvNeBGpifnIVyPeFoyWBcHP4Gla6ydMriefcy4tIPGUgdO
Rdy5JcNOIPGs+UILmUYg75obYovNX6MvpmvTCKqrKTmvsDl/pPgrpjcC0Ol7
TpWDQItU08NMik3gaMwIcRHX26+3i74lkc2gJWIrwxKu1/fPev0dPt8KGqY/
chjwECjQs9GiIakV3EMv9qVhX3u0o6popBUcr10YMduI86um416w01cwc129
pRH3g8PKKlJy/m0gwZRWMEPB9wvuZfXLcR3g4qGafCN+/P3SJPXrvncAl/YT
r9/w/+tHmmd2SXwDmjvsIvwEcH++ftd17Pk3MKXqJysuhPd7WjLJ5lknMFO6
YhwkQqDyJk0W84husPvsMPMituQVe97Slm5wiDj32kEU368474mL838H0vw6
c0ZiuN5otil3PvwOpg5yae2VIFBSgb3NyQc9IEHP5LcQ7q/ltXTr7dp9wOf9
W6Mo7BmR02NtF/pAxHfRLNHNeHz7S05Bt/tAsFqX0eYteHyWcN+hij7g5XbM
6hDu10qHvj1O0ugHrukz4Ym4vye9vlQpRQ6Aem1yz058f7j9MHwrlTYIfv35
5dyOfZbnbrDTuUHwI8urKwjfN/aF3Jn46D8IlPazbh3bj+MN8Mu9WjkI/BNE
Q9//RyB1Z8dDLXpDoGnmQMxTNQKt6R82uW8xDM447O/bfZRAntwMgSxBo0Bf
IHhtHVs/eGXELG0U8H3M1mw9RqBtLAtH8j+PAkZ1P40AfXz+V6Z4rTaNgYcR
wpRhQwIpT3TFwKgxcDGPtjR6Csf/qajAJ3McrNfojtTa4Xp/x2lwpnESiKbn
n4T2BKKP/q1JnZ0EFdM6A/kXCbRFNzTLXGAKlGX81Iu/RKBuzmSPOtMpcG6I
5hnkhNdzv5M9rWcKHLKp5gv2JJDiE+095yenwfUHGbYWwTifmnjeD9+aAaz3
Ex7YZBFIs/cHs8mLWeB8xaEj9DXO3xwJ6Y3Z2J4O1Nxs3C8DTFWry2aBPDOv
H0MegSw217qr9MyCDMZfvRmF+Pzb5A1JSPwGUdGca3sQzq+JgOrh6N/guGpM
0hS+zystSoR5Rc6BHUAlwmgN3z/5TlFi7s0DTmOh/Bb8Xijx2iCRHjcPdvll
z5kw0tCpvoLthdnzYDdFqO8cCw09zOY71Ng0D/aqFJj6ctIQk36tHYvQAlC8
pfx5UoiGBkPVSh3jFoAsm3ZJugINpbJstT+UvQi+1Ce3htnRkPzir9KexmVg
+Oaxwa5OGgr7c2I4rHYNKOYbeY+cVkXlut7xAqcZyUfGzIfe/VFFpm5m4v0e
zKT4Yo6Y5tNDiD8toc3KmZXcE0A1XzdVQ/ZFPuetIthI9jtZFrfFARpqKtom
HMFBunlVL+VNApStys9WGcJFWqnqDMw4kYhyk7FwOp2HNEp87PR4jEQxzSeS
6pM3kVJbj+nQPdRRn1/MXqFhXrLdKeSjLYcGilKVFFWf4yOny8j6rGgNNLje
lESfoZBK1sHz86QmuqbQIBDGKECu6HBlOA1qojTbNdkMBkFy1fEJp/1dLbRS
WaJetSxIqp1b5j98VBtFh1dqS3EKk0mVd6r8Wenoi+Xa6Ak2KmklVMjdxI7f
516ZQWVcVJKb6+fPzdx0tCP8lOxOXiop+j0gtIZCRzfL8s6vUankDllZXjFp
OjogZteWJkclOdUunvtO0FF8a0PFqh6V/BE/td7mTEeuOglxqRFUsvG4cw3N
Hb/vzfVVKc+oZFrC6u4ETzqqu7ry7VoslRSQ/+/zZT862v7SRNAohUp2je02
2XiXjroZOO/+LaKSClMCWY6pdKRd7Opt2EUlCz6rH+jKwOM3SQmX9FJJ2aPe
Zkde4/lH6wq2DVLJEmV2H7k3OB6h7TMrk1SyLyOZbbacjl67ddmmrFHJ3Bfb
XWw+0lFXaDALH7MIeelggce3T3TEnrg/0ZdNhIw5PmVS0UhH1o0PvhvwipCU
xmd7VVrpKHxE1fe9gAjp9tsgObudjsrWxqjbRETIkneUom1ddDQh+LQwXEKE
/L//Q8j/Afl3Z5g=
         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk8Vs8XAHBCCpUe20OJSpsi3Es/kjk8SipCSaVFiyWRUEJlK7KUKElC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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8Vc8bAHBChErXdilRqaQI5+BHmMNVqAiRSosWSyJbyVK2IkuJkiS7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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hk4Vd33AHBE5nm6ClGKzr0koXjVXqakXpJIpUyZGhUlmcJLGSJNopAh
EhmKL0L2TUKGzMo8JJGxmwzX9Dv9+/vrPJ/nPHfvvfbda639HHkHN3MnNhYW
FhFWFpa/z+nN/Y6JNgAUZQOLJXkp+o0zVfIh1gDccW9YuWWl6KtyB6wvHAdg
ssvnSmyQos+JbDTQMQfo6VnhVhORome0rE4MGgI8u1OEXdmk6Hzv3z01UAbY
NkFQO4Yo9Px8ta7PCwg0soTZXqdS6CzzUeWGexCYb+/Pdd5Kods8dvLb8Xwv
oGJVhQeikvSGZmkNl390IFbXbHFYVIIukPGabeeYNtSlDLzXlhKnd93OrsiI
0ILXMYqpR7jF6HKZ2q/KLPcAe4jO90heUXrUfJVjouRu4FnPBRELwvStzqbF
+r804KeNQdSdn0J09rxHj8um1OGCY4K3c68gPSHk/r8jP3bBedVNPJql/HSB
2JXvf9h2gd4vHWuzd7z0yih63eRONai313ng/ombfmjyH4ad3U54N5+xLJHF
Sb91hO8rT7Yq3Ap6rbj+NQddJmWP3tOFHVCkphh8/c46us/djx/M36vAk/v+
1TNXWOmNzI894+XKkPX5W+zZ+VV8cfCP6fVPNJipeM4x9z8mDlH6FKBYRQPX
dMdIkXQmju0OyOqsoMFAmIL4jhgmzgtJGNcvo0GT2XMFV08mThmLkFDNpUFu
X6p+lyYTP53RkXR5RINLzJTA8qJF3MGc/nD4DA0mdiav3Hq7gK+xPKnl5aDB
j6SEP5Lv5rDr1NHVFVYahE+ORg1kzeFfsr1BjFUqqGirK718MocrjE77Dy1Q
4Wpr7UltrznsVCyG+iaowLJ+AZ/aNYczxe1+GLRTgXLePDz55R+sSXdt/fyC
CsYanJuoMbO4jYVXnjeNChOB5sW/g2cxV7AvNk6hQvTnhCNlHrN4h3nDVEM8
FTpc1INNjsxiP/5tkox7VHB4Yj/mxjeLN7AURL30pYL3Wml+QdBvfKxdV6r9
KBWyPl0+sM+NgVl4y9hdjlChfstvOSsbBs6MTqYumZLz+V1bdDNh4KWIHCpx
kIxHzTszmcrA9/WaZlOACnlP/uPjGP2FY3PVstaUqVB4Pqapzu4XZgvzyHDi
oQKdv+z4CfMZfL/cihVxUWHAZd9Od90ZLG/w4tGG9VRgraBzR6jOYB0Uevkr
KxX0PD+WlAnMYJc/R6YvLRIQ/i5BC2Km8WN7dmHOMQIe2X5433B7CltqfR/+
9omAzFSBltFzE/jM2890hRoCtCSVd9gemsBJDM4olyoCasIP3WmnTuC06LPL
jAoCvl8J3V8xMY57vceU5MsIkAO20qeXxvF6rh56Vw4Bj3v+pJq6/8SI485E
xSMCgsV7rxXcGMWyWRcYug8JEA1baiFOjmIaT8JYxX0CUpalVJO1R3HL74ms
2rsE0L8d+xm59AObXjMO+BVGwNLrJhsXvx94TfWPS7w/Ae6mlUYbAkewYYTk
LpezBNjezpIKCB3Gx7xeH+R2JcCgYSDO1HkYn1X8lpntTAAhKrFBxmAYP67j
N1w5Q8BsYsCGkrVvWJAWMFBkQ+5PoeXGWc9v2MOkM/+JBQEF39ekXZ2GcObJ
aQv7owTEUTUSNPWH8PD2hH2EOQH+V87JcMgPYVsB+njFYQKMV9pkUnoGsfv0
5mzBQwT0iWXK9hwdxLwip+sl9AjgMrCQM9MbwGfR9ByrLgGTYWFJsnIDuFZF
6tw0IiDtmZ9u11I/vn9UnWjeS4B2kbmemEc/Rv+7LZynRYDTyLJ+qH0fFuhM
8e3eSUCJwRGjy/t6sE9KZuXoFgLOsDJNYOELtrl58ipBuoY3Nt25+AtWDk+T
v7SZABUJzbU7Xl/wg+3815bkCGAS7nmdCx3Y9+7mNWVZAqItfop4LLZjPO+U
xKAQ8O5F15c0Zit2z6/ZbkF68xsv1fqSViySUJVXJElAaJlEGMO7FW9gPigK
liDAotlcGy21YMPuqxmaYgT8ZNbGf11qxoLahyWZguT88Z4fJJiN+EGbo7cP
6cW8N1fPeDdi9gTx7lUBAio/Tm3NY37G2UUHHvGStp52DjVeasAbxf5M6PCR
8+lZmfgu12Eu2WGdz7wEHLV6sFrjW4cHLS+F25OWvdCYK75Si60PW8hG8RDw
v0dGIrkrn/D5s87b17gIGBrd/WVwtRrTh1Sck0hnr3iEqtysxmzh95P0SXuJ
5Gn5rFXhfx2oAtGcBAjqKMWLsVThVa3UelhPgM5dir0RayUu3Ww494uDAM7n
FiIPAz9gZ60gmTTSLcXRHwZYP+DAmQZHYdJnh7i2ebNV4PaQrA5WdgJiNBZ/
vlpHxz/eBitUriMg/kI3dZ4P48spiqdCSfNdqgx8KFKOR6NrQyVIj1+OUW6U
KcMdMbV+A2wEnHS/+d+FLaVY58jDU69I13q4dnJvL8EXvwV/MSad6akdYqBe
jPeUZnlsJL3Ba0v3oFYR9jGKX5xiJc/3Db6dN1EhdvLrqnhK+pxvX8/bgwWY
X1Fp/TXSXX7ValZm+ZgWgnaZkT54My901vINbrSpO8hHentQkPoO+zxs0YU0
JlkIUOP8IhbXkIPNePy5m0iL8Lykt359hSumQqoLSDP4fC4IDGfiV7et3J6S
bhY0oRhPZ2CBdgZLMOk8kU2V/zHT8UiHle8l0tHiv9zKOdKwRuStwZOkL1M+
bFwUSsXL8/6qxqTNNj6q3iWdjLUldc9qkbbV+TzSY5qIp37WR1BJy+q57zN3
eoI3emyO3US6z0giptonBpfn6kaJk04wKZnUuX8ff00iLvGTLk4vC3c8EonP
7e/dzUl69xt27cP+Idg96cQ4G+nzPnEtHsd8MCPnWSgL6SaFow737Vzw2JVc
wb9uK1AL4s09jKzGQgNY/46PCoX54j2Qjjitm/3vesUenNiYHIji/sRu4vkb
P9ehTNWrYehieKOJMOmX/oErKanRqKi10WkD6Z9evWnKkQ/RjeY4l62kCQ8t
02LPWPTmP+Wjan/Xc/HRnJ5dPHL4Ga6kS7oj36txRCEJhXO8+XGE9Fxe+pZX
UilIqT0l2pG0RE7b9SsCz9G+E6e33PgbXxZbvea6dFR3b/DZXdLHM1Tlludf
oEb/HeszSHul2Vx9P/ES6XgqRff93Z9nJdL/dmSj9IDW/GXSX+NHLwvX5aJb
6MB7afI8LP8b4TDen4eyu6LiHEjLHHxbmNf2Bv0utHMMJZ1zoMlOtDEf5Rkt
U/JI7zP6weP5qQBF34pGHOT5tDEQt/2nvBDlq4e9ViM9pUfjTiwuQiaPD/E7
kPbX1c9nyS9GIzeUg6pIJ+67wln1ogTlFDjZp5P50b+nIdfsXjmqutltO0q6
7LmyLiMJozPa9EQamW//chmNGR+nI8K/o7eU9ParL7zHXd6jX0jT/g+Zn0OH
XBNUbn9AKre3nDEm87spkOK8JlCJZt7dTHtGuryoRqUpphKxMYPHzcl68HTL
dvqV9I/o9KsK3zayXlgsjQ0VfKxG2E0xSJubAL2dT7JCTGpQ+ual6hTSqi4H
rx5rr0FsVtNi3mQ94m/N5FgY/oQYizwF+mQ9q8o8r/QPez3KVRLk1BciQDp7
rtBOvgmdGnYQbSAtWmO60dipCUXe3Wp3QpgAnm/pN3e+bEL+BfMlXiIELFCs
DrDtbEaP9zReayHrbXtwUWcqtKAX2w+xMKQIiDrltTxi24YSeyNFkzYQEHK9
ya4xtQ1JBSIXs40E+N5X+lj0g3wfM91YJE2er5qvkaFu7WhgKSg9eRMBB9S1
NhE3O5Berqfr4FYCWPmYuhcTv6IW72iXtG3k/5cha1rf+xUN5bw4dV7xbz/S
P0mV6UQhZp+VVpTI/ux3x33saSfqurF8YA+N3O8p2VSnuC5U5NiTwbeLgIpm
fXabhz3Iqriec4a07CVXoXetPejG1ZJT7eoEePNESkuL9iLYFjWapknWG/0O
9a57vajLTSLURpuA1AJXp2N3+5De08wRZbK/VtTtP6NoOIBmPa+kqeoTMCN1
YqzDcQAplmqc1DAgx3c973YreAAJ+RWmGewnx2eP9vn+YQDNjMRWeh8kx9/b
+SBVbxANmw/KG5L9PjXnfOUmGELxEQEnzcn7Q/C96K2Uf4bRt/FvgzkuBJzi
vxPqdnoYVVn/KuQn7x+7wm6PV90cRo7neA62nCfjDfB/fa1yGK3oaYhdv0KA
7uULe1tNvqOUwYt7dvgRsGp6wDLKbgQVtJ2jn4gh4DofSwj7rVEUryS0svaY
ANPQpR/WGaNI/o7t7Yw4Araxzx/Mrx1F64KWg1kSyPxfmhRyEBxDm7fvUKhP
JUB9vDsex46hVsfrjObXZPyfigq8s36i1XsPPj9uJOv9bbfhmaYJpG7uku3f
TMD+0eWaF4wJFNJ7t9KllYAtxuHZNmKTyNey/yl8IaCHJ82z3moSldZen+Lr
J9cT1cWV0TeJbtRGbRGaJmDnI0Nl24kptChr2UAXooJvM3/pyH8ziEdaf1Pd
SSro939bZ/mMgfp72vLET1OBJ09GTiCX9FSbqoMtFVoCrHSqyxno9Hq5ZRZH
Kthtrruq1cdAFuuGsOVFKvg7vfkuI/MbqWqIL1sHUKFkPKB65MlvlOi1x6ib
vM+rLchEeMXMoiP+7kppy1SQEz4uEh85h0QzaM4v1qhQ5rVe5mXiHLJcthnL
YqPB8YECxcLcOXRCgUYv5aLBvVzhvU3Nc8jG3TV3TowGbKZ1LuwS88h+/dmH
nco0GA7f9+5C4jw6IBDuddSeBi/Yt7ruzV1AcQmHXko20kBl4de7viYmSjmn
mHysQBki/hwdiahbRQ7OaYzP+SpQYXwjSewEKyi8XO/tPr4DrDyspQc914H0
Qt5G/ceqIJqR3OFwmQOUAyg2a1Y7wbXI29bhISdw3c62C5ZWg+/NRdskH3KD
h1f14psJNcjVEeWsDOOFSq+oysH+XSASxFo49ZIf0gwU+7e1qkN8y9HUz2mC
sO9gbNSdCQ0Y8I/fITEiBDn9IpENIrshVkd2g+6sMPT4BcZba+yB4bXm1P0z
IuBYJTQ5GagFvqqNYhGsYjB3V8Kiv0YbMpxXFTJZxIHZSYg3UXRgqbJM9yNT
HPxKZhWjY/bCk+hKw008krA/TDBijQdBg/3q6FFOCnykXZBKEUbA9Mq6Vc5L
AYpEX78hBYFS9HGF7UIU0ChhFb+3FUFQ+RvbVQoFzA4ckNMEBJobXToyCAqI
+baUlFxDkNTW+GHFhAJVut1r2YMI3I2SE188pEDys4Ho66MIntmY6ojEkb/X
XzqhN42g/tpSp28CBRRPXX7YvYxA8bmluHk6BbrHaJYCfAA9LDx3losooDop
ln1BEcCwxP3GkW4KFNTqanYTAO7NmyTL+imgcOiG9UEVgKTR+oJtwxQoU+fy
JjQAmBKKM0sTFBjITONk6AHkeHQ7p69S4PUzxStO+wG6w0PZhddJwfndBZ6d
xgBcKRopPpxSEH940vKDGcCZpru9ZkJSINIUt0PLAiD6h45PqZgUePw2S8u1
AihfHaNsk5KCsrciRdusAcbFHxdGy0jB//seAv8HNLvj8A==
         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hk4Vd33AHBEZpldhSiFc69CVLxqH1OGXjKmUqZMjYqShOSlDJEmUciQ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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk8VN8bAHBjSZasg3FnxlJEZC1iUuexpRQhRZulsrQS/UopUimkUqGS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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8VN8bAHBjSZasg3FnxlJEZC1iUmdsKUVI0WapLK1Ev1KKVAqpVKhk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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxdmGcgFez/xgkZka1zjKhQ6rHOKaXke1sV4jEbEqVHKSoR2UVkF4VUtjLL
Dp1wn4yMyIzskT1ykg6O9ev/9v/qenW9/nyua5fNbRPbLUxMTALMTEz/lwM6
FfVq5WREkNc2W91FpC58DtPiKiEjzhcFzJw7idRVjYji73lkxGDdlSsiSqTO
yagEub0mo76+dU6SAJFq9Ga9uyqUjBLDSrDdFiKV6Od5ONiCjGRn9x/oHCFQ
CwtJPV+XSehQNv+W/FQClWnpcYXOERIykRvMvSpDoFo9t/VWfK2EoFRJ+png
DurLVNUbX10VUKyG0cqooAhVzOgKm03bAfQlZejTUaIw9T3vhQDjHXIoP2Zv
qjGnEBXMXM65Z8si1gC1sfBtglTx+fB6NUVpxLWVA4Uu81P1GuMcA0d2oWkr
7cdh03zU7dQzVgsUSeTwX7zH1X5e6l0RPdKLRDFkryTJpfKRh6pyif68axsB
af5Su2BUvo3Ke2yLYkmtEGq8rPbMqZ6TeuD9fN1DX35UvpSxJpLNTlUMs6Ge
seNBj/zy927NZ6O6BI1w3BxhRyWkvf73wlioM8dFePXZWNDLpz61tDvMVPdO
xXGrpXXI/voj9vrSBr6+LfceRZ8OtMrXbPT3DCynrbtVTZkOdmn/hQukMXBl
31bLJhE6DAVLCyvGMLCX/Kyl5MgfaDF6LW3nysBCBtZFD9z/QO5AqlaPCgN3
+098OJK9CLcYKb4VJSu4sPO+pI/ob5hVTl5/9GEZZ7G0mFnto8FEUvyfHeV0
rO2cuDDPS4OQucnHQ9l0LDjfKr9vfh4Ujh7cl/mSjqW9Osb2Pp6Hu+0NFkfd
6Fjvkf6vH00/gWnrMrYk03GcBbOrodkcEOxNQpIz/+DLLGEqc17ToHuIXfJA
zCLW4snjKzCahllfk9Lf/ovYB9UtvZKehoiv8cZlzot4fve32YHGKei8dtDf
wHgRt3ddctolOQU2Ly9P3eZexCnMaCa2YQI8Nj8WFvn9xpfNJaKMj49Bdr3j
KfXbC5gjj6rvKDIGjXt+S521WsCJXERKwfwozHq7rNw2WMCZeJKSkjIKCiSP
rOQDC5ggx2qgyDUKeS8fcrNN/sJuK/sLGYMjUGwf0/Ll0i8sE3Ek0CJtCKg8
ZefOm9CwxJSnMO3hEAxdU1d20qBhTs27FpmXh4C5ksoZqkTDpb8fcgRKDIGm
aw2lbDsNz7xVn+6XH4SQ8nhVFDOPe0hhUiNS/RBtXfWpKfAnjt+fHuel1g1Z
qdvbJm/MYpt/uoixrN2gukNe0Vp/Fi+bblB/NX6HuhD9sG8HZnGUECnc2uo7
jN0JOlE5O4NfXlCUkPHvAim05eOrWzO4hclX7FzvN3je9yfV0Gkaj6Q/iLxY
2gb+wv0uRe6TuOpKtIF6UBsIBq+27beYxC46yeSL59ogZY2olHx0Eut7JHib
r7QC9ceZ6fDVCUzNVOBUUm+F1fwWq2veEzgLTq8T05vBybD6pKjvOD7dOlLT
eL4BrAOziQ+CRrGnsNVbky0NoN009MLw6ig+0VNfeiO7HvYLiohKaI/ijDEn
LePNOlhMeCBK2fyB81m2SS2/q4WQYnOxRdcfuMzSlP5WtgaKxjbF7WxHcHRW
5zHz79Xw4sCheBWtEczhrpf+JKQafO7ckGDbNYI/PWehUWhVoLveIZHSN4wd
+z6emqmqhAGhrJ19psO4yU97R2EAFTi0zaSMNIewUU/zR29Ehbng4KSdUkN4
4L/n3O+XMLxJ9NboWR3E9Do50ejJCjhaYqIp5DyIMxJ7qji+l4Ht+JpW0OUB
zBHoYFwxVwoUbeOTjup9mHLc2NxmMR+uMDMM0HIXHs0B+aPR+VC3LTbtamkX
jhapaeM7nA8KIiqbYW5dOLQ+6hHFOw8Y+53yupc7sa/nk92b8jkQYTYt4Lzy
DX+oWLJNWsiA8vSerjeMdtx1p7BOziwDdhe4KTVS2jGrQPznvJJ0CCoTCV7w
aMcBRMazEv80MGs1OQqrbVhMp/duhsprmGY0xH1fbcWGEncTFBYTQSHOtUqE
0Yz3yGTWL9ITYCWv4O4Vj2bMz370QPF6PFTX/JTJY3zFx87fjty/Iw4uzF8N
0l1twuUq+6a73WMhSPOsgdfaF2zJq1bnHvccTM8+26jz+oKFK7P7hKpiYKdD
c67wegNuf5+QoSYeDe+jTwrkrtfjB51tjSYbkTAyebhreKMWT9+vudiIIuHd
unOQwv1afJNFSEYjMALcBPJUPTc/Yz/l4HdH0GPgVdsXJ8T0GSuuTISRWIJB
7Qnh8knmahw7FyLUXRsI7K/NBKJ8q/DBmDEO16hH0FYaUTXEXIXZWSsPP9Px
h+sjHLIeWyoxp8mOHAv2BxBzaGX6LQsVnzzYLCO9ywfiHHoPLHFjTPEWPD6s
6QXct6p9owQqsKlaoNmJIjeYcYyRb5Yow575xWY/We6BhdP9hw57PuLhweCU
URsXaHC26+aUo+D/7MT2lhk6QZbr0QDtg6XYt7L7YnyvI4i67ekdVi3B77Pv
Vb+YvwUh7tzK96EYhxh1psuXXYcbXgN9H/SKcPZXRz8bo2vQ411LOmtUiE9g
k2Uyiy3o3c8LWjQvwBNLs+/fVl8COT+/g4qX8/DQfb3V9LSLQGLvEnrRlIPH
FnU/KTJbgABXJrX9+1vcb/i9nBZ7Bha4PR22j2bhuvA/tOmbptDKa0DQnc/A
afnJFjsfGEGegGT1Q0YaXrz74Y9woj5ECP+6XcH2Bj80Mki9XHoCHAlVYit8
qZjxZ6Nc8rQmGIlF15LFk/G7hrjQpCI1sFb7Ot5nmIBVjt9zGa85BDs1ndRN
bF/inYGizrtjFWHgpEhMrWcMtv9YnqvxWAbiDShzak+f4hyFPA3zPlEoTSsL
+c84HAfZpxFdBrnhcAHr0X99ArC50lOWJosldXvPF23OZzyxvKjWwB/BVvUW
aVObp5eu4WAH2bYfVonqHUUkv225/8JTU+foxxyT6vFQzM8d5wzXV3+Z5Tmw
gJHQs/Niyb5AGlKeUQYhaOXQz1K6Gwz0IIeQZoNdkOnju56SGgF3dEvam233
w7Rb/xv58Cioji2bbCwkwX5nVcNS11hIkur+FCOnCvY3o+mal+JANiGWslsP
QWehW/O4dBKMuNj4zrprAz0vbc9bYgoE7NB7v09aF0RyOu7d2f4aBB/+e6br
lCEczt7SqMKSBtqWqqS138ZwLkNJam0pHX71ds/XMJmD2xuru59mM0E2pHY7
W9sFKE2kiJ/ufAc5pUKOHjHW8D1u0pH/Sy4IX11+KNR4GdZOh9rMDOYBU2vW
XKzcVZDQ+1Cc11Hwl2u3t514ZAc5p1ouCTYXQgebZ/UTZntQPznB5VpfBCf8
DvqvyTmClbaw9bGKYmh5/kY3LPoO/NT8hzOhtARirlIsb/A5g4+GViFTYSl0
Kzbb8x90hQT1O+yf0ylw/M4b+W1kbxg80pRrFFkBv5U3ejc070PZa3mNhSQM
Y6FTTJ4FD+A0x8kp3XNUcMpcPn9v3g/k7qZ7zFz7BFZVm9/9vwXCiL5dvEJg
FWiXij8OkwmGFl/C1c3t1VCGlzaifUKgoqROoSWmGq5snRTM0Q+HV3vkqHfS
akDjw7mAlYxIMFudGimqqQWG96Ahq8tT0FR+mR1gUAdr+jr0JzrPQOma3t0z
3+qgnyVnQG4xCnjas9iWR+uB7cdvYbvAWPicZb/vGGsj+OTu42XXSgLxd/Ti
S7taYJflqI1gUxII1hmK6dq2wPXwJzKXzicD14+0+8qZLTDmXbREcUuBZcLZ
U1uUWyEq5kizS9tr+OZf0p2K2qAyTU6faSETHlu6rY1bd8Db+P5wwaQsCLjX
cqk5tQNUib5wzSgbvJ7uqymZ6ACdhJj55pK3YF/3PTzo9jfgGVr1S0vOhVMH
VSX33++EI8lnjxXRCoCZm6FxM+GvB9gdrys0KQSrjJ2Gjf3f4Ydjl2nO+8K/
PNKyOCDRDR80912L8ikCJ+8wp6lX3fBzVs1HWrwYRn7uTLV90QP3LpBumT36
AJWtWqxWUX3w8YDlOMvyB9h5y46vvL0PQtSOXsy5QQEPrnBxccF+aJAUPLlo
8hFIWp0HeyL7oWP28DZtxXJILbKzPfNkAB62pGW5h1Kh8suJK3t1hmCz7KKl
XCMVaMTzU53/DcGn+lvhZ3g+wU47+9uP/IdARDvxplzkJ/BgjfAcqxoC1jJV
2fyESiAd736WqjkMtFIzt1Ot1ZCaY18tiUaAbWJ3UkxUPfhHRsgQjo1C2jLD
rXSmHix5woJuXxyFwF9nym5qNQA5OHDm8/1REHnx0u/pYgOMPPDJd6kehQvY
iOcvcUDD0eF4u8EYuNm5iX3Vb4YNw1Pmjy+Ng3+MBc+RL21wj5spgPXRJAQI
sqVsbraBYdDqxIWMSdjn/2uG71A7yLIu6RU2TII5ikjkS2qHztU5PhveKVCX
Hgvwd++AgzO9cTh2CixezhqqH+0EWn1JkUf2NFSCU9vKQjfcCLw9SmuZBacT
02+/KfbAicm1uvSFWXidtxq57NADe3RD3lkJzUFI7rSn4GQP9HG9cW08OwcX
z658jR/uBcPHPRwZA3Ow+9/uO6wj/aAcrSNvPfsTYuaNv3FzD4NXK8/H8Yc0
SKEqL+a/HQOtwR8s5okLQG8y4LnQOgZceRJS23MXgDZnyLOHPgZtD86q1VYs
wFdbpkpeNA6Xdn+5qzqwAFqHpDYufBsHH9uCMQmJ37DV1PQTZpsEysyD2vGX
v2E8ONC5yHsaSMsSoW4xi8A3tjfQpGEepPjPCcSF04Hs22DjypiHMretEpkJ
dMgcWdKzFqbBuaGivcW5dKjdfZl5QIcGkbn8x1ta6bDwVMvzfToNthh+ucYq
sgSc5FOpjbd+wWiIerlDwhIcdzKqfsX1G9JZZeyO5y5Dw6ylXrkbHRSWf5UP
tDBA0PwY5/uUdQj9Yzoe+mUDQl5ENxxr3oIqdd2ThM4zo6evRSfr37Gjs84X
xIddWdAANbCfQOFGghnJnTaObKiQycZt3Zof2ZV4WNtEsaPd4sV+/E5CaKy1
RHZHFCdqHJaY+FKwA+WqCbJXB29DfD9UBQLviyEBP+bin5k86JlAvNer05Io
rs009esbXuQVpSRB7N6FhnziFEXG+dAFLCP6SkYaxartFNVY5EcfVreoltyQ
RaObraknaAKoNmxXTy+LHPJSahYKZRZCc5LyGRWRB1DG1Q3pLCZh9KfQfH+S
sgJarS7TqGEII2/K4t6IGCX0MqJaR5JrBzoRzBu6yUVCTZc3Jk3ZCajmHwdi
Cj8JMdyyH1X83a0EkYFBHQIJ7Ys4Jy3HR0CHKMzCkTIk5FdRYL1BICCjU6ek
VBAJqYhd68zYT0BCXm0UigsJJXU0V60bENBnjd7Nd8Mk5HQyOSE9ioCSE4ci
7k2SUKKVoZrAi799rdXzmvMk1Oiy2u0VT0B7LR2jetdIaO9rc2GTNAIqbj+f
JU4goz4mrrC1EgKy7pGz6DYkIx2Kk7txLwFdj37oUGxORk6tkjvKBgnoZMxC
cZQlGSVNNhbJjhKQ+3W+RbMbZMQQ2UtbnSWgT+b6vKMBZJTj3Hs1bYOAbODf
kYYwMuoNCWLlZyGizlt2cwXPyIgj5VCKJzsRHUnsyX6UTEZXWp70G/ERkUwS
2dopg4wiJtQ8PwoR0fh4sp51LhlVbEwRZIlE5O4sc8ugmIxmhJ8XR0gQ0f/7
Q9D/AO/cgEQ=
         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxdmGc81f//xgnZ2TrHiAqlvtY5pZR6f6wK8TUbEqWUohKRXUR2UUhlK7Ps
0Amvd0ZGZJW9kpWRk2Qc6/f93/3fum49717Px3Vtt7llYruJiYlJkJmJ6f9y
QKeiXr2cikkK2mYr28l47lOYFlcJFXM+L2Dm3EbGKxoRxV15VMxg3Z4rKkbG
M7KqQW6vqLivb42TIkjGRq/XuqtCqTgxrATsNpEx2c/zQLAFFctN79nbMUzC
hYWUni9LFLw/W2BTfioJMy0+qtA5SMEm8oO5V2RJ2OqZrbfSK2WMSpVlngpt
xS9S1a5/cVXEsRpGyyNColjc6BKbTdte/Dll6OMhsgh+x3cuwHirPM6P2ZVq
zCmMkZnLGfdsOcwaoD4azi2EJWbD69WVZDDXZg4idEkA6zXGOQYOb8eTVtqP
wib58RZ8ymqOJoUdLsd7XOnnw3dE9SjPE8WxvbIUl+oHXqx6YeFZJzcJa/5W
P2dUzo35Dm9SKqkVxo0X1Z861XPive9m6x74CuDyxYxV0Wx2rBRmg0/Z8eKH
fvm7NuezYZegYY4bw+y4hLLL/24YC546Isqnz8aCXzzxqaXfZsbuHUpjVotr
kP3lR+y1xXW4xp17l6a/APTKV2wL7xggr627WV1lAezSLocLpjGgsm+zZZPo
AgwFy4goxTDAS2HaUmr4L7QYvZKxc2WAsIF10X33v5A7kKrVo8qAbv/x9wez
5+EmI8W3omQZCjvuSfmI/YFpleS1h++XIIulxcxqNx3Gk+L/bi1fAG3nxLlZ
PjqEzEw8GspeAKHZVoXds7OgeGjf7swXCyDj9XV016NZuNPeYHHIbQH0Hur/
/tH0C5g2L4EldQHiLJhdDc1mgGRvEpKc+RcusoSpznhNgu5+dqm9MfOgxZvH
X2A0CdO+JqV//OfBh6hbfCkzCRFf4o3LnOdhdse36YHGn9BxdZ+/gfE8tHde
cNou9RNsXlz8eYtnHlKYianYhnHw2PhQWOT3By6aS0YZHxmF7HrHE0dvzQFH
HtZ3FB2Fxp1/pE9bzUEiF5lWMDsC094uy7cM5iATJmgpKSOgSPHISt47ByR5
VgMlrhHIe/GAh23iN7gt7ylkDA5DsX1My+cLv0E24mCgRdoQYN6yM2dN6CD5
01OE/mAIhq4eVXHSoAOn5h2LzItDwFyJOUOV6VD65wFHoOQQaLrW0Mq20GHq
zdHJfoVBCCmPVyNiZqGHEiY9LN0P0dZVH5sCf0H8nvQ4L/VuyErd0jZxfRps
/ukkx7J2g9pWBSVr/WlYMl3Hvxu7oC5EP+zb3mmIEqaEW1t1wejtoGOV01Pw
4pySpKx/J0gTmz68vDkFLUy+4md6v8Gzvr+phk6TMJx+P/J8aRv4i/S7FLlP
QNWlaIOjQW0gFLzStsdiAlx0kqnnz7RByipZOfnQBOh7JHibL7cC/nFqMnxl
HHCmIqfy0VZYyW+xuuo9Dlno5Bo5vRmcDKuPi/mOwcnW4ZrGsw1gHZhNvh80
Ap4iVm9MNjWAdtPQc8MrI3Csp770enY97BESFZPUHoGMUSct4406mE+4L0bb
+AH5LNzSS29rIaTYXHze9QeUWZouvJGrgaLRDQk722GIzuo4bN5VDc/37o9X
1RoGDne99Mch1eBz+7ok2/Zh+PiMhU6jV4Hu2lfJlL7v4Nj34cRUVSUMCGdt
6zP9Dk1+2lsLAzBwaJtJG2kOgVFP8wdvAsNMcHDSNukhGLj8jOfdIsDrRG+N
npVBWKiTF4ueqIBDJSaaws6DkJHYU8XRVQa2Y6taQRcHgCPQwbhiphRo2sbH
HY/2Ae2IsbnNfD5cYmYYEEudMJKDFA5F50Mdd2zaldJOiBataeM/kA+Koqob
YW6dEFof9ZDmnQeMPU553Usd4Ov5eMeGQg5EmE0KOi9/g/cVi7ZJcxlQnt7T
+ZrRDp23C+vkzTJgR4GbciOtHVgF4z/llaRDUJlo8JxHOwSQGU9L/NPArNXk
EFppA3Gd3jsZqq9gktEQ17XSCoaSdxIU5xNBMc61SpTRDDtlM+vnFxJgOa/g
ziWPZhBgP7S3eC0eqmt+yeYxvsDhs7ci92yNg3OzV4J0V5qgXHX3ZLd7LARp
njbwWv0Mlnzqde5xz8D09NP1Oq/PIFKZ3SdcFQPbHJpzRdYaoP1dQoa6RDS8
iz4umLtWD/c72hpN1iNheOJA5/f1Wpi8V3O+kYiEt2vOQYr3auEGi7CsRmAE
uAnmqXlufAI/leC3B4lHwKe+O06Y6RMoLY+HUViCQf0x6eJx5mqInQkR7q4N
BPZXZoJRvlWwL2aUwzXqIbSVRlQNMVcBO2vlgac6/nBtmEPOY1MlcJpszbFg
vw8x+5cn37BgOL6vWVZmuw/EOfTuXeQBoHkLHfmu6QU8N6t9owQrwFQ90OxY
kRtMOcYoNEuWgWd+sdkvlrtg4XTvgcPOD/B9MDhlxMYFGpztujnlaXDZTnxX
maETZLkeCtDeVwq+ld3n43sdQcxtZ+93tRJ4l323+vnsTQhx51G5h4ohxKgj
XaHsGlz3Guh7r1f0X+87+tkYXYUe71rKaaNCOAYmS1QWW9C7lxc0b14A44vT
795UXwB5P799ShfzYOie3kp62nmgsHcKP2/KgdF53Y9KzBYgyJWJ27veQL9h
Vzk99hTM8Xg6bBnJgrrwv/TJG6bQymdA0p3NgLT8ZItt940gT1Cq+gEjDebv
vP8rkqgPESK/b1WwvYYHRgapF0uPgSOpSnyZPxUYf9fLpU5qgpF4dC1VIhne
NsSFJhWpg7X6l7E+wwRQPXLXZaxmP2zTdDpqYvsCtgWKOe+IVYKB46IxtZ4x
YP+hPFfjkSzEG9Bm1J88gRzFPA3zPjEoTSsLuWwcDkH2aWSXQR44UMB66F+f
ADBXfsLSZLFYYe/5vM35lCcoiGkN/BVqrWiRMbV5cuEqBDvItf2wSqz4WkTx
4879Fz0xdY5+xDFREY+KBXjinNG1ld9meQ4sYCT89Kx4si+iDKlMqSBhaOXQ
z1K+E4wWghxCmg22Q6aP71pKagS6rVvS3my7Bybd+l8rhEeh6tiyicZCCuxx
VjMsdY1FSdLdH2Pk1cD+RvSC5oU4JJcQS9uhR0BHoVvzmEwSGnax8Z1214aF
vLSdb8gpKGCr3rvdMrogmvP17u0tr5DQg39PdZ4whAPZmxpVWdKQtqUaZfWP
MZzJUJZeXUxHv3u7Z2uYzMHttdWdj9OZSC6kdgtb2zkoTaRJnOx4i3JKhR09
YqyhK27CUeBzLhK5svRAuPEirJ4MtZkazENMrVkzsfJXQFLvfXHe1wKkSLnF
feyhHeScaLkg1FyIvrJ5Vj9mtoejx8e5XOuL0DG/ff6r8o5gpS1ifbiiGLU8
e60bFn0bfmn+w5lQWoJirtAsr/M7g4+GViFTYSnqVmq2F9jnCglHb7N/Sqeh
I7dfK3BTvWHwYFOuUWQF+qOy3ruueQ/KXilozCUBGg39yeRZcB9Ochz/qXsG
I6fMpbN3Z/1A/k66x9TVj8iqaqPL/1sgDOvbxSsGViHtUolHYbLB0OJLurKx
pRqVweJ6tE8IVJTUKbbEVKNLmyeEcvTD4eVOeXw7rQZpvD8TsJwRCWYrP4eL
amoRw3vQkNXlCWiqvMgOMKhDq/o6C491noLyVb07p77VoX6WnAH5+Sjgbc9i
WxqpR2w//ojYBcbCpyz73YdZG5FP7m4+dq0kkHi7UHxhewvabjliI9SUBEJ1
huK6ti3oWvhj2Qtnk4HrR9o9lcwWNOpdtEhzS4El0ukTm1RaUVTMwWaXtlfw
zb+kO5VoQ5Vp8vpMc5nwyNJtdcz6K3oT3x8ulJQFAXdbLjSnfkVqZF901Sgb
vJ7srikZ/4p0EmJmm0vegH1dV3jQrW+Id2jFLy05F07sU5Pac68DHUw+fbiI
XgDMPAyNGwldqM7uSF2hSSFYZWwzbOzvQj8cO01z3hX+5yMti72S3ei95u6r
UT5F4OQd5vTzZTf6Na3uIyNRDMO/tqXaPu9Bd89Rbpo9fA+VrVqsVlF96MNe
yzGWpfew7aYdf3l7HwpRP3Q+5zoNPLjCJSSE+lGDlNDxeZMPQNHq2NcT2Y++
Th/g1lYqh9QiO9tTjwfQg5a0LPdQDJWfj13apTOENsrOW8o3YqCTz/7suDyE
PtbfDD/F+xG22dnfeug/hES1E2/IR34ED9YIz9GqIcRapiaXn1AJlCPdT1M1
vyN6qZnbidZqSM2xr5YihhHb+I6kmKh68I+MkCUdHkFpSwy30ql6sOQNC7p1
fgQF/j5VdkOrAajBgVOf7o0g0ecv/J7MN8DwfZ98l+oRdA6MeP8zDmg4Ohxp
NxhFbnZu4l/0m2Hd8IT5owtjyD/Ggvfg5za4y8MUwPpwAgUIsaVsbLSBYdDK
+LmMCbTb//cU//52kGNd1CtsmEDmREQif1I7dKzM8Nvw/URHZUYD/N2/wr6p
3jiI/YksXkwbHj3UAfT6kiKP7ElUiZzalue64XrgrRF6yzRyOjb55ptSDxyb
WK1Ln5tGr/JWIpccemCnbshbK+EZFJI76Sk00QN9XK9dG0/PoPOnl7/Ef+8F
w0c9HBkDM2jHv923WYf7QSVaR8F6+heKmTX+xsPzHbxaeT+MPaCjFKwyn/9m
FLQGf7CYJ86hhSYD3nOto8CVJym9JXcO0WcMeXcujELb/dPqtRVz6IstUyUf
MQYXdny+ozYwh7T2S6+f+zYGPrYFo5KSf9BmU9OPwDYBtKn7tWMv/qCx4EDn
Iu9JoCxJhrrFzCP+0V2BJg2zIC1wRjAufAFRfRtsXBmzUOa2WTIzYQFlDi/q
WYvQ4cxQ0a7i3AVUu+Mi84AOHSJzBY60tC6guSdanu/S6bDJ8PNVVtFFxEk9
kdp48zeMhBwtd0hYREecjKpfcv2BdFZZuyO5S6hh2lKv/L/dobj0u3yghYGE
zA9zvktZg9C/pmOhn9dRyPPohsPNm3ClrnuS8Flm4skrsYn6t+z4tPM5ie+u
LMQADuwn0XiwUEZyh40jG1HIZOO2Zi2A7Uo8rG2i2IkdEsV+Ak7CeLS1RG5r
FCfR+F1y/HPBVpyrLsReHcxN8P9QEwy8J44F/ZiLf2XyEk8F471enpTCcW2m
qV9e8xFeUcqS5O7teMgnTkl0jJ84B7JiL2VlcKz6NjGNeQHi/comtZLrcnhk
ozX1GF2QqA3b3tPLIo+9lJuFQ5mFiRkphYyKyL0448q6TBaTCPG30HxPkooi
Xqku06hhiBDetPldETHK+EVEtY4U11biWDBf6AYXBTddXJ8wZScRNf84kFME
KJjhlv2wgptEkEQHBnVIFLw74oyMPD+J2E9jFomUpWC/igLrdRKJMDpxQlqV
oGBV8asdGXtIhLBXG43mQsFJX5ur1gxIxCeN3o233ynY6XhyQnoUiUhOHIq4
O0HBiVaG6oLP/+O1Vs5qzlJwo8tKt1c8idhl6RjVu0rBu16Zi5ikkYji9rNZ
EiQq7mPiClstIRHWPfIW3YZUrENzcjfuJRHXoh84FJtTsVOr1NayQRJxPGau
OMqSipMmGovkRkiE+zX+ebPrVMwQ3UVfmSYRH831+UYCqDjHufdK2jqJsEH/
DjeEUXFvSBCrAAuZ6LhpN1PwlIo5UvaneLKTiYOJPdkPk6n4UsvjfiN+MiGb
RLV2yqDiiHF1zw/CZGJsLFnPOpeKK9Z/kuTIZMLdWfamQTEVT4k8K46QJBP/
7w8h/gfNpglT
         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hc8Vu0bAHBbRhKe5znHipTxFCEpUvcxGhSvlFEq481IkpAkhJaM8lYU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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hc8V98fB3BbRhI+n8+9VqSMTxGSMuoco0HpK2WUyvhmJElIkt2SUb4V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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hk4VVsbAHBjhswOzjErw9mUEN1LsrahQUVIyC0kU6MxiSQiQ7gayFyI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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hk4VVsbAHBjhswOzjErw9mUEN1LspahQUVIyC0kU6MxiSQiQ7gayFyI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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxV2Hk8lc3bAHCkCGXnIFuPEBXOTUWYYynKkmRpRfbiR5Zki0hClBTFY8u+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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxV2Hk8lc3bAHCkiMrOQbYeISrcNxVhxlKUJcnSikgUP7IkW0QSoqQoHlv2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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hk8lN/3AHBkp2RtRraKSElkmUd0H0tpQVLRipQovmRJSInKmpIiZMmS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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hk8lN/3AHAkhJK1GdkqIiWRZR7RPZbSgqSiFS2i+JJISInKVkqKkCWU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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hk4Vd33AHBExqRr6F5zbzKXIRTd7GMoESoRTaYylMrslcyEDKWUF5ll
rsyur2nvEIoyT2VKkrEkSdf02/37++s8nz/O3nut59lrrXP22Dqb2DExMDCQ
GBkY/j51PUJuhN2VQeT9uqZreyhI2G3Ke+6hDGJPLGVkF6UgDt+xR8apMojO
vKdIQJCCJMvjvnPTZNDw8Aa7MomCrCuYDb2nZVBaNA06MlHQ+zW2hwsGskhy
Xlauf4KMkhKSTtpyyyHVwl1MJVlkxECaCPZ4II9MZMaK7PeRkW6XCksGTQGB
KkWJON7d6OCBz28TdJVQgtbpP5O8AmjJ3Hjjfbwyasscf6VB4UeS3iZHzZcP
opJ4qawz7Hxo3Oz1WR1ZVcR8l/olhpMXubGpP7VxVEMc29mIqNVd6GNiiV7t
/UNo1lL3fvQsD1o/dd1R5+FhdONqio/9yE50xedmGSVBHTkpinGo1exASw5M
ghx+Gkj7B/Xi6TpORHUFKiTjI6jdhhrn9oYdVZCadqSJUVHd77x1gUJW5PPy
p9SvbioKCy6R2l7Cgn68/GxZGnIU0ZSlQv+N3oZ0DouknhPTREmP/FsWXRlR
AlPKrsh0TVT4/nPCtd+bUH/nXQtdIYAWG56xrFTQYZ3TUzAvDJBjztUYUg4d
qjwCsnGiAI3fk+BXiKdD6aNKHKN7AOo8/UzC0YsOFTirlx2kASoazdL5oEaH
peE2HoaqAN2iZwbV0/7AJ0xsohbGAM0rZWyE/W8Vvt4qFfTxA+hresqv3XUr
sJ2tn4ExAKDIhen744UrMNzlYX1YIEAHNFSk85NWoNilLnQ/BCCPnrcXNLxX
4Pssz/HYewAxbF+Flw6uQLlfp6IvPwGI7GQSmZH/C35JOxlPfg6QviqrmFz8
MowP8HH2eYH3DzKp+hm6DNfrtMQ/vgQo9n3KmVr3ZThzLpEtsQSgfgeVUKMz
y1Drz43l7TSAbJNsZpy5luHPrezDha8A8tmqKSsP/gnN+K3c+fsBKnzjckLT
eQkG0jP8DAcAat/7U9zccgkWHlK4HjyI9/Pz/ONstAS3VUvPzn7A8Sj7FGTI
LUHa6H93X44BVJwUwsUy/QOq5NnLMswAVOkU39lm/QMGHGmWe0cHCO2otThv
sghp4qYB42s4/w6aSm5ai3DxsnzF0jpAjA2IPUpxEdqO17TwbgGk7fW6upZ7
EeYEy+k+YyRQZF2KOhH/HSZ9rT9Sz0KgJ1aNr96Ff4OFJc3bw3cQqCCLu3v6
+jzMPdPesYKtvnu/gtXJeWixzV/YnptArZEno/vk5uHA0y+Ezk4CfXGNON4w
Pwf1M15X/OYhkDjBVPP01hzc3Gg9pc9HoP+Gf2UZu83C4s1h3QeCBArlH/Es
vz0ND/ddDfmOzXtvrVv2wjT0rEs4dkqIQJnrFMUMjWnI2chstkOYQOjzudmY
ta/weeZCWogIgdZKOi0d/L5CVMY0ZSFOIDfjJj3BoCmoIKJxMGcfgazCCymB
EZNwLuPsiw1s3Xfjicb2k1BSTe+JqSSBZHkFBEV0J6FgTO1LBikCLacGClZv
fYbry2OsJtI4P5VmQsten2HWc/azQ7IEKv+yJexoNwHNZJoKpOQIlCinmqKm
MwHDKyxcPLH9Xa+LsOyZgI7rO4/tlCeQ/kavSObwJyihS+Oj7ifQKF+B6PDZ
T9CvZtrQR4FAbLqm4qe1x6Gkom4wxF64dy9dVHwcGpff3sesSKDsND+tD2tj
UHjOrSIKW4Nmos3nPgaLSalrcUoEspta14mwGYW1+gPi9w4SqFr3jJ6L5jC0
Me97z3KIQFcY6UbE6gCUsZ6xVcVu5UzIsa8agJ4p8f9exT4goLYV7T0An1bU
/vMKmy7rVjy02g/3XDoU6HGYQLGmsyT3P32QJ3jKvFGdQHW5Hway6T1Qoifm
1yz2P6Xeiu3VPbDG4j0vSYNAEbUC95Z8eqAPo1C3JbZpl4kGWOuGCm8mzJaw
Z+lvkwfXuqCvkrwPIxXvn+zVKEDvgB/f2u/Zg/2nuNTjik8HhAka+gR20+tv
+4rp7yF/9wtBP+yL3+0j9NfewT/VDU2L2BHa5ka+623Qf7XZhesogc6ax222
+rbBiOtXU6SwRW90FPFvvIUy89e9L2FXPNEjFW28gdl2OaoIe2L60MCnzRZ4
Ws9jagD7xYZ7xIGAFhh4+ePu79jepGL1O1vN8KaU57qQJoF2UqWT+RiaYaDS
QLszNvUB2UaPsQmeod0KDsFmfWZKehzUCHNd06risburYhvHGRvheEh7Tg32
tQk2SR+mBhglaha5hR2v+mf2+TYEw7pGV7gBgZJvfJT7zQXh1d0r0yLYXLea
gh6T6mHzxXeXNbDnXOL3d4jUQoMLMeN62BfcAkJu7K2BJXMfpk2x37o7DrHL
VMN9LaKRN7ELvDTu6qpUQeVd/HtvYwt67/34SZ0G93xL0ArFjrzNpRQAKmGu
tf7OROzrvqPD/zMoh0dXPOszsT/4tSibny6DFaKKPwuxDQKKI5bNSqGhtNFC
LbZMcLCKgk0xdGIvLm3CVmYd4Et89xLe8EvfaMMmceSjnsHn8FSo6Ptu7CWu
Oze4Jwsgv6isxBB2104jsv73PFhn0Lg1il1MEmsKoedAPY5Z60nsWP4fzvUs
2bDsUqreDLYLuVHoD08WZNQeL1vAPi30pOWgcAZUri7K/oFtRX0/NWycCnVf
c4n8whbVdtM0sUuC6ld+U1axR/UE4lvuxMNdj52T6dgpRtUL1EeP4Ftzz2fr
2FU5tZFXz8RA+5dsypvYh0qZNU7534Wf/5M5toXtdCex2/3cHajDNzjy150S
Z20fWTvAsL1863/dW64czFl0ChS8Hkn76xRQuYsr2R2U0FXe/F3vNF/ceaGM
IJDUQPHe+Bs/28kCRY97wE4k+vkadr5/0EZmViwgcUbb/8Ge9R7J3h/zGGRG
UXJWsGXd1Y2rvBIAb5qK08+/57n5ZEXbOhk4HBup+I7dX+bdMSWRDlL9ecPm
sFeKc/Y+p2SCSoOBj1PYAi97/3XlfgaK86Vpn/7GV8jUrrYtB8Q8ZSUPY1vk
KYqv/84FhuIem33Y3tmWHq/m84HrxK+LrX/zk1YtbNj/AgyIcfYg7MHkaZdd
bUVAdPFFRxX2umGU7dxYMTDTTz6fiy1i8L/K4t5SoNP9dSoF++WJTmvejjLA
9w39icPW1PvK4fWmHFwaFSr2x7bU5bc6Ul8JekpTzrpjf9OWZ0+tooH9gi98
HbD9tXTKGMqqQHiGh5UxdqqmK2tzbjXofZTjIIA9dvhd0emH9YBbnH2aBbv2
2X6tpXQIHH6cGlzG982QTW9G3wIBT+tIti5sGY9cnzmHV4DZpTQ3GHvipGPK
gfBGoCJ6KPcmdmcQ2X6LuwmE8qQLWGDX01oPdMY3gcBXosfksJ/ulUGuOa/B
jGnH+FtcL0zXZibKX7cAHgkvqxJsbaWkwrtGrcD8EKPxf9iKDgYe5/pwJmWb
fGywd/QUsKxOvgGhWhuk77ieNRc4SR9hbge9qlTN70cIJPxipdJ6TyeYOS5V
047N22ospG/XCUSSV3LzsTk+5wQo5XeCTyTtLhvsVbL5CSalLvBBKdq2Ddfb
vlDaUBbRDeJVFwJCcL2+f8l7fcqqFyRGCK+ZY9/9t9O6I6sXVIspTslh+z6S
fk372gssBJm5unH9d2odjIlw7gNsWlbxu7FPqKiLyQb0AwXTiexwNQIxctG1
bqYOAsNPQjnnsC3zRI3bRwbBCb5+6X1qf/uRzgU5kSEw5tRegVRxf/aLdpt5
OgQiP6GFHyo4399Es+wSP4DuqdY+Ku5fDV06zJaPh8FsF9fmNmzRW448dT3D
YMK2K++tMoF8OGKEhXlHgIvX8N1z2Mo6/SofHo4Ajqv0y464H2aVO9qdezAK
FM6bhXngftrQdvyK1LFxoJOZ1X8Qe5Fyfqb/6jhQe+iWv3QAr+/o5BwWOg5q
rR/138L2YY6986VxHOg2Dxnb4H6tfHQoLkv7E9ArDKcdwP0966VTkxgxASgj
Vtec8PwQ+jB2H/nIJGBlCdfjw760IzrC+fIk4M7XeVSL542D98LnmgMmgYOd
301O7IlA/xLPpkmgVbSkkbmXQFouN472GH0BCeGTSuV4ftk0PmF233oK9Bh8
eXANz0P/cjHcZQ6bBkO/ahgYsI0j1r5ezJsGq8LSo08oBJJk/m1Q9nYaBIyh
UUjG939tgcd25wyoUl1e4dpNIJW5j8kwYQa0SdqGRPHi+N/Qyn0KZ0Gg0EUu
QS5c78OdJxc754G7XI5pOieBjk+vt+YuzYM0tmFuSey9+pEvLPkWQIYs25AC
B4GGObK92s0XwJkdtk1UNnye+x/Y8kYXgK2R8O8jzARSenJsv9X8NxDiYpaY
9hsg364dNVMhi2DN1dIlqRsgnbHP28zSlkDswydSnl0AcRSLiHMXYUc8+Wrc
CVB3oDm1pX4JdK9/D9p6B5D1P20e6qNL4Nwmt7jZG4D87Uq/iIj8BI52vxi7
IUDVc4EtU0k/QUnjlUskPM8rr4pEeccvg0HU7PQiCCDxXRak5JgVsFI4YyiP
vxdqvbeL5KeugL6g05wF/gBZjJdLVRatgN6FGbHMOwA9LNp1tLNrBXQ1n8wL
9QSIybjNgVngN+jwbVPlvQbQZKRm3Y3U32B4tVrn3CmAcpn3OR4tWgUHlS7I
eZDx/L76o260kw6KDG4U9WZroqhfZ6ei2jZBh+GLMLKkJmrQv53Od56RuFW4
3nA88igyd78o/MlrGzHJemqydpqKePMy+m1dWIiegK8ZDNJU5EjzsbJ9zEqs
epuk3blyBH3poknufsxOxIQf3m4Up4GKqLysTfc4CWq46xHRdHVECmas/Ja/
g7hYMyg+9PwwSu4+m/U+eyfRUOHg6h53CI37JysITPEQJuILbso31VACVVRQ
a3kXIRHsf+WZgSqa3OrKOr5IIpLVv5NImweRr2IHXxQjH8HhMlMoTlNGefab
EgUM/MR2yb5ZBQcltNZUq/Wajh0lUDzWrYCSYpuOiXHsJjwWxmcYZuXRO5vN
6bOsZMIrR+pdzbA8onsXhtVzkonOHh3Co0MeScdaSMjwkIn4qPW+kXJ5FFxf
arVJJhPWzs4wLkAeqQk59OfJkolB1ouRkXzyKL23o3HDiEx4+OozPKPKITe9
jNTcx2SiHmmO8ijIoTRLYyopEb9/m93wzh451O65NuSbQiZK9cQGTmyXQ1LP
zPhNcsjEYwvDwuYOWTTMwBG9TiMT2iefnzSylUXHqt1un/lIJg70rUrGmcoi
ty6x3bVjZMKtR/BR/3FZlD7dXi45SSa494/tPicni+gCUotr82TC3/Tap0PL
Muil+0f7nE0yQQ2yOXJ9SgZ9jIxg3rWNQpj+o7AvaVAGsWWqZt5hpRCxrwzy
lmpl0JXOByOneShEJUzQEiqSQbFfqXdq+CiEinLtda0MGVS/OUOWpFAIbkrF
Xrs4GTTH/19lrAiF+H//Q4j/A3HWgH4=
         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hc8lu37B3BEZtJtdNt6kl1GKLpzHkaJUIloWWWUyvZIVhQySikPsmVX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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hc8lt0bAHCKzJD52LwZlcp40Evq3J6bV5SREaWsMkplSxJCGfGmpRIy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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8lVsXAHCKjCHjMXMzVCrDOXRJ9nYerihDhihlKkOpzJKEUOabJpWQ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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk8VVsbAHCKzEOmjpmbobhlKHUdsvYxbHEjiWhCbqEoMiUJocyllCRk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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8lVsXAHCKzEOmjpmbobhlKHXPIXsfjkfcSCKakFsoikxJQihzKSUJ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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Gk8lVsXAHCKa0jRMXTMlEhuGaIuqf2Y4imEiCbTzXDTIFNSmTMrNyUJ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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Gk8lVsXAHCKa0iRqUPGm0huGaIuV+1liqeQRDSZboabRlNSmctcbkoS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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hc81tsfAHCKa0Rk9ZB5reSWEbpJnS/PI+v5SiJa1rVKRdaVhFBGlBJJ
KIRQkX2tc4oQysrKHsksScZj/U7//v76vt7/nHM+5/U6n/GVsnM1ddjCxMTE
x8zE9Pu7o1/ysa0tFVH20sxWpYRRaOLBAV97KuJ4lM/MIS6MtgyWPItxoiIG
i1SukIgw4pwdK6++REV9fescqnzCyHIvM7+4LxU9iSyBzluE0cIRHfvy+1Qk
N7NHsXOEguQyxu/HV1ORes6OLa/TKCgwpFSyX5qGTBUGcx1lKei4Gqk9MUtD
oFRZJoZ/JxJ5eMWBnqqL4rVNVsb4hdCKYqa/k9FR1Jg69EZTWBDxa2UlKzKO
otdx8mnHOQTQXPZIllSsHmK5qfUlahs/OhiS+EFZTR9x/sFO3F7egb41dUtb
1emjKSvancgpXrQhr16Yom+ALton+Tr28yDVyuIeriYD5KIswalRzo1W9jNz
3zxiiHR+aJ0xqdyGkkslRDgyDVGTrVaM+3sOdIZj5FYzjxGqXHq+JpTDhg53
rcT4njdCt4Jey//xmhVd7bqi1PPGCJWoyof8G7kVSSVuP5bDQ0cJ9/3r5q4w
I/qNj+y6JnSU83E0/vzSBkwP1fkrNYqO5t4+Y10sYsDBog8S3nfoyDnDPoov
gwFF3kvEGtylo6FwGUGlOAZ8kExh/R5NRy0mz2ScvRnwIes5xv4HdJQ7kEb9
rMGAPdXKmhkJdHSZkXqjqmQFGjKz8PyVSUczKinrt/5bhqMBp7grq+jo69Ok
XzsrF6Eji0tgIKSjiNmJO0M5i5BWqm9NRXS0T1Ntd1bCIuR55WxT94aOPNsb
Tmv6LMKvrZpu9TV0xPTHMjy7fxHGMeRrXzXQEcXFNCIl6xecb5Y14uqkIwN1
NgnFuAXYCCoPVGLP3DAt/RmyADcGJKMvddFR9Mek4xUeC9Azhx7S1E1HnU5q
IeTxBZjip+Eb3EtHdgm2k65cC3Bl0zSxY4iOfDfLCwqDfsLsiNz/OKfx/b13
0z/iOg+J9ZYjGdhN0j8lLazmYefjneraM3i/614rruQ8ZD4n4OU1i+NR9c1O
UZyHZ7836nR9p6O8hGAu1okfUMRsv2DgAh0Vu8S1NNr8gFBsNNZxnY4Qd4Xl
KdM5eJY3G8xhDzkdUXHXnoPL++JOX92gI+a3iOO28hxUmesfDd+kIx3vd2UV
2+dgRpAi7RkziSIqkw4Scd9hwteqQ1WsJIq1rn7zIfQbzHld+0coN4my07a3
TVyYgZnHm5oXsQ/u3KtkbTQDLbf6izpuJ1F9hFFkh+IM7Hr8haDykOjLlbCj
b2emoUHKu6IlXhJJElvKH1+ehhvr9ccMBEj0sO9XmrH7FMzb6KPdFSFRiGC/
V+HVCfh3h33wd2z+8NW2PacnoFdlvO6xXSRKXRNWTtGcgNuqWcy5RUmERk9O
Ra1+hS9SZ58Ei5Fo9XWLldP1rxAVbBm3lCSRu3GNnsiNcagkprk/Q5ZE1qE5
woFhY3A65cTLdWzah6FHxo5jUE5DL9ZMjkR7+IVExGhjUCSq4hWTPIkWkgNF
yjZH4drCIJvpbnw/xea7FrxHYdoLjhM9e0hU+GVT1NlhBJor1GTLK5LokaJ6
kgZ1BIYWWbp5YftfuSDGKjUCndd4dHn+IpHB+iex1L5hKEMrEdDaS6IBgWzx
vhPD8Hr5BN1XiUTsNDNJE50hKKdMC4LYs+HhT8Ulh6Bx4VVZFmUSpT+5rv15
dRCKTrsX3cbWLDHVEfAYhHl8yasxKiRyGF+jhtkOwAqDLsnw/SQqox3XczvS
B20tOj6yHiDRP8wMkljuggo2k3bq2PXb4jMcS7ugV1Lcv/bY+4Q0NiN9uuDj
ooo/32Az9rjn9Sx3QqmzBwI9/yZRtNkUn8dKB+QNGreoPkiiyszPXemMdijT
HvVrCvvPfB/lprJ2WG75kZ9Pk0RhFULh877t0Jd5V5sVtlmrqSZYbYNK70fM
57GnGA2J3aut0E/lL19mLbx/one1EKMZ9jY4Sklhr+Tle/7j2wxhvKYBgV3z
7ptsHuMjFGx7KXId+8x3xzCD1Q9wpextzRx2mI4F6bfWCP2Xa924DpPohEXM
Rr1fIwy7YJ8kjy1+sTlXcL0BKsxc8DmLXRSrx5e7/h6mO2SoI+yRiQNdwxt1
0ETPc7wL++W6R9i+gDoYeK5353dsH768g9c2a+Elea+1XUdIxKO1O1GAqRYG
qnQ1uWJr3aXY6jHXwOMll4OCsdmemfE9uFENM688KY3DbiuNrh5iroZDwU0Z
5djnR9jlfLe8hbfFzSM2sePUV6ZebEXwVuvA4nZAosSLvYpLXBDa71ycEMPm
ulxz4wFfFaw98+GcJva0W9zeZrEKaHg6akgP+7R7QPBF6XL4evrzhBl2g4dz
D4dCGZStE4+4hJ3trXmTplYKVXcISl/FFvGR7h0+WAKlvsVrh2BHXOVSCQDF
MNPGgOcR9gW/gb7/DAvh4UWvqlTsz9frVC1MCmCRuPLPHGzDgLywBfN8SN9N
zlZgKwQFqSnZ5kEXjrz8GmxVti6BRx9ewYvXn643YvNxZqH27hfwWIj4xzbs
ea5rF7ePZUNB8T0yPditPCTF4PtzWGlYvTmAnccnURPMyIB6nFM2Y9jRgj9c
q1jTYcHZZL1JbDdK9a4V3jTIrDNUMIttsiu2br9oClQty03/gW2t9XG8zzgZ
0t5xif3CFtdxP2LqkAAP/rMkvIw9oCcUV3ctDu544JrIwE4iy2a17t+HDRZe
z9awSzMqIuyPR0HHV+yqG9gH8lk0j/nfhKMPFXQ3sV2uPWrzOHkNUgW6+3+7
ReaE3X0bJ3hLWmDttz8VqgZtyz0Gst/1P/ntJFC8gyvRA7xmqL3/vZ6JQMyp
XSk3QMJbYZ/13/GzG2Ure4YDB7HIF6vYWf431lPTogHftkjHFewpn/70vVEP
QOpt4YxF7D0eB41LveMB/xM1l5+/z3MpdlHHJhE46fYXfcfuLPBpHpd5CpL9
+W9NYy/mZUi/EE4FxYZdvePYQq8+/Xtl+zOQl7W7ZPh3fDlbmjS2ZoCox2yU
PmzL58qSa0uZgC7pudGB7ZNu5flmJgtcGfl1pv73/TwpE6V3vgRdEtvaEXZ3
4oTbjsZcID73srkUe41+2256MA+YGySeysQWM/yvOO9TPqC2fR1Pwn6l32LD
31wABL6hlRjsI3pfOb3fF4KzA7vy/LGtaILWh6qKQXt+0gkP7G86f3Ekl5aA
vSIv/Zyw/bWpBUwFpSA0xdPaGDv5yBW22swy8Ol+hpMQ9uDfH3JN7lWB7ZIc
E6zYFc/2as8/hcDpx7HuBfze6Ox6kwaWCHjZRLC3Yit4ZvpOO70BLG75mUHY
I0bOSftCq4Ga+IHMS9gtNyiOm9trQAjvUyFL7KqS+n0tcTUg8I24riL2Y2kF
dCXjHZg0ax5qwPnCbHVypPBdHeCV8bZ+ja2jkpBzk6wHFgeYjR9iKzsZep7s
qAfEnhpfW2zu9mzW5bH3IER7ne87zme12S67D7E0gU/qWke+HyKR6MvFYhup
FjB5VL68CZu/3niXgUMLEEtczMzC5hzNCFDJagHDfDqtttjLFAv9LSqt4LNK
pF0jzrcdISU9aUQbiFOfDQjG+frOWZ+1cetP4FGY6KoF9s1/W2ya0z6BMgnl
cUVsv/u735V8/QQsRVi42nD+d6nvjgpz7QDs2tZxO7H11Q5K7AnoBEpmI+mh
GiRi5mJoX0ruBvThXRknsa2eixs39XcDfYHO3bIav+sR9bSiWA8YdGkqQuq4
Pl+PdJ983AMihtHsDzV839/E0xwefQZt4/UdWrh+vW2lslg96ANTrVwbW7HF
LzvzVrb3gRG71ucNqiTy5YwSFeXvB27efTdPYqtSO9U+3+sHnPaMc864HqYV
OjucvDsAlE6Z3/LE9fRt49F/5HWHADU1rXM/9pzwqclO+yGgcc89a34fXt/Z
xfVWyBCosLnfeRnblyX62pfqIUCr7TG2xfVa9XBPTJrOMNDLCS3Zh+t72iuX
GgliBAj3W593wf1DyL1oWcqhMcDGGqongH2WOzLM9dwY2J5FvV+B+4394aHT
tQFjwMnh+qVt2COB/q+9asaAdu68Zqo0ibTdLh5uJ7+A+NAxlULcv2wY65vf
sRkH7YZf7p7H/dC/XEw3WW5NgJ5f5UxM2MZhq1/PPJ8Ay6K7B2KFSSTHsmRY
0DABAgbRAKTg9786y2vHMwlK1RcWuXaSSG26NxHGT4JGObvg2/w4/vclhb45
UyBw1xkuES6c70Ndx+ZaZoCHYobZ020kOjqxVp85PwOesPdtl8OWNoh4aSUw
C1L2sPcocZKojzPdu8liFhzntqvRYsfnufOZ/fnALLAjRZcOsZBIJVZ3r/XM
N6BTmt3UvEpHfq3c5ePBc2D9b6W/yUk6og6ObjV/Mg/q6xtiyiboiDNPTHJ7
7jzQr2nwkMduC7TQqquaB+c3ltDmOB3Z/NnoeXBgHigGsEVnj9GRv0P+FzGx
n6Awn8E0OUhHZdOBdeMJP0H3sMo+Dty/qy6L3faJWwAXbUaLOvF8ILnDki8x
ahGsdnjKCWFX+PwhlpW8CKaJ56zmeJ6wHCqUL85dBFOLCzytlXR0L3fH4ZbW
ReA8Kmv2toyOthg3OrEILQHnqi8J4YV0NBZxpPJi8hK47NcvlYPnlUwWWefD
ucsggfJSUDMS9+/LPyoHWhjAQrbYYsqUjm7/OjF+u3EDOGWcpHLx09Fbg6tP
BU4xEyXm/rbS74yQhccZ0WHvrcR8sLy7lacR4n+e0mnnxkpMwZ8mTAJGyLnE
19ruARvhp5XVXPnaEH1pLZHb+YCDqKWKBmcYGKJcLX62mvBtRHJ1qRhPiwHi
C2Iu/pbFTbw6dzH64kkDlNh2Iu1jOg8x/Lmg9L/3+mjIP1FJaJyXUIj2PvhI
Qx/Fa4mLaC/sIPi0oYppuh4a22xNOzrHR3xM/JeDY/Mo8lNuFrjNLECwli6Y
R585ip47bshkMwkSW2Mu/HpYoItWayq03zEEibeprDMlCzSUEF2jK8G5kzh3
yEczUJOGPthuTJxgoxDJkwY/9x2gIYZPzq2qbRRiYYGXt38/De2OtpRR4KUQ
438GeB3YS0NBVfnWGxQK0d3b+31MgoY0djl1Pt9DIRbfxKX+yUpDTz81V6+T
FELMmo9JoZmK3PVSkjMfUAjlvLsHahrxfG9lrMX3iEJYWm1pt6qnoiav1R6/
JAox01qnfv8NFck/Mxc0zaAQskLt2T8KqKiPiTNyrYRCtPBNm8bEU5FumfvV
470Ugq5e9V4mFq/fKrGzYpBC9BXeelZ0j4qeTjQVyo1RCFrj0s2OCCpiCMnP
rc5QCEnz08vc16nolUevY8YGhThm030n4SoV9UaEsezYKkzE1huFy3lTEXuq
euo1NmHCPo8vW8uViv5pudtvwitMfFNybKl1oaLor1rXygWEiSiu3NMmzlRU
tTFJkRMWJmhHZ/V77KloWvBhcbSYMPF//0OI/wFqkZ7I
         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hc81tsfAHCKa2Rl9dhcK7llhC6pc3geWc9XEtGyrlUqsq4khDKilEhC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         "]]}}}, {{{}, {}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.368417, 0.506779, 0.709798]], 
        LineBox[CompressedData["
1:eJxd2Hk4Vk0bAHBE9n3poWwlipJEi7zmWHos4TmRSIWUJbwpJFGoVCgSUgnZ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         "]]}, {
        Directive[
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         FaceForm[
          Opacity[0.3]], 
         RGBColor[0.880722, 0.611041, 0.142051]], 
        LineBox[CompressedData["
1:eJxd2Hk0lc8bAHBE9u1aupStRFGSaJHMWLqWcN9IpELKEr4pJFGWUqFISCVk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         "]]}}}}, {
    PlotRange -> {{-50, 50}, {-5, 5}}, ImageSize -> {300, 200}, AspectRatio -> 
     NCache[
       Rational[2, 3], 0.6666666666666666], AxesLabel -> {
       FormBox["\"r\"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]}, 
     DisplayFunction -> Identity, Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"ScalingFunctions" -> None}, 
     PlotRange -> {{-19.739208802178716`, 
      19.739208802178716`}, {-6.283185307179586, 6.283185307179586}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.05], 
        Scaled[0.05]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"u = 1\"", "\"u = -1\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6620279941416903`*^9, 3.6620280349585037`*^9, 3.6620283027615657`*^9, {
   3.662028365365746*^9, 3.6620284226561933`*^9}, {3.6620284563019514`*^9, 
   3.662028522499681*^9}, {3.662028583536762*^9, 3.662028626598158*^9}, 
   3.6629140010636826`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image of swing situation", "Subsubsection",
 CellChangeTimes->{{3.6620377833144183`*^9, 3.6620377984901314`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"cartAnimation", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.4", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "False", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"CableLength", "\[Rule]", "10"}], ",", 
     RowBox[{"Width", "\[Rule]", "300"}], ",", 
     RowBox[{"Variables", "\[Rule]", "True"}], ",", 
     RowBox[{"Values", "\[Rule]", "False"}]}], "\[IndentingNewLine]", "]"}], 
   ",", "\"\<s36\>\"", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQLThXaqG712tHKWbJRSC6wShwBYhuMl25HkSbnP62
C0Sv+vt/D4huC/Z7AKKrtCc/BNF+LNuegehLrk3PQbRGkd07EP3sQ903EC02
79cfsPlZHX9B9Pkr54U9gPQ6/yUiIPq3mqYHiJ522NIHRG9qmREOot1m/gXT
AnLtl32AdB3n5GsgepvPvCcget/GJ6/AfOGr/0H0lIxzTL4g/c/9ZEB0mnIk
mF4wi0cNRAsIOGqD6E87Ck1BdEB7PZhmy7plC6InOck7gOUX/3QD0ZcDrgWC
6Cy3k+Eg2mSZVByInll/0aoESNtIPATTAKrsl3I=
  "]],

Cell[BoxData[
 GraphicsBox[{LineBox[{{0, 0}, {3.8941834230865053`, -9.210609940028851}}], 
   {Thickness[Large], LineBox[{{-6, 0}, {6, 0}}]}, 
   {Texture[
     FormBox[
      GraphicsBox[
       TagBox[
        RasterBox[CompressedData["
1:eJzt1tWOK9kVgOEJXOQ18ijJI0yeYEZKlLtIk0jR3A0zMzMfZmZm5nPCNGHm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         "], {{0, 360}, {360, 0}}, {0, 255}, ColorFunction -> RGBColor], 
        BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True], 
        Selectable -> False], BaseStyle -> "ImageGraphics", 
       ImageSizeRaw -> {360, 360}, PlotRange -> {{0, 360}, {0, 360}}], 
      TraditionalForm]], EdgeForm[None], PolygonBox[CompressedData["
1:eJxFlX1MU1cYxiuh3paWQntBqDq8t/dmDkTGwKxji3hQGEbQDaZhIDhnKx1Q
YYPJyPygfGgFVjFjJgQ7dBOMi2wZGcvWUPBUmCboxmID00iabGwd0IJzBnVi
3dgf78sfNzcnOfec932e3/tcfl9F7v4giURiXHz+f1+MSfB/agojkyvchk/K
RCrVVddKp8KIunZtUWuJSDcZHsWPJYcTPj2+wLpfpJ29t69Iq8JJ3KmmA5a3
RNr4tv+Lnb3hJCl/xVeWPJGqO+hc/Vw4uXWwN/HU9sXv79a7cuPUpMAUJXGk
ibShvKLPalSTz6MHNMwGkUrmPY+8djWpvelIPSGKlHK9HXq3mvg7bqzLZkUq
jo87NjMa8jimZYtRsrhfP+Ryv6QhKbqRs5M+ga6WtXR+b9KQ9pSch54xge65
ffiuq01DQnJmT5gHBfrrzacvDjk1xM49DO7qFujwSB3T9puGzGQYD3a2CHQm
pXC9QsoSeeIhsfpdgb5wdd+YTGTJdfOW+ld3CvQzQ9TX5k0siV3/oyxeL9BO
S5Z6VR5LPg4yr0nXCjQnM1L5pJQlWd5lgZ7HOrr524XmhQ9Zkn+ypunYHR1N
eCbNKLcufv+nNXW2X0dVbfpSbStLFKnTTLBdR/uunPxAaGNJ8sYoYebQ0rph
R//Ty7uX9l/aPq298MrSebaubZPOVUv3FQXy28UnPNZT1v2zGJjgsV6xqTio
eJDHfmx7pNqj53js1xfTetbQwKMeX+7OCySbeNTrRkZ5jyKbRz1Xlt1ZvTyJ
R717Xv6jfaOWRz9icuviri/j0a8jJbL6qz4O/XSaMz0Zv3Do98hf0gdFwxzy
oHdET/LfcMhLRFVk2PnzHPJUKPbz905zyJsnkr+nbeaQx8YkZ1WshUNeP1rY
2hdbwyHPpzMvXNNVcsh7t/LS8MpyjsI8uN//dyDSzNHfDYMF814Vrq17q6/Z
ilW4P8y54J/yhuJ5r61JcVnfCcX7Gi+z96d9SqyndEdZie09Jdar6vIOzf6j
wH6Od4d6Go4psF9be8KuHyIUqIcyrVktXgxBvdLHU92hJAT1bIkoHvJNyFHv
NyrH5bpaOfoxOvq3KWytHP0amZi7pRyToZ/Bs1P6A00y9Ps71Qb/4XQZ8rDu
wbP2uuUy5CWrf8DrGGWQp9frdolF5xjkbea+K+FMDYM8yqLnE+1vMsjr81tL
j1oIgzxXFB6p3JvIIO9i4Ke87OcYnAdYw7zAfpgnOA/mDe6DeYR6YF6hXphn
6AfmHfqFPAA9IC9AL8gT0BPyBvSGPAI/IK/AL8gz8BPyDvyGPAQeIC+BF8hT
4AnyFniDPAYeIa+BV8hz4BnyHniH/wHMA/wv/gO8g7Nu
     "],
     VertexTextureCoordinates->CompressedData["
1:eJx1lF1IU3EYxk+rRJKWBCp0kZokfRNM1Ap6Ey3BoA8JIlFISRAMtVCnkrqR
F+aIpliZqHVRZERGN80PaqkZBn2plSYzzHJN3TwUFRo5Kzi/cxF0MQ47/M//
fZ7n975vZFZ+arZBUZQTf35/n72d+bWtlnFRPA9sezdvl8ruRYfZ+kGU1Fhj
y9YsyV/x/WS3ZUKUqYBvo7Gl4ksse3y2/KMombnOfbeqpWpp33Fn8ScZb/UO
Zh2pF8dkSGFJ7qTYDa/ixpNapGBnuNOR5paGPWpOoPGGWOIGamyJn6WhKTR0
0X1bTh++0BS43iPBwy5bzNA9KVJGovb7PeLq2pS8Y919Wf4275r5xZTEt587
anJ1SvGxiEdd9dNi9/Qnp/9yirtZTAcPzUhO9RJT78MemZ0IMBcqXtnQWLEY
fKdP5vuNF0uve8V7M6ki8km/VLWuGW7f5ZMt/qsFQwHPZG12Vd6VPp/Ed/ac
H8t9KbGXWoz2hFlRajOmPSUD8iPoVGn43VkJt3Vb7SlD4q1M8I+sVKUu5nXY
qo1vpKMxZyo9Q5X5uaLd1tXDcibVMJnWrEp0SZB5btk72fY1LKXuuSpRMyHR
5f5RaXv6JXPQp4qhXLEHL7gksfrA5Z8LqpTVRIy1+d/r/+HCebhwH1yoBxf0
wAW9cMEPXPALF/KAC3nBhTzhQt5wgQdP3nOO77iHe6lDXXSgC53oxge+8Ilv
ciAXciI3ciRXcib3/3GBG+fhyn1wpx59gR76Br30FX7oO/zSl+RB35IXfU2e
9D15MxfwYG7gwlzBhbmDC3MJF+ZWn2NtruHC3MOFvQAX9oa+R7S9ou8Zbe/o
e0jbS//uKbhwHi7cBxfqwQU9cEEvXPADF/zChTzgQl5wIU+4kDdc4MGT95zj
O+7hXupQFx3oQqeuW/OBL3zimxzIhZz03LQc9Vy1nPXcNQ6/ATMrJkc=
      "]], 
    {GrayLevel[0.5], Thickness[0.0001], 
     CircleBox[{3.8941834230865053`, -9.210609940028851}]}}, 
   {Arrowheads[0.05], 
    ArrowBox[{{4.673020107703806, -11.052731928034621`}, {
     5.824346350207413, -10.565959000148808`}}]}, 
   {GrayLevel[0.5], 
    InsetBox["\<\"u\"\>", {5.062438450012457, -11.973792922037507`}, {0, -1},
     Background->GrayLevel[1]]}, 
   {GrayLevel[0.5], Dashing[{Small, Small}], LineBox[{{0, -13}, {0, 0}}], 
    CircleBox[{0, 0}, NCache[Rational[5, 2], 2.5], 
     NCache[{Rational[-1, 2] 
       Pi, -1.1707963267948966`}, {-1.5707963267948966`, \
-1.1707963267948966`}]], 
    InsetBox["\<\"\[Theta]\"\>", {0.6622311026502041, -3.266888592804139}, {0, 0},
     Background->GrayLevel[1]]}},
  Axes->False,
  ImageSize->300,
  PlotRange->
   NCache[{{-5 - 10 3^Rational[-1, 2], 5 + 10 3^Rational[-1, 2]}, {-13, 
     3}}, {{-10.773502691896258`, 10.773502691896258`}, {-13, 3}}],
  PlotRangePadding->0,
  Ticks->None]], "Output",
 CellChangeTimes->{3.6628343735992255`*^9, 3.662834419395943*^9, 
  3.662914010164528*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "0"], TraditionalForm]]],
 " for 2 switch times"
}], "Subsubsection",
 CellChangeTimes->{{3.6627079303214498`*^9, 3.662707942690214*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P", "=", 
      RowBox[{"2", "\[Pi]", 
       SqrtBox[
        FractionBox[
         RowBox[{"m", " ", "l"}], "g"]]}]}], ",", "x0", ",", "x1", ",", "T2", 
     ",", "x2", ",", "x3"}], "\[IndentingNewLine]", "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x0", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x1", "[", "T1_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"First", "@", "x0"}], ",", 
          RowBox[{"Last", "@", "x0"}], ",", "1", ",", "T1"}], "}"}]}], "&"}], 
      "/@", 
      RowBox[{"{", 
       RowBox[{"sinDistance", ",", "dSinDistance"}], "}"}]}]}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"T2", "[", "T1_", "]"}], ":=", 
     RowBox[{"time", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "@", 
          RowBox[{"x1", "[", "T1", "]"}]}], ",", 
         RowBox[{"Last", "@", 
          RowBox[{"x1", "[", "T1", "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"First", "@", 
          RowBox[{"x1", "[", "T1", "]"}]}], ",", 
         RowBox[{"-", 
          RowBox[{"Last", "@", 
           RowBox[{"x1", "[", "T1", "]"}]}]}]}], "}"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"Precision", "\[Rule]", 
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x2", "[", "T1_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"First", "@", 
           RowBox[{"x1", "[", "T1", "]"}]}], ",", 
          RowBox[{"Last", "@", 
           RowBox[{"x1", "[", "T1", "]"}]}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"T2", "[", "T1", "]"}]}], "}"}]}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{"sinDistance", ",", "dSinDistance"}], "}"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x3", "[", "T1_", "]"}], ":=", 
     RowBox[{"Chop", "@", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "@@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"First", "@", 
             RowBox[{"x2", "[", "T1", "]"}]}], ",", 
            RowBox[{"Last", "@", 
             RowBox[{"x2", "[", "T1", "]"}]}], ",", "1", ",", 
            RowBox[{
             RowBox[{"T2", "[", "T1", "]"}], "-", "T1"}]}], "}"}]}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"sinDistance", ",", "dSinDistance"}], "}"}]}], "]"}]}]}], 
    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"exportRaster", "[", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"First", "@", 
           RowBox[{"x3", "[", "T1", "]"}]}], ",", 
          RowBox[{"Last", "@", 
           RowBox[{"x3", "[", "T1", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"T1", ",", "0", ",", 
          RowBox[{"P", "/", "2"}]}], "}"}], ",", 
        RowBox[{"Ticks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "\"\<0\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"P", "/", "4"}], ",", 
               "\"\<\!\(\*FractionBox[\(1\), \(4\)]\)P\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"P", "/", "2"}], ",", 
               "\"\<\!\(\*FractionBox[\(1\), \(2\)]\)P\>\""}], "}"}]}], "}"}],
            ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"ColorData", "[", 
          RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\[Theta](T)\>\"", ",", 
           "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)(T)\>\""}], "}"}]}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", "\"\<\!\(\*SubscriptBox[\(T\), \(1\)]\)\>\"", "}"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"AspectRatio", "\[Rule]", 
         RowBox[{"2", "/", "3"}]}]}], "]"}], ",", "\"\<s30\>\"", ",", 
      "True"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.662707946235718*^9, 3.6627080327540216`*^9}, {
   3.662708063147569*^9, 3.6627080763549304`*^9}, {3.6627081120762277`*^9, 
   3.66270815160324*^9}, {3.66270821637103*^9, 3.662708251203704*^9}, 
   3.662708289991188*^9, {3.6627083476520452`*^9, 3.6627083478361907`*^9}, 
   3.6627084251479573`*^9, {3.662708459612729*^9, 3.662708459678776*^9}, {
   3.662708515965661*^9, 3.6627085634523077`*^9}, 3.6627086110290213`*^9, 
   3.6627086500446663`*^9, {3.6627087075614223`*^9, 3.662708778732871*^9}, {
   3.662708863716071*^9, 3.662708864243444*^9}, {3.6627089140197144`*^9, 
   3.662708923211228*^9}, {3.6627092617957573`*^9, 3.6627096354162855`*^9}, {
   3.6627096772331643`*^9, 3.662709677752536*^9}, {3.6627098442555137`*^9, 
   3.6627099552876186`*^9}, {3.6627100782787685`*^9, 3.662710086759778*^9}, {
   3.6627101229914513`*^9, 3.6627101465041113`*^9}, {3.6627102221144753`*^9, 
   3.6627103329129868`*^9}, {3.6627103677206497`*^9, 
   3.6627103822159204`*^9}, {3.6627104145378237`*^9, 
   3.6627104697349358`*^9}, {3.662710508402338*^9, 3.6627106680393305`*^9}, {
   3.6627108032641487`*^9, 3.662710818878213*^9}, {3.662710853415685*^9, 
   3.6627108579589043`*^9}, {3.6627110788624573`*^9, 
   3.6627110815993867`*^9}, {3.662715300269844*^9, 3.6627153096294947`*^9}, {
   3.662914015384412*^9, 3.662914016397532*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0.368417, 0.506779, 0.709798]], 
       LineBox[CompressedData["
1:eJxF2mVUlF+0MHBAREJiZugYUBFREUFAkHj2kRIxECRUUAQEiw4JFZBGwQBp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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0.880722, 0.611041, 0.142051]], 
       LineBox[CompressedData["
1:eJw1l3k8lO/3/5Flxr7FzMgIJVFK0SJ1nWRLVIpUlrJEpCwRElmyq0SErDP3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        "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(1\\)]\\)\"", TraditionalForm], 
       None}, AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, 
     PlotRange -> {{0, 7.769462845773929}, {-0.041218263799125375`, 
       0.20387352081795107`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {{{0, 
         FormBox["\"0\"", TraditionalForm]}, {3.8847314228869645`, 
         FormBox[
         "\"\\!\\(\\*FractionBox[\\(1\\), \\(4\\)]\\)P\"", 
          TraditionalForm]}, {7.769462845773929, 
         FormBox[
         "\"\\!\\(\\*FractionBox[\\(1\\), \\(2\\)]\\)P\"", TraditionalForm]}},
        Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"\[Theta](T)\"", 
       "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)(T)\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.662707950564785*^9, {3.6627080138616486`*^9, 3.662708077896008*^9}, {
   3.6627081142818003`*^9, 3.6627081524038134`*^9}, 3.6627082191199803`*^9, 
   3.662708253304205*^9, 3.6627082904405236`*^9, 3.6627083480623507`*^9, 
   3.662708425579281*^9, 3.662708460111083*^9, 3.662708516419002*^9, 
   3.6627085637735415`*^9, 3.6627086114503202`*^9, 3.6627086508712516`*^9, {
   3.6627087510282326`*^9, 3.662708779226202*^9}, 3.6627088650249987`*^9, 
   3.6627089237175865`*^9, {3.662709550441287*^9, 3.662709577317346*^9}, {
   3.662709663613514*^9, 3.662709689977195*^9}, 3.662709814237258*^9, 
   3.6627098749362545`*^9, 3.6627099075733805`*^9, {3.662709944921275*^9, 
   3.662709973630616*^9}, 3.66271010098886*^9, 3.662710151549474*^9, {
   3.662710306563329*^9, 3.662710355328869*^9}, 3.6627104013664923`*^9, 
   3.662710435192459*^9, 3.662710488847479*^9, {3.662710536404194*^9, 
   3.6627105816736174`*^9}, 3.6627106351979933`*^9, 3.6627108425109587`*^9, 
   3.662710877910041*^9, 3.662711098495346*^9, 3.662715329839799*^9, 
   3.6629140410992565`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "0"], TraditionalForm]]],
 " for 3 switch times"
}], "Subsubsection",
 CellChangeTimes->{{3.662362346663828*^9, 3.662362368336175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", "f", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"find3Times", "[", "#", "]"}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "65"}], ",", 
        RowBox[{"-", "10"}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"exportRaster", "[", 
     RowBox[{
      RowBox[{"f", "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "6"}], "\[RightDoubleBracket]"}], ",", "\"\<s24\>\"",
       ",", "True"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"exportRaster", "[", 
     RowBox[{
      RowBox[{"f", "\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "5"}], "\[RightDoubleBracket]"}], ",", "\"\<s25\>\"",
       ",", "True"}], "]"}], ";", "\[IndentingNewLine]", "f"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.662362371826666*^9, 3.6623624726460896`*^9}, {
   3.6623625393856335`*^9, 3.662362673521633*^9}, {3.6623627670749245`*^9, 
   3.662362777809536*^9}, {3.662362892576877*^9, 3.6623629304977593`*^9}, {
   3.6623629688169055`*^9, 3.6623630727615476`*^9}, {3.6623631106413884`*^9, 
   3.6623632141937256`*^9}, {3.6623633521695995`*^9, 3.662363386296804*^9}, {
   3.6623634224660473`*^9, 3.6623634723853016`*^9}, {3.662363637808651*^9, 
   3.6623636614322762`*^9}, {3.6623637246811094`*^9, 3.662363807440653*^9}, {
   3.662363844857097*^9, 3.662363884520618*^9}, {3.6623639513847504`*^9, 
   3.662363956256585*^9}, {3.66236400878448*^9, 3.662364112057036*^9}, {
   3.6623641644329243`*^9, 3.6623641698884788`*^9}, {3.662364219832146*^9, 
   3.662364339447218*^9}, {3.6623657880618877`*^9, 3.662365788261029*^9}, {
   3.6623660132774725`*^9, 3.6623662741655283`*^9}, {3.662366352525528*^9, 
   3.6623663676922765`*^9}, {3.662366418517288*^9, 3.662366426829178*^9}, {
   3.6623664581883984`*^9, 3.662366700430049*^9}, {3.6623667746456356`*^9, 
   3.6623667787655544`*^9}, {3.6623668359610825`*^9, 
   3.6623668378214006`*^9}, {3.6623668772293243`*^9, 
   3.6623669598518696`*^9}, {3.6623670427416053`*^9, 3.662367106754963*^9}, {
   3.6623671472947025`*^9, 3.6623675026042633`*^9}, {3.662367535316442*^9, 
   3.662367557171943*^9}, {3.6623676062917337`*^9, 3.66236769687527*^9}, {
   3.662367738515776*^9, 3.6623678591312428`*^9}, {3.6623680225870323`*^9, 
   3.662368086394244*^9}, {3.6623681408358774`*^9, 3.6623682218513002`*^9}, {
   3.6623682533075733`*^9, 3.66236849267494*^9}, {3.662368556266*^9, 
   3.6623685581073055`*^9}, {3.662368596563554*^9, 3.6623686813706484`*^9}, {
   3.662368716524557*^9, 3.662368857266284*^9}, {3.6623688972356043`*^9, 
   3.662368987012229*^9}, {3.6623693510031385`*^9, 3.6623693575007524`*^9}, {
   3.6623693992233067`*^9, 3.6623695248503227`*^9}, {3.662369627762164*^9, 
   3.6623696305141153`*^9}, {3.662369710001439*^9, 3.6623697198664274`*^9}, {
   3.662369825930585*^9, 3.6623698457686415`*^9}, {3.662370007810462*^9, 
   3.66237001006606*^9}, {3.6623705309941807`*^9, 3.6623705503218765`*^9}, {
   3.6623848765229626`*^9, 3.662385082494526*^9}, {3.6623851154635754`*^9, 
   3.6623851572150164`*^9}, {3.66238520811036*^9, 3.6623852972626343`*^9}, {
   3.6623856497485037`*^9, 3.662385717133174*^9}, {3.662385902094715*^9, 
   3.6623859483991985`*^9}, {3.662386379708193*^9, 3.6623864276610355`*^9}, 
   3.6623908625447297`*^9, {3.662391116015093*^9, 3.662391129211432*^9}, {
   3.6623911682258415`*^9, 3.6623915946024537`*^9}, 3.6623917564208336`*^9, {
   3.662391912794508*^9, 3.6623919216575174`*^9}, {3.6623923117470827`*^9, 
   3.662392324178277*^9}, {3.6623924584083266`*^9, 3.662392476665084*^9}, {
   3.6623925697788954`*^9, 3.6623925776410093`*^9}, {3.6623926633285527`*^9, 
   3.6623927139211335`*^9}, {3.662392855042916*^9, 3.6623928861077223`*^9}, {
   3.6623929253114386`*^9, 3.6623929339792075`*^9}, {3.6623929745528*^9, 
   3.662393003774825*^9}, {3.662393932189764*^9, 3.6623939635950165`*^9}, {
   3.6623941010134*^9, 3.6623941268286924`*^9}, {3.6623947818680725`*^9, 
   3.6623947821872993`*^9}, {3.662395787190342*^9, 3.662395799632399*^9}, {
   3.6624456192680597`*^9, 3.6624456197073812`*^9}, {3.66244889744656*^9, 
   3.66244890259721*^9}, {3.662450317450881*^9, 3.6624503185706744`*^9}, 
   3.6627078952746162`*^9, {3.662715811018764*^9, 3.6627158115861664`*^9}, {
   3.6627158549328876`*^9, 3.6627158568502398`*^9}, {3.662716012258359*^9, 
   3.6627160260341206`*^9}, {3.6629140468189096`*^9, 3.6629140507553654`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     InterpretationBox["\<\"\\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\) = \
\\!\\(\\*RowBox[{\\\"-\\\", \\\"65\\\"}]\\)\"\>",
      StringForm["\!\(\*SubscriptBox[\(r\), \(0\)]\) = ``", -65],
      Editable->False], ",", 
     GraphicsBox[{{{}, {{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Large], 
          AbsoluteThickness[1.6], 
          PointBox[{{0., 0.}, {0.17719672165339104`, 0.027800602664625643`}, {
           2.26345163022458*^-17, -0.10868815380202543`}}]}, {}}, {}}, {{}, \
{}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxd13k8VG0bB3BLSlQkpUTak72SrZqftQUtFCJCWlBZsqXsa5SQ9cnOUZbs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          "]]}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwV13c4lW8YB3BtUimERNlNK+Mn5FYoobKyskeyhRxZmVnZI7KyOcneJx6c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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotRange->{{-0.4, 0.4}, {-0.3, 0.3}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], ",", 
     GraphicsBox[{{{}, {{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Large], 
          AbsoluteThickness[1.6], 
          PointBox[{{-65., 0.}, {-47.36560961724141, 
           5.93875245868332}, {-32.5, 
           2.3532023990796773`}}]}, {}}, {}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxF1Xk4VVsfB3Czk+ggbFIZShMaKB0Vv0Wnzsm4KXKVepHhFjlUpCIU9+qW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          "]]}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwV1Gs0lAkcBnDemSG5jmFGBy2RM6XVIhLK/50x86oRFUNRiFa3VSpjM0Pa
iJTpIqwdl9iVWFskq5Tyz0l2rWpVzmpWKedELtNlJyZtse9+eM5zfp+eb49j
/N4NXxN6enpr6fzffWc7JD2XKJRHWIUF3ebBQi5//dRFCv+wUZvwkXZeU5wD
bbu/z901bOcBSXpXpNRTeCvW1berjQe90x8K7GspZOwUOIqv8SApf3fCvioK
TyiS3wgbeKBYzqp0KKSwrLLnREA5D3TVc4+Vp1HYPpZ9xzuNB7zGas0vQOFp
i2+l1q48ODdw54ibCYVXBambHYe4EKb4ir/piRhFG+vaSlVcmKw2LBz9UYxb
Z7f4G6zlgteqoIbOZDH2Nn3hUcHkAhCuDnw/Md7XxVMuLdZQ98KeDYZiXOag
/tVupzUMpl4Rpv8lwtfhMSpwtAazmZHg7dUi9LLdVhH+yApezh7MjJeJsFeT
alN83Aoe1yj1xykR9v10c1wktAKvT/fUq3kiTBw/+uzlJAcYIZy0grFAlARE
U1cucmAsNme493og3nJuepAcy4HJ2m1z6/MDsUTjf7nMkgNLdoirxPGB+FvH
4zlT3Zbgqe7cre8ViNmLXmcGZFhC9Mymc7uMA7GozCqpZZklhEzMq+YMCtGz
qi3NfpgNtlqlE9UsxBV5JYP/lLChf7mLUl8pxMKM725MrmNDJj8/yjlBiOmM
iZZXBBseMrVvW/2F2FqUwDe6bgEKaVf7ZZ4QY4zNtd/vt4CMRaXZK94K8LSl
/1PuQgs42fi6zLRHgF8GT8hzWs3hmrDUveC8AKXFCfJ2O3OAlbzdRw8LMPiC
YEnfETPwqBspLI8RoOZPv26R1hTG3Fwun/QVYK29z4XiSFN4IdH8fHqeAE2z
QpIFd01gwmbC6ck0iYKGnvHu5SZwlZhhLugn8czM2hrPcmNoODSwU9pK4vHE
0WCdiTFo2NrzdSUklr/L9ShNngu6e31+j+UkRhUBU/XMCA74vfLyjiFxeDbu
mCzUCFRNRvXPA0jMV2ZL3JvnwInYYK2vM4kDnh0fKac5MGsdKpkxIFH8mRhd
lWMIbx9sSWONA2Yq6/MsJwyg6o6PQVEvYLz3Hi652QBk48rFLS2AscSyoVBk
QWeUQYGkAtBghKNqdWMBa9Sn5FMOYEZBNFOvkgmRXUtvJu4BNNtac9GFxYQG
t23X528EXB1kLKxNYcDtvNCGtkjAgz72bKf9DLA1e9MYRbuGv3SwfC8DqgrW
qIsjAAmjMMXZXQyYPX6g01wK2Pa76sqhOAZM+yg/MzYAukkWO0uDGTCZN/h+
UgJoFbKaRTgzYMB03eEi2oJV0Y/SHRlgfCPFxov2PrekKt18BgScUe9JWQN4
3+zMSs08BmiX2DRrgwBzH/TL+s3pfcfoyvciwI/rdgxf+peAqRVmukLafFLe
vGiagFMKWZQX7Uj3/CPVUwSUyOOo1EDAZnbjfNU7Aqa317Z+EAAmPdRFHB0h
IKv7k+wH2mUdRgv1XhIQHsEK8KXd3WSrlQ8R0DXqoVOQgC5nA04lPyXgm3eR
w3a0w7PWbxlXEyBd4D50EwCzDiS4JvYTkJt+ayyGdlOCbPp5HwH69Ifp0X4e
ltsV/YiA/wDCWyeq
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotRange->{{-65., 0.}, {0., 5.93875245868332}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"T1", "\[Rule]", "5.93875245868332`"}], ",", 
       RowBox[{"T2", "\[Rule]", "3.5855500596036425`"}]}], "}"}], ",", 
     TemplateBox[{GraphicsBox[{{{}, {}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVl3k81F8XxwmVogVJkmyhsmbNdk8MM6JIJRJJKtmTIimioiz5SZHsyb6O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            "]]}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVV3c81d8bJ5KsbLLKnpW9OY91SYpEiZASMr5GkiIVpUGSVGTPa8/rXuve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            "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)\"", TraditionalForm],
            None}, AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
           AbsolutePointSize[6], "ScalingFunctions" -> None}, 
         PlotRange -> {{0, 50}, {-0.38975093640607883`, 0.2038298277174086}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        FormBox[
         TemplateBox[{
          "\"\[Theta](\\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\"", 
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \
\\(.\\)]\\)(\\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\""}, "LineLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
     TemplateBox[{GraphicsBox[{{{}, {}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwNlnc8lW0Yx60yIvt5zjnWcaxCykxKHiOOUbbKSiTekoZRKSPppaKhIpXI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            "]]}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVlnk8VP37xrM0lsh+zgzGvk6yj8rSXEqaUEkR0fIotEgkUgkVssSjEuVb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            "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(1\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
           AbsolutePointSize[6], "ScalingFunctions" -> None}, 
         PlotRange -> {{-20, 50}, {-121.16880995876113`, 
           49.410878968218626`}}, PlotRangeClipping -> True, 
         PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        FormBox[
         TemplateBox[{
          "\"-\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)-\\!\\(\\*SqrtBox[\\(\
\\(-\\*SubscriptBox[\\(r\\), \\(0\\)]\\) + 2\\\\ \
\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(2\\)], \\(2\\)]\\)]\\)\"", 
           "\"-\\!\\(\\*SubscriptBox[\\(T\\), \
\\(2\\)]\\)+\\!\\(\\*SqrtBox[\\(\\(-\\*SubscriptBox[\\(r\\), \\(0\\)]\\) + \
2\\\\ \\*SuperscriptBox[SubscriptBox[\\(T\\), \\(2\\)], \\(2\\)]\\)]\\)\""}, 
          "LineLegend", DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
     "19.048605036573925`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox["\<\"\\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\) = \
\\!\\(\\*RowBox[{\\\"-\\\", \\\"10\\\"}]\\)\"\>",
      StringForm["\!\(\*SubscriptBox[\(r\), \(0\)]\) = ``", -10],
      Editable->False], ",", 
     GraphicsBox[{{{}, {{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Large], 
          AbsoluteThickness[1.6], 
          PointBox[{{0., 0.}, {0.043879516514191516`, 0.033879871508857}, {
           1.13172581511229*^-17, -0.05408605273955663}}]}, {}}, {}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxdknk01IsDxYXsL0WWF8lWyja2RzJ97+BFeLInShlZQoQhorJvWRqZQbKN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          "]]}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwV13c8V98fB3A7DZKdkYSyshpGeCMK9c3e4fNBsndkRAihtJAR9bH5iJsZ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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotRange->{{-0.4, 0.4}, {-0.3, 0.3}},
      PlotRangeClipping->True,
      PlotRangePadding->{{0, 0}, {0, 0}},
      Ticks->{Automatic, Automatic}], ",", 
     GraphicsBox[{{{}, {{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[Large], 
          AbsoluteThickness[1.6], 
          PointBox[{{-10., 0.}, {-7.153115054752247, 
           2.386162167685907}, {-5.000000000000003, -1.1779387849082052`}}]}, \
{}}, {}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxF1Ak8VGsfB/AxI+UOSpt7MxPjiOpt0y7L/2hBJW90e7tJSLYibaJ0k8iS
SrZChbEkS0hZZiSeO9nJnnVcL9mF7Dvvo/fT3PP5nM85388553l+/+f8Pw/L
9LK+OZVCoYTgc+H6/0Me/bxr59DG5+cJtFK/enTJtBYEfJXg/+NTIO7MSlrw
EzVjjubMOTjurXLln+eWYCRxVmbBwRaHdxRPXoJdFPfMOcH7V6HmfJrWgivz
f6t9PW0HGsr9aFbwvQM4OG9ev+D/8L1XXpxyBHtluzszgvHuAGnGQ9PYthNC
G5796QxVlF+HpgTj3wOlpTckF/zWJVNr/LYrnH5Sv3ZSMN99EPlR4M/5POBR
xo7GUexdgUpuXMcH0CiUxh4RzO8F9e3lo4OC+R+Dh8sFt+/YGfHRvNu3nsC8
jyhtQJDHB47RTAp6BXl8gbBcvawHW/a/4hSZTD/IUa0+1CXI5w+maha32wT5
AuDXHwv+M18gqLt/yavHjhpxUWvJCIKtPaU2tYK8wWC7uM6lUpD3OZgHHqjN
F+QNAb7U1fkc7I2iE46R3FBg/hK9iifIHwazBxTEMgX52bDrxw/+mT8cZqS7
ufHYdd67+dsNI8D75WkyRlBPBEgMH5cKF9QTCZ6jQX2+gnqiwPhHg/ys5zU8
7WLoW2MXKRwMFzkfA3LXH52wwHaefq8jXBwDh4wlpAyxe6P8I+efx0Ksfwhb
E5s3rq83ti8eem26P0phXw6pePPVMRFCN3q4SGLLX9P4o6U1EeIaFm2nYzdo
JtOajyRBgWS03twcgYib2psvib8Fgn/V/yu2N2v9faumt6DfspsVh21u16lk
fOcduOZ89Y/ARkZhi42S34HY86uDz7HXHD7VZNj+DtYxtl16iF3OzPc0OPYe
HP7ca2mNrZof3XySmQL+CfbmitjL11g81vmYCokVMV5PZvF42W1dyrMc6Imm
LXbHrv39VkzeZi4k641c+RO7v1vc6oQRFzoUA8UvYDNX7um0yebC15rWCxrY
jlYP2sPuZcBW8EvsnyHQTsktrYtEMkFcWc9KBTvG1KGxQiIbqrMtArdiZ4/T
XxhBNigylqcQ2DWP2Aa9l7Ph+smNaXTsRemF9cIV2RBaZNLUME2g5EUS314c
RqCV3Z5+A1vCwKSnlP4XNFX8OyRkikAF1EWdO3144JK1Pe8JNl9lmYlQDA9C
Ikyb7mEP2EnXf87mwR692Bpz7NWdSsUWAzyY1aoc2YRtVmyUFKT7Ccpe+DWn
TxKIEsBxmBHLATd+iS2aIJDyOpslOQ9ygcrRPfcWW8fI4Z5PeC6MeTH3s7FN
Al2mDLm5oCEVUXoX21M0+NtoVy5cLNRcoY5d05dbrqidB5SAuSPp4wS6liYT
/FAkHzR4inYvxwgUp1W14YRrATSxFSM9sYPDc4TlQwpApebERztsz+nU5pG0
AtA4pPReB9siKejps54CsN1JeTU9SiCWlJFQg14h6J7qZ5/EDuroqjORLQIi
iT41OUwgd7c5D9uPxaDw+oiS8CCBTD9t6HgwXgq9pHvtt+8ESrommha+tAzW
S4Zaf8GeYXW7cRXLgH7S9Gw09jPnmHXdp8rA/qKapRZ2sZqiuTanDJqL1Va6
D+D+M1x+zVW1HCatLKtG+wjkUrN0UGO2HPTEjDpCewh0oviXgSynSpC0ia2y
asXrVZ6jeIj3BZyOUu+I1xPIOvqlp/dYHVxhpI9vLMP9uh480oYbYal4QvfW
TwS6mfuKd1GpGfIu7tOsSCOQmkfv5znpFjgOOr4Bsdgr/UtjA1vBJHfwj8lg
Ag0lvux7vqMNbvuaeKt7Ecgr7OGZ6fftYDBs/aHXAe8XIfzO8N87QXTto7+j
zAj06r7qkri+LnhSmyh1X49AJ/+658Cy7oG9a+gZrip4P6JvWNS85Bu8Oqo2
VLKOQNQ3qS30h30Q9n1zyYwY7heDKL7T5gGYEI0NOjEsh9QnylM3mH2HG6zP
Q8oNcsjWlhdVTAyCY4S9RPZHOXSrty3CZ3gQuMYck/FwOXRjhaP249QhcBM/
Px7iJoeSk1ZzMq4Pg79H5K4QczmUr9+2m75/BIZSVpX4a8qhMrb8WX/qKGxw
yLKOJeTQu9GnfupVo5Av9+aYFEUOVWdJ+K1hj0GElY0ur4mFOrdP7d1iPA7B
i7PiDqaz0JeE1QNmWyZA9fyFVEU/FkqteqVTNTABCn2WrDgbFqq+pGp3LWES
Ngm9FMraz0KlEsLxO29Pgausr7P9GhbiGqg/2KIyDdwrN+fc+2TR3YRY+6P0
GWgo+VRlzJNFe+I96OzPM8CwGiwZeiaLtjAvXVz3aBbqLZsfBlrIIsoz17rP
BnPA9dzeqr1XFn3iivUnSM8D7YOTZqWwLDrXlrc8+ds8aAfFus2HyyC2Ro7z
kCGF/C6i5DCvLoM8Lf4+GpNJIVN4jT0yFWtRk4Rv6GV5ITInoPbpJqu1KF5s
NkffTYg8zqnsWzrPREE5Nsd124RItCk1w8OLiYbn7c6fOUolRXzd+delmSjf
Z/eR+/FUsr8yPtvpNybKaiyPVUqgkh23S288kGKiNAVr0eZEKrmMJnYmdAUT
RWeGFSi/o5IHOyxF8+hM5N61RGuAQyX3UCJHxWYY6CDZeMAgj0rudlEQu8Vn
IDRwV21bC5W0j57QdWpgIM6+NSFNrVSyQKnAzLWOgd66pcx4tVHJ6DvGoo+r
GShMuvtDeycev8d2d2gJAzlp6e970U8lhaUkZTmZDKQaJr9HZIZKXnnD9cvI
YKCdPVnP3s9Sye8xxnWZHAbatOv0mMk8lVxfG8lHKQwkXfw49QOVRt5cIl6Y
94aBpsbGdlwVpZGONeyq/DgGGtLw9V9Lp5E+9O3JBTEM1PPoX8PFYjRyJE6n
vTCKgRrkTN4pLKOR+1fVqBRFMFDlpSnJakkaGdFhaF7EZqAiTsDVeyto5GqZ
lnNFoQzEo22t2LKKRoZmmSoVvWQgrm7hNv5qGvk/uMIGBA==
          "]]}}, {{}, {}, 
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwd2Hk4lF0bAPBBSckyM7akQr0q2aKEcCZ5pV1CRJJdpJKKyFISQmiyFlOW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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      Method->{},
      PlotRange->{{-10., 0.}, {-1.1779387849082052`, 2.386162167685907}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"T1", "\[Rule]", "2.386162167685907`"}], ",", 
       RowBox[{"T2", "\[Rule]", "3.5641009525941123`"}]}], "}"}], ",", 
     TemplateBox[{GraphicsBox[{{{}, {}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVV3k4lG8XRipZQiEh+/bLvo2yPQfDDBWFlEIosicpkspSkiQVUdmSLWRf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            "]]}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVWHc81e8XlygyQjZfIZsyrr2eI1wSJSGSUbbISBFCFIqQVMrM3uta97o8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            "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)\"", TraditionalForm],
            None}, AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
           AbsolutePointSize[6], "ScalingFunctions" -> None}, 
         PlotRange -> {{0, 50}, {-0.3905698540888156, 0.19873589390559898`}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        FormBox[
         TemplateBox[{
          "\"\[Theta](\\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\"", 
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \
\\(.\\)]\\)(\\!\\(\\*SubscriptBox[\\(t\\), \\(2\\)]\\))\""}, "LineLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
     TemplateBox[{GraphicsBox[{{{}, {}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVVnk8lPsXnvedGVvK0hgS1yjCJBlbocwrYrJc+35HUlFClhQlhEpZ2lyh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            "]]}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6]], 
           LineBox[CompressedData["
1:eJwVVnk01QsXvfd3r5m6ZErJJfM83GTst0m5rzxJeIokZXg0SZ5MUfEoQ6Vk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            "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(1\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
           AbsolutePointSize[6], "ScalingFunctions" -> None}, 
         PlotRange -> {{-20, 50}, {-120.78135002988631`, 48.46049550514864}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        FormBox[
         TemplateBox[{
          "\"-\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)-\\!\\(\\*SqrtBox[\\(\
\\(-\\*SubscriptBox[\\(r\\), \\(0\\)]\\) + 2\\\\ \
\\*SuperscriptBox[SubscriptBox[\\(T\\), \\(2\\)], \\(2\\)]\\)]\\)\"", 
           "\"-\\!\\(\\*SubscriptBox[\\(T\\), \
\\(2\\)]\\)+\\!\\(\\*SqrtBox[\\(\\(-\\*SubscriptBox[\\(r\\), \\(0\\)]\\) + \
2\\\\ \\*SuperscriptBox[SubscriptBox[\\(T\\), \\(2\\)], \\(2\\)]\\)]\\)\""}, 
          "LineLegend", DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
             False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", "}"}]}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
          Editable -> True], TraditionalForm], TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"], 
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
     "11.900526240560039`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6623939648089013`*^9, {3.6623941023913765`*^9, 3.662394128070572*^9}, 
   3.662394783321102*^9, 3.66239601670006*^9, 3.66244562046891*^9, 
   3.662445655384692*^9, {3.662448882460931*^9, 3.662448903864097*^9}, 
   3.662450031992614*^9, 3.662450320015705*^9, {3.6627078960942063`*^9, 
   3.6627079025517826`*^9}, 3.662715787485096*^9, 3.662715818437028*^9, {
   3.6627158558315244`*^9, 3.6627158585094223`*^9}, {3.662716014185732*^9, 
   3.662716027939477*^9}, 3.662914056583438*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "0"], TraditionalForm]]],
 " for 5 switch times"
}], "Subsubsection",
 CellChangeTimes->{{3.662440283230195*^9, 3.662440294502184*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"P", "=", 
        RowBox[{"2", "\[Pi]", 
         SqrtBox[
          FractionBox[
           RowBox[{"m", " ", "l"}], "g"]]}]}], ",", "uu", ",", "ts", ",", 
       "ds", ",", "\[IndentingNewLine]", "x1", ",", "y1", ",", "T2"}], 
      "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x1", "=", 
        RowBox[{"sinDistance", "[", 
         RowBox[{"0", ",", "0", ",", "1", ",", "T1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"y1", "=", 
        RowBox[{"dSinDistance", "[", 
         RowBox[{"0", ",", "0", ",", "1", ",", "T1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"T2", "=", 
        RowBox[{"time", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x1", ",", "y1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"x1", ",", 
            RowBox[{"-", "y1"}]}], "}"}], ",", 
          RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"Most", "@", 
         RowBox[{"finalOc", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", 
             RowBox[{"-", "30"}], ",", "0"}], "}"}], ",", 
           RowBox[{
            RowBox[{"4", "T1"}], "+", 
            RowBox[{"2", "T2"}]}], ",", 
           RowBox[{"Function", "[", 
            RowBox[{"t", ",", "\[IndentingNewLine]", 
             RowBox[{"uFromSwitchTimes", "[", 
              RowBox[{"{", 
               RowBox[{
               "T1", ",", "T2", ",", "T1", ",", "T1", ",", "T2", ",", "T1"}], 
               "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", "}"}]}], "]"}],
    "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"T1", ",", "0.01", ",", 
     RowBox[{"\[Pi]", 
      SqrtBox[
       FractionBox[
        RowBox[{"m", " ", "l"}], "g"]]}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.662440296008257*^9, 3.662440300430394*^9}, {
  3.662440343019562*^9, 3.662440473214833*^9}, {3.66244050771908*^9, 
  3.6624406140624313`*^9}, {3.662440648192605*^9, 3.6624407288547606`*^9}, {
  3.6624412545102887`*^9, 3.662441257262248*^9}, {3.662442441442675*^9, 
  3.662442443548167*^9}, {3.662442474828332*^9, 3.662442474867378*^9}, {
  3.6624425505469847`*^9, 3.6624425759309716`*^9}, {3.6624426149316063`*^9, 
  3.6624426292027187`*^9}, {3.6624428115159025`*^9, 3.662442830082059*^9}, {
  3.6624429553708363`*^9, 3.6624430134970355`*^9}, {3.662443058635008*^9, 
  3.662443120314742*^9}, {3.662443150890396*^9, 3.662443169858819*^9}, {
  3.6624451460303383`*^9, 3.662445152054617*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "f", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"find5Times", "[", "#", "]"}], "&"}], "/@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "65"}], ",", 
         RowBox[{"-", "10"}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"exportRaster", "[", 
      RowBox[{
       RowBox[{"f", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "7"}], "\[RightDoubleBracket]"}], ",", 
       "\"\<s26\>\"", ",", "True"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"exportRaster", "[", 
      RowBox[{
       RowBox[{"f", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", "\"\<s27\>\"", ",", "True"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"exportRaster", "[", 
      RowBox[{
       RowBox[{"f", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       ",", "\"\<s28\>\"", ",", "True"}], "]"}], ";", "\[IndentingNewLine]", 
     "f"}]}], "\[IndentingNewLine]", "]"}], "//", "Column"}]], "Input",
 CellChangeTimes->{{3.662443406403431*^9, 3.6624435032330437`*^9}, {
  3.6624436002237806`*^9, 3.6624436357849674`*^9}, {3.6624441969105897`*^9, 
  3.6624444218479586`*^9}, {3.662444780986637*^9, 3.6624451234703655`*^9}, {
  3.66244517027853*^9, 3.6624454878439407`*^9}, {3.6624455271327744`*^9, 
  3.662445557708439*^9}, {3.6624457388938546`*^9, 3.662445739189065*^9}, {
  3.6624463918455257`*^9, 3.662446424547697*^9}, {3.66244825633827*^9, 
  3.6624482667836714`*^9}, {3.662448490836432*^9, 3.6624485956396933`*^9}, {
  3.6624486904939184`*^9, 3.6624486905819683`*^9}, {3.6624491170689907`*^9, 
  3.6624491417825017`*^9}, {3.6624494621648507`*^9, 3.6624495514401093`*^9}, {
  3.6624496279250455`*^9, 3.6624497820532475`*^9}, {3.662450474475151*^9, 
  3.662450476720737*^9}, {3.662707826621989*^9, 3.6627078283061523`*^9}, {
  3.6627164439882746`*^9, 3.6627164803790536`*^9}, {3.662914064002808*^9, 
  3.662914069434365*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"1.1688705502149054`*^-6\\\"}]\\), T: \\!\\(\\*RowBox[{\\\
\"21.037602627819645`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\): \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \\\"65\\\"}], \\\"}\\\"}]\\)\"\
\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         1.1688705502149054`*^-6, 21.037602627819645`, {-65}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3k4VO8XwCVRKVnGliXLjC1mBmNf3kNkjbILZSclJRRJWZIsJS0iyhJR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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVmXk8lN8Xx4nsyyiEsUdZBjNIhbqntAjRipLIlq8lv4pCCElIhSLZzTxT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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVUnk0lXsb5SwiJZKU8RrKmOm8PyqpnhCKkEgoF0WlUoaijhQi81SGU5FK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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJxF13k8lOv7B/AxtogxJDNjqxhLMWPsHar5oEUoIdspUeiclJycFntZsyVR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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 21.037602627819645`}, {-44.76025626619172, 
             6.177792701129061}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV1Hk01dsXAPBrqIylpKifcEmGRPleLmV/vxUq9ChD5lAJGUKhm/uoVFI9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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xs01GkcBvBxKdp0I6tVK0zUnHGL96ebqZcTO1Quuc20UTsxZjKHjdQs
W+3WsJoupwsTiRrFuNRW2u2Uze9bJDttaJZcRoRFFxuZGckWu+/+8ZznfP57
znkcBMlb440ZDMYWkv/bak/K0voWhNmr7IqYNyTQsX+Mrya+xZXvGLgmgQsH
v81pJHbLLLYvqZSA8/GkWW3EZYp2pbNKAqtVu/VDxLgz4hKrSALbuwUN5q0I
V59XnnA/LoErgeHJm4kL7apY60QSQI4IWoiLypaKw+wlEDdH6Dj5DOEXe233
7pQlgudEzMLZ7QgzVKkq0O2GJH15qU0HwipPe7/xXbvhLkv4aW0nwsdrxJzZ
ajEUx77qDdIiXMfa1JeyWgznG7XZe7oQPiFa4V5dIAJGiIPmzHOEbb+D6XYj
Ecxodi271I2wpQNvmJuSAIuOVvjV9yBs7ZN8P69NCGrft4ltLxDWatan+fgL
4bWFjOrvRRg02Svv3I6HRZbHak37Ec5yF7pYLomHQWtej9VfCJ/ia8MeHIuD
B+G5NWsGEG7fjtjBo7tg9hVnzrZBhOdxJN63IneBXndgU8IQwtwbzIqkRwJ4
k+H/5bGXCOtdfwkwYwvgkEnLgYJXCFcwinXv878BZv1TZe1rhCNFXF7dp51A
5TsKB94gPM2Y1ycS7IShxLV3dcMI1w4Xuzde2QEl0tpmm7cIj080bfhREgsm
svlprBGEFWCiHeLGQLOyqpoaRfjPHmxjxN4OFZMP63jvyH/l3mEthm3ADC38
WjSGcMH1qyb8Fj5U9g7ePqlDuJ4vclHk80B55HDVdT3CvmOZsuz4aKCcBn1q
DAivy0x38giIgg7GHXnfOMKDdVc7Ts6NhC+6QhN07xFOWc784/JwOKgbOANT
EwhLfDO0yU1b4aeR88vsJxHe8ZFxX5cXBgNWtN7tH4Tv5snFrtJQCEkNy4r4
iHDg9YepnIPBwNdUqISfEB4bjw46TW0GjS9PnDqFcP6HZ3OjPgQC7++0EcU0
whNbzDyy5V/BgVy+sepfso/L/9wtwB9uSq91NjIo/LP3abGvxg/CkyLDRo0o
bLOc69mQgOGsoC56ypjCe72k1lkhPtB/SungaErhJ6myNn7SKmiu8U/3mkHh
JptEtKTXE9hTnNQNMymcbBYyfkrjAop9pe4CMwpvq4hzKbFnwsWR1vQ95hQ+
6y+3XcdeCBYGb+99xNXtv/dKtVaQPpk3lk6svnmv9PZRK4gyjRHJiF3nqFd6
vrIEC9vByHPEj9U5G1klC0DqP+5RQ/zMwvCb2/q5EHrB+qX5LAp/H2f7dMjJ
FGjl/uI5xNb28cECmQmwVZ0xlsSlaXFPuvuNYWZVYeti4r6iow2tF43gXoNT
rRtx93RMWqbXNL1CTxVGEAc/bHXhLDbQig/neHziyMOOjqhDR5tMT1rFEruv
Zdqwc8foHnNankAsHy1keNqN0Dl2AdJ04vLKyxdfzxigjZeVeR0ixr9KstoP
9dHJrM9GjxA/eve4U67vpoNQU/wJYpeOBSl+XS30nTUeDmeIf1i9KMOnqJF2
3nDmuYJ43/yYBYbMOjpno+FcAXGst1twdFcVbRQUFX6JOIMbkZIXnrb+P1Gf
RCQ=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Hk4lXkUB3Aho0gzSBjKeklF6b3WvH7GMiXlZusqTJRLyBpdJAYJpcVy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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xs01GkYB3D3VJwNO6ttz25rlO7W6v3ZLuzzdlEbKhFGkXZOBiUxk7JK
Krpgd9MUCpNGNpeoRbUZhjVjXKZkRRaTS2aGiBlmqKywb3885zmf8/2e8/zx
WDGPeQTq6ejo7CTzaVtEsBdLWhB+EJJtljEihfaTY74NxHGnVr+IeSuFzDPh
1xuJ13Afcw8OSsHm17C5bcRnnkotbJRSWJd7WNtPrM/R0opfScGvi1ln3Ipw
a7LzorqnUsjZ4XnMjbhQd4SuzZcCoqOqFmLh5Z+QK0sKh0xZ9MmXCN8LCMq6
2dIA9u/9P5//L8I0TVzubZcGCNPm37VsR9gwXnjBp6YeylawPm7oQHgZg1NY
aF8P2Qfe9Lp0IpylMQ0XFNRBemPn5QgZwo9uLDvNsqwDnd1WzdxXCD8f8Tgg
ulgLhk1r8m53IUy3c+tqm5XAwoSCzZJuhEOyxDkJRyXQsGnkSFsPwo8ffTSe
UNTAoEk81deLMLvPdsuCgBpYaJ4kMuhDuOedTNLQKAYljdFtIUe4P2GdcuM2
MVR7pgjXKxD2QqY73UpFMD/HxmmfEmFVRmOiibUItJoY16B+hM0z1wReyKyG
oVPOXycNIHxOMX0pc141xOq3xGS8QTh4fuD20PN/g7XkH75oEGGlSeith11V
QN2ksxRDCJeJBb6j5ZXQf2RDmeYtwuPFi3fxioTwR5SoyXIE4Q3x0HLxcgXo
xy+IXKFCWO4SfPX1iXJo4pcIKDXCgw7WUxmHBVAwWSNmjCIs0js9wd1eBtbu
vP3BYwhfM2taPvXDE7jXq3z8u4bkA7nDWWZ/AT/ufMkDLcIeumP7c0YfAbVU
6SgcR7hbsNJgkfwhtOs8SXw9gXB+utjxWWUpfClzD9K8Q7hdte2+uqgEGuqc
FNPvyf2Ftk/Z2cVwSZW+5NtJhL2HdkTZn/0TFBaVWtv/SH+IV1Hbdx92c/Zc
3DuF8FmVNI+fVgi+zQW5rI8IMwNrjQI4BdC8iRHCmUZYqvAul/nmAWM4UpU6
Q/7LvnOl2fwuxKT46uXOIiyze/YyX3MHiqOKOhp1KHx0fP/GqRw+eIZ57VHr
Uljt7q+yrLkF15hin2k9CqdODu+YSUqHvmS+Fd2Awm4+e+VtH1KgSegcvdaQ
wkpXwcHjpVdh1bQTB4woHDSYSbOakwSpJ+5+x5xD8pCjcqexc5Clao2OMKZw
GbNcWz/CBpNxB4cTxL9cuNNins2G6MkbY9HEtKzEUj9vNngb+AfHE7v1e3FG
KyPAZJHSK404sbdXY5kcDlHOE3ZC4s9qr8gbD4WCeyZtwHguhbevLumaq2JC
Jf9ktimxIHILj+fNhFW5Hf7mxEHyF37fV/0MRiW81q+IccFbGSP5IFTULRXZ
EqPyeQ93B/rBci3F20ustiu5l6TygNQPaQxfYpl+ysrSqj2gPzNpcYC4gnY8
vzPZHbqNKxODiD8MuO7yZLnB9W+2RUUTF1qUbr2i3gx6S/LWxhJzL63b3H0V
w7EV89RxxJKe0Nh9wY7ggp4H/kZsaL82MnXMHp6st7PiEtf7T/UEh64GG+C+
SiW2+yL8Zc4EHa5vHU/L+NQ3S0ipnjYHXRdvz9vEM7MBE7Hrk3/8H5uqTkE=

              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {20.85, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{20.827226601541447`, 
            21.037602627819645`}, {-0.022127902071973567`, 
            0.21037615166717447`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxc23k4lO/3B3CVSmTLrsUSorQISeGIKHtJQvayZCckS9bsZN8JM4NU9m1s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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw9l3k8VN//x2fGFsJQH0YiO9mXtFnOIcvIaCZFtkqhlKiUSpYkZN/JWiKS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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1QlMk2cYB/BPxijUAEVROYSNcWmRCi2OZTBbaAa4ssiKIArEQmEqDBqw
OC5LOGQCGWESxTquAjOygV1wFKgg1nFfCuEaFIRRkaFCKYji2NyR8DyxSdP8
ku/7P//vfd+2VuECbqQWQRCp/77/+yS4d6w3HxQfJv5/qZnCRU7D9zETzC23
KiS9trlPwTo2Xgy3hDXwATEtv/+dP8HsF6zbXMo21pb5vnY9m2Ha4BIjRVn3
axJ4VLArtTdjOzgj1TZz+4ABuColwcbVyWjLrSyKrJg0uQMcEud/Lf6CMfhi
Dmc1lr0b/CRRwic/3QMOfI/LcJWZQv6nl09l/51oDo5R9ixFWFiAK6YKZCGP
LcG6wRPdSd7vgzsqTBf0aVbgX/1IPgLKB+DQxUp6+Rxa9Oh5n7jLGux2b34l
vNQG/BEpP2hDYAt9m6t/jw3ytwMrXecNv7G3B2daFfFE+vvAUXHrGs9l9PMa
bcqYYj/4JfueknGDCi7poLrwUhwwT8ruP+F7AKxe1du996AjeMM67Y9aLRr0
zZFKvtJdQNfbnUum3z0IpmRsqIx9nPB6ywLVWhN60ElU7W7jjM+n9uw4U4Qm
qaYzU3TpYOLzIZ31OHQzv3j2mArtrW5JNz/KAGuksvtdDWieRXbwyf0u4GKi
tsm/EC2+4+JbrncI/HMNJ6skpgfP+/mStOh9+tBfs1f7XCmHgm6/wit7F8/n
h+nnf3Lfg+fPsi+pt/yhCXhgfFx5vcgM7lcejTolYuB5kPM/tqWR4Dwwk4Ma
527O4vmQD95Ykbfgfq3ltb1RXYP9YirOUhyCE3B/fB+2qbTTcf1r7UmdJsvg
1tGCmYahUFx/s2m1VvIArg9j8qpLVZ0h3J9R8W3RSCg+z+vvCvK6hrC/hvkk
l4jAPuaVvSPZwzif09fcu9gC69cqfxH5JpoN38/WpEOqu4Vu+LzrYxJhdz/m
MWs8G3/Uw74r4kS//CN4XodmHKc+6cR5pUJeWVsW7tezGUGkDhnnXfc11PCs
cN7q44D2eBHOi4g8O/BgFtfrlbXpK8pL7H+JHCIeTMXflyDLpryOAMxTe3kw
AtyxX5cPPcf5DPahjlfleRvj9awsM67DJPa3IsL6LHnYV/NMGtMZiHnC8vz6
4xLMIyuSgpJpmHfJq/Ez4QL2XzY+/mWWGPtqSgTjcn28/tbO1Z2/jeH8peS5
yPYvcH482/gR1Q/n5+R+TTUoxPnhOyYOD5th3tCaR8GFaZx/7OI0PTEW58df
5WzyQzGPJ/uBJZFi3igxIhKSMS/HnRY3rMR+8vtlaZzTmFen+OuXXScxL8rB
LCX1JuYZuJHp24wwz7w2QGo3g/2WvC3mqxIwjx4tZtfxMC/Qw1mnQ4b7P5kS
Xcm4vWWCiA0j7Or5pmCfOhJ3UNcWfDmAdfpEuCP4lkkjUT3lBH77/5kg3v59
Ioh/AHlUVuQ=
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{119, 118, 117, 73, 85, 11, 54, 12, 13, 14, 55, 15, 
               69, 56, 81, 74, 100, 92}}], 
              PolygonBox[{{50, 124, 122, 104, 114, 84, 96, 65, 77, 41, 66, 42,
                43, 44, 45, 46, 47, 48, 49, 67}}], 
              PolygonBox[{{121, 120, 108, 98, 113, 90, 103, 82, 95, 75, 87, 
               26, 60, 27, 28, 29, 30, 31, 32, 33, 34, 61, 35, 88, 78, 101, 
               93, 111, 106, 116}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{121, 122, 109, 91, 99, 72, 79, 40, 64, 39, 38, 37, 
               63, 36, 76, 62, 83, 71}}], 
              PolygonBox[{{119, 120, 59, 70, 25, 58, 24, 23, 22, 21, 20, 19, 
               18, 17, 57, 16, 97, 86, 115, 105, 110}}], 
              PolygonBox[{{1, 123, 118, 107, 112, 94, 102, 80, 89, 53, 68, 10,
                52, 9, 8, 7, 6, 5, 4, 3, 2, 51}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 52, 10, 68, 53, 89, 80, 
             102, 94, 112, 107, 118, 117, 73, 85, 11, 54, 12, 13, 14, 55, 15, 
             69, 56, 81, 74, 100, 92, 119, 110, 105, 115, 86, 97, 16, 57, 17, 
             18, 19, 20, 21, 22, 23, 24, 58, 25, 70, 59, 120, 108, 98, 113, 
             90, 103, 82, 95, 75, 87, 26, 60, 27, 28, 29, 30, 31, 32, 33, 34, 
             61, 35, 88, 78, 101, 93, 111, 106, 116, 121, 71, 83, 62, 76, 36, 
             63, 37, 38, 39, 64, 40, 79, 72, 99, 91, 109, 122, 104, 114, 84, 
             96, 65, 77, 41, 66, 42, 43, 44, 45, 46, 47, 48, 49, 67, 50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 21.037602627819645`}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3k81V8Txy1lS3ZlLfu+3iuuJWekRcgWQhFSliIKUZKtCPnZUtlJIksi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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3k8VV8XxilJE2WeU+Yhrnm+e11JQpEQGUJRiCShjCFzxgyVTClEXIpM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              "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
             Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
           AxesLabel -> {
             FormBox[
             "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)\"", 
              TraditionalForm], None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
           Identity, Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 35}, {-0.17807983450361647`, 
             0.5678807233437353}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           
           TemplateBox[{
            "\"\[Theta](\\!\\(\\*SubscriptBox[\\(t\\), \\(3\\)]\\))\"", 
             "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \
\\(.\\)]\\)(\\!\\(\\*SubscriptBox[\\(t\\), \\(3\\)]\\))\""}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       "21.037602627819645`"}], "}"}]},
    {
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"Errors: \
\\!\\(\\*RowBox[{\\\"3.2148828406803694`*^-7\\\"}]\\), T: \\!\\(\\*RowBox[{\\\
\"13.06748159292777`\\\"}]\\), \\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\): \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \\\"10\\\"}], \\\"}\\\"}]\\)\"\
\>",
        StringForm[
        "Errors: ``, T: ``, \!\(\*SubscriptBox[\(r\), \(0\)]\): ``", 
         3.2148828406803694`*^-7, 13.06748159292777, {-10}],
        Editable->False], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVlnk8lG8XxpF9JzuJGdvIml019yGyhiR+CskekmTJVlmjkK1SCVlnJiWU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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3k01P/3x4dEiMxYZyzNYIZR2SXr6wplabOlZEslSaFkSYsQSlrsY2be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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV13c81P8fAPCSbHfHHXfmLeukEsnMvUiFVHYlSjIiSTIqDSUaVKLiK9lZ
GVEJyb0rhKQlJAnZm1Qy8nv//OPxfNzdZ7zer/F+M92O2nrwLVu2jLti2bL/
/39zTT36dt9N44dL//9jo/dFryPLffy5QrmyU/+wQ+OTnt32CeN2z6bVzWMT
dn1+1JRymXth6/qI39jWooIt4T4x3JFbH1QmsGUPs20ZEbe48t0nC/qwfzRw
mypTErhSGqtl2rHz1Z0t91QkcVuCRrwbsQ03G/045ZPK3Vf1OKUSmxFkyawP
SecWrbxSkYfNf3/3fmpEJrdu26GKO9hDzZ73PGKzuLkxtilh2E38QV8fpeRw
bZq3eh/CLlkfLsNXkMd9KW1O24Ed735zl3VFPndul13+OmzNnhbvYJ+H3Fct
V8On/7ERa+7bZYVjxVx7ytPad9hSkn3Z1SEl3Hzr8fE87DmTn32SEY+5T2rO
jDthj+6Z46+IesL1/Pe5Zi1257HlSgdiS7mdOvoX+LBfpRHdilLKuKppjLy0
RTYqLZc+75hVzv3TnCnlh53zQSF1Mb+Ce0NwvacedvRyjc5tFZVcmvfx0toF
NnqgqbQ60AdxLysEkxvm2SizMrvy9RjiJmy1zY7ATjZfZSV37AXX31+fwcWO
cdU6/DLkJfdEldqLB3NsFBgDuaSIau7Atije4b9sdES+Ws9dqIar68sLlcb2
zNla9zSqhrsj6p88b5aN9qAdA/tia7ktNfcIItjGk87KBSl1XDMN18LI32yk
e7rr8TJ2PfeT6WgsA1tTyN3MPqueu2p3uHPZLxw/xuGD8/kNXK1zH5O7Z9hI
0PpkmkVFIzelaua77E82GmxtIBz3ec/9w2dhrzbBRlXaa+vTi99zjTp/8N8e
Z6NbN+LCP86+51r5E4yWxtgItjrPrrv0gfuuTNK4cZSNEkrHuiczPnL3f22N
MR9mI/PbpCd+35q5eZ72xxp62UhxKvBostJnbk7h8FUi9ozVF07T4c/cYwWk
VbY/2CiVPz159dxnruc70aV33Ww0e1z78qh0K7c9s+pXQScbZds67vWx/sId
vy2t+LOVjU4XVkglxn/hZlrmpJKwbUXo7+s7v3BVSutzV7Ww0b8XA2acI+3c
a8XPdjo1s5HjupNrBq985fbrOw//956NBEhJyz1ffeO+iLnhlF7HRo/6Jz9p
ynVzlXbxVNpK2YhSrPfN16ibmx984n3FE7xeoWH9OS7d3No9YzZ3H7PRBhLp
LyO1m/vQR6TDoYSNKvTXKkoo93D3PJUQLy5gIxR95NDUmh9c4QX7nqUMNmrU
Gl4oNu3jftEq3LN0nY1WL64TGD/Yx02u/j6XdI2Nrr8+SVSP6OP+knl7XC+a
jXY6C7PSX/dx9xC/jh66wkYfI9S2xlr1c/8qVc8XhbNRW5vnzQDHAW7cfEN0
Swgb9Z79oaztM8TVd3wQGrGPja412FvWXR3icv998ep3xs8rXevn8mCIezBL
z2TzXja6XJDz9NLoEHfln4hnC7vYaFXHEYsOv2Fu8X+uTbY2bBSgP+sbcXyE
m9srdeTuJjZa+in2uPX0GFf+Ztj1ZBVcH9yzbb73xrg9RkWM50q4v0RNLCyv
GuPWDoqnfmGxUTrr42aNpTHuIOz1FKOz0Rab+Naw8+Pc29M6EnuouJ4KmfOc
yAluzN6R79cF8fOul2NWvZ7kCpg5HvDtZ6G2cwtrfb5Mcg3cjpBle1mI9eab
sfTIJDfebMi+ppuFyg6kOvsRprhvHIiRlG8s1HtdOUHRYYqrkEdJu/2JhQyG
1hLP9UxxD8nyV+Bfo/57ZovcxWnubZngkEPxLGQs6PflhdYvrnVsFiPdmIWq
GU7/uJt+cW187Zv7DFnIwmALu8ruFzemYsFLVZ+F7I8oHqkI/MVteGS0NlOb
hQ5/alr2qPQXV0Xm1MaLaiyUkLJWLdPgNzeyaHh3pwQL/dSdCo40/cPtFsmI
muthopxDgZRttn+5Iqf9uz6eZaJc1cyT2g2L3MDwDakxlxmoRZAvPUV6OXAi
s+mZ44po/aso80OsFUDilv+7QVdAHUanOOarVoB42yWlbTQFFFF6SERt/Qr4
/Pf4BlEJBdSSu7lxYPMKqG3NVEzkU0AnY5Z2enmvAM3FQ8t+9smjKpfjuzwf
rgCl8VPCNwvkkfmsk6e7MT9cOFSz7izII5fV6hddnVYCnTfTLh8kh5QIiv65
bivhxoPn8SePyqHhcQnnaZ+VINpXldzuLYeCH/7Vvhi6EpS4PlG5++TQde36
H9lJK6Hzhvv3U+ZyqEr/0KaJzpVwNGPg2Ii8HGJsyeI7e1AABOJUTfjrZVG/
SuJ47WEB+M6YMxt+JYvyBa+3EwMFoHqeP665Shbp1QeVpF0UgKKEV+Klj2WR
jdVmt5r7AiB2tPdMfqosumDb+0JsUAB6rz029zopi37sY52/6ysIoreuX6as
kUULKV2PKgIF4RbE1SZyZBGlO7n/y2lBSA8TVFJWlkVmB+WsaNcEYcsz441b
5GVRpheFertAEEplBwfLRWSRu79AwfVxQdC6oKLsNSiD+s8Pt533F4LEnzbr
vmTJoH8vc0TTTgjBNZKFy490GSTN72WMwoSA70VRzlSyDNoS+SPjX4wQhHS8
uScbL4Oyr3b4hRYLwaVF4+XJl2TQoTg8EaeFYPMgqcDHWwYNZ5ZoHgoUBi3X
gwlymjLouV4NU++MMEjWx4/s05BBMY2tkkKRwhCCtslkq8kg3ZmFmex4YWhy
0uLfwpRBFzdtLR+oEIanG+eoVZIySLHnq4nXchHwrQzUjf9NQ3b0lXae10XA
+x7FcewFDak8opptiBeB7haDv2+qaGhui7qOQKoIdCZ3BRc9o6FUv53UrGIR
8GzPWx7xhIbGn//3ta9ZBB4u6Tv45NLQZec17h5yosBZsWlGIZaGKv/bFeSe
IwpFY0sSHC8aKrh19Ni9h6JQyL9HpsmdhpJvXDrSUiYKzaonnULcaOhcxFMP
83pRuBVLuNriQkOmx6iOGsOi0Pf3WvJrexqqM2/dMLNKDN4QvycFbqKh8k0T
WqvXi4HuUA64mNBQnrHgWk8jMahr0le05NJQ1Hpd1TYrMThQ9TBS05CGdjDi
qZVHxMBt7U8xTW0aav7jOBteJAa5uxvG/7JpqGbab6byqRiEzfCvVWHRUOlY
5OQvnhicTRLIdWTQUPyP0kGv92IwTtpvWS1PQ07vpL9smxKD1Ch3049SNNSV
1VJO1haHrXUvBMuFaOhD2vgTK0NxiFI50qsmSEMvkwRKIjaJw68Y3N9X0lBG
7Ia8P3bisPGqzOebfDTkefZO4tdAcUgh9BgXLlDRiINjaEapOGTvqxkonqKi
Oxkvda7xxMFm79ksi0kqMp1aMxlcJw67JM2d+8epKDFa0MOyXRxOFIkXrBml
IstXZTumFsVBJOvAj7l+KvpNUhb+KkCA20GpThV9VJS+7+araiIBTi9N1J3t
paK5v956CUwC7DN9cVW6h4ryNOVY3M0ECLyokXH+GxU5nr3UobaDAF0qUx8P
dVARX+PPO5K7CJATXvvX/isVOXk1ivYfIoCVb4aG0RcqEk4+8ys6moDXT1l1
y2cqejwyVBR8mwBaR/2JDs1U5Krv6OOaTID25Dfjhz5RUVnzmu/aDwkAqx/H
pnygokOiXXXtnwjgIrDjqHkTFVH2WIVXdxDg6g5F0rm3VISyyjYW9hGAYrOU
XdFIRTTTmyXn/xDAMOJnJbyhouobi76HlxHhS6mAQVQDFfl/81Z1ECbCp3T1
wvZ6Knp9wjRJTY4IX3MzQy/XUVFAbaGjpBIRhqvnmvtfU5EiRU5iQYMI9okH
lC2xg4t+RrwzJsLGwAMP6LVUpNKfeTTYjQiuvRwrgWoq+qgtoe56mAjWH1fu
i35FRWfPn+m1CCTC3VPTnlTsFnnHPQqRRNg8t+hi9JKKLvi8JAveIML9D/JW
LS+oaE3ZmqbJeCIcOGi1Lgg70k5wU3UuEUaffOt6gahIK+34YkEJESqDuQ+O
YneOf38a/4wIg1PFvizsq0ZWAeeriXBMVUe5nUdFG66WaRx+SwQHan3zHeye
VqUB+xYi3H5xJHQ39nXlm2nG34mgpcKWoWMbHF/cqzZIBPXNQwXDVVTUh7yl
JaeIcE4R6T/D7vFLpX78S4TIT0onbmL7Xz8sZrGcBHs7rp7zxT7aJyCeu5IE
S3rTO62w/YzSxYVFSHBsyGlIE/tI3EaCN4EEJWPV22SxfYfbCPWSJECbNUOE
sA+bBBI5VBIkTyUdnn9ORT4JRNIVORJYTIlwfmJ7T+SRhugkqDY7VTSBfWjL
FgkLJRKIjQ7/m8T2utctkatGAvaAM/UPtufMaUnh1SQQ2vB+djm+vsc2Gtl7
HQkq28wyJLDd0x+R63VIYPyuQloF++DfHRSOAQmuy2jZcbHdrIcpV4xJUPA0
b7cL9oHsCKkhUxIk5iqphmG7/mNIW2wlgeNESlU29n6HSuncbSTouixPb8be
l7+LKmxNAv3gRPOVOL4uK35Sve1JsP+pjKEhtrPTdVr9bhI4WCX+DsJ2EqqR
uXKABHnHUur+Yu/Z7yo75EECUT6l76Z4fXeXzsta+JDAoD+3Kgbb0V1LXvg4
CfjyytsMcL44PHsr7x1CgqQrm8jx2PaS3gr1oSRY+bxJehbbFqUoXrlIAhP6
0Ik6nH82VEP60GUSUHacaNXF+Wnt10K3uEaC0vdCSw+wd8iLM4XvkMDjw+rc
dJzf24/nML0TSXB858tVyjVUZNWwiVWfTIIdzN0h+diWJ06xr2Tj9UaXvOtx
fVi8k1IaekCCp9eYpP24fsxVipUsHpKgsbDy3F/sLc0DysLlJHAb/V1uhOvR
VNNB7UoDfj+H0MQFXL8mlybVhppIMIPoV8pwfUNnFMfiEwlOh9XASVz/xtEv
1YU7SDA7RxEVfofzd3Dt6itj+P2/vRJ1+0hF61JFtK6QJCBhz4Hnf3E/qspT
K7tHkYByqbOmk+34+Z9sMS6hSUC+M2lqGPevQw0XLL8yJEAk6nbDKO53yTNz
bqvXSUCGN+soC/dDMYuRuA82ErBlzZazDiO439oJy/Y7SMD1+GeJ13G/Vdun
mjq3RwKyo7K63oxR0abjB/PZbhJgS/k2aIv79al7X6uDAiQgPLtxOPYXFQ1M
vfklEycBuz8/edy+jIYCF4ZC18RLQM1I+CFHPA/4BIX4Nt2VAP5rrze3rKAh
RXkzgm+GBMwfLTrdI0BD9lsqVaoe4ffZPPdVQxzPl8T8XW7NEvBMw8n1iiwN
3dt0rTxPShIC/IQc9+nh+RzyOZkqKwkSUcf4zxrg+z1QuHhRURKeRoa+TTCi
IUty4Y59qpIgJRdQxAMamu1p+iGhLwmssqGSj+Y0ZHuBRDjpLAmhr/jKxHfT
0MbS3T/7XCXh4vuTpO97aEhtOLXN1kMSblXeDH+wl4aWbNZlaPhJwut1meU6
+2kon2mr13VOEs7G2HkQPWlI4EWc29YMSeDQOypaA2hoaubr1sfZknBP/sBz
p0Aa6lBTWs3MlwTpv5HtbUE09Cjm8Z+5x5JA3/nEvfYEDbm6fo4urMXXO5pU
5nmWhrbdUgiQeyMJqh5qMS/P0dCGOo9dl99JQou+wwWZ8zQkrvmb6dYmCRZh
N0vLwmmoYkn6qdSwJJw5f2tf5WUauq+9P+nCuCTsPaoqOnWFhmK8ss9PTEsC
12jvR0YUDXm907Wqn5cE+eP3Hx67RkOUlN3dp8XJoOJQnd92k4b8jBNFezXJ
EDK8KuPZfzQ0qOwRvFKHDCP1qnWxiTTkJq7ZraJPBqf+Dbked2nIsaOm1NuE
DEot11P+JdGQ8ampAxM2ZPC/qeyymELD55nKRpIjGR7vfuZWkkpDWhaXdLWc
yDDt7K50MA3v12gK4kFuZHCWn/z6NJ2GCKXmZXMBZBgIHpdbcx+v9z0yWz6E
DHPKinwvsPkiOq9tDCWDkOSBzJ1ZNPTbLvBgWDgZJNIYCq7ZNORvyG1Ku0QG
cbN7P7uxh1ki+q+iyMCntDpyfw4NdU6lEARukeFrYuT37Xi/t/uLz0nVBDJU
rbPOqsL+iHR6zZPIkLRyNWdVHg3V3nhTHpVJBjN3xsE/2BByR6kghwzEiQ2y
ux7g+O87cKMpnwyfS12vlWAXrv7jLvGEDNsXx7Kd83E+Sb18p1VOhmWnbXY+
wE5fiDawf06GAt26kl/Y8r277ge9IIO9pu1HwwIauvOGRYqvIcMvj4mCM9ik
R2OnyurJENOWsvkZ9tXEsr4vb8mgfPngfzPY/BfCrec/4PgGGuRyCmnorPeO
Z/ItZNiYrBTkhD1rLaNi3E4GHj9rMRI7QK83Zn8nGYxytEyKsEfpRfNhPWR4
dNnR5BO2p+Apz/R+MrCzri1OY3eNm314NUyG68vagghFeL/YQjTqG8frF6+T
p4zd/Lw9S+AnGWx8sxL1sHfcvy+h9ocMuWfUt27Frov2P20xT4aFNy+KbLBN
Aw0HfJbIYL7Lt3kXduVeAdvoFRS4QVd/sgd7w6YPlQWCFHinNG/z/88fqiep
vhOlgLDX9zxrbHVJr9hJIgWM+1t4m7Ez/65blKBQwDe9O2YDtmL3gpc2jQK3
7i4psLET6l5/tJenQOkHTS9RbMmHsRuDGRT4aBbkO4HfLzreJSdeiQKDM42r
32ELnFMjl6tRYLZb90EedpjnzzPtGhTgEyvtPY89t71qcF6TAgLHt7bbYwfq
XLFT0KEAP3U0io09Lm9fZaxPgYU/GX/H8PrUrra4XLaRAjmG8fJF2PeMjW21
TCkwE3Bq42HswJ3a8vlbKNB5b7szC9vKVa1feRsFDlWSTjbj/FA6pvAwZScF
YppexZ3Hnj8veUrGngK7mz3zOdh5GQvi4i4UqK043eqD8+/C46nWyAMUOHx3
YmgF9p6a/rRlnhR4eNR2Lh7nr9DAe50ZPwpI/xygFON891K/7/I1jAJ7PGzX
ZeN6MTZMVHWIoMCfHjNtGra01Y2ppisU0LFX1b6I6632yMmIl7EUuC5RqbEd
16NS8faC3EwKPPmjJJiB63fhhWkIO5cC2yXjZ0dwfX/6qGtyr4ACFxl/B9Zi
X5hhfo4pxetLvYZycH/o0v29EFJHga/HZnbvw/2jzHykdqoRryenX/8c7i83
9nTFHP5AgaTm17S7uP8YhzYo7W+nQPvKve9fJeB4ViVbbRmlwJtPSOXLLRzP
d3HSaJICDmpafz7E4Xh2Xe7S/0WBs/5xNTX4PLew/Hjg6n8UKPyq7Jwcg/N5
89YkCkkKLipc9SdH4/7kaOR5nSIFgsRQzd6rNCTstU5TSEYK1Gf2jhfhflp2
Wa56nikFVv+NHdS7hOPTODHSo42/v9N6g/gF/L62CYbFu6TA7hD5RG0wro+4
aTVpZykgW/gp7MD9v7nZSjrUVQoKeubH3x+noRbH5VNm3lJwGIqk6/xpqM3J
J6vtlBTQsoJPnPbB88PNSGJZshRoyF6OWHTGzrjzzz1dCs5fJozr4vn0rXdy
pD5LCgqLXl84gudXp+f92rgiKbil9lGzwYGGun0Ip1VfSEFM9dYUix001B/Q
1b+jVwo23X9S42qM/cig+dEgvn6a19R2PD8HZm69oI1JwZiDlcUGPF8Hgy2S
en5JwfxQwZlZHRoaOVViEywoDVsqP8yarqahyQsXK++pS0OCcJLeJJ7Xf2PV
Ykf9pUF9q2Hng2kqunxp5UqBIGn48HBtiQbeP9BO94TQT0pDT0iSbS7eX2zw
SHKxPS8NZorfZ28PUlGgLolTdlMaBBqFvhp1UtH41z+88BJpiHww9gvh880P
pddjsjPS4H9qMSI9EZ93ZDJd189Kw6Gbi4NJ8fg8Rzj/afuCNLxZGUyLu0VF
jD8G5WH8VPgg8L4j4Drez9YXXuynUKHdW21+6TwVtR25I1eiQ4XBRz7XrQ9R
0dtSDwuLECqM79IhvllHRRXNvnLPQqkg80h8z/RqKsqaPj6mEUaFgwZ3Syjq
VBS25sJN0hUq7Hz7+ZYli4rWZyV/aU2kQix/vVSoJBUl3W719qyiwvOybOGJ
KWnkE2hxNXwlDff/LeWsAmkkqLX6zfM4GozeENQrp0ijCyuesnrjaTBpu7lr
jiiN/jXDKZEkGiSGuhvoiUqj3yH2nF2ZNOhZ3MKftVwa9T4PvTT5mAaba5PG
t49LoRcWDZvYLTTY4Rml8K5WCoUe8MLbAhm4MhjYeydQCk3EpBXY3ZOBg2uO
0IxeURB17oB3SZosbPb0M9i2mYxklUM3yWfJwu/shWIal4zkrW8pRObJwl0z
TaERPTJiZNV+2PNIFnjXL1kna5CRmu0qg+U1suDj+duaSyEjg7wZEetBWbBh
fyYd7pVE+5wu5Y+tkQPvT3eivS9LIteI1Mhd2nJw5vj7to8XJJHbw3LXF7py
cNGvaIXJGUnkJTBKuQ1y4BPk8mtVgCTyL7E+Y2QrB3drT5obOUuiCyKyO6KC
5OBm8KOCLesk0f2K/Am1Sjl4LbYqkO+7BNrwn/nOrUgOLsXUJzi3S6DakN5C
j2o5oEyIz1d8lkCD6+X90hvlINbo8omLjRJIoyhqVO6bHLBlNu2yrJBAjzN8
hgj/5CCx7UNG2h0J9Cpa7ccMVx46/e1OnrWVQPaHq03JZvKgsaPA1nWHBOq1
cE1fZy4PWwUKvLdYSiABwYQDftby0C2QbE03lUCW5wW7BlzlIc9iCx+/lgT6
GNTf0X5eHm5+LppJkJRA3fsyW9AreXgsMCA11UJC7z19buvWycMcobBd/BMJ
Vflp2hc2ysPZqqeJa9+RUNLZyg93P8uDCTlO7MJrEnJMbm4MHsC/j/N+6lZG
Qg3f+F9piCqA5eRtDvkuCZU4exQl2CrAetroOU13Ekp1X+VH3KUAm4WECkZd
SeiG75RG5F4FiEvx/FzgQkK+p8/kHXdXgNFXI1TuLhJSSbp9f0ewAlz5IeV+
z5KEEr/W3OVPVIDjZ4doFlokFO6kctm/WwFWsq/POK/En8fa+HzsUwCn/Q2t
1Xz4/g2nrdYPK8CmjSqX1y0joR6DT6TZaQXIfHYyVes3EYFc2H/n+BXh7cE3
82Y9RLTw9UvedVVFqN62LXlDJRFRKCuvTa5ShLnfT4VSnxLRKivNo7aairCn
76A4+REROVVGakvrK0Js1Mk+qTwiKkvSrrxnqQhji3ffX08gokCXa2/zjyiC
xannsdtDiCj6dlkRIUARxHYrplkfJ6KMtz9u+gcrwuyJKguXo0T0caOB4/pz
imB5sdI7zouINBUHOp/FKEIrKuoN2E1EY50w2fBIEeI/BNT+MyQifqrvR40y
RRjofn3irh4Rye+Mf3y9UhFcdZxrTHSIyIo3dsK2RhEa7puufrCGiPJSEpe3
tyjC1XwBvSkmEXm6zkgO/VWEYpvD+pYiRCRmlX5qaVERPjms3vJQkIhKdK17
pPjocIt4pUBxJREtEfKLTUXo8DtDPJqyjIgSnh+0TpKlw3rrbZfdfxOQca5E
WYkiHWyXf/UWnyGg3ls8ej2LDqRD/FlVUwS0zldu4pc6HQ47Kq0xGCOgBtlP
13Ya0iGxNOHM7V4C8hc4/8uDS4cnlN/a53sISHp6jcvpTXTwVxszC+oioIP1
VzVyt9HhlX9OcHAHAS2EmL7hc6ZD70U7mW/NBLT2c7FQ6Wk6SD4L3Wv4moBa
0H7/xjA6KB8PfJZfQ0Cn88Xbei7S4UuXQLBKNQHVhXtnE6/RQfHb7JzWCwJy
02Ju8b5HB/YeCbOHzwhISPFdwbk0OmhXtZ5wryCgQuEzUnfu0+FHm64Qs5yA
5rvael8W0IG5tmbDo1ICunUjJly+ig60/ZRPhiUEZBBqPKL1kg5Kx3I6tIoJ
qMtz1Nailg4f9FpA6yEBrTY2ZwU30UFw6B/NspCAmjm/r0R/pEPsh7/RbgUE
dEoqcyq9hQ7Pj17fG55PQLWjS+hdJx0mGy8KdeYRkG9bgVp/Dx3+RvX3U7El
q/fGLPTTIX1ZD90pl4D23326nzNBh48iWWl/sglI4JLHa+5POuxJ9Ru2xc4P
IK91/EOHsJH310qzCGjW4ui/C0t0yE93671zn4DOFmX0zC5nwCXGux4h7GUV
xC2a/Ayor9zx+GImAV2oDs31EmDAsZDu3SLY/O8GxFKEGBBmfen9fxkEFPnF
zr9FhAG/t4KcNrZQL++TuDgDPrqI6bekE9DV8VW6m4kMkIod4YRji/2NTzwt
wYCq3m9j+tjXV/D/e0RmQJPDj4tzaQREIvgfGJFigFnf/Hg1diyto5pFYwAz
TlXjP2wK21zNSZYBHvs9jUKw76x+HHVTngFEyzL6fmyaHmOiTpEBdDuFFmvs
RNNo22VMBsSfur3fCltu++wTXTYDghCj0gY7aZe7zFFlBpQr8UZcsRXd3p/O
UmWAe7b/+EnsVF+jrm8c/H1zneokbFZIziYpDQaMC4ofqcfOPE/JtlrDgMa+
P4NL2CrRYSIXNRkg2fNLF/D75dwZPfJMiwHPFwScrmKrp+3+ML2eAe91Vu3s
xM5/UL1eXZcBFtfcqEY4fmtKNRMO6DNAbUVBSQb2Q5Q0n2DIgKPxIkwpHH+t
N0L7329kgJxlqFsM9uPPgS8FgQFr5ZaCpfD6bejqUuaaMiBH5M6+TGyDX2Wj
BVvw/cwWs77j9a9cUrLuM2fAmRtvBaNxfhiL3Hwkv40BsbMPDU1zCMiU7n0q
aid+P+Vi+UacX9Wcz99e2jBgw/Db+hScf1vWm5jM2TGgt3HR4swDArKwkBHy
3s2AwLE7rxxwPjfYRRxOdWKA46plz61xvlvtm2pqdWZAyqXTVxyKCMj6eP3t
LQdwfO8W3j2N62X3vZNsJR8cn7WzmYDrqz27L3KvLwOaXec2XH1KQM4lNsOx
fgyweUhM+lZGQK6vOcXLj+P8yzv+PQ3X76GpL8bfQxnwQJS5LRXX9/D85nTp
swz4s7YySO8Vrh+BkpU7whiQG+BzvB33A3+5q42VFxkAdssGDesIKGSzgVPi
NQYc2ClRGviOgFCu17L8Gzj/pt42GHwgIBHC7aznN/Hv2epHhT/hfGmZmO66
zQCGzQtP1EJAL73uR6kmM0Dh2GGJ2504v6+Snj8uZEBt6yP7LxME5DC+8WDt
Q3w9fd+DatMElGx7WLithAF8l6uXh+H+uU6u1mG+lAG+/A5j5n8JyDE/dNyE
x4DNcr/PmawgotSmfvq7dwyI+LQx7i2NiIa0KLVdHxhwC/25e1+OiLTiTXyn
PzEg9Y/N+khFIqrZn1Qm1caAAacB8gElIhqetLFx7sL1m3Dn+hlNItIhP78w
NMmAn8vFAmwsiahhV1zfCkkmuLBCp9wvEpGa/XEFUQoTcqNDFAwvE1GktZ2D
pDQTJF7eDZeJJiITC3INQ5YJkVe8Dcfj8Dw0iMvcyGLC9MZ7QwcziChLIe5g
iBYTYl7k7atGeH7JHr97dj0TLvEneW2rJiI3abtPERuY8FTSc0PDayJSIJI3
3TJgwquYi8pFTUR0a1kcq9iUCdHkEQvpDiIK/xHbPWzLhH7tfQ/2/CKiru8B
MtP2TAhQ75BwmSUi4w5bm7+OTNAf1TLePU9Ec82SLwT3MqHikM5MIt4PBNTG
piodZMIOiQsmWwVIyDU3dv++40xoOep3qJ2E9z/3A+I9gpgwVH3cUlaShOTT
bd/5hjAh4ZwH0ZFMQq2JktzQUCY0KhNMX0iR0I7oWMWEcCZc0wm09JQlIaOj
sd8+xOHncYsbGGaRkHmY4OaVd5iQrV/j+Y9NQg43T+frJTBBuV2AIK5MQn6P
PENTkpjwJ7i8WU4V75f+GMgcuc+EX/QO0yV1EsoXehiWms0EL5NovtFVJFQu
ozz4KZcJTA2r4U8aJPTRkPjUoJAJvi7z626vIaGVYT/shZ4yYd9aavq3dSQk
eXN3pWE5E8Tvbk7PwPsnxfS37KPPmMD/PrzBXZuE9KqfTn/mMaH+9tq4tvUk
ZPZZw0n4JRPiVe5pR+mQkE1/2gujaibkh8ku6G0gIR+h6JiMOiYUxJitjNQl
oWCZ5bMtDUz4b8vUZmU9vD9TD94v8pYJb2sKCnnYSVaua459YIIYw3G2T5+E
mmLWNxq3M+HHJnffWUMSak/L1Q7owJ+b3RjzNyKhgRLFu/c7mXBGvOFOL/ay
z0I+Yj+YoLPgd+D5RhIS7z/zgdvHhNPMLxdYxiQk+2da7/gAE0RJdo0XsLVl
vgm2jzBhmUVw63ouCYG67VHxcSZ4xNH/i8S2MnzdApNMIGe3XfiEvcfKyDhw
mglCF9NuyQEJeboU38+eYYKZ+qmmfdgBfiriX38zoe4/N8172OfO3Q0k/GXC
rY9OFS3Y0TGkDpN5JuQ0u/mKmpBQQlrEpqBFJvClntpiiJ1ZMpeXs8SE++vT
zT2xi18dlexYzoIbsV8CorGrmntPEvlZ8KKcUVOA3dC3p9tUgAUGeSHcBuyW
303mwUIsmD/Y2d2N/UPQ7GGuCAv4B+zzZ7AnaeXUb2IssNf+msxnSkILnDXn
SEQWjJgfKxfFFjLM6N8kwYI3qtQFIraUFW1HCJkF0+8aPf9vlsu1J3lSLHA1
if0rjL3Gj0+hk8oC6dNej5fw9Q3PhVyUkGUBJcwqfhLbPGZ0xEyeBXu2m6R3
YNunHbA7ociC/h+bP7/CPlDSUvGAwYJnm5w0s7DXK4h7lLNYoHU/nROJLXR5
E/G1Egu2BVwaOYDdMX2yvFmFBSsfCAXrYz90eXiwR42F+69KvRj2xbp+8Ul1
Fuzb39X7Fcd7t7ZC2aIGCxbaN9RnYS8Tvioms44FilLlI2uxm4+jUhVtFqR/
6uWM4/XN6fztul6HBbWL+Zo52NaPDz7Zqc+CX7ckE4jYSvTE/S6GLPi3/OFs
Jc6f2SvvhQ9vZEFu+xDTEzt1/8Z9kSYs+NGk1fQA519gw3GhW5tYEDBsYmOO
ba6TV5K2mQUZx8aSunC+TopQBZ9bsGD4pcx1fuzqoO3FDdtYsBSdqB2D8z2h
K3xv23YWlL58mkbFhtLJop82LBA+9rpVxoCEKExVp+X2LMgcKk+5hetlMMqF
n+jIgu635pqi2DEHGnarO7EAvhg+GMH11yWWufyAGwti5oOFTuF6fRzS/sDP
nQV6H6ykPuF6vtxDcjztyYLzkrxhVWzNsjN58T4smG09MVGN+0HYwV12TQEs
OOFn4tq4Fq9n07XFr4Es0EibK16BraZfnT0UzIILXOvGDbi/vCesW+APZYEE
771TDO4/9AqR+4bhLHhZr/KdxCGhaSWTnRYRLAjf8ypIRY2Eam+E/HW8xIJe
+4VmXdzf/Dx6twdEsSD6+qax7bj/VZGqfufEscBPXDViK5OE9nkdM5fOZMEp
fVNbfxoJdfcbsayzWLDd8Wa3GpWE3D2FFq7ksED/hufpDtx/vT1SihbzWeDk
kNG8HvfnwINvpfuesKBay5OYJ05CV/dz+h69ZsE6LYnCrOW4f3yfqRqrx/cn
vfxFxPMgZh9KUG1kAZ/09M3BBSK67bLL6u57FhzKmWY74/Ni6t6IRxe+4Pc/
GuncOEhEpbu6z9uMsGAwcpb+4Q0R6bfm740aY0FJrQJjZR0RVTqe0KmZYEG+
8U7dtXi+vXAgDunNsGBDa0ueBz5fNtpttGYssuB23omsvflE1LPzP8UJAhuu
tAtMHr5KROLmNs+itdiwef/2RgUuEe1mdramrmdDthTd2ceAiNLnfGYeb2BD
Z8CPrYX4vLeh4OLqbwZsqGOaactrENE+ybKU1ZvYEGnjsScG7w8KOxQvNtmx
oXBW5cf/9x/Wx0atSEFsSPfIHp2Kx/thy5PeSiFsOPH77RwnFp/f2AKReifZ
wFwz4L4nmoBOtNB5rmfYMHFzyio5jIDSDO3WFUew4dgqT190iICmV1ZI2d5h
g1JW06CHLj4PJV7qjHvKhvUVSa06TeJoWvR19L1yNvyaqhkIfS2ObM4IGGY/
Y4MgepFbjsQRwTUivoLHBg36uk3yj8TRFeVw6+7XbPAZGn9zJl4cnX149uWa
NjbwCvrXl+wTR161QVn1s2xo/FXr3tUvhmp1n9h/mmOD7Kxpkfx3MaSUO8P3
bQF/P+bmA+tWMdQTdXz/5DIlWBaRVZ7yWgw52xyjUYWVIOxk0ar2bDFk3eF7
1V1GCXbHbvRCnmLIYPqg35K+EuwLtzSy7RRF5if0rHSMlGA6Y+v5mmZR5PBP
TP2wsRIMj+QtW/tGFPmLlPa1mCrBzFRGYe9TUXSfJeRSuE0JLrbsf90eI4pI
dvnbXFyU4NzypZEpEEX9j2bUnoUpwc/O9uWN/4mguKCIH8GvlaDxqZDr2jXC
6JCDHP+leiWYn/m+/R9LGBnpFCvFv1ECP4e8smqqMOqf6fB4+k4J+MJoK/WW
CyODwPWDf1qVgHja6WTZJyHUFfBj9MSgEtQTg94xQoSQhr/J71PCyhB7n1/r
xlNBVO2zKHRumzIEXL32vkdRAGVHVZDj2pWB78Zd0W3r+dCDYoUoUS8VEOQ7
te15xzwv0qK1hDKsAvmdYkHRVTO8W2aigttHVcBSwX9wIW2Gl87l7o0YV4E9
HnmS5yNmeDyd7BW/p1WgUiIzqtpqhjfLDLFvnVeB9q8PiHodP3nec9K//xNX
BUsdcdcP/6Z5Vg8c9enrVOHlgjTrre0UjyzewuOcUAWbymuOHw+P8gYPvHE0
OqUK/Kr0gYfcUV5VKRrbcVoVDrTt/VxMHuX5uD6QCwxTBVtia4Ns5QgPPQoL
qbqsCtDULHOFMMLzdVq11u4/Vci6Mba1tXyIV5sdlny6QhU8GLd69dUHeEkL
QTo3KlXhsdt1dXe+Ad4xm8ONaVWq0Dyi3fSwvZ8nP+8wV/tSFfQ/hq0pjurn
BexY5SjxRhX6Jph2Oyb6ePRfn8WzvqpCkd95jbnKXt4J01Vn3i2owtFTT+i0
gB6e29pP91v/qUKp5Vwa7OzhWcmHNn1fpgZ6qYdWXdXo4TF+N9An+dVgtP2F
XdhAN68u1+clSVwNZG54zs3u6+bJSOQJ2iqowbHpEyly9l28iu9qsc0b1aDF
MvymVWEHL7PxfUUHVw1YBn6u3/07eNfLT/zoNVGDXu38jY+1O3hucXXrf21W
g/otTLZSxVee6NZDrVI71GBxaOI/+YZ2nnNhtvyufWqQpkLX9f/dxls8rZL9
5awanDhRszY97DPvztmDS+Ln1cAq1+72ry2feWvCUneZhqtBwzXNyjvin3mu
4bJCDy6pwaZjLdtf3m3mVV8heJ+OUYN/6R/Dqp594kXd+a1OT1eDnOJo5W0i
H3kyD2sL3Wvw8/8mNPu8essrKV4h+N9rNUg3aps+f/Atz/IR7H9brwaVQ8a3
1vO/5Z0urSBuaFKD+RO9+3y3NvK6Kgv9BVvVQOhIDFnlcwMvu/6OVt6gGlx8
cHjuhXgdT+eHZ+mEKAeczq+tuvvzJe+OsYfNP3EOvPoYfNIw/yXv938HR8VI
HKBfGkhy83jJK7V2ZalTOGBO2yy/9csL3oaqPdfd5Tng3DG5cOg14un9Z+X5
RYMDSS1S0YxTz3kJM5bLB9dwoOLTe8HtC5W82Z0WSb81OXDiTqfd5XOVvHKB
LR/JOhxI9J12XnXlGc8gkGu8YyMH0p3ntdi55TyjnVrSr7ZzoNEydvyLXCkv
KU+z+MNODkymnTz6s/AJb2HlWqsuGw6UVj1Ccpue8J5Xrrqw6MCBcXNGc4Lf
Y56xuvK47j4O0NLaq8w+lvBgJa02348DRF7O1tcJRbxUV+kDz/w54Ml8b9fc
VchbVklZqA/gwALh3rIl9ULeiwAJrYFgDsRHqRoV1OTzTLtEkpnnOKAptmRw
hJLHM3u2GHTnBgduccp2hVLv8z4RGnf23OSAququhyT/TJ6bWyJnzS0OiPYb
/zV/k8E7L6z7rSaBA2HZg3vTr6Tzqnb5m/1K40C4wX33WeVU3vYHxoommRyA
CMo5S9UUXsc/sdnoLA7I0vylhgWTefP3cx8oPeCAUc3XH3Ntd3l6Mz2S9o85
kMKNEDxYEc97vbV4NKWUA8PuX1+M8O7wHO+eqx0p40Cr2CvniobbvCBT+VPh
zzmwrnfLes5kHK8kxqG7pBbHs4Ths/1UDM+0l/3sXx0HBr6stBWxv8H7oDt9
y/INvp7dWMzKqmu8yc7r5j3vOCC1S9k2pfgqb/XquiKJLxxwuaffs58awasM
u3PF5SsHTIykvVe/CedZNbsfzP3Gga7vUsWRVy7wfEKXU016OLBC7+zFDuUw
3lzTu8noXhzvlrf0EsGzvCus5Ia2fg6csugre9kWysupNzjrP8KB1dv7j6lX
hPB0FYR3V45xwPL7u5vnG4J4tf6t64QmOTAWuqQ9OXGc10cN7EuZ4QCpWXOJ
fMqfF3jYlDfymwMZDA/r2OdHePw80n+6fzkwmD+TtarYh8fyLLB6t8gBR8Gy
AyPSHrzi8lAVuWXqwG4eqZG44sYDcctlXnzqsPjkwRovZVfee1daewm/Oozt
mtBtbd3L2/+4/9E/AXVYOJoiZ1y+izcu+OSapbA6cEq8hFZM2PHO7g33uiOq
DssVzP8pn7TmiRfZmPSIq4Ok1/m57UWWvCQ+htwakjo4DaaLiElt5q1yHJ85
KakOX5/PaETisVyRW9lUQ1EHtXdjL0880eVZLl7NkaCqg3qdrbVLkCbvi/We
Cy4y6iDTrskfKK7MO5Sp6pwrpw6nhuZcDbOovNk/v3R+KajDp5DVdzrH+XmX
tlUTTRjq8P5pro5iYG+VdErsUDRLHZx18zkal24Z/w8Y1eIk
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJxF13k4lN37APAhEkpmCDOWZmjGUCSSSM4tKmvJnoSkSIpUUqRCUmQbS7ay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              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
           DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 13.06748159292777}, {-9.999999999999858, 
             2.0160364229639516`}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Xk0lH0bB3BCRZaxxtiaUeq+EyqeSvrdv2coVORFZZCG7MuQrIkXlaVG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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVzHs81Xccx/GTa3Vih5pk1Nz7fitlsS2XfOlyRC6JDupwLpNSaRMyZbHS
ZWRaHjxcHhiZS04lm5B+HxPK0UUajQ7JcFwKneLQlH33x/vxejz/eRuLjvqE
qLBYLA+6/9tRJjIteoFIWlnMMecOITQr8Tdl1Cref/CePxVC9da3V65TC2U9
9lHtQsjqPW1RS51VoVAtfSyEIN0i9Jj6w/E1lzlSIci/l6+fpY7v6Ja8YIQw
63rYwaMPkaRe+7/iSoRgJI/ym6I+GRM8WHNCCPZSxSNhPyJt5Y3LSg2EEMFz
NK76BxFtUzWJer0Ayi9eaFYdROTTLh/n1aECqAtzqjwyhEjPyC/8PzUEMPSm
IQbkiMz1psSlBgTD0KobietGELHjuc78lB4EI9O5g2mjiBTvajyu84wP6jF7
Vw6MIZJ44feNkWZ8UOYl5Hq9RsTNdK37XdE+UImIUhaMI5JQ+d3cuGQvcF6H
FU5MINI/6nukeC4QprSl6f5vEOFpbxl2dwiEt93TolIFIlZn87Mfng+Aex4X
o/XeIVJTdU7Pvtkfcg+a95ycQoQRB4bYavpDyvokw9ZpRFr6NBO1/HjgmxNY
aDuDSN7iFPTk8h6wqVSqnJ9FZFXRxHjECz8Y/fZj6fR7+r+zR5Vl6AeFzzSu
BM0h8jU7SGCwzxeihmXR1z4g8jzQInRp6W4wyje8ZDCPiHI2JEk55AO9C/CZ
cBYmO9m8glprHyhYskl6ewEmorrOS+z4XeDAVPDMVTGJlXyM5oI3TK6YuROt
homLgbhJxPaGWMOSQwPqmLhx97U/SfUEzfsBh901MZnkemq/1/EAiVHXtqyF
mJhqBv/7stwdkEHDfvXFmNzJtRHnITdg6mME/mxMKo7uUhjWu8IejrXkyhJM
jkWGiW7xudCksdtZSxuTW00HNlj2bAOPYpdr/E8wMQvQ7+NFb4Wr49kiKQeT
vKyhTv4bFzDpa5hYqYuJ88soPfOzzpATO/b48FJMdLJHZYtMCLy6HafsXIbJ
DtslsnNOjrCnuEe5Wg8TO8l8y6lwO0jfVOyUsRwT27N9vibCr6ArMqL7oz4m
6RNWpSyRDdgGsj09DTBp+yG1X5xuDaFDWotqP8OkstRCY8BwHdw07M3RMsJE
hTvvwo60BNbc9dOBKzG5aOR2vFxuDOY/jlXcXYVJq/RQkWvTchDffFe9zBiT
maI6r0LdRZCf2Z1pQM3NDq3xurYQZPH1sZ9TW4aNm8ztWAi+XskOa6mtMi5N
+SZowtZXpvVbqMt+c8zUmFQHC4vd9yKo9R1Kug8+VIHhzIqONurNajsvCziz
jFlCRlUnddv26uAa7gwjOBCXIaMuiJ5fo3tKyXR9uSNgmFosN2m8+3qKkT7t
k81TN5b0KCxaFcxVLc6AlQkmcWkb07vZI8zwu6lGG+qhGxFrkmPljJnseZEd
tYdrUr3jyCCTU1Ycup3aV+E9mt/czyRzncb41CHo75hHKl3MfSvzB2JqsxX7
f7Xu62DU9NiSg9Q/t7e0pN1pZ+IGOsOjqDmpXJuqyftMbWud1wlq16ptZ05e
bWCmbxZsSKDm1VqWJD6oZr7IOq9zjvollqeYnSlhwhPCFcnURQs6grfr+2z+
D2V9S6Q=
              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.560181, 0.691569, 0.194885], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwV0Hk01WkYB3BrpiQSV92xb3V/ilGkzO16U4qso8ItlWxFuqFsSbkoFEbW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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.922526, 0.385626, 0.209179], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwdzHk41HkcB/Ah9zlrPWxjyBE1s+6HJHY/PyUqjzOG9NTjCDnSPjYeRzZn
xrq2RSLJzox15c444/dIzt3sxT405JGMYyLC0Dr2+5s/Ps/neT2fz/utE3Db
I0icRCI5oyH2eE2AXsVbGiYxeeL7zQ4cBoT0GzXI/aWqdpx2HNrtP3EakO39
xJQ923AomUk16CTu/Kmaluc4XFepoI0R3s6Zi2rAgR/HN9lFTlPddF/n4LB7
IcLWeRb1u+Gmq3k4aPKjvbYID/qs8oNwsBnZeO0/h/4Pj+UNy+EQ5f2NDvcd
DWMG7u6EhvfCs5zMgSPvkR1mPIr6e6A7DFpuLSD3rAnLlXtgYb0vtpePTDM8
1RP8AhaONaYbLREu7G1r6Ial7bL3Bcs0TKaKNiS91wWSsVe15leQKUuh4Z5d
IHyaXOb6AVlnnFFb1gniUdFC1irKawh4B5sdQP4Qxl5bQy4wnqty6YAtpZGH
Puvon/XE3KSkHT5NbQdUbyCzrajD620w6JwTo7aJbH3gBjZtUBaqP313C+Wd
P0ooMLmQa5JFHd1G9lL0EMy2gmepL9tyB3mDsVz1dStYtAjFmbvIKaMacSnP
Yfm7g+rtz8iVEY/0R1uA/a8U5/oe6neyLjip3gLRi7yY+n3kOVMa3G4GzXLq
A8ohspKXrHlHE8yI0dMiSXSMacRJOa3cBCwF65EuMeRRrYTCm41g29PkrX+E
jpH3sxKfhDTAx6M7L2IkkC+aWlmp1UM8tSp8XhK51ygjs+oZSA9diXCSRjZP
GWfa1UKd5uT5EhnkbENGw0Y10Ch9wZJyyGTTW7kZVdCDx/r5yCMnZHILLCqB
QTar4yggv7M+cFysgFdSl+0UlZDvnOO13OOAc+XZ+mvKyAKWwMGEDbWrjwNG
yMi5V/N/7vsFdGf71rRUkNXDIiQjy6E0fmUs4ks6pn3macYlrAwEXYnCCVXk
Emrgf+GPgVE5LTyphjxwnv158BE8tK6EInVkBx1y+EohTN6Jmjr4ChmvibOk
5oOlr7yLCwVZZtbRJfEnCFlQlO3UoGPYhbz0RqcsaKbOlCpqIlO59v776UDa
a0j11UKeP73/ajgJ9FNWml4eo2NJ5ZgW5VIMBDZvtqvq0DGSf2L1y9QQKC+e
KqYQfiDr1KofArwkPF6b8J+Fgl8Hg8HTNdvWkLB7vcmP8sFgL9DDz4n8ttUt
/wYYGFwejCJsZtc3zfKHxeKm8T8I68px11K94XhyEXeCMEt3969BBvjdTCzi
ie42tlx5BkyeunhlkbB4RN/dfE8Y+XuWd0h47vfXsmx3qFUkzxvrIqfpjTmm
OcLi5la/BWF7Ty8lBQc4zntTcUbk9Df/5NtDaU1liIPIfL4/2w6yHWHlGmEm
Q2wnzQqGjPV/CxS5XTG9wAIk1OTrQkWmUFQ4ZpA4PxEZTZjcHeRz/wR0jna7
Joh874eoCh3YbmaZJhPWvm98NFMdzEuYX2QQxqh4Sa40RCZHbmQTJiX5OEjF
fPs/TzUT4g==
              "]]}}}, {
          DisplayFunction -> Identity, AspectRatio -> 
           NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True},
            AxesLabel -> {
             FormBox["\"t\"", TraditionalForm], None}, 
           AxesOrigin -> {12.94, 0}, DisplayFunction :> Identity, 
           Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> 300, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{12.936806776998493`, 
            13.06748159292777}, {-0.008537657892310344, 0.130674892643306}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           TemplateBox[{
             RowBox[{
               SubscriptBox["x", "1"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "2"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "3"], "(", "t", ")"}], 
             RowBox[{
               SubscriptBox["x", "4"], "(", "t", ")"}]}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.37345400000000006`, 0.461046, 
                    0.12992333333333334`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJxll3c81t/7xxUpMylFww6JMjLKuMgq2VmRkR2yV/bee6/7dtvuO0UpFXJp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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"\[Theta]\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
           TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[{{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw913c8lt//OHDKDrfZfRtZd3ZDUYR6KaJUSGlYCZWkHU2iJCGRFVJC9soo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           "]]}},
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"r\"", TraditionalForm], 
          FormBox[
          "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{"ScalingFunctions" -> None},
        PlotRange->{All, All},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.05], 
           Scaled[0.05]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxV1QlMk2cYB/APFBiWcrRQWwqFFigF5bCwLTBsURnSsEMqx8JcuSYgcoZz
ETEIAg7qoB8jrhsBtEPOLOCGAxHwGoRTh8FgMjbkGOdAYt0qFnZkPE9s0jS/
tO//eb73ffp93OgU6UldgiBy/3n/+zkkdy77cq5CRPz3WhcvPB40Tk94IN7x
9fn1cXf2NHg2b8bBI2ERLPdkc3v618Eig+TJ20I1uCE+wzxQqgE3Oqo+8xjU
gicMdK/UMHR8/3ev593SgHjeLvAnLs6FkeF64BkZL//rRAPwkqrdPT7DENz9
VVjmpw0U8HJI6JmrHVTwXN8pBu2ZCfhA7R7hRVMzcPUReWeTBW3H4mSRkjLr
Tgf/YRXcI/IyB49LL7/TFmYB1igEipVUBnik46REkr0XbCB0GbpFMsFr5XWt
x6tZ4L0vo06111lCP992tawJutngaZlqou+uFbggnF+SOm0Njo18TlvUcMB/
SVK2zm/bgLPf9Q5Xym3Bg2Hk3C4aF+yTovjlIQkWR7VPdDXb8sCyuLQAhgpN
DQi6WSa0A1cqi6fIG2jvjZjkbS97MJl5YSarH30vQfvGuUAH8LXSLjr5BN3c
Zl1KieNDf0WSx+3mS2g6daLXKccRnHN439mxV2htLv/aZJ4A/OZMbMcaxQns
d1ObWfUFmlGjWCzjOYOb3e1dMhL6YF4FAUZHxZc2wU3sR7LOzW3whTl/dYGV
LqyX9tVwLhaagn9/NqRmkThv+rfJ6KNXcd7ORMV1lzBxHgru51MKbGAexLLw
4pZVV5yH2tF5m7ExPM+CGcX0khTPb7Tcc1j0BP3W5sfGhiTubyMn8cMxW9zP
y2dfcsob0C4uA9+ZTeL+NHF9El883YLrNZIskw+D8Hq8mitOnJ7C/uutyZhs
IdYXhJAH2rRYf2JPh0D0OQHr7yhbwqIfYd7Ir2ldykj8P0Q2KiJk6ZjnvOCX
tHoE+/3Rm1Qd5OH38ev1PN4K1gs1Mk2k+mG9YP9ufs91rNfws+apsS/WqyRI
XtthzFvoPOfra8LHPMMTc8kPMM997ZsSfTXmbawsVvDzMe+QhH7f1hLzGNRb
VLUtrmcMH/xzwA1/X1Js2Jmjj/U09+xTv5/FfLf99MJwZ8yrosQMOsRhnvfk
D6PBxzAvYEXdb8DEvFiWRd1HejB/vUXHjofQGHg/yJKTU/EmkCceHojQqXfE
POa4924VHfMCd09Wummxv1eHxj3dONhfR9m8T74Q+4sYY68uv415OXptpaet
8DzPuwa15lOxP0FwujXFHPurH9n66Yo+9ifoTy2qtMO833LGG70ssb/ndh6O
SYaYN/ueh5zFxDz/9wUvXJmYlzb4Qe6NfZhnqriUVM3B/ky9UjyqzDDPtXVD
R2G1s54gQkV5WbV0GtpfM1DKtQTTAu2crFlc8H7xHaWUzQe//nwmiNfvTwTx
N7/eQjw=
         "], {{
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{50, 124, 122, 106, 116, 65, 77, 43, 66, 44, 45, 46,
                47, 48, 49, 67}}], 
              PolygonBox[{{121, 120, 110, 100, 115, 90, 105, 82, 95, 75, 87, 
               26, 60, 27, 28, 29, 30, 31, 32, 61, 33, 108, 98, 113}}], 
              PolygonBox[{{119, 118, 89, 104, 80, 94, 73, 85, 9, 54, 10, 11, 
               12, 13, 14, 15, 16, 55, 17, 69, 56, 81, 74, 92, 86, 102, 97, 
               112, 107, 117}}]}]}, 
           {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.2], EdgeForm[
            None], GraphicsGroupBox[{
              PolygonBox[{{119, 120, 59, 70, 25, 58, 24, 23, 22, 21, 20, 19, 
               57, 18}}], 
              PolygonBox[{{1, 123, 118, 114, 99, 109, 53, 68, 8, 52, 7, 6, 5, 
               4, 3, 2, 51}}], 
              PolygonBox[{{121, 122, 111, 96, 101, 84, 91, 72, 79, 42, 64, 41,
                40, 39, 38, 37, 36, 35, 63, 34, 76, 62, 83, 71, 93, 78, 103, 
               88}}]}]}, {}, {}}, {{}, {}, 
           {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
            Opacity[1.], 
            LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 52, 8, 68, 53, 109, 99, 114, 
             118, 89, 104, 80, 94, 73, 85, 9, 54, 10, 11, 12, 13, 14, 15, 16, 
             55, 17, 69, 56, 81, 74, 92, 86, 102, 97, 112, 107, 117, 119, 18, 
             57, 19, 20, 21, 22, 23, 24, 58, 25, 70, 59, 120, 110, 100, 115, 
             90, 105, 82, 95, 75, 87, 26, 60, 27, 28, 29, 30, 31, 32, 61, 33, 
             108, 98, 113, 121, 88, 103, 78, 93, 71, 83, 62, 76, 34, 63, 35, 
             36, 37, 38, 39, 40, 41, 64, 42, 79, 72, 91, 84, 101, 96, 111, 
             122, 106, 116, 65, 77, 43, 66, 44, 45, 46, 47, 48, 49, 67, 
             50}]}}}],
        AspectRatio->NCache[
          Rational[2, 3], 0.6666666666666666],
        Axes->{True, True},
        AxesLabel->{
          FormBox["\"t\"", TraditionalForm], 
          FormBox["\"u(t)\"", TraditionalForm]},
        AxesOrigin->{0, 0},
        DisplayFunction->Identity,
        Frame->{{False, False}, {False, False}},
        FrameLabel->{{None, None}, {None, None}},
        FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
        GridLines->{None, None},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        ImageSize->{300, 200},
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
          AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
          True},
        PlotRange->{{0, 13.06748159292777}, {-1., 1.}},
        PlotRangeClipping->True,
        PlotRangePadding->{{
           Scaled[0.02], 
           Scaled[0.02]}, {
           Scaled[0.05], 
           Scaled[0.05]}},
        Ticks->{Automatic, Automatic}], ",", 
       TemplateBox[{GraphicsBox[{{{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwVl3c81f8Xx+1UGvYI2WRz7fU+lMgK2StZoUiSkKw0EEmFkJVCZJOst70a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              "]]}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             LineBox[CompressedData["
1:eJwUV3k41N8XRpJ9i1BoKLI3Y1/nHoUUCqGylCxji2TJLiRUQiqEJCFFso18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              "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
             Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
           AxesLabel -> {
             FormBox[
             "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(2\\)]\\)\"", 
              TraditionalForm], None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
           Identity, Frame -> {{False, False}, {False, False}}, 
           FrameLabel -> {{None, None}, {None, None}}, 
           FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
           GridLines -> {None, None}, GridLinesStyle -> Directive[
             GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
           Method -> {
            "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
             AbsolutePointSize[6], "ScalingFunctions" -> None}, 
           PlotRange -> {{0, 35}, {-0.17852229107779005`, 
             0.5166434843609093}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{
              Scaled[0.02], 
              Scaled[0.02]}, {
              Scaled[0.05], 
              Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
          FormBox[
           
           TemplateBox[{
            "\"\[Theta](\\!\\(\\*SubscriptBox[\\(t\\), \\(3\\)]\\))\"", 
             "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \
\\(.\\)]\\)(\\!\\(\\*SubscriptBox[\\(t\\), \\(3\\)]\\))\""}, "LineLegend", 
            DisplayFunction -> (FormBox[
              StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
               False], TraditionalForm]& ), 
            InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                    "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm], 
          TraditionalForm]},
        "Legended",
        DisplayFunction->(GridBox[{{
            TagBox[
             ItemBox[
              PaneBox[
               TagBox[#, "SkipImageSizeLevel"], 
               Alignment -> {Center, Baseline}, BaselinePosition -> Baseline],
               DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"], 
            ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}},
           AutoDelete -> False, GridBoxItemSize -> Automatic, 
          BaselinePosition -> {1, 1}]& ),
        Editable->True,
        InterpretationFunction->(RowBox[{"Legended", "[", 
           RowBox[{#, ",", 
             RowBox[{"Placed", "[", 
               RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
       "13.06748159292777`"}], "}"}]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{
  3.662449558833088*^9, {3.6624496333508964`*^9, 3.6624496541256*^9}, {
   3.662449708987475*^9, 3.6624497366490884`*^9}, {3.6624497707142296`*^9, 
   3.6624497863262925`*^9}, 3.662450480491398*^9, 3.6627079146943665`*^9, 
   3.6627164474917655`*^9, 3.6627164824065056`*^9, 3.6627168599898033`*^9, 
   3.6627250044678507`*^9, 3.6627266126635094`*^9, 3.662914095438481*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Figure: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "i"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.6627142793249483`*^9, 3.662714288996791*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "u", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"u", "[", "t_", "]"}], ":=", 
       TagBox[GridBox[{
          {"\[Piecewise]", GridBox[{
             {"1", 
              RowBox[{
               RowBox[{"t", "\[LessEqual]", "1"}], "||", 
               RowBox[{
                RowBox[{"9", "/", "2"}], "\[LessEqual]", "t", "<", 
                RowBox[{"63", "/", "10"}]}]}]},
             {
              RowBox[{"-", "1"}], 
              RowBox[{
               RowBox[{"1", "<", "t", "<", 
                RowBox[{"9", "/", "2"}]}], "||", 
               RowBox[{
                RowBox[{"63", "/", "10"}], "<", "t", "<", "8"}]}]},
             {"0", 
              RowBox[{"8", "<", "t"}]}
            },
            AllowedDimensions->{2, Automatic},
            Editable->True,
            
            GridBoxAlignment->{
             "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{1.}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.84]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}},
            Selectable->True]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{1.}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.35]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        "Piecewise",
        DeleteWithContents->True,
        Editable->False,
        SelectWithContents->True,
        Selectable->False]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Plot", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"u", "[", "t", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "\"\<0\>\""}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", 
                 SubscriptBox["t", "1"]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"4.5", ",", 
                 SubscriptBox["t", "2"]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"6.3", ",", 
                 SubscriptBox["t", "3"]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "8", ",", "\"\<\!\(\*SubscriptBox[\(t\), \(4\)]\)=T\>\""}], 
                "}"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1", ",", 
               RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Filling", "\[Rule]", "Axis"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotLegends", "\[Rule]", 
           RowBox[{"{", "\"\<u(t)\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "200"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AspectRatio", "\[Rule]", 
           RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<t\>\"", ",", "\"\<u(t)\>\""}], "}"}]}]}], 
         "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"Join", "[", 
          RowBox[{"MapIndexed", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Arrowheads", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", ".03"}], ",", ".03"}], "}"}], "]"}], ",", 
                 RowBox[{"Arrow", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"First", "@", "#1"}], ",", "0.5"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Last", "@", "#1"}], ",", "0.5"}], "}"}]}], "}"}],
                   "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"StringForm", "[", 
                  RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(``\)]\)\>\"", ",", 
                   RowBox[{"First", "@", "#2"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Total", "[", "#1", "]"}], "/", "2"}], ",", 
                   "0.5"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", 
                   RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], 
              "\[IndentingNewLine]", "}"}], "&"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "4.5"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"4.5", ",", "6.3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"6.3", ",", "8"}], "}"}]}], "}"}]}], "]"}], "]"}], 
         "\[IndentingNewLine]", "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}], ",", "\"\<s31\>\"", ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.662714291401493*^9, 3.6627143776225877`*^9}, {
  3.662714482583146*^9, 3.6627145783900347`*^9}, {3.662714623414926*^9, 
  3.662714716670018*^9}, {3.662714761832006*^9, 3.662714773038947*^9}, {
  3.6627148083910093`*^9, 3.6627151628461585`*^9}, {3.662715246414686*^9, 
  3.662715284844926*^9}, {3.662715885787751*^9, 3.662715909348439*^9}, {
  3.6627239920208254`*^9, 3.6627240004043083`*^9}, {3.6627240611735306`*^9, 
  3.662724115731728*^9}, {3.662914102092125*^9, 3.662914102700555*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJyFlglM03cUx/+sgBzlPkZrS4GhMqAccigaoI4wyi0IMmQblFsRCCDBCDKO
AXIKVkCuqIjiomCCqCACHSjIUcbh5oIyNpRyVsp9dTAm4/dGk2X/pGk+fe99
f+/73i//VN033DXgEwzDSrY+f3+XxfuKGvpnWmAfH55lrEuIzxSlw3KHxVdL
Os7qDSKOaPkuazryHWK9CmZfbfUE4lGnYNLwYd4ONxcSU8k3feYRm0XWPcB1
LyFufV1yPPzAGmLDrA0LFds/EdtwjgwbeGC0HR6jPrZemBZCHMtPN3p2AYd4
j9z4aTdtEcQibBEbyUZRxOs9VWevRIghHvWoJqiqSiA+diks9GWVJOL8jTpx
K28pxF6kVoe389KI8SydaQ13WcQBJuWLnrpyiGPiz7uqLQKnTDIHenrkd9jS
QVvmLr5YAXF2lSnLgaGIuPPELf45MyXELHZ4li5OGXHNmURa9xCwqr3l4bDa
TxFbbX6dfD1OBbH/L81zde4E1I9FYtIjhhoR8ZXw2Qb8GPBIwm3O9aa9iKcC
6v1b0kiIeaHye9gMMuJq2y5+IFUVMSfYwBS3CEy8N8hMY1MQJ/tElrPt1f5h
DFvmE7Lt64G1GgqLOjXVEZv4vXCWSwdmlSqpdC8Ca7GUMpy8NBA7ikyT+5uA
eW/et3Zof4Y4vDRbIf0ycNP8/tXNTeA/GNXKXEo9ut/HH4o/6M3lIOarHUwx
k+UibjJeJrG6Z9H9/eAppdmYC/uPNxZlLjNg/8EZfY2hxrB/g309Q6kqsK9X
Z6SP6k4A9+mou0k1wP6wDJEAawbMU+yN/mM6AebXqNdWmJUErEw/lfq8Hfzl
j/jqxHhPof4veDbPZepAf/hHJsOjNXD+DRsSmRoEel/MzXffuQd6ft5Cw+us
D0gvScbRyO8a6JWqjRVEUlD/lm1kF93Mg6A3WcayHHkHeitTJRonZaH+NXdd
vJMDfuXd2r0vekL9V+00XmEZ1BuwCDXF47Cfuhdrwc7CcH5QHG12Yh/UY1FS
fgM/Qz2/baTlxy/h/B/MKLGVeMgv2BiX/KZoBuknxA48zz8C+3n1Moo0Owt6
nhTilBUO9M47TPVoDYIfu0FS4m1X0H9vOJaYWwD1dTp1J4ooEM8cerjQ1QPx
tfGCoZOiEOfrRUfrUqE/aachqjAV/HsbEasnJqG+vrxKYpYM/ZlexluHzEN/
fheD78tIwft97m6H1wE6+LX9lp2xsgJ6v3omtnHX4f4HlrXnmTlDf9pBTzvx
TMj3wS0IR5Ag3iufZk7vgng5qz9HDwdx90O+vkf3g5+KYO5SwBjkp1p8X0nk
/qt/joZH9E8wjxzmjYFzi5B/TZZZfUkc/Ge5OqrGmIK/0eGrIw2roLdxqmup
nwzzEP587VgcH/S0puPwaSvgf2GDVJzsCP13C2nO2OVBvvFM3tBbIsSjqniM
1A6I35fJXrwpBHEbnMfeilGIx82lGJ6uBX+GehIrNfMQH1Qg0Gf0YV45T3qZ
zCXwc6fVL/DpGuRX/j6q+IwP/ZuJ6G/9BPqaPCVvw0Mwn+180GPk5JItNv77
/gveJ0F/gvMX7P//+hPsx+jjQ6AFSiW4UK/Szbd/l6fZ/bZ5S9HAxHynTixM
+Ak7RL5xm9VoUSubW89w8+7/Sxi2+zzBeW29D3f5E/QvuI+degri3f4x7C8Q
NbPq
      "], {{{
         EdgeForm[], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[0.2]], 
         GraphicsGroupBox[{
           
           PolygonBox[{{134, 154, 155, 115, 133, 86, 101, 32, 60, 33, 34, 35, 
            36, 37, 38, 39, 61, 40, 89, 76, 111, 99, 129, 116}}], 
           
           PolygonBox[{{131, 150, 151, 100, 117, 6, 54, 7, 8, 9, 10, 11, 12, 
            13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 55, 23, 119, 103}}]}]}, {
         EdgeForm[], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[0.2]], 
         GraphicsGroupBox[{
           
           PolygonBox[{{1, 148, 149, 132, 112, 126, 85, 95, 70, 79, 53, 65, 5,
             52, 4, 3, 2, 51}}], 
           
           PolygonBox[{{88, 152, 153, 128, 96, 109, 72, 80, 59, 67, 31, 58, 
            30, 29, 28, 27, 26, 25, 57, 24, 71, 56, 83, 66, 98, 75, 
            114}}]}]}, {}, {}}, {{}, {}, {
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[{1, 51, 2, 3, 4, 52, 5, 65, 53, 79, 70, 95, 85, 126, 112, 
          132}], 
         LineBox[{100, 117, 6, 54, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
          18, 19, 20, 21, 22, 55, 23, 119, 103, 131}], 
         LineBox[{88, 114, 75, 98, 66, 83, 56, 71, 24, 57, 25, 26, 27, 28, 29,
           30, 58, 31, 67, 59, 80, 72, 109, 96, 128}], 
         LineBox[{115, 133, 86, 101, 32, 60, 33, 34, 35, 36, 37, 38, 39, 61, 
          40, 89, 76, 111, 99, 129, 116, 134}], 
         LineBox[{124, 108, 94, 84, 62, 122, 106, 92, 81, 73, 41, 120, 104, 
          90, 77, 68, 63, 42, 43, 44, 45, 46, 47, 48, 49, 121, 105, 91, 78, 
          69, 64, 123, 107, 93, 82, 74, 125, 110, 97, 87, 127, 113, 102, 130, 
          118, 135, 50}]}, {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[0.2]], 
         LineBox[{140, 144, 139}], 
         LineBox[{141, 145, 136}], 
         LineBox[{142, 146, 137}], 
         LineBox[{143, 147, 138}]}}, {{}, {}, {}}}], {{{
        Arrowheads[{-0.03, 0.03}], 
        ArrowBox[{{0, 0.5}, {1, 0.5}}]}, 
       InsetBox[
        FormBox[
         InterpretationBox[
         "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(\\!\\(\\*FormBox[\\\"1\\\", \
TraditionalForm]\\)\\)]\\)\"", 
          StringForm["\!\(\*SubscriptBox[\(T\), \(``\)]\)", 1], Editable -> 
          False], TraditionalForm], 
        NCache[{
          Rational[1, 2], 0.5}, {0.5, 0.5}], {0, -1}]}, {{
        Arrowheads[{-0.03, 0.03}], 
        ArrowBox[{{1, 0.5}, {4.5, 0.5}}]}, 
       InsetBox[
        FormBox[
         InterpretationBox[
         "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(\\!\\(\\*FormBox[\\\"2\\\", \
TraditionalForm]\\)\\)]\\)\"", 
          StringForm["\!\(\*SubscriptBox[\(T\), \(``\)]\)", 2], Editable -> 
          False], TraditionalForm], {2.75, 0.5}, {0, -1}]}, {{
        Arrowheads[{-0.03, 0.03}], 
        ArrowBox[{{4.5, 0.5}, {6.3, 0.5}}]}, 
       InsetBox[
        FormBox[
         InterpretationBox[
         "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(\\!\\(\\*FormBox[\\\"3\\\", \
TraditionalForm]\\)\\)]\\)\"", 
          StringForm["\!\(\*SubscriptBox[\(T\), \(``\)]\)", 3], Editable -> 
          False], TraditionalForm], {5.4, 0.5}, {0, -1}]}, {{
        Arrowheads[{-0.03, 0.03}], 
        ArrowBox[{{6.3, 0.5}, {8, 0.5}}]}, 
       InsetBox[
        FormBox[
         InterpretationBox[
         "\"\\!\\(\\*SubscriptBox[\\(T\\), \\(\\!\\(\\*FormBox[\\\"4\\\", \
TraditionalForm]\\)\\)]\\)\"", 
          StringForm["\!\(\*SubscriptBox[\(T\), \(``\)]\)", 4], Editable -> 
          False], TraditionalForm], {7.15, 0.5}, {0, -1}]}}}, {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox["\"t\"", TraditionalForm], 
       FormBox["\"u(t)\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
       True}, PlotRange -> {{0, 10}, {-1., 1.}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {{{0, 
         FormBox["\"0\"", TraditionalForm]}, {1, 
         FormBox[
          SubscriptBox["t", "1"], TraditionalForm]}, {4.5, 
         FormBox[
          SubscriptBox["t", "2"], TraditionalForm]}, {6.3, 
         FormBox[
          SubscriptBox["t", "3"], TraditionalForm]}, {8, 
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(4\\)]\\)=T\"", 
          TraditionalForm]}}, {{0, 
         FormBox["0", TraditionalForm]}, {1, 
         FormBox["1", TraditionalForm]}, {-1, 
         FormBox[
          RowBox[{"-", "1"}], TraditionalForm]}}}}],FormBox[
    FormBox[
     TemplateBox[{"\"u(t)\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                   None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                   DefaultBaseStyle -> {}, ButtonFunction :> 
                   With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  RGBColor[0.368417, 0.506779, 0.709798], Editable -> False, 
                  Selectable -> False], ",", 
                 RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
             "}"}], ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.662715125516719*^9, 3.6627151630463114`*^9}, {
   3.6627152558123603`*^9, 3.6627152865631547`*^9}, {3.6627158984707365`*^9, 
   3.662715910247076*^9}, 3.662724001349416*^9, {3.662724103834242*^9, 
   3.6627241163658686`*^9}, 3.662914105208308*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparison of crane bang-bang methods", "Subsubsection",
 CellChangeTimes->{{3.662716869616641*^9, 3.6627168866316905`*^9}, {
  3.66272772413045*^9, 3.6627277268893824`*^9}, {3.6627357082172694`*^9, 
  3.662735710338764*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"exportRaster", "[", 
    RowBox[{
     RowBox[{"compareTrajectories", "[", "#", "]"}], ",", 
     RowBox[{"\"\<s33\>\"", "<>", 
      RowBox[{"ToString", "[", "#", "]"}]}], ",", "True"}], "]"}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "10"}], ",", 
    RowBox[{"-", "65"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6629141106348133`*^9, 3.662914115250569*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJxdl3c81e/7xyki+UhWg6JQqSQaoriIMpLsUckqomyyN9myZzjH5hjvjErh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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJxll3c81t/7xxUpMylFww6JMjLKuMgq2VmRkR2yV/bee6/7dtvuO0UpFXJp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             "]]}}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"3 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"5 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )], ",", 
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJw913c8lt//OHBu2SO3232nbHdCi1CEnMusVBKlgVSyV2VEAwkNZEWiRAmJ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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJw913c8lt//OHDKDrfZfRtZd3ZDUYR6KaJUSGlYCZWkHU2iJCGRFVJC9soo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             "]]}}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"3 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"5 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )], ",", 
     TemplateBox[{GraphicsBox[{
         GraphicsComplexBox[CompressedData["
1:eJxV1AtQy3EcAPD/ppq8tqi2obJWLa/UMN3K5tnkkbCEnDfrsrNEXY95hCOP
K0cnyUoUWiFCHhcxjsta5T1vi4Zmm78x8yiPu75f/e/+97/P/b+v/+/3//85
SxQzl1MJglj05/x7vXo5XJQ4dbeI+HdYxd8dS/fNbKkXd9h9+0Pa6MCX4EhW
qzLI3wiWhsb3E+82gy2MzEu+UZ/B2doSWzzdDjaZZvcYxPkBXl11K6XVpx0s
OySx2+WUMR1OySeLRyV16fBV8suke6wYZ3BmadvQ9CAaOHFbhp0V7ArWao9I
5tK7g7dN2OvyyLMnOIZuMN93p4Nve5uDhKkMsEeDThWY7gZmhTg3GhN6g6cM
Kbp4U9EH3LXpXXWzwh2cwctKu7vAA+zN3Em+XOwJTr3QHHRlFhMc18W04dkY
Fjz/KmNsFnscGzxqHVvK4/cFB1eIHs0S9ANXbemjqB3ZH2zqJar7xfUCx/C1
z+YGeIOTaZVntjJ9wAxNsc5BGQD+GaUqEm9C36gaf/ejA+33tmBReQYHvNBS
GN1k+886x+S8lb5ge5pLsdyETmirmaNexoXnT57Ok9tb0BOS321/s8IPbFkj
dRW+QPPFSW8KF/qDo5uFHPlj9PD5cfH6qADwyeKh3Wc3oJ1q1fQwCQ8cumfe
Fbd69HUKWSRtqYH3k1ETo09ZT8D85v4qbZ6CCj57SyU8vtQJ8u/IqhkNT3C/
PzyXxU6rw/1e9oXjlHEN93uwH/GVUoHrExxuUO4MxPWwHk0yNJaivcuosoAd
OK96AflaYsbvJ+SOv8Y5B/u5x9l6KbthPv+ppNpoxfkPW8tac51xnmlejR8O
RGD81oRfsWt/4HwMJXlNXIn5EcYszicjE+tNab25mY35UqGqIicEv+c2R925
UC72E5GZSutnrL9/SWq4jx7raXaQp8PcIF9cb0gd/o0K9cW2lfkumq8Y//a9
5FjzDOw3doA18nwT3v/OV511o2A9dcDliYJ27G8pIYZlvcL4XQbJqeUcrGct
FHAuuWB/z/byRooO448LVJXRbIx/URs7SO+E8fKxIzQJDzA+MZs8kT4Q46nr
PFgFXXH9zr+ShER4dNwniI1m11yelgl29Dx6UE3jgjv/3wmi8/tNEL8BngPL
+w==
          "], {{{
             EdgeForm[], 
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{50, 96, 94, 91, 64, 71, 59, 67, 41, 60, 42, 43, 
                44, 45, 46, 47, 48, 49, 61}}], 
               
               PolygonBox[{{93, 92, 87, 84, 90, 72, 79, 11, 54, 12, 13, 14, 
                15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56}}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{1, 95, 92, 76, 81, 65, 69, 53, 62, 10, 52, 9, 8, 
                7, 6, 5, 4, 3, 2, 51}}], 
               
               PolygonBox[{{93, 94, 85, 88, 77, 82, 68, 74, 40, 58, 39, 38, 
                37, 36, 35, 34, 33, 32, 31, 30, 29, 28, 27, 57, 26, 73, 66, 
                78, 70, 83, 75, 89, 80, 86}}]}]}, {}, {}}, {{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             
             LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 52, 10, 62, 53, 69, 65, 
              81, 76, 92, 87, 84, 90, 72, 79, 11, 54, 12, 13, 14, 15, 16, 17, 
              18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 75, 
              83, 70, 78, 66, 73, 26, 57, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
              36, 37, 38, 39, 58, 40, 74, 68, 82, 77, 88, 85, 94, 91, 64, 71, 
              59, 67, 41, 60, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}], 
         GraphicsComplexBox[CompressedData["
1:eJxV1QlMk2cYB/APFBiWcrRQWwqFFigF5bCwLTBsURnSsEMqx8JcuSYgcoZz
ETEIAg7qoB8jrhsBtEPOLOCGAxHwGoRTh8FgMjbkGOdAYt0qFnZkPE9s0jS/
tO//eb73ffp93OgU6UldgiBy/3n/+zkkdy77cq5CRPz3WhcvPB40Tk94IN7x
9fn1cXf2NHg2b8bBI2ERLPdkc3v618Eig+TJ20I1uCE+wzxQqgE3Oqo+8xjU
gicMdK/UMHR8/3ev593SgHjeLvAnLs6FkeF64BkZL//rRAPwkqrdPT7DENz9
VVjmpw0U8HJI6JmrHVTwXN8pBu2ZCfhA7R7hRVMzcPUReWeTBW3H4mSRkjLr
Tgf/YRXcI/IyB49LL7/TFmYB1igEipVUBnik46REkr0XbCB0GbpFMsFr5XWt
x6tZ4L0vo06111lCP992tawJutngaZlqou+uFbggnF+SOm0Njo18TlvUcMB/
SVK2zm/bgLPf9Q5Xym3Bg2Hk3C4aF+yTovjlIQkWR7VPdDXb8sCyuLQAhgpN
DQi6WSa0A1cqi6fIG2jvjZjkbS97MJl5YSarH30vQfvGuUAH8LXSLjr5BN3c
Zl1KieNDf0WSx+3mS2g6daLXKccRnHN439mxV2htLv/aZJ4A/OZMbMcaxQns
d1ObWfUFmlGjWCzjOYOb3e1dMhL6YF4FAUZHxZc2wU3sR7LOzW3whTl/dYGV
LqyX9tVwLhaagn9/NqRmkThv+rfJ6KNXcd7ORMV1lzBxHgru51MKbGAexLLw
4pZVV5yH2tF5m7ExPM+CGcX0khTPb7Tcc1j0BP3W5sfGhiTubyMn8cMxW9zP
y2dfcsob0C4uA9+ZTeL+NHF9El883YLrNZIskw+D8Hq8mitOnJ7C/uutyZhs
IdYXhJAH2rRYf2JPh0D0OQHr7yhbwqIfYd7Ir2ldykj8P0Q2KiJk6ZjnvOCX
tHoE+/3Rm1Qd5OH38ev1PN4K1gs1Mk2k+mG9YP9ufs91rNfws+apsS/WqyRI
XtthzFvoPOfra8LHPMMTc8kPMM997ZsSfTXmbawsVvDzMe+QhH7f1hLzGNRb
VLUtrmcMH/xzwA1/X1Js2Jmjj/U09+xTv5/FfLf99MJwZ8yrosQMOsRhnvfk
D6PBxzAvYEXdb8DEvFiWRd1HejB/vUXHjofQGHg/yJKTU/EmkCceHojQqXfE
POa4924VHfMCd09Wummxv1eHxj3dONhfR9m8T74Q+4sYY68uv415OXptpaet
8DzPuwa15lOxP0FwujXFHPurH9n66Yo+9ifoTy2qtMO833LGG70ssb/ndh6O
SYaYN/ueh5zFxDz/9wUvXJmYlzb4Qe6NfZhnqriUVM3B/ky9UjyqzDDPtXVD
R2G1s54gQkV5WbV0GtpfM1DKtQTTAu2crFlc8H7xHaWUzQe//nwmiNfvTwTx
N7/eQjw=
          "], {{{
             EdgeForm[], 
             Directive[
              RGBColor[0.880722, 0.611041, 0.142051], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{50, 124, 122, 106, 116, 65, 77, 43, 66, 44, 45, 
                46, 47, 48, 49, 67}}], 
               
               PolygonBox[{{121, 120, 110, 100, 115, 90, 105, 82, 95, 75, 87, 
                26, 60, 27, 28, 29, 30, 31, 32, 61, 33, 108, 98, 113}}], 
               
               PolygonBox[{{119, 118, 89, 104, 80, 94, 73, 85, 9, 54, 10, 11, 
                12, 13, 14, 15, 16, 55, 17, 69, 56, 81, 74, 92, 86, 102, 97, 
                112, 107, 117}}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[0.880722, 0.611041, 0.142051], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{119, 120, 59, 70, 25, 58, 24, 23, 22, 21, 20, 19, 
                57, 18}}], 
               
               PolygonBox[{{1, 123, 118, 114, 99, 109, 53, 68, 8, 52, 7, 6, 5,
                 4, 3, 2, 51}}], 
               
               PolygonBox[{{121, 122, 111, 96, 101, 84, 91, 72, 79, 42, 64, 
                41, 40, 39, 38, 37, 36, 35, 63, 34, 76, 62, 83, 71, 93, 78, 
                103, 88}}]}]}, {}, {}}, {{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             
             LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 52, 8, 68, 53, 109, 99, 114, 
              118, 89, 104, 80, 94, 73, 85, 9, 54, 10, 11, 12, 13, 14, 15, 16,
               55, 17, 69, 56, 81, 74, 92, 86, 102, 97, 112, 107, 117, 119, 
              18, 57, 19, 20, 21, 22, 23, 24, 58, 25, 70, 59, 120, 110, 100, 
              115, 90, 105, 82, 95, 75, 87, 26, 60, 27, 28, 29, 30, 31, 32, 
              61, 33, 108, 98, 113, 121, 88, 103, 78, 93, 71, 83, 62, 76, 34, 
              63, 35, 36, 37, 38, 39, 40, 41, 64, 42, 79, 72, 91, 84, 101, 96,
               111, 122, 106, 116, 65, 77, 43, 66, 44, 45, 46, 47, 48, 49, 67,
               50}]}}}]}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"t\"", TraditionalForm], 
           FormBox["\"u(t)\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
         DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
           AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
           True}, PlotRange -> {{0, 11.900526240560039`}, {-1., 1.}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"3 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"5 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJxdl2k4ld/Xx1MqoRQypUKDoYyZEpYkVCoypVTIPCczIfNM5nk8CiHzcA6W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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJxc23k4lO/3B3CVSmTLrsUSorQISeGIKHtJQvayZCckS9bsZN8JM4NU9m1s
ZyYpSyiyhOLTotJCSRLxe77//vzjel3DPPfc57zPM/dc14jYuhvabWRgYChg
ZGD43+///2P9YJSh70Jm+2SYE0vGkV04Jtyt/0K7sV3C+83X20ek8Xl6xD2d
oz3tg5IUYxMxeZwIU76QfHa0/bdLIMnuiBJu/pPsEHDkbbtKuL+bfMEpDGFb
5hSTmW0v9HpQdERMA2uZZot3Df1oPx2WPy9UfhZ36LQFvD6z1D4V1XZx0xFd
NNf3TX3p+6/dPXz7i/F6A9SOYV5kOLIRA05oyAzln0cP/6TzlRu24GrDdatq
6wvo8lKo2OMIM56Qznlwe+9FZKDxT51uZcNrQew852aMMbNAmTFjkBOjyoey
OO6Z4N9Swy98Z/iw4A2f2/VD5ti6c81e5IwgVpz0+cr1wwK5DzjvrvDZjXXm
4/TSWit8EXFqUvywKOayjIwZ5tlg5T6e79LbxTDsCtPvyCBb/MCmOenFIIE1
tQ1vaiyv4Cvh1vimQ/tR+ULw0XlhO5yMDP7e4CiN7Q/THzJstEdaaZ7zD+oh
HOMV5t76zh5NznqssLyQwb0HYjoWyI5YJ6D0O+i0AjLL3tA5LemCde7r2y+3
H8dDT35t/Mvkim9MjIafq59AQ+OTT4s/u6K54/qRCE9lrBj78L633B3fMysy
/TughkH3GNqPZ3ii9Wj8JU0+dZQ4E3/ObIsXqn5iUzRlOo0Jq0/Hrvt64arn
vrWxFQ1c6HLYlGh8HQ323/4tJ6mNbIzvz5ry+qBX5PXe1lM62Fd5gks+0gc/
kpOimW108U1vpPrW3z7Y18LE9btKHzW+zLMmDvui8JnqkfWe85j2RW5YKM0P
rx9wL5U4cQnZBHegJHsg+hmxHH7BaILP4Vfvg6hAJM1Mzo8PmuDSlR9vRRiC
8GuqeTHzTTP8ZKl59M18EFZyxmzv+2aBCksRflkvglHT0tryWKstbmFlu/T9
aSjm5gw/dFS6gl+pX37c2xSGngsi5ZrtV/DMhOBOcwhDMxbHEsanVzFPoD+H
1BCGzzX/yw79ao/nzx2cbiGH44kvtGa1KGfc+5/Oyd+3biOzdq8Fu6gLPmG5
zru9+TZKHx/bGN7ugh+eLCXwLt7GzHFjBstVV1zYbTzC5ByJlR6KHV81PPBH
DouTlXEUTsY+NO9f9cLv1vMJ1P0xKNTbuPRuy02sTaqo1emOx7v/hX0OcbiJ
TCnXnn5Zi8euv5bCL7puIuefS9m35BKwmOzZEJvgj/p2LjyBdxOwPug/ewuh
QLxvQ+se8k7EOQ/Dq8ZXgzHg1fUAD7YkZPB6+0VYMRz3HziS/L4qGQe8nSR9
vMORLCrA3t2TjBoDrl+EqsKx86OuM+V9Mnbz3Un3k4zAP/ev39HgT8GCgVE3
2d23ce/QsJJocAoeKLAeb+CNwntG5ZNqOqno+syl/6BWHG5/+txwYDINT3IN
J7QkxOHBocmkXYtpWDhp+l/WYBz2fP2TY82ajgU8PN2nLOIxa8vKp2fK6Xh+
cURRyzcB/bZeVpcvSEc9rso0rsY7ODN84P5JiwzUicjuslRMweMl6fzDQ5n4
IihvPMQ6BcM2rxh9nM3EBZ5aaldUCu5/0sk6tyELS5k/pXePpKDDil3fm8NZ
yGzL8iTBNxXPivV6qcRl4Xg580aOtjT0+rDUuQjZqFAfNhBgl4ktQ8bbGYpy
MOpc1/nZtEwkG0f3RzTloOstqbywx5mooruNtjKQg+U2AweOiGVh3JsN67iW
g48Mz5UFfsjCK9NvEgsv56Lak7+7O91zsOLDA7PGHXn4dmWziWlxPpIuutV9
8clHjZ+nLg+M5OP+Wqsbd+Py0S38/jtnlgK8dvHVonpRPk6Xcwvw+xRg7rPF
Jctn+XgrOFfqhPZddNR4MjghUoBFc4fanwQVYlK72c+Z7gL85tqYM6JUjHRz
Jp2VLYX4ZPHrwRuXivG68eCuQxyF6CjE+U/CqxipY/O1pgKFODXYsaeutBj3
8r8QyT1QiO94JXeHc5GwaZYS88SgEFd+ZXh8/kbCOOHJxZaMQpSoHS4Ie0jB
reRv1YxCRbgxQl5qoZuCk99HdM/uK0KBo+NXPWcoqLqy6VDE4SKU+XW2JUOo
BPn0ROvfQxGeqt3pHZ5Sgn3hKt5nrYvw47HUpFf+pehR60TOvFuENWK1ursu
3sPbz5RVlfiLUdxlWbjC5x4eMW012i1cjM/v/xTQz7iHMgZGg7/2FeMt36Vj
TaP3MPbV4u9IhWJcZl07JXu5HJ/TDzgrGBfjDsuXHPVX7yNN5i+5M7kYc4a/
bRGJvI8SD/SusmQX427x4q05pfcxmC1e/0xhMTKJqP5XM3sfn78STi+qIK5n
ycVwy/MB6tewRkz1FKPbbXE1p9CHWElhrQvaQEJ1j7agAtJDvDCu7STGRMLW
yHDKm86HuCLznIPORsJklnXPMOYKFM5mFp7cSSLmqs8247QK3OlWNJ0lT0KZ
ouHI3eWVuE2yslbKgYQulwa0R75XYVvNNd6URyR82n/WS5uhGjlKH10cfUrC
y1VVJzs4q3F1V2fojj4S3vpxJ+mRXDWqrNqmO42S8L2E09kl/2p8mahlW/SF
hJkKAUIyTDV4S+Gv7r4dZJxuG5f/IlCDx5VUhXp4yVh0X9Hq3oEaZA8qqrPd
ScY3q4pPZQxqsFbEcI+PGBmdZUR/embUoPK/GvKeY2Rk5op/XSpei3qRr5TC
LpFRJiBgrkChFt8Hj7GHXCbjPoXb4dlatdjoHxJy3YqMFp7d27Nda9HR0lDu
pAMZv1qeKqTV16KHZkWTni8Z/QoMH9zTrMOGye7uoBQyQrJ55EuTOoyxlqx/
mU5GtYWt+hud63A9UUdMJJuML3vFQu3v1KH0iH1Uzl0y7geS17mxOmTwLZJl
f0DGWxW8V4ud6vEIlFPXHpHRyv+OUmtAPZ5QuWAY3EnG92Fk4bH4evyQx1D/
+ykZR7jDv/FU1uPZ+H1D3c/IeL37yNOyhXo0o07pbRgh482t5VKDjA0Yc/ID
5/ExMorzB1/+x9OAZequ6XbjxN8H7mI3Pd6A7/90DJPfkJHa0T0tFtSAe/2i
BepmyFiSM/fpcmIDHhk7Qi38RMa9GUfD0+42oHzdF46IWTJ+N75kwPyoAQdq
82cOfSdjQQS7+9atjView72bZ5GMnxh3yGjzN+IPkpd7428ybrSlnUmUakTf
5199zv0hI53N0UhQtxHH7U/k26+Q0ahxhOtUciNGGJqf2buBgkvFB8gJxY3E
PrVJB2ykYOneFp2J2kY0/K3+qHsTBY1UX9BvjjRiX+bTFe0tFLSOXQnp+diI
81+eFARtpWBuZ+nxXcuNqPhmfq6EiYJU5z6vRzubcNyjO+c1MwUfRMx+4D3Y
hIwB/guzLBScm31+1EWlCRd/m/35vp2Ct1ZUTwrYNOFzvkrGCTYKjl9w++jh
1YRxEuIsHewUJF98oN8d3oQV/gMtRRwULKwuOhxY0oTDTzoF1HdQ8C11NXuk
sQnvSXI/2cxFwZqnlYUy3U0YQ8oVRMJ8NduVEsab0MLlNa87NwX5z9ld/fyl
CdmazJp5eCjY7seyQ/NfE0a0pDHWEt6x6bwyiY2K9+5vX9TkpeB/WRu+W8pQ
8a54yxNDPgq6GHJcbVOjoprAr5Iewo+7NyvuMqKifJ/7AUV+Cs4Py9oF2FHR
xrfyQgHhZb2v0+O+VKzUkhP6S3iGKZR8IpqKWwKDE3QFKEh7rV6Wk03F82o7
CtIJJ5Ai3/8tp+KNF67nhgkby+Sev9xKPJ8lF5lFkIK2lr5HZAeoKLyBuniS
8FtvG3mWt8T/J2aq2RDWYk8wfveLiilmAnEBhA0npWJbtjbj7faygVjC1FjH
J6mCzdi7o4rjDuET3Tc3uBxsxi1V2frRhJM0E2VOqzbj6PeBGF/CN6pHdHdd
aMb/9rU9MiVc3hSu9cuuGTtre5dlCM8wP9n9zK8Zxb/YHV4n1jtj3I+kuGYs
lvh9hU7YXqdPPKCgGd+0z2T6ERbJXNAwrG7GgO3FvWKEhz558ko9bkZBx5T1
TmJ/FOb8EtZHmtFiv6icOWFmU8Wi4c/N+OF+y7WPxH5vHX535v5qM17U6C50
IDzLee9GCHsL6hvUv5ok6uXWTpW4KNqCXqKz3GcIG8Ro6kjJt6At36BhCVFf
LZGQidUzLUiLHE39S/QDn3xm34BZCx7qvjqmTlgoTrjqekgLohTNtZ7or+f7
f8WfTm1BiWVbfM1JQY0NjmTukhYUWzvGu0L0ox3rwuWa3hZ0ZNk1zE30Kyt+
Hn/L24pP3geQHhP9byGzw/+BVCve2aG9P30bBfXPWW/2UWrFlRN5VDMiLwwG
R6gbbVtR443PwuPNFDwez9X/1LsVHZgHC64xUnD9yFRpXFQr1qZeNtpE5HG/
y88w9oeteE64cIqHgYKM1rkeA9iKMy8PNySuEfPUd24lYbAVpbUyslZXyThn
IbRT50Mrdg4rR1kR+fftvPx4y59WNBxKCmtcJmPF5eFvNOY29MlZjmUk5oXh
QGvCzd1t+CL8baEmMU++GfxykT7Shu/g726dd2TsD06efKzWhqN9t++vEvNz
8p6Fs+rFNty31c2JVEzG0GeyAncd2jDY8pcZhJEx/4vhnc3xbdhW3KF56RQx
T/8IMvoOtaHaYYXXTEhCspYc5bV5O7Yot4yGNBH339mNDC4u7eg+vFxdR9x/
c39oU6YD2rHnJofwtH8x7hJRrg/Macfvore+7VYuxjO/P9gGj7QT+1cTf4xe
hEPCcoL3tBBjj0wsfnxaiB16iieyLyEKH3x2MresEPcVXQN3O8SBxqg5zZhC
nPzJNPUsBPEh5/pYlHYhRhfo9eg1IHZ1qcbYZt/F44HM8UfYaNis28ZheTcf
D1HIpsbcNGStk2ufsspHocvhs26CNLx45tAOI+F8DLVL1/aToKFnXKcwT1Ee
/nEVrfuiTMPPrKlrK0W5eJrz7ydDJxoqDOdL+BZlo6rkcBnJnYZ/yZsGDttk
I31T2saP3jQ0ezb8/bVwNgZcn7+pEUxDP1r8Nv7CLOzdGy9rk0rD9PT3k1sK
MlE761gvJ5WGLCHDaZ8y03Gylfu+dxvxfMN9KSom6XhwZ2R0D52Gt7aYqcTx
p+PXv8VyBj00nIwpYd2WnYabQ87ubh2n4Zld5tnZ2alYc1+9vuENDfdpAUeZ
aSr+tzp4kvyWhgM+pVwVAqm4Wi3EajJLQ57DhYeKslPwhy8lTXSZhlabOh5L
ZCcT58ter7pVGjLKTj74ZZKMb7+NHVVkoKOUvMWGFv5knOW/Z7hzKx2ptJ9W
MllJmHOL++Mpbjo6PJlmSTp4B0Ny8nj5pOloxnFph7N4HP5s+2w7coiOW1av
PDlEjsXOcc6AaBk68qveHJ0RjcW/k6nMncfo+K9824KccAySmDuj7qrS8dLK
BBgIRqEAwznuRTU6rudobG/NisTe0qUryhp0vKFx/u8evkjUm1U+W6JFR4a0
3N1dXLdxwc18y6vzdDzsH1X1cHs4bnotnfj4Ah256m9TX8SGYcq96y+KL9IR
89+VfWMKw1Lp8igFUzqGRu3Zw7Y5FJ16lJa/mdFxT9J9Hq7wEBRLj9ubaU7H
lIt/Rjg2hOByMOku3YqOv3Vs5eaWg/BcFPu8mg0deT1zdj5aDES+2KDfDbZ0
fH1wh0X0jwB0OUcRvWFHx5MJIfXzn26iwsqGMx32dGxWGa1Mfe+HX9xL9mx0
pKNYycHeA9M3MOz29g+XnOg4VJd9QHnUB5O/j8zedqbjz78SCcmt3picd1Kd
7EJHUXYRtYmi6/g2aOxbjSsdx3txQjDKCzUfkWer3eh47lzNl3MunngrO1Ox
yJ2OVS2lm26d90A92bLxEA86GpkVOGm4umGt6/oOTi+iPir/mZRvcMI+V7ly
OuGwluT9Xb0OGD53JdX2Oh3XVITaXqXbYYbo7f4FwmFbPslOW13BrmN3Lvt4
09H3nHbNpJQNTly+eeIjYceGs42FHy0wiX7CWcuHjko9ZSV+AaZYltnzLZfw
LlPPm+rsF/EDq/CjN4QfT1n6biKdw21GRz9x+tJxvv5yl4/rWXyZ/cdKnvDz
3c4SVVKA29idpLQIF7JzOnfP78dr74JO6xGmZSznNrzjgDrNA9WnCKvWK7xU
npWHCsdr7hKEy5qyLtP71IHv5uHglf9d72VgjmmJLlSXek/TCLfmlMZ7oiEo
ix1J9SVc7KFDeXDgEgTuMc3cRdjM3fX5ROZlkHky87WGeH2cCWVX1jZYwy6d
56mKhEX/5hVtOW4LDK+3x1cR+3OLVn9rs9tVyL+fOsxHuKcobXSZZA8NM5c9
3In9JVtNRL995Qgs7ebmjZ5Ef7cccG9ndwZLm4TsOaI+0n77HOI1XMGD4cM+
fsJBFz30dALcgbHXbKsMUc+fzEbrgWMeMD7/QeEEUe8Q5ab7OgueYJkdRJUl
+sE/X1qQk+063Ck3jt9N9AtNb1PjM0lv+L57UOrRNTqyBczIiVn6wiOFyt+B
RP89Lyr51e53A3oadgtIOhDrzW4r0Ev1g0cXxK4YXCXqf+6S++kufwjmZjvw
1oKOTXtZj0TLBAPvlQcdQkQ+pBIPHH8lHgLBi0+a9Yj8hGm+Y56pCQGuizNd
/sZE3tPbSz48CwVXZsYIAX06zuixDXgzREBDWPPhcR0ij/01OZAQAe67x9Ti
iDxvsjo/si5wG4Kk2kntp4n1XzoSaCUbCbKlzu5OJ+gorG+VnWoXDfT9tK7X
CkSewhRoeZ+iYe1vcbq6PDEPkjToOc4xwN9bkzBzmI7fwv7Ze3vGwqC0MUes
GB1ffK8bygyMh0l+P6FkESIPrNxWp9bjIW3A/l7sHjp6dGR9fx2aAH6VsUcv
8tNRraZOai4yET7VvNI5y0LHC06iY/Jnk2DbzjOW74h5eDuM68aFmCQI2ymz
7MFIR8HkhIprPUnQ9rtz4Mo/Gpa9PHs9WDcZ5O8wyJZ9p6HAM04pvXMpsMgm
7vSwn4aHjubNXTJOg4CNklOexHxfSNaN+JGRBg5DQ8uST2jIv3jsbehoGtTt
8dznTtwfHjHN3I40SYeNLwcyLt+n4QWld6d2mWXAsZAYy4YIGp6NZTpmfTkL
5MxnmEqI+8/U18hek9wsKNLW8432p2GCR5KZ5kQWDMoMkMU9iPWB7MK6WTbs
2PItj25GzH++l38+m+ZAzb2py2EHaRgacKUk5GIebEhdsBDeR8PK6NPCzDl5
UDfusblSmIb6OseSIt7kwcO5aMMCLhrWfUt9pOOQD7wyNfGxPxAPJR0OF/Ir
gErj5JPuxP16f89QqKVOIfS/px7s8ES06w0NF3UthI4w2qs/tojPhbumXycW
wuKj/QHbNBDvPDllf2KwEL6RYh7QtiKu9fwpiTYpgtobt+0So9rxtmbYfacr
xcBuINW64UY7etA6d+dFFMPJ0aNGl+zb8b+RtcEOSjGwGji43Dvdjl6kt7TF
j8VQfvjT8dn1Nlw/Zf/4P2cS3JvWyfD43oYvJXQdO+JJEPZ1MfDVZBteVdJ6
nPOQBLRrrMwXqG3Y3yFgtX+OBBF6k3tmPNowsmfbiV5PMlhIbn4UatmGX1sK
mkxSyMDPdPEYg24bKnu5XJ2oIcOvDV0RNoptuEmYT/rCEBmOHDBroEi0YeeS
2houkOGyN+fOV1zEeupYzx5eIoPDZ5kF5g1tqPra48bnP2TYMEdWP/m9Ffd8
7CjI+kuGXdHWrE4TrTgV8aNNaZUMXncUHTO7WpHb4fPg8D8yMGf6W3bUt+K6
49PJK+tkmLe4I86XRLx/3ZvYb7mRAiWqTm6Vp1vR/LYSx/OtFNg2qt69/2gr
/p5794d5GwWof+zYKEKt2ChgdvwkMwV8N3OHZ/xtQZ/83KaA7RRQZHTsYv3U
gmMeE0txrBRoqE/bGzHcglK/B2OT2Siga8J0xq2qBe22DZYFclBA0IJP/G1+
C9Zy6B+15aQAp9Kd0xfjWrC51Wm78g4KsJX02yjat6C3RHbtIBcFNuImt/IL
LVj331RIAjcFqk/4jwueasG0140FyjwUqH3Ztby8swWFDN17gngpoFDljo7b
WhDK/EZZ+Sgw5bjIPPq7GWeX7WVTCatb0D+cft+M4/IDr1n5KbD85YRpzQvi
PKWtORJEuOB6t5sQNuONfTa73hH+b8+rw/EPmvHH4vYqZQEKaFtMU/5kN2MY
kdAEwtdStcevRjXjda9f9EHCQ7ZhI8+9m3Hs7xSwChKv1/UnScm2GZ+cjmJR
JjxyYbNumUEznlNqEbMlnNckPsal3IyxfbpxgYTXldrPB+9vxuj32yGecFqY
4qNZPuI85foMkgnP7d8oa7y5GYWMzBPiCBePhj2k/6TidETCPuK8CL3OEicP
TlORNcCUzZowwyXTD1l9VBwSqFQ7QTjnQ2Q9YwsVz27qfryNcP5OwXqPMipK
c9Sn9RPr3/Yv6NtkOhVPCoTWRBOeStjtqBVORbmlE3uOExYZvHKowYOKw2Hz
o5PE/oz0tWjttaTiZFrllC/h1YikjiQdKm7dEim/hXD6ii5l7TgVuStDX8US
+0+SN//jIkFFumNVLyPhFpR8MsFFxfzLwtu9ifoJk3fw62yg4omfm3PHiPr2
/Qhaav7ehHnS035HCZOd/CLyupvQYyVp7xOiP8j2o6fZGptQ7anvj3Wif9Jc
LzWFkJswh+LOcZjwH2WzNw7BTZjLRFV3JfpPfewBadKlCSmP+U0D2SkgLUQ7
ZWjWhIsbyukhRL+GGXUdVJVvwn3uwYnXiP7u5EpIbBJtQqeRwQU9FgoYi9R8
k+FowrqDvhX7iDxs7G59tu9LI+7a2SveQuRHsUGGR6SoEUP/hB2wJfL1R4jl
5n93GlGgcTSAeQMFXB4xrRTfasTMie7oe0Qer9+rvSFl3ogTjxjHe4n8juYc
2KfB14inxFJci36TofS/aQP2LY24ck6zbv0XGdpXtYbGfzWgf6BdmxExL0wb
4pl8BxtQZl5T8N0cMX/s9m1oT2jAsIMavMmfyBAV2D+UGtiA5rIM0ZQZMoj6
DCk7OzfgkN/so6r3ZDDk1P29R6sB2d5VZN6fJgNlr05fDmMD3ucreXl0jAxp
t7dWzwbUoxVflkV0JxkSlxcjXjvVI3fD095tHWTQ63rnOGhajw+NU3eE0cjQ
deDRrUcK9Xju3pNDl1rIkLzxfl3rQh12z/B0pFaRoe+h3LiQSx2uXRRwuJRN
hnr+kqMKl+tQztv/u2YGGYTqpbjOa9ehQ0emzcFUMmhGHIyNl6zDZIkV9ql4
MjzqDNqz90MtqsglNA4HE+sv0zQdtqzFxfL+ZM6rZFj64KVboVuLZX0ut0Ws
yfDQ7Xdn7IladFV5+1HCnAyfTnR66vPWooiVyYYdRmTYXtNft6G/BqfmMtqv
qZPhcRijsLBKDb51apcXESaDpSHrtLx0DVZumuaM2UmGgYj1FgPBGtR4rhcy
w0uGLd5VX+/8rkY8srQ7jJUMIZKNcuqV1Zir9l+R0l8S7DX95h8kUo1d+7mX
aC9IQPb8fP4VezWO1K8KhT8jwYv2mleKa1XYU/GU4eRTEgStOgttm6jClKPN
v+NaSRC1vybov7QqFA7YwlpbQoLFAONLoduqsHXiXTn/TRJYpyQJ+n17iHYK
858u8ZLAdmN5I73vIUq+iXDV5CBB/1bw4ql4iFmB1y5KM5MghGft5oTbQwzc
4mf65l8xOLLRnN7NP8At/AwBE++LITHjdMzc7/v4XFbbQam6GFiO3Da6zFKO
/p/Olj1ULwbaqrUs47d7yHMrbkeiUjH47+SZa+q/h1NFjqr28sWwjVVRVjPl
Hm65Ifnrn0QxnPk5eO2HwD0siFfg791WDIMXHJ0zDpQhD6vFsam+IjA/X515
06QEXZijZzefK4LXjcyN5xVLMF3Z4uexM0VwQb+rXVGwBJ9sFe+3VCmCxG73
p4qTFDzn68mTKl0EHdJuQSvWFNxucMotkakIqKcFA1Ndybg7+lXxy/ZCWKpo
7bidWoxnpp9/oosVgqVy4NxN32J8ITrHOSpYCKPf8jeFmBZjNFmy4h1HIcgN
hoo9EirGPMfbZU+W7wLLwMfPQg+LULNr9t1y2V3gtbl+Xr+3ELVIrQ1KjHfB
9iMfY/OBAqwcCtELq8iHu2nv5fWX8pGvnINnc3Y+kBUU/Jg68jF2ZbTJLzwf
NpEU8ufM8tFPLBSPmuSDwmqfe1x8Ho7vO77wk4F4PHuOl2MpB0+MUscfGuQB
ZbZ9++rnTPwdFe1v9TYHVsQPX4lozsTCMKtnXL058N3eekk+LhNft/1xaq7N
gd0qBUo8BzPxeoNS25uIHPAVqV544pWB3Avp/yIkcuDaaFbp9i3p2MoerGro
kA2D3x6xoG4KMsnUcZ6ZyoRfpOW/buIpWGE79p6pKxNmnt05q7GWjMcl9ffS
qjJha0edhl1VMn7K02dhD8uEzYavGr15k5HmGlF6WCwTeDhyf9OH7uDfuj72
2/YZ4GykvbnHPA55H54/0/MuDbzhZtom/jgkX7Ps0utNg36PV0sJQ7Go8nKN
qasmDd7nedSm68SiwEr/r8LQNGAY7z/jDTE4GeF/78OeNJj8b142+lgU1sq6
7X58KRW87t+onrANR/7PD/eIdiRDV/aocOjecLQPqYp1Lk0GwY9RnTHvw/Bx
7unm+3HJIPJU+kCnQxi+vjRRwGGUDMVNfX0fvULxW/0Yv9v7JDgUcEJjTiEY
O+LoZRGbkiCnPvxHW+ct1D1sYBXWfwekf275Ymx0C9v42Xpm0++A7SOb9k/X
g3DQcOxArNgdkPn9qyalNQCtGXuMt5xKBPmooxwK3n74IFh6kfVGPFjFOm/p
YvPDcyof02OV4+HqLxOufeU3UPJxs8ufTfHAG9a059w7X5R7EaRQlhQH1vus
qIZWPphUfDj/8r1Y8Kuf+wq3vPBajVCU9Fg0nGxPKnwi7oW1m5a/9eRHA79a
hPCefk9k7pXxNb9CWLXnqKqIJ4Y4pNqZfo+CI156beXF7jgSM7izfVMUaHsn
RAxVO2HFpj2P9aRvw219pU084k6Y3hopJLAYAfs+bVJ5mn0NR/bZfxtvi4A/
ayIbg6Mc0SE0+LSaQQT8UvIPVPe2xzzZV7nFnuEwsvXuH4tUW7SW4ujDulDY
Kf1B99luW9S6/3jLWmAouJCMn1Tes8Hvid1qchqhcLDrL4x2WuOK5luJmOEQ
eJFo8MhMyBIL0kT+VXwJhuLVf18lhi7hV1s7hhNOgVDWe1LvOe8ljJ/avdi/
HACpW4OpjhbGmGdmKnkpJgBmpi+2OSwYoSrNn1+tzB9oE5spFDVDLPE//yjq
gx8wDh7O6s8/jxWC2/Vbvf2Az2WK8mnlHJ4qjq/7sMkPaAZCR96GGiDfa4Zp
PtEbMLb+mbt+UhvjjxZeWLfwgR2VAtv2PdLCZFVvk+mv3nCC56JB8MOziELn
XzYGeMMFJffp9+ma2Nqpua6dfR0mb9b4pzxUw8v/sXRufUmcz23oVzUenUK/
Mg7xYltPGHSdbHs7qYojUjZZcj88wPOyW2bbGRW88nxLlBqbB0jlbLgx/EMB
81vy9TmSXCBtpFtOPfQYPl4d5Thb7QxG8laf+XbJo+TOpYfXB53gWNkevr/X
j+L+DON/pdzX4JutVcg2GRks0njuWS3vCCW75EO3LhzGYb8ijSpjB0jbcln3
pukBNGVvu3Mnyw68Pync+HtIClmeqHZ5UK/CF82rHKY796FHSeL7s+NXYB/v
Fv2G43txMHZFd2qnLbiJtYk3XBNB9TEjywIlGyB18VwQuSKEFjcl3120sAYd
U/uIBywCKP+iuMBK2QK6y1T1I8R48YeS8C/KrcvQ/nz9D5czF+oeYYVpNIUq
jwYj8ykOPMs1pMa+wQTKdL7btm5kRR3diUeyasYQKHSvXa6YCS+o3wnTDzeC
lNxH5nvzGfGKtYmG9WND2LBi9TpmgQGntxX2X9t8Hg4u69KHtFfaswzudozG
60N7iy9rrN1iu6J6UUQ/mw50NUVNKSrMt2e18TtQk87AyVdpc8+CP7ZXJY79
yN5xGmxVxM1016baz4fX3vdMUwWumyfnWV4Ntf8Z+XMsQvoEBBZLa/QKdbbb
HNqeJHBEFrY23OrOjqtq/6WbMK3rIAm6FYf5XdTD2rcFKaQ3TnLD+w8ygYcM
rqv4X/0qGqiyqsLgzhPEV0xSiS2okG8NEYGQ0bVh/9dtKoFn9o5n3jwMctou
Ense9qsUqE4cl6EeA82/nUwvOcdVcvbKrSXUK4NBFl9vxst3KrLiiXt+mKhB
z8yTa5psX1V0T1gncI1qQJXDzY6l8Z8q9s6Ta1IXtaDC9g5rt90flU+mye5y
Q7rgcFWcK7N0TWU2DN2zJc+BYf3u2SPPNwJ7o2FpysfzUBgX6cFZtgV+hl0y
iyi5ACWDh6QdJ5jh6btVORe7izCwX51d3okdwnXxiLbYJXjJPEbh7+MGq+O5
cZ+KzEDp966linw+qD3gG1xmbQ4RaX8bVnIFIfrJ2BtzIUvI16jyeZUkDNtS
bTMN+q2hW/DThQQjUYiUGaWkP7SB19kj5QKHxYBS0sr9Mt4W/D+3M1MlJWEk
QVH1uM5VULN50NhzZj+camHgsthvB5zDCuI1QdKQopDl5bfNHiLXt3auZxyB
jNRMxuSnDvCO6YLOiefyoPsnZExF3Rm23R/hMDNTAIad21N+yblASl3l6Lsf
x6H81cf2XAlXOHtwPu6olhJsdI4Jbt3mDr+Yz6gaPTsFBhfvruQ5eEK/+DmR
jU/VIPHE9qFj057gyPvzn02XOnT5ang+NfEC4Ty/FNkpDZDVjGF5pnUdBm7w
zbFZaMM9tpuzlw/4wNEhPhHFBB3Y/ULmCIXkA/0aF9w4HuuCK88nnXc7fYHd
4PTZxxoGcPRj0Hbl7TdgsFrUK1PXEL7kkWetvvqBofznu5VgAva7nu44WB4I
Fz67yDGymoKzbXRNiUgQcD/3eXzvtSls0ZvW4swOgmklCYaZ6MvwbMXWqSnq
FgxOa2/j2WoFNv+pTO09GgJfg4u15s5dgZKPClGCrGGw752wAOPgFZgNvNRw
7mwYvNjCc6PNiJgL0lO+QeFhkDrJ+98uKztw4YyVaV4Og3tZKdFRUQ5gFaYm
2/YhHGJLWe73S7jAvIvhWH/LbbBp5z9W2OgCbmmiOb4/b0P7RuaVCS1XYGrj
COGWioSxkhviyV5usHBwl/HRjEgQrtY+5+PkAaeMOwIW3KPA+p9L1Z3vXnAh
2+6Yr0gMHD7/zu+E2nV4clex1ftSDFy+KiqXlXEdcizsphwSYoCf9Ps/51Pe
8LTPMP/AcgwM+ozXut/1gXURVyOJ57HQylu61BnoBxsqJjOGAuJB/ZM0W8KE
H9id/0TmqI6H4GmnVMaTN8H/fWS/6kw8dO1h0WJcvQkNpSzc/ucSoGEH6emp
yABQTwh4pieWCPMD87LxLbcgaFOToV33HbjCRHPe9jIM/lF1Jy9FJMPh93Yv
pLnC4cUL7b7jhckw2HXesM4wHGaNxD05WpPBmKNu59xgOHieW8kgLSRD1vmH
jBxjEXBm8z/6JdsUWLrWNTf9KxI+lM/0ziqnwiWXJ/ldN+Jg6WA2t/G3NHjJ
196zvyMO3kiYafzYmg6vrJu8vrLFA/n8IctQ0XQY8+pKSiiNhzx9NY6QS+nw
4OB0ktrrBFi+cmNukZYO/5nkr0kdTIKST9vsGpMzoDvgv7d/n6WAuXVj5eH9
WaD77wZ31VIKVLHMV4+qZYGMOSM1STQVUm94mV+/nAXzx9vXh/xS4Qd3+s3b
8VkQLrTAaL0vDS5u5Anm+p4Fy1Jn/tyMTwe7mF2szyqy4e/Nxy94fLMAjWRm
TCVyoZNl8hBrSRb4M741slLOhc/Ud2IHR7KgkPTmg7FRLuwJP3dz5lg2fNzo
obwrLBc0TF5+Ovk3G+I/+UevTebCf1V7mS9H54LaGeFJvqQ8YJcbSamlF8DY
NpHPBl/y4QQt+crqzwLgXvonz7eeDzo9Z2rsxO7ClUpx5Rc7CmB07wfv7Ki7
MOhmabz7RAFM4VgBfV8h3CirbeKOLoCU8I3pJT8LIUuv5pqfyF1g3W5Suz2t
GIZ/9L34SpwvKJHlDqSKYrB9TR5aOFgIAmEbv5/tLgYRz5yHC8cKwf1Xzina
WjFccFx89fpsIexLv9hs6UQCpxuL5MsuhcBx/EjRudNkkN/nE71cXQivTEpV
6zeWgNR7vzfFCkWw59Ap9BYpgYP2RYIuqkXwvT7zrbpqCVgKhZpLaxXBS9Ut
Ixy3SkCXvDKVbFYE3atNlCt/S0B/4afzfGAR5L38mfFmsRSOBeV0LWERXDxV
Ite4dA/+rugIckIxqDcfz9DhL4cRN2p+jWYx+LR23vl2vBw6NIdztfWLgfHz
EKOZfzn8/dmybGFRDFmz2qxD/8qhR/7oGGdAMbD1Legc2/oAjkrvXy+vK4bH
/2pEz+ytgEe8kfMxwiQQ3bJ9QkK9AlL+Zi1GSpBgdcj2NseVCjj48oJOgDQJ
9DdJ3dhAqgBfE+HXWsdJIBT1U9VkbyXYyD48e8uABOeN/rrP7KiCU1K78VQg
CeT442+J7q2CJx+tA2tCSTCrnct5RbYKnHpOWAtGkUB3TLb0x4Uq2KW5mjKQ
TILiVLN29fQqyNrd6TBAnKf1k2e21/NXg1zIzIzoAAkGViKn5KWq4dohK6bN
L0lwVP1Be7NiNSxL5h58M0aCXaejIp6bVYOCXpm/z1vi+uzx5gfyq6HAROKt
wiLx9wPHKzJFa8C8Qmp9mwAZ4tNnjHiP1MI1TR+ll6ZkOJRU8KBOtRYOdJx9
HWxBhqqi4wzG52thjXIzT9SGDOMfqUFFXrXgTh3z0HMkw1XeUMbL9bXQNDag
d9yXDAn3iofPn6yD4o20ZpskMnH/YQ7YpVsHIbvUy26lkoFRdq7ks3kdjDA3
3U3JIMPwmzHvuFt1EBNiXno3jwzlyc07v9LrQCV5aFGvjAzmnMf379SqB9L5
LM+/bcTzV215ymxWDxJznHZR//s8x+y796pTPcQPcOqzdJDhbUXlzIf4esj0
jllZekoGDedYo+fP62GGI6/w6gsyuPhVPxj4rx6qI+N23RsiA0kPJp7/rIdk
397w98NkmDp0rGCMuwGOTouwq46T4fTpzd9XTRrA1N55MeYtGW68Mz/A7NQA
T0NCym6/J8OeH52bBAIaQKd4TNlvhrie6pTDyfwGOKLiwKo2SwbVbbUHUv5r
gLqalKOOP4jr3xD0uP+zAXinjGYFF8iwIkblerKpETqzI0Ie/yL2Q6LSbF28
ER78O6W5ukSGUuGNvKFOjfDGpFtq7R8ZsiPb5gSCGuGhZbxI5DoZHN26heru
NIKY3xWjTRsoMJibYf61rhHufB53fL2JAj59isaxTxtBo+OU1onNFOAz/REs
Nd4IknVatvFbKBBgbKPsvN4If950n+TYRgHNupU21h1NUJLDtHKKmQJHT7ud
rRZrgs2ePvOOLBRwG7xrtKLVBJc87QMyWCkw2qraUWTeBKy7q9nz2SjgVR3E
o+XeBEszDaNZ7BTwTr6jkpPWBN/GQhg8OCnw0VFz4+nSJmgOY7HW2UGBclGL
8O/UJlDVfzO/k4sCT+tON2U/awKrQPOa/wjr8bhlakw1wR+9z6Q8bgoondDm
+/mjCb5u+vRYl4cCGQLah+4yUmH3VAv3T8LtU34rf6Wo0MDkobKLjwI5NTEF
95So8N8YL18R4TW+sBoTAyr0vRDatZOfAoubhw4y2VLBVO67bizhBK9vW5q8
qeB46kPZd8KPLqjJOUZR4ZWi4+GzAhQovKv2gD+HCncsx6cyCMvpWtl1P6CC
03wBdZywv8E2Y3+kgs4RgVYuQQowevt6Hxikgmd5z8wpwl6dPQ2T76mwFjet
aEeYfdd1rsQlKrwQ6agPIsyaMBkCzM2gTh83+9/n53cPei/O72qGCrwjlUj4
845Sh+LDzeDqpS0aSXi34du+C2rNMHrousZ1wm4MqXs2X2yGs9peqRcJb5aV
ONfg0Az8glXbDxJmXmcydfBvBtJCWvUysd6qm2WH+ROaQVU6JqyFsFSTZ0/X
3WbQFlgM9iJ8d+CF0M2aZtjJcap8D+Hjw/ISUp3NwGI/vIFG7M/+N8wvx0ab
wddDMMqYMGW9TSh6thnqIvxOvCX2e0i/df3Yv2YQ/nNp1xXCk9NeTh/YW2CH
sMjBV7wU+Nmjb5wq2gIfziu5niasLdpGVZVvgZ9vOV+TiXpuXt0f9+1MC6RK
Mgf9Jepv7LqZnm3WAiJ+CXoahG8618nOB7eAa+xIaDPRT0WiVyxyUlrgzZLL
zHui3wSfHO1Up7QA+fHhIEbCRRKfJdN6WiDlxYTaXqI/D90tlNvP0wo9bAon
poh+vzKcU58g0QoDP06WPyXyUF1aozOv0AoKPhb1JUwUUI0Qzqoxa4WzF7QK
zhL5MVH9rLLDpRUYpNoCWYh8HVqtm/AIaoVj6YVLj4n8PR85Mba/kPj/fdse
7/zf5+ulDpKR1a3A3qXASyXy6zURaDD9qBXCFiW36K2Robe3VkPxZStwu8qk
ja6SweaFxqbkD62g/5VCM1khg5CGS8jH361Qf2Qi7vkyGeaCreuVmNpgcEn8
t8ofMtSNX85JEmiDA+vj66TfZIieCj7ydn8bMO6NmHP5SoaDbxezhZXa4GXP
7qaYfjL8elZ+RlOvDSyzw5Xzq8iw6y6/0xn3Nnh74Xl0mTcZZMkHOoRq2mDM
LOLX+VUSuJX0fBCVbYef4Z0f/m4jASXqmd+gWjv83rC8K+ZLMZR9LH7taNgO
MxmK79j6ikFiZMOKlmc7BPf4XN6QVAxVT4fbJh+2Q+HA47BwnmKI5Fw+C6II
jYcXsrYKFUGh4grPsyUk3i94H35jUgCcYor+5Rtp4KDt6tbLXQBHvfvLrLbR
YJuwzruy5/kgtq9fPo+XBsL3Cv/Jnc2Hr+TL9y2O0IC19P1k+rE8kHY12b5u
TYOYCf3ybI4c2DfUOdJnT4P1x4m8ub3ZYOS5UTrBhQbjrOQ/iZHZQFNqdXp9
gwY7FrUq9VezYLPF73cdCTQ4cNfmtczHTOiq1ZUraSDWk+D3r6Q5HX6Ob9UN
bKGB4anQZ9Pe6VD1bucjNRoNoNHchP1wOkRpO2FhNw0+0x0VdUhp0HrKllo4
QYP7alNianGp0KhVcmt5igavF6PeiGukwvUL3olq72mgkvbAf32NeF+rKh5B
+UqD4ruKX9O8UmDUffROxSoN/uSSUdc0GUj3511jGOigtKUr9d2OZKgwF480
YqRDVH6Jp+ezJNip9cu8hYUOTJcK3nhBEoBPhUuvAB3YJNy4RLQTgeWdgvPC
UToUeapxVb6OgRsPzOYL5engMcB3WsM0Bkac7fNUj9Mh2und+MDLaGhNu33V
WJkO16f3HOzojQKfbaupE5p0UAzx3CpFvQ1Nq8GHBbXocPSWOss1uduQ6hv5
SVuHDmNdiWZ3KyNgUMe5IsyADqEeKv1zlHBI585317lEh3WpUw8kUkIhWJ9h
UtCUDr6N45VCrKFg0f/LctKMDg3rXh84okPgxs8iirwlcb2iHfXUlVuwhG8d
+qzowKX2Z5/HjyD4Lt6pfMmGDol+FTP8HwPhGWuwyKmrdMh7bHVYfdAfFpve
HCyyo4O50+mHnU9vwi6Dee0Fezoc7HxmqdTmBzOJinWu1+hAo+aeZirzhT6b
5bV0JzrYvOt1scz3gTMvOoyrnOlwTPZaZXmKN6wtvN3X4koHfn0d+31BXiAx
KFh0340OjxpkB0y8PGF7j614ojsd/i4lKoY5eEBWV02drQcd5Fjc4SzVDWqa
NxpIedLhUxn7nyCSC3FO0/71H2GmmrrkkgQnkD0YRo73Il4PO9eGjhuO4BRV
ZCV1ndif8qkTL23s4UV0oXgTYZrzgOyEzlUw2HPj93FvOlgqZU6PydtCv9zu
wfuEjTZ/le8XsgZ5amwThw9RX+vN5/24zMElq/GeA+F4LWGzMx8vgTnmUqoI
H89O8WBpuQDfBA8/+EJYVSN+JX63AWzNutbG70uHJCetkV+PNSF1r/orBcIe
ydbR5DEluFleu36WcCGboTVZXxKKBWqP6BJm2FzzildyB/6yUHQ59b/HW5pu
Xz4pj6ZXVWokCU/LMT+78FsNqQLNGzcS9hP6uveHvg7+cyJb9BHXTzk5ukIb
Oo8sGouPYgkH9quc2MBgjP1p5KMnCKssPrqiIG2G0mfKH0wQr/fT6+VEGxNL
ZNdaO+JOWHVC6bOKmg1aRmXhL2K/Pl90EdUwuYIb5zxMXAjL3jC+peZmh+9c
gleGif2OuKjJdCzCAWe/tZTJEFbZGtW7J+caMj0sEEGifhKn9x141umKaSam
gotEfdcWTVz5X7jj8fvTpbsJa6u9uXjguwcqDh0L1ST6Q3tCn2647IWmnw70
abrQocpWSHx87Tpe2DlUoUj0UxlXXaMJow9GNrceW3Ik+vWQ0l1F9huYk0F/
Q3cg6ttwnD2X2w9PePwTCib6lUZmef9D4Ca+XCnwfHGFDg+/a/4MEgvAcykH
nIYt6DA7lbJzk2IwVvjF/pIzp8PVPTYZG4RCcH3nfqEoIk/ySr5R/kUhKHWz
ymQTkb+qdyIqxiWhmHA/wOcykU+2+vbmispwtM0MEzynR+S/KvTxnEwEJq8P
2SsQeY6+9PLrvroILBOb+POayL/mE5m6wKbbeH9q1844Yj7UL2+fqKZF4b5n
Alw8J+ngKZaQQVGLRptfTtRkYp4wKFSWJD6OxkejidxXZOnQKvN2CrpicBdT
8G57STo0nVO/zj8Qhy7zWHhbnA48CTuSq87F4/SQ5atMUaL/vqUrKg3G4+f/
dNzSdhH1lW89fXA4Ab0PyRt8Z6eDj57BL/fxO/hP/GYxaTsxj+SvcgwcTEJW
eb1GnW3EvPz0ZauVWxKy72iX9t5Ihz1BjPuvzSXhJ043P4lfNDhE8hDb+yMZ
JQNshHcM0+DJzxk1noVU3GPSHJnznAala2oxOcfTMNog4SbXM2IeKx825bmV
hj+eVrKOPiLuR1fqNn9hSscqX+3DlEoamOZeLNqxJwNDoxcMrSKJ+4cjr62s
ZhYGTWUl/QihwR2edWuGuCx0+7sz2DuABrHGbPdoA1kosEIJ0PUg5v8ltUhB
02xkb004r2FKg2slrwoOO+fg6S/P7S0kacB0MzmTFp+HR79d1lgVIe4f3y0e
Vj/Pw5M9DczxO2mwNcJ+PJU7H+f/s7t0i40G211ef9ufl486JycrzD8iGFee
FCssL8A/nzOeB/kiPN7YwXbathCvHqAw+95qh5avXmMPfIrRJmbcm8e9HeL1
q25eSSvGI/ubruRatQP/9tfNnLXFmCD89YuZajsw2M99MJovRgHjBtd7DO3g
IHHFwtuJhHGqDx8HzbeB41Jk4Ew0CU01dV8dn24Dmxb3PoNSEuolbSRS2QaT
H/37tr4noX/qgFdsYBvIX333mMWCjGX9kbfSndvgvGXOvHwAGTv/fQiJMmuD
pLdfpoyzydi3kzXUWqsN1kg7brs1knFy765I4eNt4HVRazBwmIwbOWUzn0q0
wdC9HmroAhk9+r/OW/G0wawL9+ttS2SUuPd+9femNth8LdqX/IeMaiFtTfE/
W4GNop8r/5eMTy/cEBP5rxW2iDjotK2QkXPcSL9uoBXgUvrtk//IuDz0nmX0
QSsop/Gm7WSgoHaZZQebQyukBS2zOm2mYKAd27/si63g/DhylbKFgrmDqwfE
TrfCQWMWz7GtFEypXkyWF2kFhzizz8LMFNxySGOilb0VqubGvhxjoeDRZjKo
r7WAXlWtp/p2Cn7j3XNLb6IF9nR9YFRloyDfz0CnF90tIDY9z3GEnYIyP30y
jJqIx0cwn5eDgh6+tBcm6S2Q+JpD4SknBWlPan6+Cm8BlxFXteQdFBwV5/c0
82qBH/GJfee5KPgneXuxqUELqAll2jZwU7BL0PbqmHILGP/scTbjoSDjmF+x
sXQLTHuULPwiHLJV7upLwRa4nTGwfJuXgoc++laf39YCny2/BrHyUXCxTiyl
f4k4z3QWB8cRbq8QZtOZaQb/J1lr64Q9dugffPqyGebMvf868VNwYXfSklpH
M1RHTHg9Iyx/9Jl3e3UzLDrmOvzv+x3ThxYeKBY2w/WNRq+I8wre2fSttC6x
GXbZbuhqJJz+4K7r4aBmWH8ZILtA+KzEj83lzs2wvyx3p7ggBVddnvqJmTXD
A0nFED3Cm4OY+gvONkMaSdrGhXCTYQ6rgEIz/LDTbw8lLCvXOr9TrBmC2p5J
EOcxLGhu7tvD2QzNUj62//u+S982UoXIGhVuifN43iZcrxGWL/aFCgUH/A09
CItR7Mn7xqjwpJFv6znCOV8t+/Z3UiHvRcMdMcKzD/xED9VQ4c8D+6/fiPUW
+tAfytylwsQz+d0P/vd9nRHNm/LxVDhTd1TUinCxJe8dxZtUUJ5xXtlCeFeB
8rKyPRVoH+bKSMR+mYv10NUuEOdL+b798oRXQrp/nlGlgpfpjtAWYr8T1bUy
9A5SgTTUd/8YYe5Pf8zNtlLB7OyvWyxE/YTIMmk2v5og/MbSPjuiviVuLPbX
/muC+4fLSmqJftim0rshoKUJ1KWM9h0m+uVoT+dURFkTDNt47Dcn+inpemzI
nfQmqOQM3HyL6Lcs6dyjpe5NENJJ0igk+jOnY+VSnXkT5NKm7xcS/RscaeD4
SKsJNEQMvqazUjC7YNnzv71NELdh45ol0f+bgm+oSY81whQ9wduZyM+niaSx
U52NYO+6t3UHkS/2sLl7JjWNwHLZ7W3FJgo+bqJIxMY3wu9Zu75OIo+hNt/u
/lNthPMGS9JuRJ7z/qpI7jnUCGbstQGtRN5b/BtOqu5sBOfRy5Xrv4k8l2+Q
jllsgBy5j91XiXlRJOmldbi8Aep5mL7c+0LGIWNzNYvMBshgMgi5+5mMW21P
8SZENIC1q+Om2I9ktI+d8f1p2QB5p26PKr8jo2zIFtlhrgY4uzV2RHicjCNj
a7qbbtXDY2UP6eFOMr74bNJT7lwPpal66xIdZPwy5V5uZFoPsx8fKrrRyMjm
fKypUq4ePo/Ozk42k/FizBB7xJc6mPqy6niykozfzjRPPjStgztpzcJr6WTU
bzH/GHymDiro2ntKU8j4/KncrJF8HcTaHMnVuEPGAiXuf1s560CcW03wSjQZ
qzv9TFO7aqE/TeWqsD8Zz5nkrGoer4X7ld2vKZfJyCR5d1xXohZ631GaSi+R
8b2a5Glj7loQdfolc/cCGR0eFL25Pl8DjlEtW911yBgcKCE7UVYD/z42+qac
IOZn1ZKhrWANsClUq8/ykjFRy6Y9maEaJCJo1t+fkpDE9XhEc74KSJLRZps6
SMjYtMbAMF0F+ueT4tjbSSj4T6/0FlbBvf+88lnrSMjgl76h4lYVKE0vPim8
S0LNi4XKDSuVkGybc1Xch4QHKI78p9YfwofP6Q5UARLOLK0d6p16CAUJEVLN
XCT8OOZ8yIr2EJ5oKV7/vwbrxB8KhA3guJwVHc5i06DLIiOJbM08ibStSDmj
CQ3GFUnuM4Qxkts0MxgjZ8gSCePZSnJ38JG1jlw1jm0d775Jqe2f+H1/tVuK
sEzFV6X4ZhX8xRcro28owrnnOZQK0SoYDSoYfSPgobjoFLdEqhIWRLHyTT0P
HXwC6tv3VkDrPa1+9hkeDramXiGIVsDQa//7a0Y//Dv/ovHWVDn0DmR9PfcL
D9tUporCeeWgIDaiOKbBw+7RTWe3qpaDX6VJXZIkD9ttDfJHVcrAT0hrVam7
EB/yXWRZmiXQu/Yo0dK4EFm9M0EdUiUgvUwJSvilEM961jLFPxYD18TEre5Q
IdZL8mxqa4pBQCPZLRMKMfSaiVenfjG0cF7Lin3loob9RLmI6T1Q8NlAjK3l
olH20Ii8Pw9AImL2604uyrcXHDppy4OLB8VvtG3jYvTWDcuRx3ggqd1eFS/O
xeGggZk94jxI6YqNGftQgPNeweManELQvtPYPMwpwNvaX0yJ3VwoCfn9qZpo
ARqpdma0e+XD0MB+X2JHHgpuXbY5YJgPTr7R9C91eTgV5T9ULpEP1eEiKk0F
eai2KBMpV5wHggHi5NbgPLy3x647doIDO5oSHu7Yl4dsNaruW2c2vKobv18d
xcGKPMbd5VAmGOWet9VXZ6O65eL+u+ZM6F7fsuuNDBsjg2YfXVFlQj3DXfLK
OgsXKC6HnTpzwUf+b8blNyzssp549F0pFwZLbXd0h7Pwusac7mJbNmxkrfmF
9dxF5qxCirReJuSIPKQFujFxqdzckiSVCY8pIm1lFkwMCfOjpk5nQNuu3ujX
BkyUzI9o5mZngHzWGElkMxO3Hvwkn/Q5Hc4tOS8IqnJxzR5Sr3WkgU0dYfD5
Sg6OH3BQOyF+Gwj5Wg5SIdmo+Ir3E6kpBUyaYhtXKNlYZdn8NMc3BShsmR2v
jLMxpHlDjfMQAypN3SQ9tmXj9OWru61qkoEbFmmhUJKF3j9tkuj3T4JQlTrN
kNeZeL4U3Ss1k2C4yHypviET+XdGu6ZnEuGtzdH0WXYmKtj9eyTAMRFE38Xl
6LpnooZA+cFmswS43s7SM1/LwKh4f47J8XgINvJ+VKOSgd/4m+IIX+MgWW42
9YJYBh51Fil0bIkDqyXcPT+bjgxW9NdPpDhYHe7iCtWlo85mSlzbqVjo+/HO
rSbpuHP+4eUXtBiQpn5YynRPwxe9J0PSF0Lh07zHstSvtzH5pn3nIiMUSBfa
nojI3kZBz749QlqhYP+SE/f3aAqWHR6PIPqGgKBp+wlWQApOzi0wBtaCQH3/
21OO+QxMM/c/ZHvkBuQ8vdGftkRH6mSGYft4ACx4HdJ72kzHtMsZ/oLkAGgR
+i4luEVHuZEna8ZT12FKXy9JWomOtGzhI44cf/jG/tNizCgJ9fO2t1k6+8JY
a4n3jTsJuHDMc1tu91V4ts54tGqfgEpqehKmR69Coi5hQ4BaAspSLbaNy/vA
E2z4eKb+FnZsHpAQm/SEGoPI0bjhePyHsbvnUqsbLMp8syPticMFzf8pW5xw
gyLfEYHWQizuS1n2qHzmCswOsXXZ+liM1Mxdr+mjgvNj7vZO01hUNMTSiX9d
QInSlfra8yYuDm3MU5WhwD1/e+LUpWh0IW50ktS6BLUvq7VG30Who/AsLfmM
IzwztJx77hqFHyzEVs/cuQi751ZaXH0i8aCgqH74lC0c6j1OGQ8Lx+G4igth
ETagw/Jcs/0WhqtC3+m1DdZwYOZdPN4Mw+b+0/4fj1iB2APtENekUPQ8Yd1e
4GQJ/D3PA8Wyg3EuL7mO4H4OJFaeKUntDEY5s4l6AzkLOFsnNSzGDsLkRnuu
TIIZfG79wu/nBmLWfXdrxh+mwJLra3x3PwD1pKbzjQpPgXUYqzdROwDdOqq9
9ekmkGhc8/Pe36/j+wbm+JjvSYhtNOgjNfgjf9AnKUaNBMmfbT+sRvvhWucW
v3W7YxAx7zVcEe+Ld3T+tBPiGMKE5dofZvSrSAh2obLO6UM/jcq+lOGNVm5v
C3RRD8Kky8t6c7xQZmZW2op0GMYIJ0eIbE+8UGvbpe2mAwJ709nOIhrq7Rqw
HlTWhqpw5RHhMncMIu78QE3VBNcVgjqx0g1/44wInrTvB/7LqG/Uh1T0kHnJ
yErdC+Fap3lXG6/gwK5ntJgANaD2ybzxaXHBlFPqVMuflSGlYIc0J8kJawLb
i3sKFaHJ4rfzV9IoWAI66vHWClDmcXjbTqYjzvDfKocayYL7NNm1teAiOkoS
m6o8tsOXxiFP21I7pKVYuvyaJQmZ4z6GE9U2WC3v7cnvFgdzS9qCU4MV0ubT
V1qDhcFYRI/Tzz+PPWkXenk662Tjqci2sORzP/qvYbXs8H/y+72CB8fvmqH3
zA3TQN9FcsLjqIP/lJ7GsY7lWY/B9+TITMVrWQ3G6NAvXDtpMkoWNlW1oSQD
mqmaz2vEviJn1QQTYkoNkKR49y/9TD75RU7PGU06EVvkhHC6L5/s2RWgRU8g
oM/4Pt3JBw7kaea1BxGjgeT/AFjnW2s=
             "]]}}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"3 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"5 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )], ",", 
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJw9l3k4Vc//wLnXFsl6nUL27LJnSWas1+7aSiXqFiGRQooIkaUia6QiZEuh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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJw9l3k8VN//x2fGFsJQH0YiO9mXtFnOIcvIaCZFtkqhlKiUSpYkZN/JWiKS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             "]]}}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"3 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"5 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )], ",", 
     TemplateBox[{GraphicsBox[{
         GraphicsComplexBox[CompressedData["
1:eJxV1AkwVHEcB/AXbXYcybPWtdvuWiHHLq2xEaEcUU1jo2YidGBoTW1Scsx0
aHW5m9lioiREjHJkarSzru2QRFEaOSqjspGjxGg6Zvx+05t58+Yz/+/7/X/v
///P4+w9KIpQIwgi/M/99zmQMpRdSM9bT/y7JtyLd5D7p1W97otOKp8olI2P
guuPSb7qSyfBp6Lv/JqMnwWfVF9nUDzyCywgbvqVHlHzWPRD0YsLEfUU8JT2
kM/4KBWcl1BTF/9BCxzcUG4ZwdYFKwPvlpSRemCnJUuOpqaT4GrD4bZLVjTw
e2mxhFtmADYP/3l1xNcQ7KySS3UHjRYtp3ZHPa4PMQG/NytKz/lpCk542lgx
lsgEG787sDmJwQJv6mrtFgazwQN72ngSEw44xSLrScsn9DGZf+7OCjNwyLCb
CzOaC/357p3jLDiZgzMzSp0YP9D948yLQcpVYAObZ3JFrgW4nIxlx4oswd78
HsUajhXYbZafJRxGs/KbXA8WrgZT41ZaK8TW0N/WHzFeIlsb8JXqE4UL82hP
eprlaKMtuDuoLZ2SbAcWP+lwdPPngfd8UVJrNfng3Z7nmd5v0UUNG84uDbQH
t5SsNZLWoKP5uY9opg5g1+WRus1JaMquoNbzfegAj1v5YZ5rwE+T46mB19EF
b27vkmgLwE3bkinfVUo4z6lTHRqUBDqsT1VJCDmvj+eHPahvta/AGDwXquJl
+JuBP7u2RLpowv7KRWYMnk4n7neV3/HIbg9cf1raIYHRMlh/d+s6r3vn2nE/
HG2y7wz3YP/R6javJyrxfNvHaCw86sP5TbKNG5q7sP60X8YWSiL2f0P3ZGeF
M/azPEVZJXbG+docyAdfErG+T0mR6RQH83pqDEkTC/vVfrVxZmYQ8nLieNiZ
/QGY15o9PEbfjvUvSwQKOh3Hc7x8RCoS67mI70XGKbHedJ/e0ed2mM+Sf8uU
2WK+363zdMIc5j1753OtVmC+Syhh3b2P39M5KCXsLPD9ca0DX5cyMH/j2kKl
40ust60ghKUmwDxdMzzFQQfzBcyOpIBarD/BK+1t52NeXCwrZ+ljfpmI1kwq
MF+lQ0YJnTDPHvhI29iyOE4QJ7jkZJ0WFxzaOqbZJbQG//9/J4j/zzdB/Aac
UL8q
          "], {{{
             EdgeForm[], 
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{93, 92, 76, 84, 71, 79, 53, 65, 17, 54, 18, 19, 
                20, 21, 22, 23, 24, 55, 25, 63, 56}}], 
               
               PolygonBox[{{50, 96, 94, 67, 73, 35, 60, 36, 37, 38, 39, 40, 
                41, 42, 43, 44, 45, 46, 47, 48, 49, 61}}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[0.368417, 0.506779, 0.709798], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               PolygonBox[{{1, 95, 92, 90, 81, 87, 62, 68, 16, 52, 15, 14, 13,
                 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 51}}], 
               
               PolygonBox[{{93, 94, 91, 85, 88, 78, 82, 70, 75, 59, 64, 34, 
                58, 33, 32, 31, 30, 29, 28, 27, 57, 26, 72, 66, 77, 69, 83, 
                74, 89, 80, 86}}]}]}, {}, {}}, {{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[1.6]], 
             
             LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 
              52, 16, 68, 62, 87, 81, 90, 92, 76, 84, 71, 79, 53, 65, 17, 54, 
              18, 19, 20, 21, 22, 23, 24, 55, 25, 63, 56, 93, 86, 80, 89, 74, 
              83, 69, 77, 66, 72, 26, 57, 27, 28, 29, 30, 31, 32, 33, 58, 34, 
              64, 59, 75, 70, 82, 78, 88, 85, 91, 94, 67, 73, 35, 60, 36, 37, 
              38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 61, 50}]}}}], 
         GraphicsComplexBox[CompressedData["
1:eJxV1QlMk2cYB/BPxijUAEVROYSNcWmRCi2OZTBbaAa4ssiKIArEQmEqDBqw
OC5LOGQCGWESxTquAjOygV1wFKgg1nFfCuEaFIRRkaFCKYji2NyR8DyxSdP8
ku/7P//vfd+2VuECbqQWQRCp/77/+yS4d6w3HxQfJv5/qZnCRU7D9zETzC23
KiS9trlPwTo2Xgy3hDXwATEtv/+dP8HsF6zbXMo21pb5vnY9m2Ha4BIjRVn3
axJ4VLArtTdjOzgj1TZz+4ABuColwcbVyWjLrSyKrJg0uQMcEud/Lf6CMfhi
Dmc1lr0b/CRRwic/3QMOfI/LcJWZQv6nl09l/51oDo5R9ixFWFiAK6YKZCGP
LcG6wRPdSd7vgzsqTBf0aVbgX/1IPgLKB+DQxUp6+Rxa9Oh5n7jLGux2b34l
vNQG/BEpP2hDYAt9m6t/jw3ytwMrXecNv7G3B2daFfFE+vvAUXHrGs9l9PMa
bcqYYj/4JfueknGDCi7poLrwUhwwT8ruP+F7AKxe1du996AjeMM67Y9aLRr0
zZFKvtJdQNfbnUum3z0IpmRsqIx9nPB6ywLVWhN60ElU7W7jjM+n9uw4U4Qm
qaYzU3TpYOLzIZ31OHQzv3j2mArtrW5JNz/KAGuksvtdDWieRXbwyf0u4GKi
tsm/EC2+4+JbrncI/HMNJ6skpgfP+/mStOh9+tBfs1f7XCmHgm6/wit7F8/n
h+nnf3Lfg+fPsi+pt/yhCXhgfFx5vcgM7lcejTolYuB5kPM/tqWR4Dwwk4Ma
527O4vmQD95Ykbfgfq3ltb1RXYP9YirOUhyCE3B/fB+2qbTTcf1r7UmdJsvg
1tGCmYahUFx/s2m1VvIArg9j8qpLVZ0h3J9R8W3RSCg+z+vvCvK6hrC/hvkk
l4jAPuaVvSPZwzif09fcu9gC69cqfxH5JpoN38/WpEOqu4Vu+LzrYxJhdz/m
MWs8G3/Uw74r4kS//CN4XodmHKc+6cR5pUJeWVsW7tezGUGkDhnnXfc11PCs
cN7q44D2eBHOi4g8O/BgFtfrlbXpK8pL7H+JHCIeTMXflyDLpryOAMxTe3kw
AtyxX5cPPcf5DPahjlfleRvj9awsM67DJPa3IsL6LHnYV/NMGtMZiHnC8vz6
4xLMIyuSgpJpmHfJq/Ez4QL2XzY+/mWWGPtqSgTjcn28/tbO1Z2/jeH8peS5
yPYvcH482/gR1Q/n5+R+TTUoxPnhOyYOD5th3tCaR8GFaZx/7OI0PTEW58df
5WzyQzGPJ/uBJZFi3igxIhKSMS/HnRY3rMR+8vtlaZzTmFen+OuXXScxL8rB
LCX1JuYZuJHp24wwz7w2QGo3g/2WvC3mqxIwjx4tZtfxMC/Qw1mnQ4b7P5kS
Xcm4vWWCiA0j7Or5pmCfOhJ3UNcWfDmAdfpEuCP4lkkjUT3lBH77/5kg3v59
Ioh/AHlUVuQ=
          "], {{{
             EdgeForm[], 
             Directive[
              RGBColor[0.880722, 0.611041, 0.142051], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{119, 118, 117, 73, 85, 11, 54, 12, 13, 14, 55, 15,
                 69, 56, 81, 74, 100, 92}}], 
               
               PolygonBox[{{50, 124, 122, 104, 114, 84, 96, 65, 77, 41, 66, 
                42, 43, 44, 45, 46, 47, 48, 49, 67}}], 
               
               PolygonBox[{{121, 120, 108, 98, 113, 90, 103, 82, 95, 75, 87, 
                26, 60, 27, 28, 29, 30, 31, 32, 33, 34, 61, 35, 88, 78, 101, 
                93, 111, 106, 116}}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[0.880722, 0.611041, 0.142051], 
              Opacity[0.2]], 
             GraphicsGroupBox[{
               
               PolygonBox[{{121, 122, 109, 91, 99, 72, 79, 40, 64, 39, 38, 37,
                 63, 36, 76, 62, 83, 71}}], 
               
               PolygonBox[{{119, 120, 59, 70, 25, 58, 24, 23, 22, 21, 20, 19, 
                18, 17, 57, 16, 97, 86, 115, 105, 110}}], 
               
               PolygonBox[{{1, 123, 118, 107, 112, 94, 102, 80, 89, 53, 68, 
                10, 52, 9, 8, 7, 6, 5, 4, 3, 2, 51}}]}]}, {}, {}}, {{}, {}, {
             Directive[
              Opacity[1.], 
              RGBColor[0.880722, 0.611041, 0.142051], 
              AbsoluteThickness[1.6]], 
             
             LineBox[{1, 51, 2, 3, 4, 5, 6, 7, 8, 9, 52, 10, 68, 53, 89, 80, 
              102, 94, 112, 107, 118, 117, 73, 85, 11, 54, 12, 13, 14, 55, 15,
               69, 56, 81, 74, 100, 92, 119, 110, 105, 115, 86, 97, 16, 57, 
              17, 18, 19, 20, 21, 22, 23, 24, 58, 25, 70, 59, 120, 108, 98, 
              113, 90, 103, 82, 95, 75, 87, 26, 60, 27, 28, 29, 30, 31, 32, 
              33, 34, 61, 35, 88, 78, 101, 93, 111, 106, 116, 121, 71, 83, 62,
               76, 36, 63, 37, 38, 39, 64, 40, 79, 72, 99, 91, 109, 122, 104, 
              114, 84, 96, 65, 77, 41, 66, 42, 43, 44, 45, 46, 47, 48, 49, 67,
               50}]}}}]}, {DisplayFunction -> Identity, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"t\"", TraditionalForm], 
           FormBox["\"u(t)\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
         DisplayFunction :> Identity, 
         Frame -> {{False, False}, {False, False}}, 
         FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLines -> {None, None}, GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {
          "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
           AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
           True}, PlotRange -> {{0, 19.048605036573925`}, {-1., 1.}}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.02], 
            Scaled[0.02]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"3 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"5 switchtijden\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                   "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6627215537827005`*^9, 3.6629141732069807`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"plotSolveTimes", "[", "]"}], ",", "\"\<s32\>\"", ",", "True"}], 
  "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzE8oQwEAx/HnaTOblh6W5T+roRxkVsPKRJYTI23aZWoO/qa4bGSHkZpa
E0+NJqRY+VPjNBflX2tLYZm1tp2GqZG4+Jf3e4dfn9P3V9Y/pjGSBEEUMoPG
opLvnI4X1d2M+weu8U6JXMYKgkiHkqomPvxLSSnoGrkUQTqzuhKeUbsyKJNq
6uEAmWaAo8W1wzAV75qEDfJSM7TaaixQEUnYoc81tQS5W+plqEz+rkN9oG8D
7t+u7EBT/vYe+9/tPGI7r+8Ytg0FT6D28dkPhUlPCIaz5VHI93NNeYzJtEUz
7BWo7XCcY6Ghg5xehdwmzQGcd1x5YKLn/hoWh8xv8L3xnHUhy/AJJeEAq1cn
JkWMN7Yq1kjzRwbkxM54MD4XFMKw00rBi6cBMdTWUQWwp5Muh8LomAS6X/UK
ePg1yOrWPShh62yLiu02N9snGAUxWg3/ATwFwck=
  "]],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.019444444444444445`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQGRB5xrV5SI7zN1AHMPhB84odyoV54I5TeEHfh3
49bFQGYo3yH0AN+X6XfzFptA+AwhB/SFdy7rdoTyDwQduLBB8XTEXWOo/sAD
RXnLTpaVQfkOAQeaGo0SC3mgfAa/A/a/5qnunGcEVe99YKobU/IsHSifwfPA
RcE7l/S3GkLl3Q4sv/Bqmp85lM/gcmBT1dKnaRsNoPKOB9K1ZTYFKEL5DHYH
Zq64yv2UXR/KtzzQGS2303SlLpRvcoA7RexbgLgOlK93wGHVMpmdZlpQvsqB
8FMNxwTPqkP5IgfkvxfUWBmoOAAAT/Jc+w==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.019444444444444445`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQGRBz42Wqs/3WruAOYeCD8QODEw5l8slN8QdsCi
LPd9NDOU7xB64FbOUtXtS80gfIaQAw23MiL3ukD5B4IOiPDYCfA+MIXqDzzg
VZ0jZVQO5TsEHFi0KyN4ASeUz+B3wDb8V8KaaSZQ9d4HvvU8zW+UhfIZPA+c
/FDpLjTXGCrvdsDgvPJDJhEon8HlgM453+LWBiOovOOBL1dnBig+MITK2x34
9z6YIUAfxrc8kOfU9/RIhgGUb3LgypFJ8U/Y9aF8vQOnevevEX6sA+WrHLiT
2fqpR0kLyhc5cEBi7p0GbjUHABQSXr0=
         "]]}}}, {}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{-100., 0}, {0, 23.710527851131648`}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\)\"", TraditionalForm], 
       FormBox["\"T\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, Method -> {}, 
     PlotRange -> {{-100., 0}, {0, 23.710527851131648`}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"3 switchtijden\"", "\"5 switchtijden\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.6627210995307803`*^9, 3.662721135348794*^9, 3.662721246235611*^9, {
   3.6627213090368586`*^9, 3.662721322524062*^9}, 3.6627213930424366`*^9, 
   3.662721488203504*^9, 3.662721526698577*^9, 3.6627215919142637`*^9, 
   3.6627233921258893`*^9, 3.6627234269971733`*^9, 3.662723520961917*^9, 
   3.6627235693153477`*^9, 3.6627236781558647`*^9, 3.662914157704625*^9, 
   3.6629143976505713`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparison of crane solve methods", "Subsubsection",
 CellChangeTimes->{{3.6627277307060757`*^9, 3.6627277362579575`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "compare", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"compare", "[", "r0_", "]"}], ":=", 
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"plots", "=", 
           RowBox[{"{", "}"}]}], ",", "f1", ",", "f11", ",", "eps"}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f1", "=", 
          RowBox[{"find3Times", "[", "r0", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"f11", "=", 
          RowBox[{"Most", "@", 
           RowBox[{"finalOc", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
             RowBox[{
             "f1", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{"Function", "[", 
              RowBox[{"t", ",", "\[IndentingNewLine]", 
               RowBox[{"uFromSwitchTimes", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], "/.", 
                 RowBox[{
                 "f1", "\[LeftDoubleBracket]", "4", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], "\[IndentingNewLine]",
               "]"}], ",", 
             RowBox[{"PlotLegends", "\[Rule]", 
              RowBox[{"Placed", "[", 
               RowBox[{
                RowBox[{"{", "\"\<Methode 1\>\"", "}"}], ",", "Below"}], 
               "]"}]}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"eps", "=", 
          RowBox[{"epsilonOC", "[", 
           RowBox[{"4", ",", 
            RowBox[{"(", GridBox[{
               {"0", "1", "0", "0"},
               {
                RowBox[{
                 RowBox[{"-", "g"}], "/", "l"}], "0", "0", "0"},
               {"0", "0", "0", "1"},
               {"0", "0", "0", "0"}
              }], ")"}], ",", 
            RowBox[{"(", GridBox[{
               {"0"},
               {
                RowBox[{
                 RowBox[{"-", "uMax"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"m", " ", "l"}], ")"}]}]},
               {"0"},
               {"uMax"}
              }], ")"}], ",", 
            SuperscriptBox["10", "6"], ",", "1", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "r0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "40"}], "}"}], ",", 
            SuperscriptBox["10", 
             RowBox[{"-", "2"}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Show", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                "f11", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}],
                 "/.", 
                RowBox[{
                 RowBox[{"_", "?", "ColorQ"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"ColorData", "[", 
                   RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                  "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "2"], "[", "t", "]"}]}], "}"}], "/.", 
                  RowBox[{
                  "eps", "\[LeftDoubleBracket]", "8", 
                   "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", 
                   RowBox[{
                   "eps", "\[LeftDoubleBracket]", "7", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Placed", "[", 
                   RowBox[{
                    RowBox[{"{", "\"\<Methode 2\>\"", "}"}], ",", "Below"}], 
                   "]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{
                   RowBox[{"ColorData", "[", 
                    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                   "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}],
                 "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"300", ",", "200"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", 
              RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<\[Theta]\>\"", ",", 
                "\"\<\!\(\*OverscriptBox[\(\[Theta]\), \(.\)]\)\>\""}], 
               "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Show", "[", 
            RowBox[{
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                "f11", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}],
                 "/.", 
                RowBox[{
                 RowBox[{"_", "?", "ColorQ"}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"ColorData", "[", 
                   RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                  "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{"ParametricPlot", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["x", "3"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "4"], "[", "t", "]"}]}], "}"}], "/.", 
                  RowBox[{
                  "eps", "\[LeftDoubleBracket]", "8", 
                   "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{"t", ",", "0", ",", 
                   RowBox[{
                   "eps", "\[LeftDoubleBracket]", "7", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"PlotLegends", "\[Rule]", 
                  RowBox[{"Placed", "[", 
                   RowBox[{
                    RowBox[{"{", "\"\<Methode 2\>\"", "}"}], ",", "Below"}], 
                   "]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{
                   RowBox[{"ColorData", "[", 
                    RowBox[{"97", ",", "\"\<ColorList\>\""}], "]"}], 
                   "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}],
                 "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}],
              ",", "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"300", ",", "200"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", 
              RowBox[{"2", "/", "3"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"AxesLabel", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
               "\"\<r\>\"", ",", 
                "\"\<\!\(\*OverscriptBox[\(r\), \(.\)]\)\>\""}], "}"}]}]}], 
            "\[IndentingNewLine]", "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"exportRaster", "[", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"compare", "/@", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "10"}], ",", 
           RowBox[{"-", "65"}], ",", 
           RowBox[{"-", "100"}]}], "}"}]}], "]"}], ",", "\"\<s34\>\"", ",", 
       "True"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "//", 
  "Column"}]], "Input",
 CellChangeTimes->{{3.6627277374209156`*^9, 3.662727738546193*^9}, {
   3.6627322636183815`*^9, 3.6627323475627313`*^9}, {3.662732395243514*^9, 
   3.662732405100499*^9}, {3.662732453818022*^9, 3.6627325904928236`*^9}, {
   3.66273289621145*^9, 3.662732915656228*^9}, {3.662732958625675*^9, 
   3.6627330953205347`*^9}, {3.6627331874488163`*^9, 3.662733302840678*^9}, {
   3.662733361800733*^9, 3.6627333772807007`*^9}, {3.662733541603126*^9, 
   3.6627335433673873`*^9}, {3.6627335748176603`*^9, 
   3.6627335886885004`*^9}, {3.6627344879459887`*^9, 3.662734516829455*^9}, {
   3.662734618368404*^9, 3.6627346184624696`*^9}, 3.6627346866848116`*^9, {
   3.66291412437947*^9, 3.662914126085809*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000049261937779789656`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.662733305762739*^9, {3.662733365461314*^9, 3.662733380126706*^9}, 
   3.6627335469439096`*^9, 3.662733587234459*^9, {3.662734490804013*^9, 
   3.662734519489338*^9}, 3.6627346260568647`*^9, 3.66291417639748*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000012064693799224027`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.662733305762739*^9, {3.662733365461314*^9, 3.662733380126706*^9}, 
   3.6627335469439096`*^9, 3.662733587234459*^9, {3.662734490804013*^9, 
   3.662734519489338*^9}, 3.6627346260568647`*^9, 3.6629141797337418`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.00001310462446363732`"}], "}"}]], "Print",
 CellChangeTimes->{
  3.662733305762739*^9, {3.662733365461314*^9, 3.662733380126706*^9}, 
   3.6627335469439096`*^9, 3.662733587234459*^9, {3.662734490804013*^9, 
   3.662734519489338*^9}, 3.6627346260568647`*^9, 3.6629141826057205`*^9}]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJxdl3c81e/7xyki+UhWg6JQqSQaoriIMpLsUckqomyyN9myZzjH5hjvjErh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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJxcmndYjv8Xx0MaSKhQREmpiLSHOm1paQ/tpb21997P03iep72fdoTSQsfI
ThGirFBJaCkV4nd///31T9frOvf9uT/nnPf73J/7uh5+Jz9j1/UMDAwHGRkY
/vv//398b3P7Nd4m9bY197NMvtyBglyGxV8H6L2vN7bJ1w4dwHXGe7r/OHX2
sj5J5+SQOoJjR83LS+709boY7cnhvS+BYyzGL/Rln/Sev/b+d3aQLO5y+bF4
yexlr6CbwWurvSdQ9foxDeHr73sz5xnKVRxV0OYNE9W/Y7zX71V/xLo2NZyl
TMtvl5ju1d46cNhvgyamsw8dyxKe650tETyTbnwS/7ax81PSf/QebNZvPV15
ChkSPoXPKy73clbEvbj5TRd5eDeqBMPvXqaz3KHvZQ1wy5n9nnP5/3oXKfH7
n6sYYts2IY20AkZ83Ty8XJpmjJ6KmoXNCsxYH3V8d3yzCZ7f4mf0beMmbMts
E+h5bIqrUobtkpu2YYlDjLnoNgvcvYHHort5O1KM94k4ilvitQ1Xhvc5ciD7
C3W5b6etcOeGt0VWzLuwyLQh4G+WNQ7IJX3aubIbX+5kMExuskHlzlP8SX94
8DXLkSH7e7Z44o9zsrLKfsxnkhBl/2ePhabV1fOWB7GtUDheRNIJvfLr1Nwr
BFG2zNhbHp2Q7jIzlTIrhH/VC3MXdJxRb8nJgN4igklKZGUHRxfMMSyo7yw6
ht0aI1sPZZzFkaeyxs40cazA7M4YDjes+v1+pM7lOAq7kdfHlrqhjdc8szm7
JBqsy5cMP++OexulvjOUyeD8Y+ZZo0eeKHO0t4UzSxYb8r4VfzPywkHyI9P+
WDkcVs6zOPbKCzPiGA7sCVZAPDR8q+WTN/qqdLN+oCnjdwn5iuSfvijY+8hT
fFQd2RaLWp8kBxDrD61ZJWrguxmWuLuPAvDI/dYevmOa6CJ0Z3Pa9kB8Mqo3
GU3SwhRu8SO+pYEo8aYtSMX7FI5d2hN4pzUI1+vzyB+rPo2G59qKC/qD8VHE
tASfgiE++eqdrcEegn1fzarc6IZ4r+NE/TWjEKz1CWNvjTLC8qu0o1uHQ1D9
53N/xhMmmHoxrEr6TSge05A6+XXRHPn7uG6R3oXj1KiVv2eABfLxSMlN80bg
9RMXKbtnLfB4YtHpbbYRGL7w88Had0sULFQ6eW00ArsCne8Nrp7B2dwTNXnP
IlFHNGj7JW17vPGlxlLyajTySB5xqX9pj6z2I4PSy9GY17h4+p2kA07W1cWu
l4xBa/3lyYo7DhjycNb3V2MMCusYBN6ddcQEQdILZ2osjo4zS4rbuSB1Nrdt
86U4nD4XoL290QWfV9xqjX4Uh9ozp3zcF13w/I5DHK8m4lBfO0I5NMsV0y7P
M2vxxGOvtqLf5ltnUeD3mXNMCfE4t2SSfUnNA4MuT17YpZ+Af4+Wst2ieKDu
gqkC+9kEbP3Lu17tswey9+ZsnY1JQLpvRSUp2xOb9H+ku11MQH9/ru2n33th
4N4LtYo7EnHtVHote4EvHlJ97Ov3NBG7SyRpE7O+eHtZ7vP0VCLeO5pndvCU
H/oIZVEMGJIwkjJMG/3jh5dnjNIHjiZhzXsJFXK7P/IoK1y9mJGE01EpHiai
geg5myKyppSMPurtzm4KwdggnOvTmpeCLvt+tK56BePIlYYf9+tS0Cvd60dn
WTCWY2fao54U/OLwgta5LgQ/tvx+n/kxBT0MBAavPwpBs6ZhjVXxVCz8YrW+
xy0Me7Z1LqU8SMW9ugJHF0vCcNf+9sDjb1LxYrzFEYsnYbhRoe5f30wqGmH/
ME0+HKmrDafqOdJQ9Eqc8zJbBEZZj1dY2qShodENy+29kQgZ25x9v6RheLrw
rpuLkVjC3T/Z+CsNO14fSaQdjsIUzYjIgc3p2Lh/uPhSURRufPn95ZBYOirZ
qWrXhEZjU+l3u/v+6ege726vrRCLJ1yiOdwW0nHorXBsmXc81q2L8Ysez8D2
7G/kyqx4TBGrvcSxmIFZPbY8HS3xKMHcI0jekInb6lf37v4ej7MBr5ulD2Ti
IfKsbbtvAh78rO6hapeJed25S8eDE7HG8UOg2dNMbIyduaJPS8TBAesH8D4T
SRLXF8I7E/F1VUwg+/dM7I1wdNrwKxFph7712bFkYaBlWflwbBLeCTpfc10p
C0XdKi85kZLxKN+/HTE1WXhA9a1+6MVkXDodlt7bmoV3Qg09ioeS8VKZadD4
1Sxs5NxTunlXCvofUW8Ze5aF6uLb42mVKfhH597+kvXZ2Da+tEeyIxWzp9/F
7LHOxtGrpkt8I6n4g9Y73e6ajSvPdM/s+ZOKS5RTzFL+2Xh74YGOtFoa4bd9
Tp+SslFqb5jDr4E03HB5cQvz+WysbxaTuDCdjruKexpcV7KxhCe/a3FzBh7N
nGi6zUBCOx+laA2xDMz9cnp1EysJa4+52fzzy8BWlQupZtwk5FY50fp+KQMj
ivj6RuVIeMrSLEdqQxbW/TVLawgi4VWdh4IbBLNwt6/uQGkECfdOlrmOaGVh
LeV8fkQ8CX+nucWWZmRhmlVi4wKJhGyFlywjdmRj2QZG6xcNxHrSM5kxAiT8
8et8r9srEuaUlC1f1SQhbUdnztJbEga2/Yj+50bCLbI/eX0+kZDxSV14YQsJ
fe3OR3HPkHCppiWFXYaMz47ue+y2nowPY7j4Iy3J+Kn95y91ZjLyXdXh/BZB
xq5OCdZNW8hoIC5Gf4tkbPnqNWLCRcR/NTn+PZiDyZzrH70TIqPnhyFlbZkc
JKVxxWw6TEb3p0FulJM5aPClW4bvGBljZJs8JT1zcFpY7xGrLBlH2ZsnMlpz
8GzDlQ3DmmQsF7d9NHEjBxfS/VyNT5GRWaKkRG0oBw/d/zzfpUfGATWNR+uW
cjBxR1OZhgkZ58lbOKkKuTg4Sbllbk/GFFau40H6uXi+leOAgxMZ7R1l9pg4
5OKhCjtWQ1cybhzk5N6dkou/bqxL/eRJxrMhv9jWCnNx5MxRkVQfMkrv18n7
1JyLTtODntv9yahdGLb5ytNcjOnmGR8591++sR8qxnOxwKHw0O5QMubGqbFm
Leeie7/kAaVwIt99OtvcefNQ+aa3qWI0GZ3udT6xEM/DR5feFXDGkpG/63it
tnoe8srsanoeR0YuSomemEce8j1IMmZNIuP7be0M/FF5aAmkxehkMhasiGRy
kfPQdTdz9EgKGVkpuW82VechS9rI/J40Mv49HDvBcCUPmW/NWmqmk9F/JYW2
fC8P5zdKdZllkJGutvR+ZjQP476I7tTPJGNo+pXLk9/z0K7jXMThLDJm+ioy
vGfIRxvZi9/mCE7I/9X9kiMfdWWjzpVlk/Ff0dmnT4TycS0ulPs4iVhP4Ifs
Q/l8VH+v8qmZYI4hjve39fJxZm/oCBuZjLNaJ7qu2+fjAGP3BguC3wiMtXcG
5mOHY61HKsERm4LuXkrOx9C/ozsqCPYtdX/XXJiPH2pXmMoJtoyUmqltzsc7
B8r0k/67X1vnc0VvPv4EtxkjgkvreK8WPc1HjftLc0wEy8kcsM4fz8e4lM82
NcR+zIsedWUt52Ok5mv5QwQXBmTfSd5EQZYnfuQ8Ip9Kh9eBMbwU/Dmn7jpB
5LuNReRyiDgFdwX9vLX/v3qwTp/zVafgCX6hi6pEvS4z5bW4mlNQ9m6AlC5R
T9Eqio6NBwVfHQmzOEHUOz/CVcU4ioLz+1/xcRH9yJUKiz1JpqCJp3jhC6Jf
d/xVVhWrKTg4vP/Of/20+YlOB+5T8Iwq2CUnkHFDop0052sKbn7RMjJO6MF7
dzzLxhkK7uk4InKE0Mumcb6QTxxULM185xQYScYk2+QfT4So2MplYBNA6E37
7AnZ6/JUPLtbV9uS0KNCi//LXHsqbmhz3/kukIznj7zYGRFIxcyxu8zRhJ4X
b5356JBMxT+XxDYx+pIxrbPgk0gzFUe9chweupMxzzdmuf4nFX09WUTkbcnY
KXrtjygrDf/aTqsLnyH8t7HicMseGn5tnkhlsCCjybTaYIMKDe2MGRq8DYn9
HMpsSc+goX7T+R1SakQ9qeHRf0pp6GSkpuKjTMa+O9OsPq00fHuq8glZgYy7
pTT2nXxOw08SOTK5EmR0dM/uestbgP7D634m8xPzxsng6wnxAhSzonFt5iX8
feuVX5FaAdJiikbCd5PxZ5+hoo5bAepwlQZwshP5KP4LSb9YgHpirs+Vf5PQ
SunDmSC1QhQaK/3tN0hCIcctl6pMC7FM9V5g/gMSNh/ize4/W4iyL/i5q26T
cLn5Z82uzEJs/blrZ2QnCfV/93yOf1aIt96O3hYtJ+Hoes6qEucinOA0So4j
5qrGLh+brOAiDNcTZdB1IOHTTfefhqUWYZ3mkhSDFQn9yzM6NZoJHts2K6pD
wvAPQZvqF4rQ5NzxwoTDJKw+6FSfEVeMQ9PnTdWms/GhXGTyutxiFFgTfHD6
YzbOlbL+DqoqxiwRRUnd0Wy8nHYoUfdWMaqbujBueZiNO2heX29vKEGXB2J+
HQ3ZuP3RxPOnySXINP0i9IpTNm5hReoatQS7Euy/1lplo1lqpenBuhJM/677
LMkwG7UTN9Q73S3Bti4631blbMwT+1NQxVSKbhU9+ad3Z+PeH/phfCmleCKu
ZIbyIAvPpyRdWaaWovCB/EB/zMITpmNnHtSW4mSe7jeFK1nY+5rUZX2nFLc4
mH8orczC40YR3YqMZQgCcu3UkCw0i+arGIsrQ6H9htuc9hPsbHI2KrgctW/N
KpS7ZKL86s2GZ8nlOORacsHeIhPdrS2XDtDKsffKK52tOpnEfqQSGzvKcSF7
12HJY5koFiynb7ZcjiPJ2x6XrmSg4cyNkH2hFdjep9a0mpqBVxP11u2Sq0R+
ZjUX0aJ0jDdtFuqGSjT6Fytfn56O+nf+NZqfrERxpQf1OyLSUa639kqieSWK
XM+KvnImHX+Rmw1qz1WigJSa4ZE96Wh1/+HSuouVqHusp3aqMA1bAxkz/hyo
wslCzgvfUlPRg69NOF2kCo0Cu0ZjQlOxTP/g0e3iVciRV8K3wS0VTVlE7DmU
qtBc+ivfR81U3Hyk6+d78yrczaC6/ff6VJSnDnyipVdhm6FBWVVEClpLfl50
+lqFv46K3WNxSEYGua+5ZvNVKDdn8m5ePxl3PEo7qL5chY+id5oNKCajeYzX
XvYN1XiNpJDhuCsZQ7Ue/fDgqUamaLL4wuMk7LzzQlhYuxo1pRet7sgl4UIf
/9fzFdXI6zqZGLExER84Nzx4S6/G7mWDnVoLCbi3W8OFpakaGRlf3WB6n4C/
X4336bdXo3BSQrpbVwLeUNaaKrxfjWN9RYwNngm4KtpgfXSOiJ8ZjhJ7HI8H
Hl3jUleswTyXi/q5GXH47+AtoztQg/y6cqUcIXEoOnpiUVWjBrtWa09mOcah
YPMDR1H9GpyWvPDWQS4Ob8n15Xfa1eC+6Fp18UexKJ1psXwjrga/RX98SI6K
Qe9OM73oGzV45p7Xts9PIzG+38W3qK8G34oGVP6pjsQwnuHiC/drkFWqMflv
UCTxHc3K0vekBhtYj/Xc44pExoznn4vHalA7fv2VQMsINNrPb/fzbw3+KjNQ
UhsNw0vbZD9Uradj4d8TJSJNYSi2w1xdi4mOPfpmK3/Dw/Dk71dF4Wx07EqP
5znHHYbNdjs1MvbQ8aic/FSGRSh6HCMfNZKhY5Nn82L8k2C84c9tmy5Pxztm
y2hWEYw+RSbQc4KO8mEuUty+wVhsvo6TSZ2O9tJ8iX6bgzGB3HtZ8zQd1+fP
VttonsPPJ4r6nc7S0aiyq9iwIxBte6a4BD3ouDzyIO9wUiBaMjnOvveiY4x0
2Kdlo0C8XbWsAwF0/PB15JfL9wAsZpvxoUfSUTRj7me+QACOLqS1MJHp6H3m
fmk3jx9+HdjMJppLx39+h0LSrvpidu7zV1r5dDRQpXWr2Pgi3e91s3cBHWeX
zh71LfPBnzvkODwqiPxuHCu/uc8bPeudqyyq6Pi+34021uuF5733kqCGjr3G
spbTdl6IR0eiftfRsbrJYaq33BO/ca4mCFyg43iNLGsArwdeamMeedNKxxu0
lL1fr7ljwuPpOPIlOmrdXLQ0snFHr11DONZOx7jShT8fi91QNK38scRVOoYk
DeL+XWdx3dzabP5dOt5flvwkuMUZqd7CXR/u0dFcY1oqtMkJNxbPXhd+QMc/
jI8DOrWdkMnXN6b6ER2vFljZbkx2RJP7k50aT4j9fb1S3Llqj9SiViObp3R8
2xJPMZa2xwdTp/h9huioIXpecMDfDnPd2OwintPxy+06X/fPNujVniah/oqO
bJbXlCWfWSGTOs3+4AgdhT/wFrxhs8L6vU09fwmm/Zo46aFtiem7/v0sf03H
lZNiHEevmyO7t/6wyxs67jw+8/bsshkeCrz2XuAtHS05ixyTjpsR35E7fbLf
0bFYUnzRt9YEj19gn5V9T8eig3ZtJ94b45cI9YLXBHeHr2bO7TZGudsh5ls/
0PFSz+8vm7MMkTMw0auM4G2d2jCVcRoLKiaqBT/S8Rclsjx1TR/3vO07x/+J
0MevrFXpjzr4aOx9QDnBf/oa6aMSp7D1NZcVxzgdFZ87/dFOPInDwiIicQRP
dUt9iH+mifoCb8bGCbZjKZVMEdBAAaH5GNUJYn0jrufmQWromiW6nkYwjwhv
zeItFeS/pOPxkeAjKg7rbx5URtdZjjahSaI+edQymdsKqFKt/c6JYDHfZ690
HWURDzZ/oRFct7wjeP0/SZx7uvbsFsE9JvqSNqXiOO+0tXSS4IuFSRevBIri
rmE+1fWf6Ti3pmvH0CKAu9/23uIimGHdrmHZB9w4zhTEx09w3F55OBbIgp4f
71kd/C++uE2PnPxCufTvSd/9/zHnyy+Cw2zgPh1tu4PgMUq/L3vsXuiVWhRa
I54nPi/UJbBJEEje0g/fE3wjr2XDmReH4T5fv1bPf3HGkJx8w+NgM6ZWmkVw
F5fPo9sdUqCgcPChOcH0aemfirxyYHz91+Du/3hWx/RXoiLkrxieHyLq45Ir
JLI2rQzfIy45JhGsXc5vwy+iCobP6r6JETx9Ibt6/I0atORc1R8k6r9wkZJ+
L0cD5lQjktwJvjz6Q+KBhhZsDfHJWSX6meTkfmNq5STkVu8R2kBwh2vK1hhH
XXjV9fVCJKGHW/pNOxa49KEjm2fzN0IvCj6v4uMeGsDqhV7F9jE6fuQ6SFnk
NgJl7lPsWwi+tSfhqcOiEbyOtmm3JvS3sel96qsBYxgJ0A74SOjXoZ+jZirR
FHj2y6RxE/yEVi8SZ2cGgetf+moTejcwv+LNL28OQvU2jdmjhP74u71iZyxg
eFPF3SvDdFR+3yNYZmUNLJsNDJpfEP7QDXUPkbKBJ12M1YWE/44kV8+YsdvC
mGVb8xnCn2pPkUXojh3I6yspRj2m44yDrFDsbkcwtjHaKd5Px4d60Tf/JjtC
XM7N7tcP6ZixZelm7A9H+HL8rwXPfToOQSRH8oATuNWt/ZC6RcdPCd5TtCQX
WObZ63nhBh3jq6V+8My5gNOPtqX9SMel5/2t5dausDk7yuArMY+e1n3yp0uc
hcScpq0CV+iY5jsZVDPmBjcNH8vZttExh+Lpu1/PHexnb0X8N9/iZZpjizrd
gTHZ5OSb83RMPfBqdyrJA24rq2/eRcxL8817U9VOeMHHfTJ/ttOJesVhYWO9
F0xbmDFvrCbqM7pZiI3DGxZzNX2elRHzMIBr8v4XbxgwForbTqWjb9khW7YC
XzDyvbyBI4GOYe25hQYr/vBiU2MPOZaY300FP0bEAsBgKSaHMZqO7lF2847O
AeASsFQ0HErHm/0evm4DAbAooXVkrw8d/77irNCkB0KRQ0mxmDkdT5AjnORO
n4PqVQ4TvwN0JLnWtJ2sCoXvBoeoYvuJ/uz+Z1w7FApX1Hl3TBDvx9SI67pr
G8Lg9t9ZBC7Cv2/WVkrOhsGc/Zd1dGZivbXH7HmHwyF8ee658Nca7H99ufB0
ewR0iq8/K3K+Blk8HNwSb0RDj6Z94bbGGhyx+6y2cT4aJmz4+OfpNdhG9/sZ
wx8D4yWgWF5agytLO4usEmLgcg1rV0NmDb5M6bvSqB4LqpwpjHHuNUhoR8fY
KQ6itRZ8VXlrcDl1PRXfxwMn67Ds11016HPUeclrNR52jNTaZu+oQSvx7fw7
OBJAiuH33R7mGvxxLb9RVysB7m3gUu2Zr8Yo6SmRwJYEGK19bqHfV43iKWFK
CaGJILvhCvdT52rcXxq64QxLMgw5Xt6bYVuNOW7dPsL8yXDld0qvokU17j7z
QnhWPhlK312eStOpxv6wLBdXr2T4rc/A+0i8GiV+Z3X8eJwMFooPpOZ/V6EF
c8KX7NwUkM0fKHmRRZw3R/IveuxIg11UifUHUqrwiHmYR4FwGnC5Kqm4x1Zh
/BUZ2evKacBTe1b3Y0AVSqiVfZvzTIPFvR+Hs4jz6P56Wu/yrTRIbjRMv76v
CtfknX9HBKRD4Vj859KmSjxfsMuU+34GTPkcixKuqcShOpqe3NsMeOaQI3mh
pBI5fXvUDRYyQCiFh6shqxInp/3Z7PdmQp30jhkz30q8yLT/MId/JqzYVeuX
ihPnafbmoF6uLGA7iJ/7HSvwScObM1NW2VAp4cLNbViB+8O/+8f7ZYMQ9w0D
S+UKNPojfGtrcjbkaj1438pTgZzT975tvJgN/7ZaW/UNlaMJ6wlV140kaOvQ
LU1TKcfg9Muv350nwZ/q3KutO8rQ5N3BryFLZJjqKd/o+a8UExiMJm4y5kAf
ZRZ2fyvFfYe6hm9uzQEvFck6Q+J7Zsj685ELB3Kg2Zx/v0RoKXaGlRyW08kB
uzDyfO+rEtQU+1rIVpgD3629cuTzi7H183m3iqO5IKMUFvwxphglBKP6q2Vz
YWTvqc44z2KUHDvtVqGSCwv1Ov5lqsVYkedwNMk4F87WWORazhZhkQYl+3dw
Llx4N2P9RrsIr3e1fi27mguzhX81jBcLUHw7eY2imgdaeFW5410BcR6+atp5
Kg8YiveXb3tQgBemMtyGjPJgb7jjpYayAmx6cuHygmMeUKXDDrhpFaAc9XT8
6/g8GHXWWDxIo2G9Fs8O3Rt58Cbse9zHo1RM/vU3L0M2H7Sv/dVr5qZiaXV/
gJpyPmw4cabdm5GK8goRlT808mEt9V7AyAgFA9loH1WN80Eg1CHAOomCr7g7
zmd758OJ1+1DzK/y8XTE3b/vK/LBM3cwTjoiD8WPLQnZrqPAvK/u1/0uedin
UPNdnpkCppPuHzYY5GFC2acr7GwUaJ0Wzeniz8OtCrzqdbspMKCq+OLF/Vz0
zIjbHXuMApumt3yZ5MpFMQef2bfWFKjUGxeStiBjf8VWI7VWCjzrVL5wWZCM
7IF9OnXtFIjvdrUVWCRhiuK5G+t6KCD45WriuxwSfnmdy1XRR4GOV6sHex9k
o6VHyP6gEQrAvJqtlHwWZvv4hMaso0LOdr/n35myUMju0D9LJirYes9fKXme
idoTe0ZFN1PhpEIJywu/TGR8nxTbzkmFs996+W/UZmBa0BZV+0NUOEoVq89g
T8fEAPmH23SpcLetKp7yJg1FltZF2Z+mgqiy3i5KYxpeTMt1rDWhglXk/Qfn
1NNQSbnr5k4bKtS9XqnqDUlFtkjGJrI3FZ6bcTxPeZ2MV1dLu19lUuHyZme3
n/XJaFh4fbqITIX1t1Y2255LRs5bvjLG+VQ4xhXxjp0tGf9xSe9qKKbCtSK/
f2zKSShgITE01UCFGCWGyZjyBHz150f/tdtU+H7BXuedTwI+Nd35resuFczl
dbbKKiVghg6z1PkHRL4BZ349fx2Pdt2S8jGDVFiyKNXp2x2PQbqPF2+OUuF6
ffEmBoFYVA3r2j44S4WbNo84f9+IQabSNwL6C1QwY/qw6atdDG5h0tG5vUiF
B59nNJuKo3HV/P1AwSoVmLv/3mncHoWK+ZvyP6ynwT3/YZX+tTBM2JYsssxB
g8C2nTVCJWHoEHBt/U8uGoj8qT8cJheGHhWzH7/tosH5p5ywLigUa996d9za
Q4Pur+FnWj8Ho4nS1dKtAjT4d40+ejcpGPc5Pah8fJAGzisDFcP8wehyiqch
SYgG596Hpb23PofMo/W9oyI08Hic1Fs8GIgn7Dz/ConT4IU+m3GYdyAGzKew
1x2ngV+p+qnTrIHoe0KMj1eSBgeGty18UQtA/3MKyj+kaWAqxXe8xcsP9947
7QCKNMh6PuSxsdYXpYIuO8ScoMHuEaV6k3c+eLZ/wuaKEg2+Bn01eGLojdcZ
PmptVqFBSIuHsLG0Bw48En5urkGDRLs7F9QD3VHc+VGXoSaR38yn/iOtbpj6
JHJCTYsGzx+kvZsUPouKRzW5tmkT+6vdZ9Xl6oqiFdG7vhK8K44WnlDtglKf
1zv0nqJBvYluz7q9zti7JnFLX5cGO98WOHZaOuFTvbVRVj0a1KZMXDtLdcSD
50zkegmWtq4pa9vqgBf1PvayG9AgVkzLtIZmh1ExCp9bCF4WSpl/zm6LF9Jt
jdVO00Dm08YXPOvPoIeY+qyZIQ223XMREY+0xCQtQb7nBPv5qe1TWjTHwwrb
83SMaPDe+4KCmo8Z1t+naXQTPHW6a6PKpAmqXtaU5TOmAUejH5OsvTGqdZ73
iCV4imX89qFXhrhYYPd6mOCP/05lCFYbYCXnVKaQCQ18lJIOzOfrYs73kQhf
ghO+Uu3akrWR7dPt+gsESx4u1/MJ1USHK9I7PhOcx3vt134PNXx2ELt3mdLA
8R7vTOEVZbw4P1umQrCD6MPznwvlMGrEodeRYPGbDxOORkmgDeeePZEEx8XM
733fK4xHXM+1ZxGs0rDW2baJG+WZ+jJoBDMUbtC0X7zVO3Dcsbzwv+tz5jK8
Xu8CxQM1s3kEj9FPX5I9JAwPt3+ISf7v/l42JktxCXioEKjn/9/zqm/ps+nL
QcrL85YmBD+RK8nr9lAG/QNfa44SbLmvw1pMXQ08zeKPrv/vfqnk06FGmnC4
+d7KYyI/Q0VBWre9Nry15dqQR/BcDgP/Dx9deFx/U9/gv3he/IcDUQZw8rbA
yHqCXQzSxwXuGELhdF5tK1Hf50xkF3E9Y2CzPNtmSjAnf6qHzDMTWNRcWr9A
9KtBWmDiyAdzOJVV7c5FsHb2cf297pZgZOUXW0L023AdM++GWSv4SzYd4Sb4
yOrr4fY/NhAucMfiH6EfvVHNyzGJdvBx8W/UWYJlHgh+27fRAQS4L0ze0acB
T1Xsj/5MR3BSf5DmQ+iR8ihzjOe0E/y6/unmFUK/L5UNXZx2OEP5uScqP3WI
ett6878tdAHl2OjtDoTeexlHN0fUusFJz4vMLwn/bA2MsuAJd4eo8LmT/YS/
/jC/yL+o5wGfDhgEdanTgC3xWPL1H55Q3rs/O1iVBosk+VenVX3hQKDOSALh
X3luJVkapx+oN9fGHCP83RXK+HzwM8FBRTueydMg5/blDrZ7/iAlysLyT4YG
b1xyzDf6BIJclrj0NDFPstxWb/sPB0IDJcba4BgNQPRRyHMIghq+saBGMRqk
n/n2L3HHOSArlURpiNLghsnaZExnMJR82v+LjZhnB+U7ofdfGPSetmGd3UHo
v/L8vSL3cPDbMpB5axsNns04jHs+DYckEdMt2Vv/m0d2Et+rI2B8Z9YW5k00
6DtkEu2jGQWD18SPkBloEHbtYLtsWix0HYr+M/eVCuORwvWWc7GwxCy6KPWF
CtMxUhoyR+LgVk7tmt8kFQT4GGRkKHHAfXRZ59EYFdpvcGwad46HDbSM+Z0v
qGAd1zw5vi4R5NmqEzZco8KdAxGO2yQS4fo2l875Lip8Oqy8UdopESDRUObV
FSr8ze5O8LiVCBV3mnaSWqng2tIaGJ2QBHJuw9Fl1cT9ItWqautS4JqGFJte
KhX47mnqrIingK/hxhBMpMKwT5R3nUMKpDTKKB+OI9bfntwzjSlg49Gy8DWM
ChdOS9Zvj0mFDMFErh2eVHgcEcf5cCUNQvEFeUGHCl9IL1+tHkoHbcYtVd+0
qKBZoNPEZ5EOR494ibxXo4IBnj1uciUdWnRotecVqPCMuf7XqYAMsL6vHDwn
QgUfk76Hfp8zYcvPJ71bmakg+FBSS7ifBJqbNhd1X6VAkuixroU1EhxnsuKy
7qDAsfsUhYvHyOC+zXT1x0Xi/KNns48xnwwTXbrrt9RRoKh7Y27KkRxwVuCx
e0GmgPnfi2yn5nPg6rrfXoOOFLiX3LnNOzgPKH/mUwL/5YNyeXSQb3YeCCff
/rhxNR+i+sq5PWrzoChB43fOAnGeU3zJcvJFHuir1/iSJvJh4oWzI10qHwwv
rLQLPcoHudkNPm/m8+HldZGAQUo+tA/uiV1zpYJuHdPxXQfyYStrDXdGFBWu
fLjz5SFPPmj5D+7YSpwzLKv7Nody5INGrevf30iFvcuqRV2M+eB9ueGeLzcN
vj1IUvgwmQc1NbmZDQ9pED0TUPioMQ84JI/ziwsVwuN1/M/3iubBx51ctwoU
C0Hkro/dOH8eVGxla1kyLIRXRxlv0LnzoGFnqhwlshC2Hx/cuY01DzbV/FOx
flIIlJiOoNzPudD4LewZa1gR8Ggvy6vV5MLHzxlTF7EY+Nwrk0K5ckG7od0t
dKgYDEpITH+35EKoaVuu1EQxJFw/1R3DmAsBX6X68zaVQF7j7HXfHznwLcBP
8J1pCTzgCStjfZoD+tUsPU2fS8D4U228WGYOvF25PDu7sQzqlluEMn+Sge3p
7bzYXWWgNul44vg4GV54z+zZKFIGgY+tSf1PyRCjs+XBvG4Z/Nx4dcOnFjKs
7X34xTC3DFqqff+QnchgtlOHj5+nHEKrJ93mHpEgjzHfdkygAhZUQtzWaNlA
+uppGyddAX5CQSOt8dkwv66BznGyAgy/hHaae2fDjNfjGQ7PCmDsankfr5oN
o3+FuiJaK8BfX3/V4GsWzHdub/y+pxKe/e7ienwiCwrXRnhtKypBLr6Vq+Jl
BhiFrBO2rq8ER9fjgQs3MoCX2udl3FoJEtbtkYpNGZA200M5gpVgcp//5oWo
DJBucuYlv6uEIpOnmnv4M4C+LSF3094q+Jkq18Xlng5+K6/U7+VWQbDUkMGb
mVTgl/q14FNYBc0im07lvkoFKwVp760VVZDJEx6ofCsVTq172HaipQoGh81C
4qmpcHHpkIXB3SoYY4uTb1ZMBbsinUX11SrwPPYnjJqSAm9C9F56nqmG2MPz
p5h2JYNd9YurWg7VUOul/mHoXxLcP3NNdO/Zauh61vOkcCoJaHLKlW0B1XDe
99fbbT1JsIXTvIOSVg2KXJM9l22SABu/zPFeqYa509337lQmwi+L48PAWgPm
oXcveB1MAIXJgSPiW2vgdnkRZWZLArxQTubm4agB3WhGJe+leLitt/3i6N4a
eCFm+9vibjzsfhR+fqt4DWgxKMksuMUDeUDgvopZDZQnPZqQb4qD6ZcFAX3F
NcDSXeRx0TwGhMnhmybKa2Aqk9cjUygGNvzds+1fdQ38a80+ZfczGtQYwmz2
N9fAt9Smla/UaAguERvedrUGJsZcBBqfR8HsN6/wjpEaCJSTG7xqGAmUhXPX
mXbQ4fQu9th+9TDgtzxSVcxFB/4L/E5lW8PghqRurRA3HV7vmCtyGwmFSnbS
pkN8dGD+HuM95RsKW5oHDz8Qo4NrYIldeVEIJKxGvcs9SQcVmaS4+e/n4Fz6
pE69Dh2ipJqjnbvOwbPChbvt+nSIqUxzepJwDu4pRU13mtCh+lGHTsmuc3B6
a/SQnT0d5qRN/FZUgmB866V7R4MJpjE+mcwLgIeLRfN9oXRIVX4XzmEbAA13
OwVMIugwvvt284lDAaDG+7HcIpYOoyuP2JOv+kPmPv4JhnQ67Hxj7Pzhnh+M
fBvTsMikg6irxRcWGz/YmBzcWJtNB6aqqf2H53xhap1PrGgenejrN1+H3b4Q
39Fn/LyYDmNPdmpR3L3BzubM4+lSOlj+27e+4I8X/Gt0ObVaTofnYqLstBwv
iDx8SONvNR00Lyd9S+/yhHWG+XINTXTgc5tyNWDxgMlvv29HdtHBWMdsKbTe
FWyeiokvd9Ph0Kf1VjQ1VxCOy63xukqH3QK/7NvfugD/5bpK6KXDmYbbjHMc
LmBYxrGaf5vIV+6Ki2ecEwhsel/zso8ObJHVZRl7nGD7EX0Lzrt0CE568ay5
wxHKGB++CrtPB861TRPz3xxAXNlId6afDsLfdJsPtNlBWrqSyq/HdPC+4+YW
9cUWbpxTgn8DdIjwYR4a3W8LxyvFbRaf0GGbzsCW+ixr2LMnLmL8KR1aSD/S
uW6fgZPNJTWPh+ggc6uQPWPVCu7Hze7MfE4HiZ32pJSzlvCYIcnR/gUdurRi
pNjLLCBsc1nnkWE6GKZwK1U8MwdeGa7Uyy8JfRnfGBxWMYMzO0W6PEfpYLW+
3f/8HmOQ4f/uzPyaDn5ZhZURxkYQWVW3t4zgMdf5SaN0Q6gLvXyl7Q0dFvVX
+FVm9OEEiyNN6i0dPJUs1Y/Z6EF54vWkCwR/2FykKf1QB0QuymVmv6MDT8qV
yrS6k8BY2lazQPA642yTl5xacPFW2UPD90S++UulkKgBPvVxDA0Eu+T/OHpr
Xg0Oye/QWiGYJel1l72DKsQPsJSqjhHXX7r57Hg5wP5eng1JBK+w+H58E3kC
6uz+RiLBYz8P/LlpJQ89TJ7MiwRPOZ6M/SgrA/+2cNbxf6CD3HG1h7BTErjv
X7bUJvhVwWJIx5dj0Ez6s9/9v7jEeSfvehGw7qz/E0fw3L9ITrqrAPQXes7m
EWxYbpt3Q5sHqtJ/r5QRPNal/5NE2gxxY9t4qglm8FgaEPR9rrxl0cGkgmC+
82fKhvyZcJqnupZK8A0Sx1Zaxy683pyxPZngwtFnkoPcB1Bk7UmBz3/xnZ/9
ey2E8ZnrYfnT/8XPB6/bST2KdicMf4oQ7D9lSfniLoF+L5cG14j8hEcmKasp
0tiUPXT3IcHPb67VdNPlsO1K6escgue6ZZyFbymi42kfPZ3/ru8LslA9ADi5
otjwm6gvrz350m8VVeRYm5ulEyz4YMqZPqeGXXXnDmoRnMaZ/4m7UgPrVFq1
3hP9q5W2NrI+rYUXuNIt/AnO5t864Pb3JBqUXtWOIPpvK+we+s5aF9M+jYv+
IPTy73DjhNYmfdyfa/DPmeCxRyyTIV0GWKeTlCBG6Cvu5eFtXJuMUO4bn2QK
occon7nHL8aM0HN/xcjwCNFfeTtaWKcxzrl+2OzwirjefjDNycUUJ7eGFBUS
ep5uqXjWoGCGveey+R4QepfkbvMc3GaONtUT+3YQfhCVU8Kr1yxQU+1lgSjh
F18Z/bK4PEtsSZXfrPiMDjaBHowH3a2wnfp0XJ3wm9D6A42MHNZ4ia3R4ATh
x4RkYFadskby3I+uI4N0aDBMFztz3QabzA7Rlgh/T++hc/C72aGV1JvaQ4T/
pXMSUyLeOKB7sZDWGDEfLK496k7WcsR7wl5LOXcIPXsdyYu+6IhivEJpo7eI
+sd1GUskOWH+b4VLW68T/XqR+LNR1AUPKB79k0rMJ22X3TKcFBf0c6h2WSXm
V/rze9Yeay640mNI7eugQ1n6SvizQVd8pFXW8KeVDhz5IhOVQW6opeu3Q/YC
wVG88jZv3HBmQbvBo4XYf+3RdgZNdwzNMLfvbCD0NS2iwrjTAz0CLostVdIh
MG1L/myHJ74aFvn4m0yHdyF9KkKLPrj+V67nGDG/g/VkVpJMfdHAY0yul5jv
BpKkq/3tvtiyhee8ayodMopWWncG++FSmiuvSwwxv7VWm05G+KOeV4o7nxdR
3xLh8eDlAJQtucpQ7E6H3jXy0kehQGwpjPm55SwxTyR/86mbB2L+mwKG9w7E
ejofPN+0B2J3U1SXpDkdbmawGvgHBOGLgXK2KiDeP6rF5qxT5/Aa6ClcOkHM
8x/TZmU7g/Fi0o+xHnlCf6oP1wtoBuM5iZu1PZJ02FEjs2VDdTDqtZkaeh+i
Q/vrZ74c1iEosCqnWsxG9Otc5m/Hh6HIw/bG8PiLGnCuPxXCUxaBwvFvDqc9
rQHbfiW9kfsRuGdIavPI4xqgXJC6nLoYgSIB8+/d79bABw2D0cu6kege0M2n
2lkDcTMihiqrkRg7GbHyoqAGVj7oRQgaRaPrhtD7laY1sL6ZxJTyIxYnuylZ
JwxroDtpy/7UrXGoGy9WNqRbAyYRjm2qAnGo3vi85btaDdCT+/cU68Xh89qA
O++J80yL1pk7w+VxyKTtpdmxuQY0/LltQlTjscR+caPa9Wr4GZ9azhKbgBrh
Z6x6O6thMSr61FFKAm7MTDwrdbkaWJVXVU42JiCLyLvrbPXVcLGj/qPxswQc
MlgYCM4h+O/nrEGhRMyHmG/7nKrhwcBxW5NHiahU50KfYyDWL3kwc3hTMmLR
4pPmX1Vg+7ItrZo3Gc13aUg7LlZBz6rhq03Hk5Fd/UN7z+cq0Cl44HrRIhkd
bIz+Cg9UQenlqy/06clo3373yM+iKoisvj91VyEFWaspAoFiVWB/ISnI2iYV
xVqZM34IVUEj3/bFPu9U5J645+LPVwXGotqtfNGpeGFGJtWGowoOTra2XihL
xQT/dXN/VyqhR1xxQOBdKvZ+eznkd7sSdhdOi3vapOHbDpZpXrNKYBlfWSdo
kI6x62hlXAaVIP3tg/dtm3TclNOoyXqyEn6Va3w09kpH9VLPxHG5Sjg/6X9X
Iy0dZ9xTBL32VkLLMQXPoJvpqHLAY3P4nQqIPCo/8EM8A4uzdXftHikHF1Xr
C8qMmailvCdi6H45HL5eP/FreyZyxamUJHWVw+naq8fo+zPR+SlqPykoh4n3
gU+vK2SijfPfKibzclBb37p/iz8RZ/3wavVJGdze8y5z88tMfPvx4D3pG2Xw
u9PkW/6nTFzsIEl5tpaBgFlwO8tcJqp7sFy/ll0G5zqXDDtZsnD5AsMwq04Z
7OWLJB+Sz0KHRM82g5vEq7dq9z0dWhbq8Yoo7L5YCtr1DBWUqiw03POO4XV5
KWSrhUs+bMnCSVv7GL2oUhi0M3NbuZWF41cOZ47JlMJRiVOD9jNZ+DDYKPRl
E/E95lKhYaSajc9/h/02JRXD2U2Pp4JeZmPcVPKtS1HFYBJuZLbyPhvZZdrj
Wb2KIcpdZNFtKhslMvfvbTpZDNSrb+tYVrOxRfW16CWGYtj+oWzBgJuEKwxy
ax8CiiA+o/HKZzMSLvRYmi7aF4EwLUdvjy0JyZKagesNiuDwwkK2vAsJ1VcO
y+wQLQI1suSMdCAJq3+Mnlz3sRAmWadlxLJJmPmMfUzYqBACnawityIJr8lO
X1pTLgT/LXw41UdC+y4F7sEjhTA+nC54/iEJs+umXruxFMKhm4Zyiy9ImH/m
QEkgFsCZgvnUiK8k7LlrkSB2vgB453f+oM+RUCHG8uxEcQE4mfw40b1EwpGz
Zy31QgrAX/C1TsU/Epaq2RmsHCmAweYWR4cdZFwSK0wu5SmA3qXB5692kpGU
v8CnzFIAiuK9HxX2kHGna1tn+CcavPfceP6qABmTNdkHnxXRgKkmia1Vkox6
h5ZzXFJpkMqr6REkS0bFy6b7fpyjQbX/+B5+RTIKWu8ZZDWkQRPlgbOcGhnl
eeMX9jHRQDwuKMfsNBn/FO0ofLtIBbZL58ePGZNxxi+7ufgTFVzKNbV+mpJR
tOKY1rabVOj0XeM6eYaM319d/3i/lQoOew6FPLUh493T/Nxx5VRifb37J+3J
aLPmGz8dSYW/fqxiK85k7GU7/bDMkwpK0t+lJM6ScUF0dfS0FRUs+m24Ld3J
KAAF8RdlqJAqE+bk5k3GPvb4o/aCVBjy9r9m6EvGiEq+p1s4qeCsmP1W0J+M
iVe8BV3nKYBuj+3zg8gYycE+wz5GsLBSx+FgMo6MG492D1DAR9uztzWEjH47
25acrlPg7MqvwP1hZNxFbdLd3EIBVU/qQEQ4GUv12z9fLqZAyeD7RzcjyHj/
iO4Lq3QKsJ+Jc12MJGPoji3Pas9SoIluY7k3howVC4d/6ZhRgPn+eN32WDLe
aOmrnFWnwOSwddQCwS1iRkP5EhT4uN79WW8cGZWd9Ipl+SlAi26tC4kno4rs
ccbX7MTzwl7NcSeQMaooYk/M33zIFkxvaSB4ILjmK9/3fNjY4fb8QCIZmbqF
4m6/zocKax7nNIJXTseOuz7Mh6WTJ01GCA45JHyQpTsfKlsoFVxJZDQ+UqrT
VJ8PJ642qCkR7K5r7qxHywfnWhFZQ4LjAp6GzyTlw8XS66EGBLtlphXlBOXD
taFN/2QJXkr++VjCKR8OhHfe20LwX33agReG+RB906O/n3ieyZOP1aGQD+5v
7zGHEXx/1fwMz9F8iPwbem4rwcc6fUyv780HE3M+thwiH8elqlKHzfmQsdOt
/0/8f7/n9lVm/JUH3f4LLaYEm9YbaDZM5UEkzb2xgKhXz+K1a3ov88Cr2+/a
HaKeR0KkLs7fyYODmy+MvSPqH7db/HBBex4oX3+w7VM04Yf7ovJKNXlgvs7j
5FAUGdmDKiY+5eYBE6tEbAvRv1VG1hOZcXnweeOjywFEf7d4fTwp6ZcHNJHR
N/xE/znz6jjf2OZBU+3GlWuhZHQYHt0nrpgHAT4639rOkVHnsUrQa5E8sNx7
sYed0FuEXHRH6u482Db90MU8gIyL+1xlPy3lgnVDlwzdh4z2HM4u9RdzQYO3
WlHVlYzVRS9lJ8tygepQV3bDiYxnOmRzhTJzgXc1ZV7IgYzT/JrbWlxzIWc/
xaSB8NfxBlmTeeNcOCO81/S2BaEvyUpzOZVc2B0le/gO4UfKA9uRRzy5IPnr
nWq0ARm1Nq8E72bJBd+Ku0GSumTkvZnH5raUA7bJKw5PTpJx84qJ+6YnOcDB
umDUq0JG9brL7l7JOaDomzLocZzQq//jqAeBOXDN7OZ+MzEyXmvn2SjqkAPa
u5JWhUTISF8mX1xQyIF+qqBsDB+htx3h+tofyJAbHWr1i42MF26dtxXtJkH9
mMExwXESmj9YqVGnkKBVNut7yDsSPj1+u8/ZjwTzvM5fL7wi4cvbNju6BUng
sdEp/2k/CYfFjDSv5mWDjpI6x4c2EvYevHRS3jcLTstn3jsYTcKU5K7HA6ey
oM940vRVMAk7Oqz4fASzoObit5cBviS8JzhX3/cmEybqYlvM7UnIHran4aNu
JiRF2G79DCT0XnnbuHQ4Azrq5hr3/cnGOquzyymbMsAvyIPn/o9szDheV8n/
JR1YH5gUnvmajdUNlV5Bdemw/CbwvMJoNh7zGWzI5CfiuvnPJjuycXVnxjSd
Ow0qrA7c+eqVjXlZPs9erqSC2tv4UwediPcb85nzXK9SIfiAaIWmZTay+FYX
XaalQgPqtKppZOMMi4zwOc5U2DFwe01wTzY6WxsZiu1IgfUu7yzIfVnoWxiU
smchGWSiFKtMurOI92mv4c6hZEh+PEFluJCFJw7f2ySRlwxm+u/COQuykGnC
/AcjRzLU7k9aFXDPwvWpqlnHdiVB5NpjlbGNWdhTeCnztGgC9G+/LHfzWCbe
7p8MLNmSAKkWTVPv+DNRKsut4OdMPMSJ0RcnODLRf+zY79G2eDh7so/74nIG
Cqtzf7RTjodJu353qd4MPLdbYdDdPA4ORp0v/q2VgdxrE/zt8nFwYO6s0gXZ
DOSV91XaxhsH36Zu8OkIZ2Do81nnn/diYaNQTLUSawb6H7bOUJqIAdVfkk4c
D9PRy5/H20UoGrZ6KpuEnUzHsGsbbA7PRsGdnCaJXpl0dBgV/72zKwru0nXk
vgum470Lf9htdaKA4c9iBxNjOg5whbI2+UeCuI102iFMw3M3Rr4F9oXDpcyo
Fr7jaahT4/OHNyMERKc+ZC1sSEUeJcWqQpMQWFjO6L08k4LDwXeGNHlDwPvj
rR2WIylYzyfwWu5SMMj0bDhofCEF28YzItJen4MPhffnN1ik4D9P7RsbFYLg
71HLCLuaZLQcPMh1jykIumyllv2zklFFc/OP3meBYCxxvMQ9OBkNb7GeMvEN
hCm4ZMV8MhlDMkwtuOoCwHbbw671X5LwXIHtAxk+fxirtoD5Q0k4MAZCa2N+
4FuTaGjOnoTKJUF96xL8gIvLKbvyZyJSP27d733HF6x7z2SO9yWiVb+AyjMj
H7DSU6gUdUhEuW0GY9bxnvBkVpP1Ym4CFrOeLHqk7ApcVI5jl8ficD3NtFxz
0QXYBbp1K+7GofT38VOSTS4wtGRyKrglDkX7Yo547XKBNwblc69D4/BD7pGT
lstOUMq5cozCFof1lL3s8Y8dgCZFn3bxiEE+I5KOa4YDrGtc87SViEHl35pZ
t086wP2nUz8P/Y5G45uz596n2kPbpnfqklnR6PX655BAki1o1ApLCrREYdD8
mbLzzVYg8tzJ1/tTBCYLeYXvlLaCOn2lJ6mNEXg4Kps/Di2Bs84wNdgvAk/t
md5o9dICrvdmMt//FY5SAkd9ZTnMwZ5H7ukp9nD0FZaXsbpmDOufZuf0HQvF
tXOjfkfNjeHdb2tf5h8hqCbMKb193gjqxDd93dsRgvcdWj6uFzWC4Qt3H6Ji
CC7ejNt4xug07JowX57QCEaW5ZnVrLZT8I29dP6qQRCqXRxfZP6pDVpBf+b6
mIPwF6fNgKqiNrTdDdxEuxGIlPG+nF+PtcCTztybczwQNbqPx17l1ACDzRVp
X7YF4MqXz0XuPupQ0RvZLXXfH9cPsEZO3FeD7GOKHtqx/tjXlsxokaYKg465
s3kjfhgueOBGg7Ey8GwYdnbL8EHhH61twceVwPijaXDakjcek/2ygXHnCXj1
UsJA0cEbL4toVwfPyQPfs1c95lJemDrPe1TgqzRkNp1VdXvpji8afOwCVqSA
4XXoaW5wR6HJE1erN0vBq2vxM7Z1bmjwS/0jqkvAP0c9jYqgs3g14UpE+08x
ODhkvm0jqwuqILexv/8RiDpyz83Axxn5DgkekPkpCvrPHnAffuqE29M2Rq0T
EobKZ8YL5QWOyJDe933XEyGYygddmV8OmHzn76EzKYIQ6Jvp7GjjgNr/uu4k
7hIAyRge30llO7RjFNgetcAPy7Imp9oZbFHQ9M3izRE+eHbjk3fTTWvceZe/
6WIxL/iP1ppvU7VCTtNvgUFte6BDjh4f988C8wrWNnNNcEPrOkov93VzZLEp
NZDL3wmqPh9k70ubYsu3tXuv2bnA9e3mkbdzxmhtZHCpqpYDHhvfNONtNsJv
uaELxaY7QEnKfSzFxRB7rjgHvdq7HWYGH5tLKxigccaq7PAfdkhpOjl0qVEX
J3KsGu4tsMHLu5sKE3edwsnsq8z1e7bA2flPW5oTtfBvzg9BWugm6FquoArP
qONo44uhDiZWsKnfXPDHXBUPTEm/E33ADO0ln78aRClhgvXULk5kgogAnaMm
J+XQkuPmacrURvjnPtLLxC6JffspZo81N8Ksss3A87rDSM2RXh0bZgRhl74P
a8L8KBwcvmm+hBE8B8KPiORtQuG3klb/m/xUFvvCJ0LCyib/7QBMKlnx
             "]]}}}}, {
        ImageSize -> {300, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, 
                  GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJw913c8lt//OHBu2SO3232nbHdCi1CEnMusVBKlgVSyV2VEAwkNZEWiRAmJ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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJw113k8VO/7P3AkS7YyQ7aYMaQ3SkkhcRFJJClJe0SKUihaLEkl2ZKUtVCy
Zo2ynhtt9hhboezZzRHZ+d6fx+/x8weejzlnzj3X9bqvOYduc/WwHQcbG1s1
/vW/v//vRw79///ulfF8XV5hIPWjpjqXUp3h7w9vmQXsab4dx7wSfeC8x3Pe
aew9gonX2q89Bgef/Iej2Le8U7e+jQ6FJH/tiG7sk5nadRcXw+Fruio0Yev0
T93LOxEFt6I2eH7ClnnZxxaU/xL867yP5GC72SmnzPjFAyMzpyIW+9fw4DGn
3NcQ+mBd/UPstzmrUlM7E+Hd3Rm3K9hcwnPF6VzJsP4FUWyOHZESkHF9Syp0
5X2K344tseQfw3E0HcJeWitQsAeX/72xvJ0Bgcq14tXLDFQ3vFCafC4bbucc
8n+N7ReTttfDOQd8Sptf3sK+XGItmuuTC7xFB8qksR+wPWIax+UByTb1fWyJ
gRIS5X6lZeRDTMuawELs8HPqV64VfwDVS4O8pthSJVdPyLUUwN2hM/XC2Bri
gz8oPYVQvDZxb8siA4XZKdLsx4qg8ufKfktsIYMcfU2OUkjgD2zdtcBAKDG1
w1C4DNpcpfaPzzOQS0ZDXF14GTwO0XJ7hW0utyqAR7wclB0f8CzMMZCYcNvk
U+kKaLLpU30xy0DXhYLmODZ+hnMb/N5qYKtEG7dKJX2GmUj3rtYZBpLl/bhh
SOEL8J2LTxfC3mk4vTpy01eQ1n9fbTvNQJWH/DYf21gJnTtOv5iaYqDttgFa
qxMr4dX4GrV72MIucjN2jCqon6nof/6XgdLrvWNAphoMD7WavSUZKJlZkWhB
qYVGi5/2Z8YYqOl+N+uh23ewaPdzJ0YZiLE5ezDs43eIFrAQksb+rJ3xzXX+
O2y14//FHGagdV+4jqd7NsAtJysF2UEGss7jt2G/1wj7bJk9xj0M9OVe7E3d
e02QUpmv86CbgVqd3jV6lTXB7N1I7ZIuBuq99u7WE7ZmcB/jVdr4G9e7tufb
Zq9meP/P/G97O86z34CcuXsLDIRYZbY14fVNO0XqWrfBQe6bq8aZDLRt2Opn
fmwbSB8zFmHH5loaaGD72Qbo1aubtAacz8in7GsP/4DzF9dfNqhloOeyTpul
dH9ChvMTN9nPOC8cDryTlA6QnjVwpH5ioKMft4gmmXbAr5lFdc4KBlptu950
q18HqKvwnetEOK+SuyyJuQ6IXJsm5lbMQJa3+eK+d3TCnJRI9J5cBnKaW3fv
S9RvmIuw51LIwXkNX9GRrvsNxzvkknizGWjknI5oMlsX/BOWC67MYCD9rRbH
47d3QWcuZb1aKgP12SmFZEd0waxdmlZeHAN1+n73NTnbDXs60qM9XzGQ9zMH
uyr3bui/q2ho8BKvL8L86c4n3dCi/Mu7JpqB1i83/GxB3XDHIiL123MGevb2
zX11eg/cnBNYuRaI83fppZbHrx54TCtOkA7A6zHIvtAw3QPSB94kVvkzUNkr
dwpVoBdm2w/WbfDD+8u6dcVaqxfC+PfUZ/kwkMXSuC/tRS+U+krmPHbD+eDV
3q5k0get58JXRM8y0JC5RWxIYj+slMUkR51moL3vz+ioFvbDtYHdg1KnGGjy
S45fRV0/2NxeVtlwnIH4rUPpOTP9sL3Vj0PgCAN1y0a1EEYDEJBSVJRqiPOS
bX8p7s8AnP8xVDqgzEBXX1sfDBEbhDO7M3xBCefdfnxEQGkQvC5XcL74j4Gy
5kLe3NEeBPsdL3T3bGSgl+MON+Rs8Osu/YS/DAONNpJzaamDsDhg0NO5joEk
eSgN4RpDcMQ/41nCtCz6eFSznrVvGFIm48h3f2VRw7asVyXHh2Fs3GPxAymL
TpalMtwdh0Fb6C3925gsYmtqOJEVPAzcs2kNbf2ySOmju+jupmE4mrPMXdIs
i2TYE/aVnByBojX3KqPey6Llkst5j0+NAttz/iSvHFm0Q09pZsZxFHYqy52z
zpJFRXpvQg/fGQUhxhsHRroscgu7OlAfOQoK399zRb2WRTXabJkjzaNgJL7y
8PBTWXReROpDuvEYHKm24Z53kkXsLvl3PDaOQ+MQxbjnsiwS2Gc7SqiOw3DU
hdxKB1mkuvlP0V+dcWCJmSyHX5BFddvG/ZWPjUOdrn+Y3Bn8fhByvvfhONgx
4jIlTGVR9f1gcYfecXCUPWvioiiL+kTLFheeTEBGBMNTb5Ms2vRWY69F9ARY
Dk/OCG2URYeV/96LTZyAROGSmlS6LCp/pTHJUTgBgxIHhNrEZNGXXE1liZ4J
0FMo/LmOG9croEOdWM8CXfGVWN5eOoq/PRgXd5YF1ofzlcK66EgqXadEy5YF
jqMJPFK/6KhMNdWm7iIL4h7q5Sn9oKNFq7tHfzqzQFMpcmlPPR0dLbJRC/Jl
Qchkm8PhIjqyu1gbZ53IgmoZg4cNH+nox5/OGrcUFtwsurX6UD4dgSxbnu87
Fjz2uaRmkk1Hh7o1vtzPw+sJYru5K4mOImcM98l9ZsEpvsyEpad0JC8tU9De
w4Ln7GeDXZ/Q0eYnnGpOAyyYQlvIwSA64hOKjJsdYoH4uQFa4yM62kbYnJpm
seDPvYr9L73oyLzYpyR4mQW+znGV0g509LBCTdpAjAR3oan3gfZ0FG5/1OSY
JAlej40V523piNvINc5GmoTCjo8fmGfpaGr/ru/WciQ0WSR7+Ryloy3yy284
tpLgnar9+ZsuHeU2vpZs2EvC0JPHK1o6dCRa8snqlBEJLzhNf2Zo0dFHWumu
LmMSLC6l3gjbSUclipT5BjMSHFcEzlsp0xGbkho6fZyEdZ9y1jWup6Ofw5G7
xR1JIG1s20CEjg6KkcZbr5AgVf3n0DthOqq966aqe5WEx9pXT/oJ0NHNPY+j
jF3x+z+vn1RfhT/v3v2b19whYcDVVCBwnIYSVCoOqfuTsKbnisP0CA3J3a18
2PmYhBOqQf5nhmioi3em2iOQhPcEc93WPhoK4zEMfRtCQtfN+gvff9BQ5lWF
C0nhJAz37mCpt9IQ07DdVfQFCaEl2fqvmmhof0tOmlcECSMc0weu1NPQ+9Mm
SbuiSTheNsvJ/ZmGTleHK1vHkVAXeHzhcjkN/aa3D0XGk2B2ZKCikaChqkzd
0eoEEjLWh9THFtKQffZwrWQiCZcvXR7blkVDwTxbzjumkFA7eyf0+TsaUmwd
THJKJSFNqE5oIZWG9p1CBxzTSBCV2PuqIhEfX6n/6dA7ErYG1cofiaYh+TGh
yposEtS4viX2RtCQ2gX50qBsEjrvDvBdf05DLOFRrv05JJgXtQY9C6Uhwad3
X2bkkjA9fiBNLoSGYvt+TFq9JyFcSSrnfSANDa9f+3YJ+6twnleTHw29LXVS
25lPwrW+qb22D2ioacxApAr7l+Cdub/3aIjv3pFzVh9I2FlsuIniRUPi5jd0
bT+SoH6BIzHhDq7vvp3t3djKH1hrVW/RUJ1EwMjxAhKkY8wLDl2nIYU6k5ua
hSSoHts189uZhmQd7ObjsC9x71G4ehV/vhNOSxxFJBxADOPlyzS0zkP7/lns
i+FR54IcaOjLu5TQfOz9UdaOUhfx+bX+m3iKSbjds90xzY6GuD++N7HAnn88
cKDyHA0N2hvu6cC2FtbeanWGhl4PnpAUKyHBUCmA789J3J90kcCD2DuHAn7f
OI6vF2r6whu76Ox8OucxGrp3/QekYdskhF4Ps6ChKLUnjxqw8z/xq8sepiHN
TKPrk9h7fm6czjKjIZ3yH6sFS0kI+xeVCaY05G8ioSuHrbZZzr7OmIbmN3XL
78DOCvWUOm1EQy4aqwt1/3e8us33kb24XsdOrxhiX1IN8r2tT0OkLZrdh10S
XrCTV4+GPmqvTtHHlryRMPxCh4ZWIw7KLmyhPo64jbtp6ENliKYSNuNf+LE8
TRrK0PCVWY/dXyoqbKBOQ5XDuV+X8Hp/m+t+b1TD9SmZVfuNHVte+9RalYZG
QzY5FGGnyt0+wVLB+deRcHiKHRbAtsl7Mw3Rkt+o22L3rpFaFFCiIaHUl81b
seXz/VpjNtGQjexvw1lc7/645UKljTQ0O747uBA745dWUiGDhrLHgjPcsQV8
52P202nIaTEtVQW7wHQwyV4KuyxB7wnu74booNJ/4rg+2xV7NLANY+O6H6zH
76fcdqkD50VIcNHsjTANrdmyahcV+9vrwpjta2nIktz8KBnnzXU3c7ZcAPc7
9+c3dey6T8vd3Tw0VJYusnkfzmffRkdxvWUZJNsQ+v0/nO+U6IoHM7MyiFq1
/ZB/Hgnj1xXkMv7KIBmvtfM9eH9kNvsuSQ7JoNmxo+338X6qb8oym2fKoP5K
ym5fvB8vTz64lVMng1pvBt94n4nnyw2THodKGVQTsvDvdwbOl4qEe0epDNpZ
86hLHu/nnxN/fpanyCD1Uy75V/A82Ftm/Z/nGxl0Y5PvC+dkEibmsirUX8mg
eF6dX1eT8PXpe3rePZNBat1BaSfxPEmpPzQV6y2DbpVHvGPhedRRrdQcfFQG
8au7hFDwPCuVt084eEgGVbr+eUTgeRc7pNcsaCKD9sq4MS48I2FZxcjlia4M
+htRZPw6lASR3QX5EUoy6PDUUGVnAAmz7pqNpewy6J3aSJWlN87Tw5bCB4vS
SMy7MCzDkwQe9k5Z0xlpJPpUWJPdA8+vkgj3zlFppDuosenFTZyH1tFznG3S
yEPVmu2hM+6XUWf05Qxp1CYY3uZiQwKv8cztZynSyD5Xpi36HJ4fwb9/Fb+R
RppxYqHoDM5Do5umULQ0CnZ5rrV0ggT+VQZWhX7SaPcP/2/6R0gYzHfbqmQt
jaqSg6/x6JOwWlJp1IuKj6fzOD6QIaHGPMKnQEgaBej98VPagPPmnls6tUYa
TSdro1oJ/H1zz0ztCrs0mrwSGsIlSoKiRYLShfENqC0zZnk/P56XL77r3Pq2
Ad0Q8KmRmGWBvrl2hJLnBlTPdityroYFDy6yNzy7uQFp64saq1exIPM0vWbZ
dQPimNwZ7fyVBSNxqvzNDhtQYhOh2FHGglcS8tWPrTagM7NVZv75LBC0eskm
pbYBHV8Tr2H4Cp/f+0C5fUQK0X9JF59xYsGTuVMmZ/5IoWdTl9fvdGTBu1N7
9vX0SKFfnflX1+D7l6D5Zz9Gf0ihkO3VsqnWLPCX6/Pm/yaFbu1o6P1swYKH
GV4hbm+k0MY+ZSvnXSzolWV4LpyWQvuul+mmr2JB9Ln6nN3HpVDslS1eH1cm
wKxQb423hRR68FBFW3h2AvpGSDq3iRS6n3tdJndwAgSvfueX15BCdz781Eur
nACJrdxhEcJSyNc8zPbO4wlIdrG7YftNErnJvD1axz0BdrNpbKXqkmipntO1
dXIMlBKsVKK2SyIjEW6ZO8NjIOwy+8BdRRIl3ghgSfSMATm0690OBUmUHn1L
0qxhDH6zj00SopKohPeB2uPMMXi5jtrE/08CUZrknhxyHIO8RxtTA/IkENm/
tc6waxQWmVz5OzQk0E0h7uOSZSMgq3z7EM8ucRTZ8eLZV7UhUHgvcj3bSgxd
IcuOtyYMwJnfp7JMY9YjoeInHp/1+wBiTrMJ/hFF+f6XHBrrukEiX+eE1mFR
VCu5OLfX9jfwmxpemv4kgsoVXy3lnWiHyXXXv8WbiKCx3Md9hUJtYOYieHFu
vwhKdTuU3MLZBr8Trnw1NxJBm81r5ZfmWmElOKKcc68IYi8IsXboawWOA67P
XXVEkKFBpt2XglaQl2kUvr5NBB2rERt9dKEV+AquayysF0EhPzZuOP6tBYJu
29heEhVBS9e6dJtLW+BrLku9jSqCbvWbpp3KawG6fnHjh3UiKDI/0iYooQXi
ajORF58IctpqTLh5tsDDIzzViitU1KX58cjlHS3gt9WT/d8AFcmfE11eeNcM
qv9e2x/rp6LNWc8P7EpsBiNa7vWCXirakvn0/MOYZlgscPf27qKifzp7lvYF
NMPFdyJalJ9U1LDv7FnnS83wptfnglUtFS0JBXee29QM/pMy5w6/pyLRNKul
hqwmsB+eTfySQ0XtB7eMNKQ0wVDAUWetbCqyDCyQ7UpoAiF+vWcbM6j4fkfl
tkJ4Exwpdx3lSKYiTnYLcZvbTbBb+NdkYzQV/VmlF+y/rwmeRrsVf/OlIjGr
n2x5o0zYcMCk0/YeFYlnjh5p/8OETZb6Fuw+VFQOVZcEe5mQU03R0/KiIkkd
wT9RP5iwPcRlKecmFe1bqbY3/cqESf41WtlXqKhGNPueRCIThvdPHjl8mYrY
UgVFBOOZoKTW+v6vAxWtV28KFoxlgqedgIn6RSqadSrV2xnOBLZg+6wyGyqa
SaT30x4yYbHn1tOeY1SU12OQbuvABBWlpVI/Syo6oxD4TMGeCXpnp+U2H6Wi
PX9678ycZwL3+djIm4ep6OILiknpaSY4l2nyC5vi9U9EcQyaM+H3ocbhjyZU
NGAQNC9shs/3CF04a0xFL55unjU+gNfr1ZGZsY+KDFu+cPcYMoEhRTE+uIeK
54FvSPpuJni4Hoz7p0tFMQ/4a2AXE36J2tBfAbZJN7VLnQlV4o5xrN24PzNF
dfu2MyF01vlmuDoVTXKfns9VZML9iE4+2Imvp30pK3MTE56rMcsH1ajo0oUz
tz5uZIK8Zt6L3apUpHPo8D5Slgkap8or+pWpyKDIb3hFkgkx/SsCL5SoSH3b
jP5lCSY4XbN1NVKkoro7Xmr9YkwYurAtME2Biq7aTnYuijChVbdb+/RGKto9
diUimsqE0llDbiF5KtpBkxkzpDCB63d5p4sszusJ3YsVa5mQdoc2JEenIpYJ
PHkmxITmxnKeVhkqulASetRFkAn6QbY+WhuoaGzqYNERfibUnElrG5OkoopE
o9PH+Jhg9/WzbpwEFTWm5b6yX8OEw7s4dVeLURE9aIEng4cJozlXmz+IUtHG
I/bb+riZQH+lfdNBhIqG9W2WNmJT80MVNlCp6HtT7hU3Lib8yQjpqRemIs07
DN/G1Xj9uieT762jokfpN3W0sItkxW7uWEtF0r9ux2VxMoGdf/jQoCAVnXpA
pqhiv8+d2hYtQEWJ69+cLFvFhKnvJyUO8lPRiTUn8k9h/5HQ52Xno6JfjT8L
ObHfGdUt5fJSUejA2KUCDiY4rqPPXOChopbCE59uY7/8ajUlzo37WdRWZYTt
8OveVM1qKhoasvRkYNdUon/enHg9S1rta7C//dgxr7qKipqFR3uX2Zlgc2b1
cj87FZkZVT9fwY5JOsweyYb7V6j9lx8f77lab9WBFQoK90ua3YjN9e0vx8oS
BfVXX35riq0FwSvZixTElkgu3MWWLdo+a7tAQf9tjZpF2CUB3KPr5yko/nFV
tAD+PGvZN/+smqWg1IaBvgvYMo5fyzxnKMhP9gizBntcfD5+6z8KuhXlegFw
ve6eHrzVO0VBFZbpsaXYPx/kGT3/S0FJ161vGuN6s/XeF9g/SUEX1s1M92BP
fbr1dYFFQXuMG0Qe4X6dOGa93nqcgk6v7tOcxf1sTIpKo4xRkHR53+4K3P//
Sh5u+zJCQVxPCn9H8TLBx41TSGmIgg423eC4hvPzuLDDtvMPBak+YPhcwfm6
u2o6OWSAgvYW74x1F2CCQZ/L7N9eClrcJp2WjfMpISXD8baHguTSCqO7cX5H
IyL+HeumoHsypgrSwkx4EX83pugXBQ069fGX4Pw7ZbJ/8vmB69tez/YU758i
zV+vRdso6ANf8uv9Ukwo+++ZTVoLBTW/8xNdK80EVUX5m01MCnr5n96lSjrO
v/qafrk6CopUbEsf+48J5K2umI81FFQnolAoqYz7z1aueKCagrbv3BtqtYUJ
RlXwyeUbBW2cbYxcVmXCSItFfUk57mfa1eUFPE/iP+eKHSrD5zu6GsQBExZa
zFR6CAqSkBM8eGQPE5iH2ojVJRTkdnY0uX8fE1KUjpsZf6Agd2U/+6IjTDi9
O2zbtzQKet7w5KiiE673BaLKMpWCplI+ORY6M+F6doxMfzIFrfrD2Hr8Bp5X
38Vn2d7i+kyFF5Z7MCHu5ODeHXEUJC+bELE3kAkBRQrnQ55RUAdrUyBPBhMu
Vo7uEA+joDN/Ozzu5eD6xsrkJoRS0JcJn9k1H5jg/8kz+X0wvr7Wd799CNdX
aeBc0yMKOtLX+s2JyYTw2x9FOTwpSPa19R/XRSb0ehjeeHWHgq4+See8xd4E
7+ssb+++jetPBr97zNUE2+56XL/hTkEu1WQUc20TSGkbr+11xv3XupS9IN8E
UdaycukXKGhZ5E9JwuEm6F/77vOEGQWNS8l+0czDvua7/+5BCnp0r/N9dVET
KOxysVprSkG9GQW/LpU3gQrnNqqKMb6+7LYfVfVNcMPq5MgFAwoS6U2Ulhlp
AgYl4TihQUGHd0++EJRrhvls9SMCdAoyi/7gPvWyGcbzmu2vyFCQgprGmvyk
Zvg1nM2s2UBBoTsCHzzIaoa1Dovp/hJ4f/h8lTtY3gwWB0uNFigUZJq869GD
gWbYsF1idwkX7mdg8OyjbS0wlzVQ935EGN2tWd9U3tACzcvST3flCiMjk2ua
vzTbYDQy5vU5TWFU61GtWhzYDo5Emrj6x3Uozdso7rLObzCc2iDvLbYOLXnl
7r3f2w02dhxhS05r0WzyWQHurX2QHifo13VRCPmk1fGaBgyAmKPAU95EAfSE
11ihjT4EzjLHDkYy+ZC/vNeuVM8RWI4dKz9ZzYeMNXJa3/iNwP71h7QkK/hQ
wWzu55jQEVALfLsrNIcPVT165n4/cQQ2e7X5Hw/lQ3fX/nNQrR2BultGUqcO
8qEFSow5h9QoTLIb3d/yZQ1qjhqQ1f0wCoWFynaG73hRdk1OdhS+X6Xf0rIe
esOLxKMMkkVHxoCR7L3iH8OLdqQdyg7+OwZzd79t/BTAi7o7G3tcOMchfLe2
tpQDL6pyOCPJt3Ec/L4XXTu1kRcdMPePv3FxHD7/8lWRi+VBexpL//IMj0Px
0zo3z2c8KLHXKGyBHAeLt599mwJ4UGlMu+/Q3Dicetg4dec2D7I6cQc+8E7A
ibMSZ7KO8SALc8Pr4v9NwGr6YkLWOh6kFifl/PcCtkFzgvh9bhR+8Exc468J
KJxTOXHyDjdSuvyyarl/Ar6HaUlFu3Cjpz0aH+TH8PGr5L9QrbnR+TQjdH5h
Ak5mev5gaXOj9u25M/V8LIg13axrOsOF1LeKtforsGBQqFQq/iIX0vSy5O06
xYJQ6vLk27NcKKftZqLUORaYXBlhT7PkQmmJM3stz7NgIDmo/p0BF/rjfe0R
usQC20ijwy9pXMjs8VjZNTcW8PMYuyi3rUai9485a4ew4EXZM8c1hquR4sX9
hq6lLCjId79F2b0ame/w1niEn68+hru+l1BdjXJYXzUjP7HgWNeNIob0arQj
NelEJn4+KzDvNaf940To2s53aS0sMJu0LP+cyIkeh+gf7h5jQXnlni850Zzo
zGFltzwWCy5+NZR+GcqJsns9rzz4ywJXzmNNVz05Uf/Qta9icyyQVWmNWbHg
RNM1yoifkwRWmElZ4ypOdH1bhs9GcRJCKWpKb+dWoS3jSVL5kiSUT29fe3Ni
FUo/fs5MT5qElSzNo+vbV6Hl97JXjBkk3EiPFjLIWYXcP/vSFTaTYPdz0d7q
3Cq0Rl1OkVuXhBdJGlXeRRyoVHMqfB9+fjbcesKyLZsD5RWf0qXbkuA1/V+n
SjIH+jTyIv2fHQkJP/P72p9xoOmg+6XPLpEgGfaRtsmJA3HGK16PvUZCbNvE
jTAaB+Kf3vfwF36eH/W539whyoFKct72u+Dn/TWL5sfkBTjQS8mGFg4fEr5y
367OnWNHOVv8bETuk5DItq3oSyM7ChK7XM35mITisLruL/fZ0Z7x/D1rwkmY
jPcOWnWHHfG1RVtaPidhl8jUPXBmR+KX99bEviBB7Dvv0bzT7Kiyse+7dBQJ
lyUk2yN2sqMeK6ORwZckZDSJS3xXZkeaRwwLhOJI2KgTn8/FYEfn3Fc3bIsn
4VuFsrCLEDvq9fjcYP+aBO0NlyL0BtmQvJbup6gkEl42/ea5/osN2ezRCoxO
JuHogzfDiU1saG7y74MXKSR0us/z8ZSxoeWQGA6fNBIK5Pj4vkSyoU/upTXi
mSRI3dAwmQphQ0689+v+YrfVTq+VfciGKJ7NQ9+ySFAYmtDwcGFDVOHL1rY5
JIRPPTZVMmFDZttfc5zLI0HcR+aKry4boifObqfnk8A0mxRr38GG7gpce9SB
LUMcl/OnsaFC7T8Beh9JONLvHPBbhA1569/cPoK9ZFUftIOPDb0tMp0ILiBh
zL58AI2sEBNeg88+FZLwXU+12KFlhVjgBnfLIlyf2l0DlLIVQtt78UwP9gdB
OUvb5yuExvs6lcFiEnZ850vj81khOjKvr7MpISHzeJRLjuMKESDyZqgZW6y9
wH1Zd4XojCpzSislweSX+afXSiuE46wuVYAggQ+9jDcSXSF+aF2Ov4g9uVpu
/RjbCiHBGShcip2ww045dGSZkGcNnhdAJJQ09Q+qtSwTEy+rQy2x+y/+Z9GG
lokrmR4RkdjF7rk37qQtE8+QwfWW/73+kPuo9PNl4rjzZbpAGQnsUilz6O4y
kX1ud4w2dk6xpON5x2UidPNSlz12zHhP1mrLZWLcbWYkAPus+r3GJN1lgmh3
LUjBjpXybN2vtEzMzBfuLcOeZxz7OiKyTAS4igQ1Yq9nhqUEsS0TLn3VAZ3Y
wZn5D1RGloi40Y06Pdg8oH++oXmJ4FW6GteFrcpdst8VLRFvdMYy2rATg5J0
RdKWiAtfhuyqsDmsHpp9CF8i9K3fleVhj450eB6/u0Rsy7hbGoXNVb+FueCw
RMgdSLe6hc16uGL58ugSQfl5M9Ac2zSyca2e7hJB/ttiycAmApR4+hSXiPd6
63PGcX2GeoMM/ESWiMPHb8fkYl9W8KxVZFsiUEfcOhfskXaP1LrhRYJ0YAoo
YvP4re11aV4kOhNOBLXj/thmFHmtR4uEO8M78CH26UcXlqzDF4mA2+Xz33C/
dxtemeC+u0iwgl1szmGPPY+0yXBYJH7Y9+wicT62cjsPL8IiwdPLUFnBeeJW
ZQgmKi4SGhUP9T2wt3DxNpiKLBJlvdUFkzh/M8jzcPzwApFhLVNSjfPamUOh
HWheIBYXS/dswY61HUmdIRYId4vzko9xvlWknUTNwxeIL7kd+Ztx/kv2i0sI
6i4Qk/LiW+Twftpu7beWobRAxLzmr7V4T8KUH31BQ3SBMOO37/LKJcEYymvt
R+cJg+huSyKbhAtzgmaNEfNE9PM+OfIdCRoq6rUTvvNEyREu3rF0EixHT/oI
Xp0nGqeyDHvw/o/W8E032ztP7Pu9rewjng/2JQlT3eQc8Xz3DwuRRBIEGnl4
13TOEd5smknteN4IDmiFb/82RxjE62tEJ+DrG5E7Al7OEW03hnm48Lz6FDnp
ZWoyR5w4fIPrMZ5vt59K2cgnzhJnhdXvGQXj+f3Wv+7ik1miXHOPcnwgCYEp
tjsz7swSTSq7f0/iefq+8IA4HJ4lvO8HHfbxI8E3TUf49soMIfkhZq3xXRI6
Bt1WnToxQ3DdkZv3w/O8ZmmOvWLvDCHDkIi76oQ/32SAt/K2GaIoYI/4ocv4
+yT/kxg3zwzxN6rYfcGeBJ+DvSntef+IiIgDfgtnSHDrir/FK/yP2GccxvbS
BM+rsx52C8vTxPaNjOPa+0lwjfKamBiZJm6wVRm0GJJwwDNrtuvzNDEkc6Nq
So8ECc0zb3pvTRMFzI49feok+A96kM49U8TOkauJj2VxXo+Ly4fWTxE9sxmT
ZTIk7Dk6fjm3eIq4v/5SyqQUCddf2h1jfzFFvH4isV93PQlUE1+HCpMpYimL
a00gHwlKWfvpf/L+Et2vEi17J1kwfi+WpvX6L0FUevFmTbCA/vpj+tMnfwmH
TauWboyywNPjov8Bx7+ETNCP6LF+FmjZJyuM0v4SuarmzgFtLMgh3EO6AycJ
gz4BXe9iFgQ8raz6YU8SY8E1oTu88fe/dTrvRguSOCrgcqH2Nr6f2Qih7rok
kfmNZ/QUvj95kt8VpyhOEheVeJZsrrDAuZunvqGKRTiJ7GlfcxLfbyR11Sur
sAhX5w1ZX9RYcC0ufUOjJItQ0SEE2lRYIGY3fsiTh0WYj30d7FLE9zuNz+Sq
KyYIJ2NFvh80FgROmxxZ+m+CCLKbe2fDz4IKX9bQx9kxwv/F4OvsCny/Z6y0
qapxjEjmeben7OMEiJ1d82AwfYwoX6B7Eu8mwC/u9cQB6zFi+3rLd34vJsC7
/PPP/KpRQnHc1cLQYQKsbvfE0ONGCJ4bo/7u/BPA4W7q/OfoEHEhbdW0t/44
bOPRP6+kNkRckfcpV1cfB4V1ERRP4SHCt7iv7LfiOKxL95jaXz9IfO3g1GcT
HofTf6eiAvYPEtGy6l/v/R4DEdXKiBLdP4R2anO0v/sYeGyVyLDc1U/sfaQ2
6RE9Cvc36Zpel+gnbtyoLtwWNAo/x8n++Pk+IuaaA63FaxTQYU6zzUV9xI6+
oOwx61E4fVVNgFu7jxDg5XE9pjAKTwv03rTo9xJ3AnMz12WOwGNvwdBLZ7oJ
xzDNGY6cYehkmOvp6nUTukHvX07HD8PklceBm+S6CXn98xxtocPw+Gb4ri3D
XURkjcK4o/MwHFuz1Cvk3kWUf+jqr1cZhotXpb+6b/pNbFhMr7qfMgT+/Yde
2xa0E7Zv/AQfPhkEf5l/uiW+7UTKye3nL3oNAs+dw77aB9uJW92PJjUvD0JG
cGxQXu9PIoJdOzd13yDsO1r902/tT2JnlvfJ8qU/0PHt36UW5zYiPU1G++uF
P3AxVGyCYdFMxOuaTwoqD4Ax90DcK5lmQuRP+oyY6AAEajk9MRtpIlTsBYsF
2QZg8VbF0AHfJoLBz7hWwuwHtYB1teV5TIL65Aivwu1+sO8qefpZrpEozG/Z
oFDRB0M28Sj6bwORVC68MpzWB1ZCT7emlDcQYdxHraKe9UHt3cwXDtYNxFYL
Zesiuz7I5HCsCoz/Tjx9NWDGxd0H8V9rFkmrOiJhRwhRtLcXnI4JtOcu1RIe
Mdn8Ozb3wjFhAcPhhFoiP/rn40hqL3zXcTXIH68hOO/c5ZHr7YGq4Xnn5oBq
ov18R6COdw94tcU1P+z4Rig0fOV4mNsNv8JHJzx+VhAdfLK5BvxdwFWw8Wh8
WAUh4mU13d7/GzYd6JDbaVpB7Pka48Kb+xtWLO4ezCkrJ6wi5GjTB35D8Ix4
y1JmGWFkoZMg6P0LjK255SwMCEJcYZXk3o4OGJW5/mnmUylx8Nx/VfpJHZBx
jP/JQ8NSYqBFm3eDSwdwWR3QuXighPAWjpc5y90B/5IHBA6eLyK0ek7z0Le2
Q8yo7Va10g9EfKt4wvPbP0D8A2VNm+kHoi5QPUhL/wf4hsnaOf/KJ0p+sKcW
8v0A9pQxNT+OfKKugc96X0wbKBwROWxu+Z5wPs5BiypqBZdVAZos5WyCWdBT
IPO3GYjLnzM1a7KI2rDORduCZgj0ebZ073IWceCcPuW+dzNkpevcVDmXSRgc
znppxtcMW8e15AsephN3olLeSNKb4JhvsWLzjiSiojw8yndvI+xoO6/ncu8t
kVDNvuk8RyO4Nxv9TWpIJCLv1XwWJhqgvtgtuc/9DWEypSLRo94Ar0cEW1p7
4wn3Qn4PXYXvIKVyyMBpbzzhIxjxCT7XQwOHvGl6ShyRNBx96KVWPeyPvXjK
dOolEX/6hdsuhTrYtV/52FO3KOJbs9jbsblqmFXUa4u3jSQMFT0lUq5UQ9/i
piBpqwiiIGnL2KruKii0+hrqZPacuLm20+PFl0qw3R/B3uj9lPiqyyDVgr5C
4KqXUu8jQ4l9vumrhpe+wAtPWQd6wRNCutmYouP0BVK2LagfXxdM1EYqzpWb
fgZz/7T0jmY/4tVB1QAdngrISjnKvvH8Q2Jnjozq8I1y2DVk8bFs4T7hzzd8
Xa23DGafLZsImt0jjjy9FfumGIHw0LJCHa8PYVvAcqjahIB2nK1q8ZU3oRFm
vm/DfwRkvbJhj1m6TXBu9T7Q11wMc1ucSmbrbhJPXsVlyqYVgZ0WU8Plgxth
9ZXvUax3IZg6sDvO1LoQd+X91I02foSQU240+uI1QthsodN9Nh/U2zTk9/k6
EYXrfSJ6K/PAnS3JolP+ImHk6D/o5JALnCm02FRtO+Ls0FXTYM0ccK1MOx5/
34ZwG1WxG+LOhgmbwXXE9FnCpOPfFra0TMg/a3KES+8kIVrPE/HG4B18UWy7
bjFiSVxPnGsiOlKBz27AtX/qMPH0yOY8c9dk2GwVHT1cdJBIqubmOcHzFl7r
VK94mxoRA2xjMW3Rr8GwmE9o1as9hPeArn7t5nj4JCP2qNVaizD+Xffsqkcs
BLD+qdpybyfWyviv2hoVASI1cps0zm4iPly76dz+Pgz+45LzLb4iSey6VTnf
ExEEykJVrg5neAiDFqXA3jJf0DZSO9SoNlj64Z5ZytVKV4iVX54fS76rk7Xj
+ncp8rPO/wHcJuDh
             "]]}}}}, {
        ImageSize -> {300, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJxdl2k4ld/Xx1MqoRQypUKDoYyZEpYkVCoypVTIPCczIfNM5nk8CiHzcA6W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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJxc2nc8V+/7B3CjZEUD0ZQ9ykihoUtWSDaFZGfv7L1XZG/etre997goSVtS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             "]]}}}}, {
        ImageSize -> {300, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJw9l3k4Vc//wLnXFsl6nUL27LJnSWas1+7aSiXqFiGRQooIkaUia6QiZEuh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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJw113c8V9//AHCy9/tNJRJJRSlZ2Zxj71WKomS1JCOVFimJpCQNomWUrSRU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             "]]}}}}, {
        ImageSize -> {300, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJxd2nc4le8fB/CkVJSUlYqMskJKJMmnjEIqyd4zEdkjyR6Z2Xs79t7z+NjO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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJxc2nc4le//AHAUSRtFkoZIiKgUqbdkRXYiWdmr7JWRPSLZ2c6xHXtvb86R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             "]]}}}}, {
        ImageSize -> {300, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"\[Theta]\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(\[Theta]\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]},
    {
     TemplateBox[{GraphicsBox[{{{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.368417, 0.506779, 0.709798]], 
            LineBox[CompressedData["
1:eJw91nc81d//AHCbRORaGffaRORSRsY5knEp3EvciNAg7aWUnUpGZGU07ZGR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             "]]}}}, {{{}, {}, {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[1.6], 
             FaceForm[
              Opacity[0.3]], 
             RGBColor[0.880722, 0.611041, 0.142051]], 
            LineBox[CompressedData["
1:eJw113dcje//OPD2oj3PHdKQJC1ChetKdTon7VSniJC2otLQUNLSEhFvokGF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             "]]}}}}, {
        ImageSize -> {300, 200}, PlotRange -> All, AspectRatio -> NCache[
           Rational[2, 3], 0.6666666666666666], AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, DisplayFunction -> Identity, AspectRatio -> 
         NCache[
           Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, 
         AxesLabel -> {
           FormBox["\"r\"", TraditionalForm], 
           FormBox[
           "\"\\!\\(\\*OverscriptBox[\\(r\\), \\(.\\)]\\)\"", 
            TraditionalForm]}, AxesOrigin -> {0, 0}, DisplayFunction :> 
         Identity, FrameLabel -> {{None, None}, {None, None}}, 
         FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
         GridLinesStyle -> Directive[
           RGBColor[0.368417, 0.506779, 0.709798]], ImageSize -> {300, 200}, 
         Method -> {"ScalingFunctions" -> None}, PlotRange -> {All, All}, 
         PlotRangeClipping -> True, PlotRangePadding -> {{
            Scaled[0.05], 
            Scaled[0.05]}, {
            Scaled[0.05], 
            Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
        TemplateBox[{"\[ThinSpace]", "\" \"", 
          FormBox[
           
           TemplateBox[{"\"Methode 1\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm], 
          FormBox[
           
           TemplateBox[{"\"Methode 2\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], 
                    "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxDividers -> {
                   "Columns" -> {{None}}, "Rows" -> {{None}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
            Editable -> True], TraditionalForm]}, "RowWithSeparators"], 
        TraditionalForm]},
      "Legended",
      DisplayFunction->(GridBox[{{
          TagBox[
           ItemBox[
            PaneBox[
             TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline},
              BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
           "SkipImageSizeLevel"]}, {
          ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
        GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
        AutoDelete -> False, GridBoxItemSize -> Automatic, 
        BaselinePosition -> {1, 1}]& ),
      Editable->True,
      InterpretationFunction->(RowBox[{"Legended", "[", 
         RowBox[{#, ",", 
           RowBox[{"Placed", "[", 
             RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Left}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Column"]], "Output",
 CellChangeTimes->{
  3.6627325996813326`*^9, {3.6627329079978013`*^9, 3.6627329270092726`*^9}, 
   3.662732969798592*^9, {3.662733017812614*^9, 3.662733047926953*^9}, 
   3.6627330810764403`*^9, 3.6627333127156825`*^9, {3.6627333724032326`*^9, 
   3.6627333884115906`*^9}, 3.6627335553208637`*^9, 3.662733595782528*^9, {
   3.6627344916516275`*^9, 3.662734520540094*^9}, 3.6627346269605184`*^9, 
   3.662914193769105*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exportRaster", "[", 
  RowBox[{
   RowBox[{"plotSolveTimes2", "[", "]"}], ",", "\"\<s35\>\"", ",", "True"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.662733697980934*^9, 3.6627337224783087`*^9}, {
  3.6627339691255555`*^9, 3.6627339717414083`*^9}, {3.6627347612616553`*^9, 
  3.6627347754447055`*^9}, {3.662914143930561*^9, 3.662914144460407*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143994596486`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000103835798214`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143994915285`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"2.044498554161722`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399515049*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119746682127`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143995395656`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00011899855959`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143995630817`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000103835798214`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399612254*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000139997495452`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143996387835`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119746682127`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399664503*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00011899855959`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399687024*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.0001197252663`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399740562*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000139997495452`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143997648573`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119884374172`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143997918816`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00011899855959`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629143998157578`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399866806*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00012008688108`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.66291439989143*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399915861*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399941379*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914399995427*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144000199475`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"17.22598069045638`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400068485*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400120026*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144001460495`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144001947474`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.0666360612438983`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144002445664`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.66291440044166*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"9.055951436806925`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400488699*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144005774975`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400629039*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.1538378204711053`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400678578*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.00001310462446363732`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400911373*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "1.986783059075089`*^-6"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914400934389*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "8.69563417679255`*^-6"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144009897594`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144014205112`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144015664425`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914401612452*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144016659126`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144017149477`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000018165215986448263`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144017369633`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144022562647`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"536.6628664205297`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144022998233`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914402387911*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914402439949*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "1.7189104382315368`*^-6"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914402490812*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"3507.0943993793207`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914402512828*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144025692563`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "9.408231217912257`*^-6"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144026195717`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"3.2467453498436307`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914402796007*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144028431897`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000012064693799224027`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914403041654*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"6.3735039664124375`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144031624136`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914403212798*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.0000209193490240509`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914403820002*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "5.299727671660088`*^-6"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144041407833`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "5.648511443492046`*^-6"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914404262337*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119225127676`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.66291440450126*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119225127676`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144045227747`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144045727415`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119225127676`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914404599271*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.0108444570601194`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144046498103`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144046713257`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00011904243323`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144047188663`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144047463894`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00011904243323`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144048009405`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"5.36941786163536`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144048249645`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.00011904243323`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144048750153`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914404901039*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144049480886`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"5.604698541158647`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144049701014`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405019631*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.7609664463813024`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405070673*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144050916877`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144051432314`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405167678*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405220227*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.6184929795367606`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144052427483`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.5820584937346902`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405293352*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144053183703`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405370418*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000015216884096927332`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405490014*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000023217935653315932`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144058737125`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119086560282`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405926647*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119086560282`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914405974181*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000119086560282`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.66291440602841*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406079447*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144061566563`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"3.98071669809996`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144062072*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144062975693`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000025131089338400427`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406349115*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"2.158099041125291`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406403673*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000027314637654779957`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144064491005`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406513386*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144065643916`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.1284318745667108`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406612877*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000118946613576`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406638401*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406690452*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000118946613576`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406714944*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"InterpolatingFunction", "::", "dmval"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Input value \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"20.000118946613576`\\\", \\\"}\\\"}]\\) lies outside the range of data in \
the interpolating function. Extrapolation will be used.\"\>"}]], "Message", \
"MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406764982*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\", \\\"::\\\", \
\\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144068184586`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914406866994*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"5.437215763395701`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144069161367`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144069679723`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.2481053748483921`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914407016383*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "bvluc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The equations derived from the boundary conditions are \
numerically ill-conditioned. The boundary conditions may not be sufficient to \
uniquely define a solution. If a solution is computed, it may match the \
boundary conditions poorly.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144071249757`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"bvluc\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144071733007`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "berr"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The scaled boundary value residual error of \
\\!\\(\\*RowBox[{\\\"1.3983768950942372`\\\"}]\\) indicates that the boundary \
values are not satisfied to specified tolerances. Returning the best solution \
found.\"\>"}]], "Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.66291440722602*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\\!\\(\\*StyleBox[RowBox[{\\\"NDSolve\\\", \\\"::\\\", \\\"berr\\\"}], \
\\\"MessageName\\\"]\\) will be suppressed during this calculation.\"\>"}]], \
"Message", "MSG",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144072774773`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000028113790470121556`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144075109687`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000049261937779789656`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914407937022*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.000027620657399057313`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.66291440839787*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.00002653343459750424`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144084564114`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.00003203643025923794`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.662914409271552*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1000000", ",", "1", ",", "1000000", ",", "\[Infinity]", ",", 
   "0.00011065144907659815`"}], "}"}]], "Print",
 ShowCellLabel->True,
 CellChangeTimes->{3.6629144099016533`*^9}]
}, Open  ]],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.019444444444444445`], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQGRB5xrV5SI7zN1AHMPhB84odyoV54I5TeEHfh3
49bFQGYo3yH0AN+X6XfzFptA+AwhB/SFdy7rdoTyDwQduLBB8XTEXWOo/sAD
RXnLTpaVQfkOAQeaGo0SC3mgfAa/A/a/5qnunGcEVe99YKobU/IsHSifwfPA
RcE7l/S3GkLl3Q4sv/Bqmp85lM/gcmBT1dKnaRsNoPKOB9K1ZTYFKEL5DHYH
Zq64yv2UXR/KtzzQGS2303SlLpRvcoA7RexbgLgOlK93wGHVMpmdZlpQvsqB
8FMNxwTPqkP5IgfkvxfUWBmoOAAAT/Jc+w==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.019444444444444445`], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQGRB0CkQ465A5h7IBzMPyAC5TeEQeT3mkH4DqEQ
fgaUzxACUS8A5R8IgsjvNIXqD4TIJ0L5DgEQeVYon8EPwl9mAlXvDeE7QfkM
nhD914yh8m4Q+TQon8EFIv/aCCrvCOGnQPkMdhD+OUMo3xKiXwnGN4HIhxtA
+XpgfsNuPShfBcJX0oHyRSB8cQ0HAJsNNdk=
         "]]}}}, {}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{-100., 0}, {0, 23.4228515625}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[
       Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(r\\), \\(0\\)]\\)\"", TraditionalForm], 
       FormBox["\"T\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, Method -> {}, 
     PlotRange -> {{-100., 0}, {0, 23.4228515625}}, PlotRangeClipping -> True,
      PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"Methode 1\"", "\"Methode 2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.35], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.019444444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.6627337771465235`*^9, 3.662733893717124*^9, 
  3.6627340360979953`*^9, 3.66273467428304*^9, 3.6627347487397823`*^9, 
  3.662734788479941*^9, 3.662735913135452*^9, 3.662914209712507*^9, 
  3.6629144114699316`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation: 3 switch swing solution", "Subsubsection",
 CellChangeTimes->{{3.6628787265350776`*^9, 3.662878757015112*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"animateSwing", "[", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "sol", ",", "anim", ",", 
       RowBox[{"width", "=", 
        RowBox[{".8", " ", "1024"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"q", "=", 
       RowBox[{"solveHautus", "[", 
        RowBox[{"x0", ",", "y0", ",", "0.005"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{"q", "\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"anim", "[", "tt_", "]"}], ":=", 
       RowBox[{"Grid", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Show", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ParametricPlot", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"x1", "[", "t", "]"}], ",", 
                  RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", 
                 RowBox[{
                 "q", "\[LeftDoubleBracket]", "8", 
                  "\[RightDoubleBracket]"}]}], "}"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                RowBox[{"Point", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x1", "[", "t", "]"}], ",", 
                    RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "/.", 
                  RowBox[{"t", "\[Rule]", "tt"}]}], "]"}]}], "}"}], "]"}], 
             ",", "\[IndentingNewLine]", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"width", "/", "2"}], ",", 
                RowBox[{"width", "/", "4"}]}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"AspectRatio", "\[Rule]", 
              RowBox[{"1", "/", "2"}]}]}], "\[IndentingNewLine]", "]"}], 
           "}"}], ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"cartAnimation", "[", 
            RowBox[{
             RowBox[{"Flatten", "@", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"x1", "[", "t", "]"}], ",", 
                   RowBox[{"x2", "[", "t", "]"}], ",", "0", ",", "0"}], "}"}],
                  "/.", "sol"}], "/.", 
                RowBox[{"t", "\[Rule]", "tt"}]}], ")"}]}], ",", 
             RowBox[{
              RowBox[{
              "q", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "@@", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"x1", "[", "t", "]"}], ",", 
                   RowBox[{"x2", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "/.", 
                RowBox[{"t", "\[Rule]", "tt"}]}], ")"}]}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", "False", ",", 
             RowBox[{"Width", "\[Rule]", "width"}], ",", 
             RowBox[{"CableLength", "\[Rule]", "10"}], ",", 
             RowBox[{"Variables", "\[Rule]", "True"}]}], "]"}], 
           "\[IndentingNewLine]", "}"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"anim", ",", 
        RowBox[{"q", "\[LeftDoubleBracket]", "8", "\[RightDoubleBracket]"}]}],
        "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"anim", "=", 
      RowBox[{"animateSwing", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2"}], ",", "0.15"}], "}"}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"exportAnimation", "[", 
     RowBox[{
      RowBox[{"First", "@", "anim"}], ",", "\"\<haut\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Last", "@", "anim"}], ",", 
        RowBox[{"1", "/", "4"}]}], "}"}], ",", "True"}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], "}"}]}], "Input",
 CellChangeTimes->{{3.6628787612409735`*^9, 3.662878837600401*^9}, {
  3.6628789503045893`*^9, 3.662878988872411*^9}, {3.6628790367380753`*^9, 
  3.66287907816778*^9}, {3.6628791368404694`*^9, 3.662879217380123*^9}, {
  3.662879281281475*^9, 3.6628793658319054`*^9}, {3.6628794063925624`*^9, 
  3.662879407494875*^9}, {3.662879437671739*^9, 3.662879561023386*^9}, {
  3.662880020326414*^9, 3.6628800823175297`*^9}, {3.662880338316315*^9, 
  3.6628803423583107`*^9}, {3.662880509140317*^9, 3.66288052650112*^9}, {
  3.662880606012805*^9, 3.66288060632419*^9}, {3.6628807327162933`*^9, 
  3.662880785203886*^9}, {3.662881212171753*^9, 3.6628812439946947`*^9}, {
  3.662889103556245*^9, 3.662889124484393*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"Final time: \
\\!\\(\\*RowBox[{\\\"15.607027780768504`\\\"}]\\)\"\>",
  StringForm["Final time: ``", 15.607027780768504`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628795000238423`*^9, 3.6628795611691*^9}, 
   3.662880020758587*^9, {3.6628800523830037`*^9, 3.662880103934041*^9}, 
   3.6628801382273827`*^9, 3.6628803499983253`*^9, {3.6628805099990597`*^9, 
   3.662880527790842*^9}, {3.662880589883342*^9, 3.662880607701153*^9}, {
   3.662880737961607*^9, 3.662880785884192*^9}, {3.662881227477912*^9, 
   3.662881234478095*^9}, 3.662889132443486*^9}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"20.281844755899183`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 20.281844755899183`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628795000238423`*^9, 3.6628795611691*^9}, 
   3.662880020758587*^9, {3.6628800523830037`*^9, 3.662880103934041*^9}, 
   3.6628801382273827`*^9, 3.6628803499983253`*^9, {3.6628805099990597`*^9, 
   3.662880527790842*^9}, {3.662880589883342*^9, 3.662880607701153*^9}, {
   3.662880737961607*^9, 3.662880785884192*^9}, {3.662881227477912*^9, 
   3.662881234478095*^9}, 3.662889132452507*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\\
..\\\\Presentation\\\\animations\\\\haut.png\"\>", 
    ",", "\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\..\
\\\\Presentation\\\\animations\\\\haut.swf\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.6628795011119986`*^9, 3.6628795622552147`*^9}, 
   3.6628800218206215`*^9, {3.662880053451155*^9, 3.662880104997798*^9}, 
   3.662880228578423*^9, 3.6628804531534123`*^9, {3.662880512112918*^9, 
   3.6628805294832754`*^9}, 3.6628805915957737`*^9, 3.6628806616133375`*^9, {
   3.6628807397639666`*^9, 3.6628807747201986`*^9}, 3.662881014875989*^9, {
   3.662881228855199*^9, 3.6628812361708736`*^9}, 3.6628892040433807`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"export", "[", 
  RowBox[{
   RowBox[{"hautus", "[", 
    RowBox[{
     RowBox[{"-", "0.2"}], ",", "0.15", ",", 
     RowBox[{"Threshold", "\[Rule]", "0.005"}]}], "]"}], ",", "\"\<s37\>\"", 
   ",", "True"}], "]"}]], "Input",
 CellChangeTimes->{{3.6628903366804066`*^9, 3.6628903737598867`*^9}, {
  3.66289042194459*^9, 3.662890425983644*^9}, {3.6628904981291065`*^9, 
  3.6628904984736395`*^9}, {3.6629143007132063`*^9, 3.6629143036902833`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"Final time: \
\\!\\(\\*RowBox[{\\\"15.607027780768504`\\\"}]\\)\"\>",
  StringForm["Final time: ``", 15.607027780768504`],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628903805747232`*^9, 3.662890426113742*^9}, {
  3.6628904872775908`*^9, 3.6628904986462584`*^9}}],

Cell[BoxData[
 InterpretationBox["\<\"Interval: \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0.`\
\\\", \\\",\\\", \\\"20.281844755899183`\\\"}], \\\"}\\\"}]\\)\"\>",
  StringForm["Interval: ``", {0., 20.281844755899183`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6628903805747232`*^9, 3.662890426113742*^9}, {
  3.6628904872775908`*^9, 3.6628904986497602`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{GraphicsBox[{
       GraphicsComplexBox[CompressedData["
1:eJxkXXVYFdvXVsTC7rgWttfuZhmIrdiNit2FgoWtiCgpggJyOAfFxEBERBci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        "], {{{
           EdgeForm[], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6], 
            Opacity[0.25]], 
           GraphicsGroupBox[{
             PolygonBox[CompressedData["
1:eJxNnQfY1tMbx5/n+e3HntmirITsJGQ0iMj4Z2crexMqicgWIWSWmT2KZJWQ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              "]], 
             PolygonBox[CompressedData["
1:eJwtmnnAltMWxb/ve5/3mRo0qzRLJZUrjUQzpVFSSZo0kOaoaJ5IM81CimuK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              "]]}]}, {
           EdgeForm[], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6], 
            Opacity[0.25]], 
           GraphicsGroupBox[{
             PolygonBox[CompressedData["
1:eJxNnXW4VUUXxq9ics7ujYEiWCBiEhaCKCEoKoqgoNgdmKjY3Ymt2N3diYXY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              "]], 
             PolygonBox[CompressedData["
1:eJwtmnfgzuX6xx97Pc/zeT7jaxxOMpKMomS1aWmXcqRQomGnpKWhzOSkodK0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              "]]}]}, {}, {}, {}, {}, {}}, {{
           Directive[
            AbsoluteThickness[1.6], 
            GrayLevel[0]], 
           LineBox[CompressedData["
1:eJwl2Hf8z9UbxvGPkVCRaE+KrEqlNGgptCUlEjKSCqGiEimjSbJCtpQ0kJEt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            "]]}, {
           Directive[
            AbsoluteThickness[1.6], 
            GrayLevel[0]], 
           LineBox[CompressedData["
1:eJwl2HccTmUfx/FbqOytokGoUGYRUpSG0lI9LSHSMkp50kBbFKWtrZJS2ilt
e8+szEShgVK0xPP+vp4/Pq/P9ftd13XOuc+5zu86r7tmt+s69ilSKBReLlYo
TCpZKEzEEmzGLpQvVSjUxrHogK7ojeplCoX+vJoblSsUtpU3plKh8AsvrFwo
LMJeKFuxUCjKV6A7DhV/z+/yzcZfWqFQ2Kh9mvapOB8XYIbcdAzQPpM/RBFj
N+B188fhDVwvbm/Mcfp/EbfmquIqWOVaNsltxkYcoe8HPpx/4nr8I9fNXGxD
L/MG8nD+lbdjEMpWKRRa8Rbjt2ErrnHum/kW/Bf9cRM+x8X6uvHleAWjsSbH
x2GOdV76naMj1xH3lH9YuyHfyyfqG8yNxL+jFnqL68r/wZMd708+lGuhNo4x
5mde4XfX5BrohxtzDcZ2MbfgXEWwR66b8XXkaqON/mritfLV+Xi51jhX/gDx
Um5s3jKejgbGNcS/zvUhlzR2KS/DEpQzZ3nWADfWV5SLoZG558ifixZoib3l
WhizD1c0ZoVcJW4l1xJHyi9ELeevwptQFbXFz/CC/LbcC3FFXo0KqCnuzP9g
uGM+iFY4DvvKfcAleDdf5nz/cmfulHWJxvo6yp2XdYWHcDxOwPY8I26LNpgr
Lm7uIc65yT3ZkfUt95DjjNT+AztxgVz3rHO+zLxO6C2/l3mv8xv4St/z8qPw
Ap4W32rOp/o+QzXtA1Be/m/9F8n9lTXHF8lfiAb6LhQ/yEfyQG4jP4i/x9HO
9x2PlXsNr+J28Q/8Jt9lzhHG3KLdQa69uKX49Nwn7MLdOE7uHr7GmKvR3fj+
4rdyHNQTn+naZmjPxPHil/klvIj64lV8Dr/Ao7Dc/Gbie7Sb89fij7XLaX+D
ps65jq/EjTmO/pdQUbtC1qH7X8qYm+VK5jdwT/lr0cOcdVwcw7O2Xdswfkf8
NjYYe7b4Ae2zeCjfj/Xy36KD3ArsweGpKVnD8mPERbQL2gWejmlolPql77u8
j/o2cM3cW/nDMUm8M2tU+1/sQk/xg9yLf8ucXLv2F8b+zn2yZtAL34oP0X8w
Vvvd1fzev+SmYZf41xybJ/JO/oX/4Em53txXfILH8CY26luVGs3j+FFMwEep
W7lveV9RDIvxFUrpm513AHNSl8ytkfUkX871VEB51M4xcKx2HX4f76GEuB9f
a27PvIt5tuZ34jW8NrU4ewsWY2veD4zDgeaud76V2i+aOwi3Y2DWnNwWNDPm
Zy5l7htZT/rKO99J3C61S66JvqY4Gkv0NZG7RfsD7Uk8GR/iI5TKOuS5mIc5
WID5OErfWY55Nk7GKdhPbjzvz1863hPYN/UOZbFJvBmP4wtUNq66fCX+XNwR
p5t/BjrgP3n/9Z2m3T51H81Sa+Xe5LdSn4zpJ74+exNvzu/jRRiJvuKnss6y
Z2g/mbqceo+z5Wq4Z6Vzf8WltcvgT8c6J7Us9TvvSd4RlMy1ZU/Vfjx1lcdj
Y/Yr8x7h5llj3E7+0TwT8ctY5tndx62NG8KDcX/2H/FQvsfYvbJ/4Ol8A2QP
w2bz/kzdw1P4B3+jW2pY9nU8hOdST41djNLmlcEIuequ+dnUUn6G92A36mOA
Y5xg3G1cIs8q+774ffFofgVj8Gf24qxNxy7nOF3znZA9nzvLX4YTcs95IS5K
jcZJqc35jkgd5JdxPi7Is8Vvqev6/sJXGJ11Iz8Rh+Br57uTZ8rfwbNSr/kl
Hsz34W7ci3uww/h3+F28jffxXsakljj+dbg39dM9r4xK2WfxXPZycw/mg3AD
+uI58x7lxzACj+BhlJV/KvsVRub+5t7m98k/yfP5cZ7HT/B1zrm381zP3dFW
vqtrOZGvEJfP+cV9Uj95D3ZnT8m+gYOM+caYA3kd/+xaP+IJqI96qJvfav6A
1C3j9sE74nrO+y4/i9eyD4gXmT9F+6PsmeIJPAqf4Cjxx1lbxnzODcVfpObg
MzQQf8qTs/5RXzw+exq2YXu+k/LOOv8xrr0Z3tF+O2tVX3/xT/xWaq72N7kW
bpF7lfcKj6FaagK34+V8cupZ7gUPyj7Ac1PTU5f4QPFA7eo8W/xwala+U8S3
a9fg+eJT3Z9PxS3FU3lkagJqZt/Jvpp7Z8yRqXGpCeJ54gV5rlidOie/znVX
99vb6m+T7wKslF+B37O2UQKds9bzvLlL1mb2Q/Pey3uWd8+8KvIDuCrfmjqV
GoOD9P/mPEPl78cQzHasn3CMY/yY99aY84xtJT6fT0y9z1zxBnO7aH+XtS0+
WbsdyuSauFTeRS7Na3kmZuERjMUa81bzxOwNeBJTMDn1SN/H5v3NR+V+YWre
Z6zNd7nrOjR1wdhf9R3P2/l0ub7GfM/FMER7BN/Hr2MsjjW2RZ5dvkXMOZjX
86lZf/l+4Cni3XmGvJz3lz9Muw52Za3glOxfeWcwJOfAaXLHcXu+1NhLsl/l
t3LjnNd9apLanD3FuAfyjSRerX1J3lfugRuyToztm7rJw/L8uJy+8hglfgE3
aF+Re5K9V/8aLoMJ8svyjmjfnf2Yl6bGZ5/EjeKNqVmpR9lXsv/on5E6mJqY
tSL/X7mufJX+y/km8Q7eKv4y9zTfAlmT+VbnnWlnXWEc7jDmR34i+7m5xfkM
8Sl5V/INI75XPBgrxStQLLXA+YvmWXFzDMMDeF7/JWio7+LcM3TKvqXvUt7F
e1zLJ3kPcTSaognmmFMl3wVYJV6J27LPy9+amp66lD0er+JQfOtYrfJMUTv7
hPPV4gWO8XT2FT48+4b2EbxY/Jn2Ij5MfKd2HV6YGpIaL56NWagr/wxPw3S0
Fj/Pz+FZTMw9xr7mNUzNdi2NtRuhjOPth+aeeVVebG4j7SW5v7jc+NP5Wn19
UFRfcRTD3vqWO9bo1DH0E19l7Ja8D9oN+C5xW+07U7PFI/Lb+SbuLd8/vy3v
jfZWvjprJXu69hgMzV7DF/Kw7Nl5J8VLsy5zvsxBjzwPv+dKrsCVUDHPxvVV
Mq4yXtP3as6d9Zp9Rv9YvIr14gLG6++A24yZytNwnnbH1Past6x5uavMuRrX
4Ey5HbwTY7DKcXrkWrJu8t0jPsmYptr7yw3PPc/77B7uh62usZb+Lby9lG/u
cs5bRs0vrZZpPyQ3Ut8MuapyvcR1tN/lLjgDzVEL5fBPSe8mFuMrLMJCLMB8
zMNczMFszMJMzMB0TMNUTMHkkv//H+p/CuGm/Q==
            "]]}}}], {{{}, {}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.368417, 0.506779, 0.709798]], 
          LineBox[CompressedData["
1:eJw123c4V+//OHDZSVLelSSRURlF0jB6FhFKESLRkEpFlGzZQqVky4hssvd8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           "]]}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.880722, 0.611041, 0.142051]], 
          LineBox[CompressedData["
1:eJw123c8lt//OHBZIZUUldGQKKlIWdFLyCZvK0VWqIQQIXuGZCWRkb3XfV+4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           "]]}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[0.368417, 0.506779, 0.709798]], 
          LineBox[CompressedData["
1:eJw923c4lW/cAPBDEiKyspOQQgsp1I0UWRkZibKy9y4zO3uPzDMoGdmcY3xt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           "]]}}}, {{}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[1.6], 
            PointSize[Large]], 
           PointBox[{{-0.1019367991845056, 0.}, {-0.1019367991845056, 0.}}]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[1.6], 
            PointSize[Large]], 
           
           PointBox[{{0.1019367991845056, 0.}, {0.1019367991845056, 
            0.}}]}, {}}}, {}}, {{}, {{{}, {
           Hue[0.67, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0, 1, 0]], 
           PointBox[{{-0.2, 0.15}, {-0.2, 0.15}}]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0.5, 0, 0.5]], 
           
           PointBox[{{0.2697367991845056, -0.03855104885008169}, {
            0.2697367991845056, -0.03855104885008169}}]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[0.5, 0, 0.5]], 
           
           PointBox[{{-0.06586320081549436, 
            0.03855104885008172}, {-0.06586320081549436, 
            0.03855104885008172}}]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Directive[
            AbsoluteThickness[1.6], 
            PointSize[Large], 
            RGBColor[1, 0, 0]], 
           PointBox[{{0., 0.}, {0., 0.}}]}, {}}}, {}}, {{{}, {}, {
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           FaceForm[
            Opacity[0.3]], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJwdl3c8lv/3x6UildCSSIXsGQrhyMreEkqpFCor2WTL3iN7yx63vQ5uq7Ju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           "]]}}}}, {Axes -> True, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, DisplayFunction -> Identity, 
       Axes -> {False, False}, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> 600, 
       Method -> {
        "ScalingFunctions" -> None, "TransparentPolygonMesh" -> True, 
         "AxesInFront" -> True}, 
       PlotRange -> {{-0.4028923190892542, 
        0.4028923190892542}, {-0.16291004603066292`, 0.16291004603066292`}}, 
       PlotRangeClipping -> True, PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.02], 
          Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      TagBox[
       GridBox[{{
          FormBox[
           
           TemplateBox[{"\"u = -1\"", "\"u = 1\""}, "SwatchLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    AbsoluteThickness[1], 
                    GrayLevel[0]]], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.25]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[
                    Directive[
                    Opacity[1], 
                    AbsoluteThickness[1], 
                    GrayLevel[0]]], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6], 
                    Opacity[0.25]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), 
            InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = 
                    True; MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                    "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.25`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Opacity", "[", "1", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = 
                    True; MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                    "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.25`", "]"}]}], "]"}]}], "}"}], 
                 ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "Automatic"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{"\"Ellips voor u = -1\"", "\"Ellips voor u = 1\""}, 
            "LineLegend", DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.368417, 0.506779, 0.709798]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[0.880722, 0.611041, 0.142051]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.587148, 0.40736066666666665`, 
                    0.09470066666666668], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{
            "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(0\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(0\\)]\\))\"", 
             InterpretationBox[
             
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \
\\(\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\\)]\\))\"", 
              StringForm[
              "(\!\(\*SubscriptBox[\(x\), \(``\)]\),\!\(\*SubscriptBox[\(y\), \
\(``\)]\))", 1, 1], Editable -> False], 
             InterpretationBox[
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \
\\(\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\\)]\\))\"", 
              StringForm[
              "(\!\(\*SubscriptBox[\(x\), \(``\)]\),\!\(\*SubscriptBox[\(y\), \
\(``\)]\))", 2, 2], Editable -> False], 
             "\"(\\!\\(\\*SubscriptBox[\\(x\\), \
\\(e\\)]\\),\\!\\(\\*SubscriptBox[\\(y\\), \\(e\\)]\\))\""}, "PointLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0, 1, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0, 1, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[0.5, 0, 0.5]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[1, 0, 0]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    AbsoluteThickness[1.6], 
                    PointSize[Large], 
                    RGBColor[1, 0, 0]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), 
            InterpretationFunction :> (RowBox[{"PointLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.5, 0, 0.5], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.33333333333333337`, 0., 0.33333333333333337`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.5, 0, 0.5]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.5, 0, 0.5]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.5, 0, 0.5], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], 
                 ",", 
                 RowBox[{"Joined", "\[Rule]", 
                   RowBox[{"{", 
                    
                    RowBox[{
                    "False", ",", "False", ",", "False", ",", "False"}], 
                    "}"}]}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}, {
          FormBox[
           
           TemplateBox[{"\"Simulatie\""}, "LineLegend", 
            DisplayFunction -> (StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
              False]& ), InterpretationFunction :> (RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
                 RowBox[{"{", #, "}"}], ",", 
                 RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
                 RowBox[{"LabelStyle", "\[Rule]", 
                   RowBox[{"{", "}"}]}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& ), Editable -> True], TraditionalForm]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
        GridBoxSpacings -> {"Columns" -> {{0}}}], "Grid"], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[{{{}, {}, {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[1.6], 
          FaceForm[
           Opacity[0.3]], 
          RGBColor[1, 0, 0]], 
         LineBox[CompressedData["
1:eJwdl3c8lv/3x6UildCSSIXsGQrhyMreEkqpFCor2WTL3iN7yx63vQ5uq7Ju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          "]]}}}, {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"x\"", TraditionalForm], 
         FormBox["\"y\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, 
       FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {"ScalingFunctions" -> None}, 
       PlotRange -> {{-0.005, 0.005}, {-0.005, 0.005}}, PlotRangeClipping -> 
       True, PlotRangePadding -> {{0, 0}, {0, 0}}, 
       Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"Simulatie\""}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    PointSize[0.5], 
                    EdgeForm[None], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    FaceForm[
                    Opacity[0.3]], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"EdgeForm", "[", "None", "]"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"FaceForm", "[", 
                    RowBox[{"Opacity", "[", "0.3`", "]"}], "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}], "}"}], ",", 
             RowBox[{"{", #, "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   TemplateBox[{GraphicsBox[
      GraphicsComplexBox[CompressedData["
1:eJxE2nk01N//B3BpsUTZ+dj3fZmxZb8vS7ZIWUooWghF2YWKqFBUSvYICdnH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       "], {{{}, {}, {}, {}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{1585, 1588, 1282, 1332, 1283, 1284, 1285, 1286, 1287,
              1288, 1289, 1290, 1291, 1292, 1293, 1333, 1294, 1376, 1351, 
             1434, 1398, 1500, 1455, 1569, 1514}}], 
            PolygonBox[CompressedData["
1:eJwVzLcyBFAYhuGzy5rhApRmpLVCRSUr5cKMWK7QYFcnNbaSKqETGhqlQqqE
Siq4AaVRSZXQeBTPvKf4/lOYTPekoiGECOPU5IRQTYKDWAgvtDJNLb0UUUcx
JZQSp54y2mhggj5y/fXwv9E9LdBnXSDf+0kPSfDKEYskaSdic61bzNDIF+es
MUk/5bxxzBLDdBB1f6PbzNLENxesk2KACt45YZkROslyf6s7zNHMD5dskGaQ
Sj44ZYVRush2f6e7zNPCL1dsMsUQeXaPuk+GKj45Y5UxuonZ3esfFoU15Q==

             "]]}]}, {
          EdgeForm[], 
          Directive[
           RGBColor[0.560181, 0.691569, 0.194885], 
           Opacity[0.2]], 
          GraphicsGroupBox[{
            
            PolygonBox[{{1585, 1586, 1494, 1551, 1377, 1414, 1313, 1336, 1312,
              1311, 1310, 1309, 1308, 1307, 1306, 1305, 1304, 1303, 1302, 
             1301, 1300, 1299, 1298, 1297, 1296, 1335, 1295, 1364, 1334, 
             1583}}], 
            PolygonBox[CompressedData["
1:eJwV0MlLVWEYwOGj4FVwIBtwKHEqpNLMpD+g0rbqdakZuNESihx2DpC2a9rY
sCoFB2xAypWlmzRXKaRhJqJlIqGt0tyk+dzFw+99v3PgO5zs2pvhG9FBEETR
TXEoCM5THBMEZ/W3HtcR/U6a+Y4O8oUk+1Vt4SlTBM4uayUNPGScHc5RRClh
rvOAMf5G7qSGZp7wkf+U0EEvM8S5o0JfssBB+zVd5aj5vr5nm0I2yXX+Vk/r
iqZqlxboumbqgObpnCbqFT2jvzRLX+tJXdTD2qT5+lOP6WM9oZO6xyU2yHE2
rKd0SY9ou66RYe7RaWLN5fqCryTb6/UH6eZ7+o6tyHfxhmVSPOvUfmZJsFfr
K75xyN6oj5hgl4u08ZxPhLxTpkPMc8Bep3cZ5U/kX3GbPj4T750qvUU3H/jH
BVp5xj6J/07D
             
             "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nf8VmMYB+BfmlRaRHsro6GlHWkolabQoj21Q1uLJtFQNERTRSjaUWlo
76kho51UFJXr/vjjcn+/z3PK+573PIdcLbrUezVRQkJC67sSEmJu9Y8aHJfH
0IBi2E5ITBKSkozkbHPts5yQx9KQ4qRgu/WanJTf4XlKcMFax/iXscjoxd3s
0GtxSn6XRpTkorVOJOJzvTf3sFOvzc/yOF6Iz+aDDrH2ID/oT3BJ7sxdfKG/
RgbXjdMfYq+ekl3yc5yW3yO7az7SH+fF+M76UDkTG/WC+mfyk5TSL5txMxNT
xt635mLr+eRP5EZmKbOqud583d598ntyfTN//F3marO5uc9+UfML/SWzStxr
c7PZ0kxlf7dcJ+6D/kt8X3OJ3sR8X89hTtUbmkXNp83v4u+L308eJmemvLzC
3GS9kLxAforS+h9mF5Lwpf6Q/U9jjzf0++PfJRdgv56aPXJdfpXH0zieCdcN
t5aFzXoZrshdScpXeh/uZa9ej9/kCTShLGlISzrSx+8Y9zA+Axl5gAfZF/eU
3+WJNKUcmdhvvQFn5Ek0ozx/WutGMr7W+5KZA3H/OCt/QHMqcNVad5KzRO9H
Fg7qz3NOnszL8Xz77m9Zy8oWvSLX5B6kYKneP76D68brD3NAz8qheHY4L08h
p2um6cV4Jc6C/racjR/1wvpCuVI8T/p1syd3U9beMvMb6/nlWfGsUk3eYA6I
eyhPkB+JZ0BeYx6M94C8WG5sVo2zbW4xW5nZ7B+WX4gzpF/QS5lL9abmh3ou
c3rcG7O4Wdn83nzZbBFn0BwRz42Z3axgrjS32isiL4rnl+ryxvhs1v8ye3EP
3+oF7M2O78nAeBb0ifKjHIozzZE4z1yUP6IlqVw30loOtumV+FvuTUqW6YPi
PHE0zg+X5Km04mluWHuNVCzX34zfimNxz7gsT6M1leN+kJuf4rzyhzydNlQh
D8fj/nFFnkFbqnIz3h+kZoU+mLyc0Jvxp/wx7ajGP3FWuZeV+pB4L3Ey3jVc
lWfSPs6vezHKWk6268/wr9yHNKzSh8Z7gFPx+3FN/oQOcX79+dHWcrFDr84t
uS9pWa0/7Jo5cjmGxbnUJ8mPcTieTX6O55vr8qd0jPPvujHWcrNTr8FtuR/p
WKM/4pq5cnmGxxnWP5ALciSeEU7LLfhLnhW/g2tm6CXopKfVx8p52KU/yx25
P+lZqz/qmnnxnPJWnH19slyIo3px/cs4W3Ge9V/Mlvwtl7b3jTw7fmf5Y7kk
VeR1Zmfr6eR35HpmXrOiucrcbe9x+fN4js3KZg1zU3wns6b9+A/2AL2OmSHu
s7k8no14/9t+zJwf59WsaD5j/hD3O94l8d4xp+gNzMJmJXOtecxeCfmr+DPx
jtB/jXcAN+Q58Rzan6k/wat6ev1dOR979FoksjZQv4/v9RFxP/lNb81NeS5d
qB2fl4L8bq8N/8jz6MpzFOKM9bb8K8+nG3XifchZ6+24JX9Gd+rGbfI5Blm/
n3X6yHjXcE5vz215AT2oR2LXv2k9I+v1UfFbcF7vwB15IT2pTxLXD7b+ABv0
0WSL96FehJ/0kvrXcnVqyT8m+v//x4ra+w96hxcV
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1Xf8V1Mcx/Hvr7SMhq1IaUsZIZKiSEVDaC8lDWkIqVRop120twZp770X
lTS1aC80aE/Pz8Mfr8d7nHN/39+995xzs9ZpWqFJUiKRGJYskXgfFW9JJFYl
TyTK4ry8AH11N+VueAKDdJ/pjvLNcB/myjkwld9rfDSfDoPll7CaL4DFfH3j
lfjVfDls4Avhgn4qfQgT9HtoKSzU96MJ/InuxrbSl/Ekv5TmwznMlQ/S8rgR
v+/aVvSY/gRtTjfTIriE++V5NCf+wTT5d/oGrmGf68fQ9PgLQ4zvpK/G7/Nr
6NNYwjcwtzK/hi+Pi/I0OTMmyovk/nwSvpafwhBda/k4/xEeiN/XjdVlwFC5
GBrqqshr+TdxSV6MoWijP6FrgYz4Q9cIVfXr5Aq4LC9J9v97/lx/UvcxMmG/
7gNU06+X38IVeSmGozGqG/tJ/zauysswAh+iCZqiGZqjhrk/m/cOrsnLMRJt
4/3pPsGDOKD7CDX1G+SKuC6vwABdMvTQFcAyPj/m8Yfom7EmMcrcdvFu9J/i
oXj/uhaopd8oV8INeWWsS3yM2sY26Svjprwq3jPa6//WtUTm+C3dJ3hX/4tc
BYlYz/GO8IX+lPwZHsZh3aeoo98sV0VSrBPdd/hSf1puhSw4omuJuvpf5WpI
hrW6b3TJ0VN+GuN0X8ln+NbIivlyLkznj8Zv8HdimFw8/i/de/IWvjqSY7r8
ML7n1xn/lr8FveRttBie4ZfTxzE/7otWwHjzO9CzupO0Df2VFsVlPCIvoLnx
L2bEeqRlcD32oevH0bviOWO48d9oCVzBK3Hv8fs4j6XxjOhbaOXaenSrrgY2
8i/E/87PoFnwA7/evIF8CvSWn8UK/gks4CcY7xj7nf8c2bBQzoOZ/HHj4/m7
MUJ+NZ53nI/yNr4mUuAn3SBdSvSRC2KirlPcO98W2ePciT2K+vrtci2kxM+6
79E5zi65HXLEc409igb6HXJtpIpzUvdD7CM0NLZT9y5Sx7PQTYq9EGs41mWs
tVgv8b7ifuNMcM1v5tZBGmzS/Ygu8azl9siJP3UTdPdgpFwCneKMkHfxdeNa
vjBu5WfSrLEuMUneS0vHfnHNYJoKffXPYbKuq3yB/wK58Fc8gzhn9Lvl93Ab
NuumxP8X54yxPbp6uD3WXHwr4m+hG7rj6ziLzNtr/H3cgS26IbrU6Cc/j2lx
jXyR/xK5sUh+FLPiPKRlY32aN5HeG3s8zhpju+hrQewd+iyW8T3iDOT38fWR
FlvjfNalQX+5UOy9+F/lS/xXyINTup5xfup/lxsgXezFOK/jGWOA/EKs87jP
2Gt8BzyK07GOdPdhtFwSveIslv/gGyI9tsd5rrsN38iF493pesTe4zsiL87E
OtPdjzFyKfSOs1rezzdCBsyK/Y4f+R3xPeBvx7fyizEe9yVfjfWDx7BYzovZ
/NlYs/wDGCuXjr3LF8Ryvk+c4/wB/gPcidlyNkzmd8Z3hb8DA+P+aHEU4VfS
J7EwrjGvF3+N7xxrgn8J+fgl9DHM4Q/QcnEuxL6gGXEa3xnbTUvGveD12Pv0
uVjHWCEfpW8jkcJaj28MfzDOEtqY/kJfjDUXZ588h2bHWUyR98Xfjf3p2lE0
LQbFc40zEUX5VfQpLIrrzevNX+e7ID/+1U3WZcI4+Q30i++XfIj/EHfHGtbN
Rf/4zsZ3Jr5Z5hw21gT3xP3q5sW3Ib5Pxo7omuJe7NHNRx/9DbkrHse52K+6
BzFeLhNnHP88VvLH6DtI8owGmvsfR8l1AQ==
           "]]}, {
          Directive[
           Opacity[1.], 
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV0nlgjnUAwPF302bagR1tjGyYrajZHOXqdJWoFhGhFirXEiLRRakoV6Ry
RAfJXbmKEqncXe6rUM7ooqL0+f3xeb+/3/P+nuf3vO/zZBeXFPWNikQihT6i
YyKRupTiImKIpTRxlOFi4kkgkXokcQ8teI1H2MMCsmMjkWNaoPnUN25LWa6i
HOVJJoVU0riEdDKoQEUyqURlLqUKWVwd9uFZ7g3Xts82LdQ83jU+QksG0YB2
VKUh1ahODjVoRC430Zje3Bl+v2ttDWv0zXAP+pM+Ge7XeJ8uIo9f+JCRFHMz
UdZ8qa8zmCb8xSeMow/tuYxTLOE57qMV0c7/SqfwKNfwN58ynr504HJOs5Tn
6cYt4bk6f71OZQjX8g+rmUAJd1GTX1nGC3SndXgnnL9Bp/EY13GOz3iZh+gY
3hHrvta3eIpa/MZyRtGDNsRYt1Hr6HQdyvWcZw0T6Ucn4q35Rt/maa7gd1Yw
mvspZ812ncOtxJpv0jcYxg38y1om8TAp1uzSedxNgvm3+g7DSTffr4u5kj/4
iBep6Lsf9QHKG+/Q97iN0uabdQaVjQ/r46QZ7w3PSBdqVT2uN/Ifn5Pj2Cta
SQ+F/0/7a6ruDu+HztcsPRruSztron6nuTpLq+jP4b/SEZqhB8Lz1fe1mp7Q
fP7kY14i0/GD+iDJxjt1LrcTZ75FZ/IETbnAOiYzgC7U5gwrGUNPimhGAYWc
ZRVj6cUdNCdijy/0VQbSlSTHvtfZPEMF8x/0A6obnwx7ah39H9NIjMI=
           "]]}}}], {DisplayFunction -> Identity, AspectRatio -> NCache[
         Rational[2, 3], 0.6666666666666666], Axes -> {True, True}, AxesLabel -> {
         FormBox["\"t\"", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
       DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}},
        FrameLabel -> {{None, None}, {None, None}}, 
       FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
       GridLines -> {None, None}, GridLinesStyle -> Directive[
         GrayLevel[0.5, 0.4]], ImageSize -> {300, 200}, 
       Method -> {
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, "AxesInFront" -> 
         True}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
       PlotRangePadding -> {{
          Scaled[0.02], 
          Scaled[0.02]}, {
          Scaled[0.05], 
          Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
      FormBox[
       TemplateBox[{"\"x(t)\"", "\"y(t)\"", "\"u(t)\""}, "LineLegend", 
        DisplayFunction -> (FormBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 TagBox[
                  GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                   AutoDelete -> False, 
                   GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                   GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
               GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}},
                AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], TraditionalForm]& ), 
        InterpretationFunction :> (RowBox[{"LineLegend", "[", 
           RowBox[{
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                   "]"}]}], "}"}], ",", 
             RowBox[{"{", 
               RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
             RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
             RowBox[{"LabelStyle", "\[Rule]", 
               RowBox[{"{", "}"}]}], ",", 
             RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
        Editable -> True], TraditionalForm], TraditionalForm]},
    "Legended",
    DisplayFunction->(GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}]& ),
    Editable->True,
    InterpretationFunction->(RowBox[{"Legended", "[", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], ",", 
   RowBox[{"{", 
    RowBox[{"t", "\[Rule]", "15.607007765300068`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.662890382502055*^9, 3.6628904279589562`*^9}, {
  3.6628904900595455`*^9, 3.662890502502097*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation: crane 1 switch", "Subsubsection",
 CellChangeTimes->{{3.6628813376262226`*^9, 3.662881345602521*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "animateCart", "]"}], "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CableLength", "\[Rule]", "10"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Width", "->", 
      RowBox[{".8", " ", "1024"}]}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"animateCart", "[", 
    RowBox[{"init_", ",", "u_", ",", "T_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "sol", ",", "anim", ",", 
       RowBox[{"width", "=", 
        RowBox[{"OptionValue", "[", "Width", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"q", "=", 
       RowBox[{"finalOc", "[", 
        RowBox[{"init", ",", "T", ",", "u"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sol", "=", 
       RowBox[{"Last", "@", "q"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"anim", "[", "tt_", "]"}], ":=", 
       RowBox[{"Grid", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Show", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"ParametricPlot", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
                   RowBox[{
                    SubscriptBox["x", "2"], "[", "t", "]"}]}], "}"}], "/.", 
                 "sol"}], ",", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                 RowBox[{"Point", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "2"], "[", "t", "]"}]}], "}"}], "/.", 
                    "sol"}], "/.", 
                   RowBox[{"t", "\[Rule]", "tt"}]}], "]"}]}], "}"}], "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"ImageSize", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"width", "/", "2"}], ",", 
                 RowBox[{"width", "/", "4"}]}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"AspectRatio", "\[Rule]", 
               RowBox[{"1", "/", "2"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"PlotRange", "\[Rule]", "All"}]}], 
             "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Show", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"ParametricPlot", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    SubscriptBox["x", "3"], "[", "t", "]"}], ",", 
                   RowBox[{
                    SubscriptBox["x", "4"], "[", "t", "]"}]}], "}"}], "/.", 
                 "sol"}], ",", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"PointSize", "[", "Large", "]"}], ",", 
                 RowBox[{"Point", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    SubscriptBox["x", "3"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "4"], "[", "t", "]"}]}], "}"}], "/.", 
                    "sol"}], "/.", 
                   RowBox[{"t", "\[Rule]", "tt"}]}], "]"}]}], "}"}], "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"ImageSize", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"width", "/", "2"}], ",", 
                 RowBox[{"width", "/", "4"}]}], "}"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"AspectRatio", "\[Rule]", 
               RowBox[{"1", "/", "2"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{"PlotRange", "\[Rule]", "All"}]}], 
             "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], 
          ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"cartAnimation", "[", 
             RowBox[{
              RowBox[{"Flatten", "@", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    SubscriptBox["x", "1"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "2"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "3"], "[", "t", "]"}], ",", 
                    RowBox[{
                    SubscriptBox["x", "4"], "[", "t", "]"}]}], "}"}], "/.", 
                  "sol"}], "/.", 
                 RowBox[{"t", "\[Rule]", "tt"}]}], ")"}]}], ",", 
              RowBox[{"u", "[", "tt", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "init", "\[LeftDoubleBracket]", "3", 
                 "\[RightDoubleBracket]"}], ",", "0"}], "}"}], ",", "True", 
              ",", 
              RowBox[{"Width", "\[Rule]", "width"}], ",", 
              RowBox[{"CableLength", "\[Rule]", 
               RowBox[{"OptionValue", "[", "CableLength", "]"}]}]}], "]"}], 
            ",", "SpanFromLeft"}], "}"}]}], "}"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "anim"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.6628813548349843`*^9, 3.6628814514113703`*^9}, {
   3.662881524779278*^9, 3.6628815467622128`*^9}, {3.662882725015572*^9, 
   3.6628827418484993`*^9}, 3.66288494869411*^9, {3.6628850079400907`*^9, 
   3.662885015467413*^9}, {3.662885581434848*^9, 3.662885616354977*^9}, {
   3.6628856700283422`*^9, 3.6628856701011267`*^9}, {3.662886097402525*^9, 
   3.6628860989614177`*^9}, {3.662887024600072*^9, 3.662887035440774*^9}, {
   3.662887392943617*^9, 3.662887399070823*^9}, {3.662887550639989*^9, 
   3.662887550751027*^9}, {3.662888790180846*^9, 3.6628887996524124`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"exportAnimation", "[", 
   RowBox[{
    RowBox[{"animateCart", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"paraDistance", "[", 
           RowBox[{"0", ",", "0", ",", "1", ",", 
            RowBox[{"P", "/", "3"}]}], "]"}]}], "-", 
         RowBox[{"paraDistance", "[", 
          RowBox[{"0", ",", 
           RowBox[{"uMax", " ", 
            RowBox[{"P", "/", "3"}]}], ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"P", "/", "3"}]}], "]"}]}], ",", "0"}], "}"}], ",", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", "\[IndentingNewLine]", 
        RowBox[{"uFromSwitchTimes", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"P", "/", "3"}], ",", 
           RowBox[{"P", "/", "2"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", 
       "]"}], ",", 
      RowBox[{"1.5", "P"}], ",", 
      RowBox[{"CableLength", "\[Rule]", "10"}]}], "]"}], ",", 
    "\"\<crane1-1\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"1.5", "P"}], ",", 
      RowBox[{"1", "/", "4"}]}], "}"}], ",", "True"}], "]"}], "}"}]], "Input",
 CellChangeTimes->{
  3.6628832586787167`*^9, {3.662884652204147*^9, 3.662884655411425*^9}, {
   3.6628847059151945`*^9, 3.662884706019269*^9}, {3.6628847433397303`*^9, 
   3.6628847534268665`*^9}, {3.6628849709558744`*^9, 3.662884984722645*^9}, {
   3.662885069443055*^9, 3.662885088578632*^9}, {3.662886192480919*^9, 
   3.662886192520553*^9}, 3.662887184174884*^9, {3.662887521166625*^9, 
   3.6628875233738446`*^9}, {3.662887616446672*^9, 3.662887616829612*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\\
..\\\\Presentation\\\\animations\\\\crane1-1.png\"\>", 
    ",", "\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\..\
\\\\Presentation\\\\animations\\\\crane1-1.swf\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.662887508081806*^9, 3.662887527470688*^9}, 
   3.6628876057580185`*^9, 3.6628878670265665`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"exportAnimation", "[", 
   RowBox[{
    RowBox[{"animateCart", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", "2"}], 
         RowBox[{"paraDistance", "[", 
          RowBox[{"0", ",", "0", ",", "1", ",", 
           RowBox[{"P", "/", "3"}]}], "]"}]}], ",", "0"}], "}"}], ",", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", "\[IndentingNewLine]", 
        RowBox[{"uFromSwitchTimes", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"P", "/", "3"}], ",", 
           RowBox[{"P", "/", "3"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", 
       "]"}], ",", 
      RowBox[{"2", "P"}], ",", 
      RowBox[{"CableLength", "\[Rule]", "10"}]}], "]"}], ",", 
    "\"\<crane1-2\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"2", "P"}], ",", 
      RowBox[{"1", "/", "4"}]}], "}"}], ",", "True"}], "]"}], "}"}]], "Input",
 CellChangeTimes->{{3.662882749390832*^9, 3.66288275831917*^9}, {
   3.662883237718854*^9, 3.662883254014412*^9}, {3.6628845806114206`*^9, 
   3.662884581139814*^9}, 3.662884645004034*^9, {3.6628850578188295`*^9, 
   3.662885062018795*^9}, 3.6628861916406555`*^9, 3.662887183231286*^9, {
   3.662887328607047*^9, 3.6628873292292404`*^9}, 3.662887540926666*^9, {
   3.6628876131107063`*^9, 3.6628876134643755`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\\
..\\\\Presentation\\\\animations\\\\crane1-2.png\"\>", 
    ",", "\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\..\
\\\\Presentation\\\\animations\\\\crane1-2.swf\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.662883034196641*^9, 3.6628840538551884`*^9, 3.6628845827319107`*^9, 
   3.662884769137727*^9, 3.6628850425249987`*^9, 3.6628853256089163`*^9, 
   3.6628867803353033`*^9, 3.6628871898701773`*^9, {3.662887318241996*^9, 
   3.6628873312349157`*^9}, 3.6628873840432262`*^9, {3.662887457142396*^9, 
   3.6628874805795946`*^9}, 3.662887543077007*^9, 3.6628876083130035`*^9, 
   3.662887757315797*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"exportAnimation", "[", 
   RowBox[{
    RowBox[{"animateCart", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", "2"}], 
         RowBox[{"paraDistance", "[", 
          RowBox[{"0", ",", "0", ",", "1", ",", "P"}], "]"}]}], ",", "0"}], 
       "}"}], ",", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", "\[IndentingNewLine]", 
        RowBox[{"uFromSwitchTimes", "[", 
         RowBox[{"{", 
          RowBox[{"P", ",", "P"}], "}"}], "]"}]}], "\[IndentingNewLine]", 
       "]"}], ",", 
      RowBox[{"3", "P"}], ",", 
      RowBox[{"CableLength", "\[Rule]", "60"}]}], "]"}], ",", 
    "\"\<crane1-3\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"3", "P"}], ",", 
      RowBox[{"1", "/", "4"}]}], "}"}], ",", "False"}], "]"}], "}"}]], "Input",
 CellChangeTimes->{{3.6628853570584145`*^9, 3.662885385474326*^9}, {
  3.6628856263133955`*^9, 3.6628856583142643`*^9}, {3.6628858914414215`*^9, 
  3.662885920067444*^9}, {3.6628861879717717`*^9, 3.662886188031989*^9}, {
  3.6628871782704687`*^9, 3.66288717902267*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation: crane 3 switches", "Subsubsection",
 CellChangeTimes->{{3.6628903069196353`*^9, 3.6628903114636054`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"exportAnimation", "[", 
   RowBox[{
    RowBox[{"animateCart", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"-", "33.3"}], ",", "0"}], "}"}], ",", 
      RowBox[{"Function", "[", 
       RowBox[{"t", ",", "\[IndentingNewLine]", 
        RowBox[{"uFromSwitchTimes", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", "2"}], 
            RowBox[{"P", "/", "3"}]}], ",", 
           RowBox[{"P", "/", "5"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"1", "/", "2"}], 
             RowBox[{"P", "/", "3"}]}], "+", 
            RowBox[{"P", "/", "5"}]}], ",", 
           RowBox[{"P", "/", "3"}]}], "}"}], "]"}]}], "\[IndentingNewLine]", 
       "]"}], ",", 
      RowBox[{"2.5", "P"}], ",", 
      RowBox[{"CableLength", "\[Rule]", "10"}]}], "]"}], ",", 
    "\"\<crane3-1\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"2.5", "P"}], ",", 
      RowBox[{"1", "/", "4"}]}], "}"}], ",", "True"}], "]"}], "}"}]], "Input",
 CellChangeTimes->{{3.662887667053485*^9, 3.66288768438214*^9}, {
  3.6628877221893654`*^9, 3.6628878249734154`*^9}, {3.662887874198114*^9, 
  3.662887876741119*^9}, {3.662887917566166*^9, 3.6628879181965265`*^9}, {
  3.662887965014216*^9, 3.662887967380889*^9}, {3.662888035198412*^9, 
  3.6628880375020866`*^9}, {3.662888199261753*^9, 3.662888210348718*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\\
..\\\\Presentation\\\\animations\\\\crane3-1.png\"\>", 
    ",", "\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\..\
\\\\Presentation\\\\animations\\\\crane3-1.swf\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.6628878696712627`*^9, 3.6628878782675524`*^9}, {
   3.662887919163056*^9, 3.6628879345921917`*^9}, 3.6628879694036903`*^9, {
   3.6628881970510025`*^9, 3.6628882077834425`*^9}, 3.6628883735574875`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", "=", 
     RowBox[{"find3Times", "[", 
      RowBox[{"-", "50"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"exportAnimation", "[", 
     RowBox[{
      RowBox[{"animateCart", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"-", "50"}], ",", "0"}], "}"}], ",", 
        RowBox[{"Function", "[", 
         RowBox[{"t", ",", "\[IndentingNewLine]", 
          RowBox[{"uFromSwitchTimes", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"T1", ",", "T2", ",", "T2", ",", "T1"}], "}"}], "/.", 
            RowBox[{
            "q", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], 
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
        RowBox[{"2.5", "P"}], ",", 
        RowBox[{"CableLength", "\[Rule]", "10"}]}], "]"}], ",", 
      "\"\<crane3-2\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2.5", "P"}], ",", 
        RowBox[{"1", "/", "4"}]}], "}"}], ",", "True"}], "]"}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.6628884362677345`*^9, 3.6628885067477126`*^9}, {
   3.662888621365173*^9, 3.6628886616304684`*^9}, 3.6628887131163254`*^9, {
   3.6628887739250546`*^9, 3.662888783611182*^9}, {3.662888814044858*^9, 
   3.662888839132253*^9}, {3.662888984282735*^9, 3.662888984634704*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\\
..\\\\Presentation\\\\animations\\\\crane3-2.png\"\>", 
    ",", "\<\"D:\\\\Synology\\\\Studie\\\\Bacheloropdracht\\\\Simulation\\\\..\
\\\\Presentation\\\\animations\\\\crane3-2.swf\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.6628887522415447`*^9, 3.6628888170639086`*^9}, 
   3.662889132263112*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Other things", "Chapter"]], "Title",
 CellChangeTimes->{{3.662736958071499*^9, 3.6627369825352535`*^9}}],

Cell["\<\
These things have nothing to do with the research, but rather with generating \
small video files for exporting animations.\
\>", "Text",
 CellChangeTimes->{{3.6629956488680873`*^9, 3.6629956805164623`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Finding all ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " names"
}], "Subsubsection",
 CellChangeTimes->{{3.662736985023492*^9, 3.6627369950784483`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "names", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"names", "=", 
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Names", "[", "\"\<System`*\>\"", "]"}], ",", 
        RowBox[{
         RowBox[{"StringMatchQ", "[", 
          RowBox[{"#", ",", 
           RowBox[{"RegularExpression", "[", "\"\<[A-Za-z]+\>\"", "]"}]}], 
          "]"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"names", "=", 
      RowBox[{"StringJoin", "[", 
       RowBox[{"Riffle", "[", 
        RowBox[{"names", ",", "\"\<,\>\""}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"FileNameJoin", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<..\>\"", ",", 
          "\"\<Report\>\"", ",", "\"\<names.txt\>\""}], "}"}], "]"}], ",", 
       "names"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.662737008327546*^9, 3.6627370751112375`*^9}, {
   3.6627371087276587`*^9, 3.662737132791168*^9}, {3.662737168280641*^9, 
   3.662737223575193*^9}, {3.662737272271273*^9, 3.6627372749994574`*^9}, {
   3.662737383215099*^9, 3.6627373987110233`*^9}, 3.662738219014582*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing video codecs", "Subsubsection",
 CellChangeTimes->{{3.6629060308317547`*^9, 3.662906035079754*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Internal`$VideoEncodings"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Animation\"\>", ",", "\<\"BMP\"\>", ",", "\<\"Cinepak\"\>", 
   ",", "\<\"Component Video\"\>", ",", "\<\"DVCPRO - PAL\"\>", 
   ",", "\<\"DV/DVCPRO - NTSC\"\>", ",", "\<\"DV - PAL\"\>", 
   ",", "\<\"Geen\"\>", ",", "\<\"Graphics\"\>", ",", "\<\"H.261\"\>", 
   ",", "\<\"H.263\"\>", ",", "\<\"JPEG 2000\"\>", 
   ",", "\<\"Motion JPEG A\"\>", ",", "\<\"Motion JPEG B\"\>", 
   ",", "\<\"MPEG-4-video\"\>", ",", "\<\"Photo - JPEG\"\>", 
   ",", "\<\"Planar RGB\"\>", ",", "\<\"PNG\"\>", 
   ",", "\<\"Sorenson Video\"\>", ",", "\<\"TGA\"\>", ",", "\<\"TIFF\"\>", 
   ",", "\<\"Uncompressed\"\>", ",", "\<\"Video\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.662906023510543*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1680, 967},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingPageRange->{Automatic, Automatic},
ShowGroupOpener->True,
TaggingRules->{"$testsRun" -> False},
ShowCellTags->True,
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 9, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 96, 1, 64, "Chapter"],
Cell[679, 25, 332, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[1036, 35, 105, 1, 34, "Subsubsection"],
Cell[1144, 38, 1408, 36, 132, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[2589, 79, 102, 1, 28, "Subsubsection"],
Cell[2694, 82, 1335, 35, 182, "Input",
 InitializationCell->True]
}, Closed]],
Cell[4044, 120, 136, 1, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[4205, 125, 102, 1, 28, "Subsubsection"],
Cell[4310, 128, 7094, 206, 814, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[11441, 339, 101, 1, 28, "Subsubsection"],
Cell[11545, 342, 40464, 858, 2787, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[52046, 1205, 99, 1, 28, "Subsubsection"],
Cell[52148, 1208, 29483, 605, 1639, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[81668, 1818, 107, 1, 28, "Subsubsection"],
Cell[81778, 1821, 25175, 491, 1755, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[106990, 2317, 99, 1, 28, "Subsubsection"],
Cell[107092, 2320, 31773, 649, 1417, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[138902, 2974, 100, 1, 28, "Subsubsection"],
Cell[139005, 2977, 13917, 234, 156, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[152959, 3216, 119, 1, 28, "Subsubsection"],
Cell[153081, 3219, 20455, 372, 1332, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[173573, 3596, 102, 1, 28, "Subsubsection"],
Cell[173678, 3599, 16828, 289, 612, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[190543, 3893, 102, 1, 28, "Subsubsection"],
Cell[190648, 3896, 29792, 607, 1196, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[220477, 4508, 258, 8, 28, "Subsubsection"],
Cell[220738, 4518, 33564, 713, 1706, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[254339, 5236, 115, 1, 28, "Subsubsection"],
Cell[254457, 5239, 20767, 393, 444, "Input",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[275273, 5638, 177, 2, 79, "Title"],
Cell[275453, 5642, 229, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[275707, 5651, 381, 12, 36, "Subsubsection"],
Cell[CellGroupData[{
Cell[276113, 5667, 11665, 281, 882, "Input"],
Cell[287781, 5950, 4814, 100, 590, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[292644, 6056, 384, 13, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[293053, 6073, 1115, 36, 42, "Input"],
Cell[294171, 6111, 724, 15, 39, "Message"],
Cell[294898, 6128, 724, 15, 39, "Message"],
Cell[295625, 6145, 726, 15, 39, "Message"],
Cell[296354, 6162, 663, 13, 21, "Message"],
Cell[CellGroupData[{
Cell[297042, 6179, 331, 7, 23, "Print"],
Cell[297376, 6188, 303, 7, 23, "Print"],
Cell[297682, 6197, 353, 8, 23, "Print"]
}, Open  ]],
Cell[298050, 6208, 698, 14, 39, "Message"],
Cell[298751, 6224, 697, 14, 39, "Message"],
Cell[CellGroupData[{
Cell[299473, 6242, 307, 7, 23, "Print"],
Cell[299783, 6251, 339, 7, 23, "Print"]
}, Open  ]],
Cell[300137, 6261, 698, 14, 39, "Message"],
Cell[300838, 6277, 659, 14, 21, "Message"],
Cell[CellGroupData[{
Cell[301522, 6295, 313, 7, 26, "Print"],
Cell[301838, 6304, 344, 7, 26, "Print"],
Cell[302185, 6313, 314, 7, 26, "Print"],
Cell[302502, 6322, 361, 8, 26, "Print"],
Cell[302866, 6332, 325, 6, 26, "Print"],
Cell[303194, 6340, 334, 6, 26, "Print"]
}, Open  ]],
Cell[303543, 6349, 700, 13, 56, "Message"],
Cell[304246, 6364, 698, 13, 56, "Message"],
Cell[304947, 6379, 697, 13, 56, "Message"],
Cell[305647, 6394, 654, 13, 21, "Message"],
Cell[306304, 6409, 307, 6, 26, "Print"]
}, Closed]],
Cell[CellGroupData[{
Cell[306648, 6420, 10311, 177, 101, "Input"],
Cell[316962, 6599, 377, 8, 23, "Print"],
Cell[317342, 6609, 122614, 2158, 417, "Output"],
Cell[439959, 8769, 375, 8, 23, "Print"],
Cell[440337, 8779, 158866, 2829, 419, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[599252, 11614, 448, 13, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[599725, 11631, 3660, 90, 349, "Input"],
Cell[603388, 11723, 25994, 478, 217, "Output"],
Cell[629385, 12203, 18756, 360, 250, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[648190, 12569, 196, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[648411, 12575, 7896, 110, 31, "Input"],
Cell[CellGroupData[{
Cell[656332, 12689, 1235, 18, 23, "Print"],
Cell[657570, 12709, 1155, 17, 23, "Print"],
Cell[658728, 12728, 1158, 17, 23, "Print"]
}, Open  ]],
Cell[659901, 12748, 104994, 1876, 250, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[764944, 14630, 323, 9, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[765292, 14643, 5160, 132, 313, "Input"],
Cell[770455, 14777, 231502, 3861, 217, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1002006, 18644, 415, 11, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[1002446, 18659, 4729, 121, 429, "Input"],
Cell[1007178, 18782, 268596, 4514, 250, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1275823, 23302, 196, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[1276044, 23308, 20120, 277, 52, "Input"],
Cell[CellGroupData[{
Cell[1296189, 23589, 334, 6, 23, "Print"],
Cell[1296526, 23597, 390, 6, 23, "Print"]
}, Open  ]],
Cell[1296931, 23606, 329830, 5715, 512, "Output"],
Cell[CellGroupData[{
Cell[1626786, 29325, 329, 6, 23, "Print"],
Cell[1627118, 29333, 392, 6, 23, "Print"]
}, Open  ]],
Cell[1627525, 29342, 296278, 5137, 542, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1923852, 34485, 127, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[1924004, 34490, 10894, 236, 963, "Input"],
Cell[CellGroupData[{
Cell[1934923, 34730, 1112, 17, 23, "Print"],
Cell[1936038, 34749, 1169, 17, 23, "Print"],
Cell[1937210, 34768, 1274, 19, 23, "Print"],
Cell[1938487, 34789, 1078, 17, 23, "Print"],
Cell[1939568, 34808, 1252, 18, 23, "Print"],
Cell[1940823, 34828, 1200, 18, 23, "Print"],
Cell[1942026, 34848, 1109, 17, 23, "Print"],
Cell[1943138, 34867, 1113, 17, 23, "Print"],
Cell[1944254, 34886, 1266, 18, 23, "Print"],
Cell[1945523, 34906, 1109, 17, 23, "Print"],
Cell[1946635, 34925, 1167, 17, 23, "Print"],
Cell[1947805, 34944, 1237, 18, 23, "Print"],
Cell[1949045, 34964, 1079, 17, 23, "Print"],
Cell[1950127, 34983, 1221, 18, 23, "Print"],
Cell[1951351, 35003, 1188, 18, 23, "Print"],
Cell[1952542, 35023, 1111, 17, 23, "Print"],
Cell[1953656, 35042, 1113, 17, 23, "Print"],
Cell[1954772, 35061, 1239, 18, 23, "Print"],
Cell[1956014, 35081, 1109, 17, 23, "Print"],
Cell[1957126, 35100, 1167, 17, 23, "Print"],
Cell[1958296, 35119, 1244, 18, 23, "Print"],
Cell[1959543, 35139, 1081, 17, 23, "Print"],
Cell[1960627, 35158, 1228, 18, 23, "Print"],
Cell[1961858, 35178, 1114, 17, 23, "Print"],
Cell[1962975, 35197, 1170, 17, 23, "Print"],
Cell[1964148, 35216, 1245, 18, 23, "Print"],
Cell[1965396, 35236, 1081, 17, 23, "Print"],
Cell[1966480, 35255, 1228, 18, 23, "Print"]
}, Open  ]],
Cell[1967723, 35276, 185983, 3299, 956, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2153755, 38581, 543, 16, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[2154323, 38601, 10352, 236, 709, "Input"],
Cell[2164678, 38839, 602137, 10077, 217, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2766864, 48922, 305, 8, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[2767194, 48934, 8095, 187, 633, "Input"],
Cell[2775292, 49123, 491061, 8197, 217, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3266402, 57326, 245, 6, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[3266672, 57336, 7500, 181, 300, "Input"],
Cell[3274175, 57519, 497267, 8218, 217, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3771491, 65743, 406, 12, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[3771922, 65759, 2099, 62, 198, "Input"],
Cell[3774024, 65823, 1864, 48, 42, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3775937, 65877, 109, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[3776071, 65882, 3807, 101, 167, "Input"],
Cell[3779881, 65985, 3089, 63, 312, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3783007, 66053, 4613, 80, 325, "Input"],
Cell[3787623, 66135, 156808, 2622, 227, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3944480, 68763, 282, 9, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[3944787, 68776, 1839, 29, 56, "Input"],
Cell[3946629, 68807, 1660, 23, 49, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3948338, 68836, 407, 13, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[3948770, 68853, 1917, 58, 307, "Input"],
Cell[3950690, 68913, 1504, 39, 103, "Output"],
Cell[3952197, 68954, 987, 25, 54, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3953233, 68985, 125, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[3953383, 68990, 12513, 258, 799, "Input"],
Cell[3965899, 69250, 955043, 17109, 2961, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4920991, 86365, 446, 15, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[4921462, 86384, 1183, 30, 152, "Input"],
Cell[4922648, 86416, 43332, 815, 218, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4966029, 87237, 321, 10, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[4966375, 87251, 3272, 89, 371, "Input"],
Cell[4969650, 87342, 268550, 4653, 250, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5238249, 92001, 119, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[5238393, 92006, 1025, 23, 92, "Input"],
Cell[5239421, 92031, 9338, 165, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5248808, 92202, 213, 7, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[5249046, 92213, 6141, 150, 434, "Input"],
Cell[5255190, 92365, 36266, 644, 250, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5291505, 93015, 211, 7, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[5291741, 93026, 4481, 71, 132, "Input"],
Cell[5296225, 93099, 182407, 3218, 714, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5478681, 96323, 211, 7, 28, "Subsubsection"],
Cell[5478895, 96332, 2848, 67, 373, "Input"],
Cell[CellGroupData[{
Cell[5481768, 96403, 2038, 40, 152, "Input"],
Cell[5483809, 96445, 366141, 6455, 872, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5849999, 102906, 272, 10, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[5850296, 102920, 6895, 163, 439, "Input"],
Cell[5857194, 103085, 13054, 273, 250, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5870297, 103364, 231, 3, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[5870553, 103371, 428, 12, 31, "Input"],
Cell[5870984, 103385, 223563, 3996, 511, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6094584, 107386, 662, 14, 31, "Input"],
Cell[6095249, 107402, 12291, 253, 217, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[6107589, 107661, 128, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[6107742, 107666, 9372, 213, 865, "Input"],
Cell[CellGroupData[{
Cell[6117139, 107883, 390, 8, 23, "Print"],
Cell[6117532, 107893, 393, 8, 23, "Print"],
Cell[6117928, 107903, 392, 8, 23, "Print"]
}, Open  ]],
Cell[6118335, 107914, 271015, 4762, 1428, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6389387, 112681, 372, 7, 31, "Input"],
Cell[6389762, 112690, 453, 10, 21, "Message"],
Cell[6390218, 112702, 408, 10, 21, "Message"],
Cell[6390629, 112714, 423, 10, 21, "Message"],
Cell[6391055, 112726, 408, 10, 21, "Message"],
Cell[6391466, 112738, 407, 10, 21, "Message"],
Cell[6391876, 112750, 406, 10, 21, "Message"],
Cell[6392285, 112762, 408, 10, 21, "Message"],
Cell[6392696, 112774, 406, 10, 21, "Message"],
Cell[6393105, 112786, 405, 10, 21, "Message"],
Cell[6393513, 112798, 404, 10, 21, "Message"],
Cell[6393920, 112810, 408, 10, 21, "Message"],
Cell[6394331, 112822, 408, 10, 21, "Message"],
Cell[6394742, 112834, 407, 10, 21, "Message"],
Cell[6395152, 112846, 389, 10, 21, "Message"],
Cell[6395544, 112858, 404, 10, 21, "Message"],
Cell[6395951, 112870, 389, 10, 21, "Message"],
Cell[6396343, 112882, 389, 10, 21, "Message"],
Cell[6396735, 112894, 389, 10, 21, "Message"],
Cell[6397127, 112906, 453, 10, 21, "Message"],
Cell[6397583, 112918, 423, 10, 21, "Message"],
Cell[6398009, 112930, 451, 10, 21, "Message"],
Cell[6398463, 112942, 453, 10, 21, "Message"],
Cell[6398919, 112954, 453, 10, 21, "Message"],
Cell[6399375, 112966, 426, 10, 21, "Message"],
Cell[6399804, 112978, 450, 10, 21, "Message"],
Cell[6400257, 112990, 423, 10, 21, "Message"],
Cell[6400683, 113002, 453, 10, 21, "Message"],
Cell[6401139, 113014, 375, 10, 21, "Message"],
Cell[6401517, 113026, 424, 10, 21, "Message"],
Cell[CellGroupData[{
Cell[6401966, 113040, 217, 6, 23, "Print"],
Cell[6402186, 113048, 216, 6, 26, "Print"],
Cell[6402405, 113056, 217, 6, 26, "Print"]
}, Open  ]],
Cell[6402637, 113065, 453, 10, 21, "Message"],
Cell[6403093, 113077, 453, 10, 21, "Message"],
Cell[6403549, 113089, 375, 10, 21, "Message"],
Cell[6403927, 113101, 453, 10, 21, "Message"],
Cell[6404383, 113113, 377, 10, 21, "Message"],
Cell[6404763, 113125, 220, 6, 23, "Print"],
Cell[6404986, 113133, 453, 10, 21, "Message"],
Cell[6405442, 113145, 425, 10, 21, "Message"],
Cell[6405870, 113157, 451, 10, 21, "Message"],
Cell[6406324, 113169, 375, 10, 21, "Message"],
Cell[6406702, 113181, 217, 6, 26, "Print"],
Cell[6406922, 113189, 424, 10, 21, "Message"],
Cell[6407349, 113201, 376, 10, 21, "Message"],
Cell[6407728, 113213, 218, 6, 26, "Print"],
Cell[6407949, 113221, 424, 10, 21, "Message"],
Cell[6408376, 113233, 376, 10, 21, "Message"],
Cell[6408755, 113245, 218, 6, 23, "Print"],
Cell[6408976, 113253, 426, 10, 21, "Message"],
Cell[6409405, 113265, 374, 10, 21, "Message"],
Cell[CellGroupData[{
Cell[6409804, 113279, 216, 6, 23, "Print"],
Cell[6410023, 113287, 218, 6, 26, "Print"],
Cell[6410244, 113295, 216, 6, 26, "Print"]
}, Open  ]],
Cell[6410475, 113304, 405, 10, 21, "Message"],
Cell[6410883, 113316, 408, 10, 21, "Message"],
Cell[6411294, 113328, 453, 10, 21, "Message"],
Cell[6411750, 113340, 406, 10, 21, "Message"],
Cell[6412159, 113352, 426, 10, 21, "Message"],
Cell[6412588, 113364, 391, 10, 21, "Message"],
Cell[6412982, 113376, 407, 10, 21, "Message"],
Cell[6413392, 113388, 453, 10, 21, "Message"],
Cell[6413848, 113400, 407, 10, 21, "Message"],
Cell[6414258, 113412, 424, 10, 21, "Message"],
Cell[6414685, 113424, 407, 10, 21, "Message"],
Cell[6415095, 113436, 451, 10, 21, "Message"],
Cell[6415549, 113448, 391, 10, 21, "Message"],
Cell[6415943, 113460, 425, 10, 21, "Message"],
Cell[6416371, 113472, 451, 10, 21, "Message"],
Cell[6416825, 113484, 424, 10, 21, "Message"],
Cell[6417252, 113496, 453, 10, 21, "Message"],
Cell[6417708, 113508, 453, 10, 21, "Message"],
Cell[6418164, 113520, 375, 10, 21, "Message"],
Cell[6418542, 113532, 375, 10, 21, "Message"],
Cell[6418920, 113544, 426, 10, 21, "Message"],
Cell[6419349, 113556, 424, 10, 21, "Message"],
Cell[6419776, 113568, 376, 10, 21, "Message"],
Cell[6420155, 113580, 374, 10, 21, "Message"],
Cell[CellGroupData[{
Cell[6420554, 113594, 218, 6, 23, "Print"],
Cell[6420775, 113602, 220, 6, 23, "Print"]
}, Open  ]],
Cell[6421010, 113611, 406, 10, 21, "Message"],
Cell[6421419, 113623, 406, 10, 21, "Message"],
Cell[6421828, 113635, 405, 10, 21, "Message"],
Cell[6422236, 113647, 389, 10, 21, "Message"],
Cell[6422628, 113659, 453, 10, 21, "Message"],
Cell[6423084, 113671, 420, 10, 21, "Message"],
Cell[6423507, 113683, 453, 10, 21, "Message"],
Cell[6423963, 113695, 218, 6, 23, "Print"],
Cell[6424184, 113703, 423, 10, 21, "Message"],
Cell[6424610, 113715, 220, 6, 23, "Print"],
Cell[6424833, 113723, 451, 10, 21, "Message"],
Cell[6425287, 113735, 377, 10, 21, "Message"],
Cell[6425667, 113747, 424, 10, 21, "Message"],
Cell[6426094, 113759, 406, 10, 21, "Message"],
Cell[6426503, 113771, 374, 10, 21, "Message"],
Cell[6426880, 113783, 406, 10, 21, "Message"],
Cell[6427289, 113795, 406, 10, 21, "Message"],
Cell[6427698, 113807, 391, 10, 21, "Message"],
Cell[6428092, 113819, 451, 10, 21, "Message"],
Cell[6428546, 113831, 425, 10, 21, "Message"],
Cell[6428974, 113843, 453, 10, 21, "Message"],
Cell[6429430, 113855, 424, 10, 21, "Message"],
Cell[6429857, 113867, 453, 10, 21, "Message"],
Cell[6430313, 113879, 377, 10, 21, "Message"],
Cell[6430693, 113891, 423, 10, 21, "Message"],
Cell[6431119, 113903, 376, 10, 21, "Message"],
Cell[CellGroupData[{
Cell[6431520, 113917, 220, 6, 23, "Print"],
Cell[6431743, 113925, 218, 6, 23, "Print"],
Cell[6431964, 113933, 217, 6, 23, "Print"],
Cell[6432184, 113941, 219, 6, 23, "Print"],
Cell[6432406, 113949, 217, 6, 23, "Print"],
Cell[6432626, 113957, 219, 6, 23, "Print"]
}, Open  ]],
Cell[6432860, 113966, 11985, 247, 281, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[6444894, 114219, 127, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[6445046, 114224, 5400, 128, 372, "Input"],
Cell[CellGroupData[{
Cell[6450471, 114356, 602, 10, 23, "Print"],
Cell[6451076, 114368, 660, 10, 23, "Print"]
}, Open  ]],
Cell[6451751, 114381, 778, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6452566, 114398, 469, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[6453060, 114412, 311, 6, 23, "Print"],
Cell[6453374, 114420, 369, 6, 23, "Print"]
}, Open  ]],
Cell[6453758, 114429, 326467, 5661, 509, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[6780274, 120096, 118, 1, 28, "Subsubsection"],
Cell[6780395, 120099, 6849, 160, 512, "Input"],
Cell[CellGroupData[{
Cell[6787269, 120263, 1671, 40, 72, "Input"],
Cell[6788943, 120305, 458, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6789438, 120318, 1383, 33, 72, "Input"],
Cell[6790824, 120353, 759, 13, 31, "Output"]
}, Open  ]],
Cell[6791598, 120369, 1151, 29, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6792786, 120403, 122, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[6792933, 120408, 1456, 36, 72, "Input"],
Cell[6794392, 120446, 564, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6794993, 120460, 1456, 35, 112, "Input"],
Cell[6796452, 120497, 436, 8, 31, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6796949, 120512, 128, 1, 79, "Title"],
Cell[6797080, 120515, 217, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[6797322, 120523, 180, 6, 35, "Subsubsection"],
Cell[6797505, 120531, 1327, 31, 112, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6798869, 120567, 113, 1, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[6799007, 120572, 50, 0, 31, "Input"],
Cell[6799060, 120574, 724, 12, 52, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
